Class LithicOkHttpClient.Builder
-
- All Implemented Interfaces:
public final class LithicOkHttpClient.BuilderA builder for LithicOkHttpClient.
-
-
Method Summary
Modifier and Type Method Description final LithicOkHttpClient.BuilderdispatcherExecutorService(ExecutorService dispatcherExecutorService)The executor service to use for running HTTP requests. final LithicOkHttpClient.BuilderdispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)Alias for calling Builder.dispatcherExecutorService with dispatcherExecutorService.orElse(null).final LithicOkHttpClient.Builderproxy(Proxy proxy)final LithicOkHttpClient.Builderproxy(Optional<Proxy> proxy)Alias for calling Builder.proxy with proxy.orElse(null).final LithicOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)The maximum number of idle connections kept by the underlying OkHttp connection pool. final LithicOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)Alias for Builder.maxIdleConnections. final LithicOkHttpClient.BuildermaxIdleConnections(Optional<Integer> maxIdleConnections)Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).final LithicOkHttpClient.BuilderkeepAliveDuration(Duration keepAliveDuration)The keep-alive duration for idle connections in the underlying OkHttp connection pool. final LithicOkHttpClient.BuilderkeepAliveDuration(Optional<Duration> keepAliveDuration)Alias for calling Builder.keepAliveDuration with keepAliveDuration.orElse(null).final LithicOkHttpClient.BuildersslSocketFactory(SSLSocketFactory sslSocketFactory)The socket factory used to secure HTTPS connections. final LithicOkHttpClient.BuildersslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)Alias for calling Builder.sslSocketFactory with sslSocketFactory.orElse(null).final LithicOkHttpClient.BuildertrustManager(X509TrustManager trustManager)The trust manager used to secure HTTPS connections. final LithicOkHttpClient.BuildertrustManager(Optional<X509TrustManager> trustManager)Alias for calling Builder.trustManager with trustManager.orElse(null).final LithicOkHttpClient.BuilderhostnameVerifier(HostnameVerifier hostnameVerifier)The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections. final LithicOkHttpClient.BuilderhostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)Alias for calling Builder.hostnameVerifier with hostnameVerifier.orElse(null).final LithicOkHttpClient.BuildercheckJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4). final LithicOkHttpClient.BuilderjsonMapper(JsonMapper jsonMapper)The Jackson JSON mapper to use for serializing and deserializing JSON. final LithicOkHttpClient.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)The executor to use for running AsyncStreamResponse.Handler callbacks. final LithicOkHttpClient.Buildersleeper(Sleeper sleeper)The interface to use for delaying execution, like during retries. final LithicOkHttpClient.Builderclock(Clock clock)The clock to use for operations that require timing, like retries. final LithicOkHttpClient.BuilderbaseUrl(String baseUrl)The base URL to use for every request. final LithicOkHttpClient.BuilderbaseUrl(Optional<String> baseUrl)Alias for calling Builder.baseUrl with baseUrl.orElse(null).final LithicOkHttpClient.Buildersandbox()Sets baseUrl to https://sandbox.lithic.com.final LithicOkHttpClient.BuilderresponseValidation(Boolean responseValidation)Whether to call validateon every response before returning it.final LithicOkHttpClient.Buildertimeout(Timeout timeout)Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries. final LithicOkHttpClient.Buildertimeout(Duration timeout)Sets the maximum time allowed for a complete HTTP call, not including retries. final LithicOkHttpClient.BuildermaxRetries(Integer maxRetries)The maximum number of times to retry failed requests, with a short exponential backoff between requests. final LithicOkHttpClient.BuilderapiKey(String apiKey)final LithicOkHttpClient.BuilderwebhookSecret(String webhookSecret)final LithicOkHttpClient.BuilderwebhookSecret(Optional<String> webhookSecret)Alias for calling Builder.webhookSecret with webhookSecret.orElse(null).final LithicOkHttpClient.Builderheaders(Headers headers)final LithicOkHttpClient.Builderheaders(Map<String, Iterable<String>> headers)final LithicOkHttpClient.BuilderputHeader(String name, String value)final LithicOkHttpClient.BuilderputHeaders(String name, Iterable<String> values)final LithicOkHttpClient.BuilderputAllHeaders(Headers headers)final LithicOkHttpClient.BuilderputAllHeaders(Map<String, Iterable<String>> headers)final LithicOkHttpClient.BuilderreplaceHeaders(String name, String value)final LithicOkHttpClient.BuilderreplaceHeaders(String name, Iterable<String> values)final LithicOkHttpClient.BuilderreplaceAllHeaders(Headers headers)final LithicOkHttpClient.BuilderreplaceAllHeaders(Map<String, Iterable<String>> headers)final LithicOkHttpClient.BuilderremoveHeaders(String name)final LithicOkHttpClient.BuilderremoveAllHeaders(Set<String> names)final LithicOkHttpClient.BuilderqueryParams(QueryParams queryParams)final LithicOkHttpClient.BuilderqueryParams(Map<String, Iterable<String>> queryParams)final LithicOkHttpClient.BuilderputQueryParam(String key, String value)final LithicOkHttpClient.BuilderputQueryParams(String key, Iterable<String> values)final LithicOkHttpClient.BuilderputAllQueryParams(QueryParams queryParams)final LithicOkHttpClient.BuilderputAllQueryParams(Map<String, Iterable<String>> queryParams)final LithicOkHttpClient.BuilderreplaceQueryParams(String key, String value)final LithicOkHttpClient.BuilderreplaceQueryParams(String key, Iterable<String> values)final LithicOkHttpClient.BuilderreplaceAllQueryParams(QueryParams queryParams)final LithicOkHttpClient.BuilderreplaceAllQueryParams(Map<String, Iterable<String>> queryParams)final LithicOkHttpClient.BuilderremoveQueryParams(String key)final LithicOkHttpClient.BuilderremoveAllQueryParams(Set<String> keys)final LithicOkHttpClient.BuilderfromEnv()Updates configuration using system properties and environment variables. final LithicClientbuild()Returns an immutable instance of LithicClient. -
-
Method Detail
-
dispatcherExecutorService
final LithicOkHttpClient.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final LithicOkHttpClient.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final LithicOkHttpClient.Builder proxy(Proxy proxy)
-
proxy
final LithicOkHttpClient.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
maxIdleConnections
final LithicOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final LithicOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final LithicOkHttpClient.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final LithicOkHttpClient.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final LithicOkHttpClient.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final LithicOkHttpClient.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final LithicOkHttpClient.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final LithicOkHttpClient.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final LithicOkHttpClient.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final LithicOkHttpClient.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final LithicOkHttpClient.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final LithicOkHttpClient.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final LithicOkHttpClient.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to com.lithic.api.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
streamHandlerExecutor
final LithicOkHttpClient.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
The executor to use for running AsyncStreamResponse.Handler callbacks.
Defaults to a dedicated cached thread pool.
This class takes ownership of the executor and shuts it down, if possible, when closed.
-
sleeper
final LithicOkHttpClient.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final LithicOkHttpClient.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final LithicOkHttpClient.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.lithic.com.The following other environments, with dedicated builder methods, are available:
sandbox:
https://sandbox.lithic.com
-
baseUrl
final LithicOkHttpClient.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
sandbox
final LithicOkHttpClient.Builder sandbox()
Sets baseUrl to
https://sandbox.lithic.com.
-
responseValidation
final LithicOkHttpClient.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final LithicOkHttpClient.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final LithicOkHttpClient.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final LithicOkHttpClient.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
apiKey
final LithicOkHttpClient.Builder apiKey(String apiKey)
-
webhookSecret
final LithicOkHttpClient.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final LithicOkHttpClient.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final LithicOkHttpClient.Builder headers(Headers headers)
-
putHeader
final LithicOkHttpClient.Builder putHeader(String name, String value)
-
putHeaders
final LithicOkHttpClient.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final LithicOkHttpClient.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final LithicOkHttpClient.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final LithicOkHttpClient.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final LithicOkHttpClient.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final LithicOkHttpClient.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final LithicOkHttpClient.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final LithicOkHttpClient.Builder removeHeaders(String name)
-
removeAllHeaders
final LithicOkHttpClient.Builder removeAllHeaders(Set<String> names)
-
queryParams
final LithicOkHttpClient.Builder queryParams(QueryParams queryParams)
-
queryParams
final LithicOkHttpClient.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final LithicOkHttpClient.Builder putQueryParam(String key, String value)
-
putQueryParams
final LithicOkHttpClient.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final LithicOkHttpClient.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final LithicOkHttpClient.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final LithicOkHttpClient.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final LithicOkHttpClient.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final LithicOkHttpClient.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final LithicOkHttpClient.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final LithicOkHttpClient.Builder removeQueryParams(String key)
-
removeAllQueryParams
final LithicOkHttpClient.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final LithicOkHttpClient.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final LithicClient build()
Returns an immutable instance of LithicClient.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-