Class Account.AccountHolder
-
- All Implemented Interfaces:
public final class Account.AccountHolder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.AccountHolder.BuilderA builder for AccountHolder.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the account holder. final StringbusinessAccountToken()Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. final Stringemail()Email address. final StringphoneNumber()Phone number of the individual. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final Account.AccountHolder.BuildertoBuilder()final Account.AccountHoldervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.AccountHolder.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolder. -
-
Method Detail
-
businessAccountToken
final String businessAccountToken()
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Account_token of the enrolled business associated with an enrolled AUTHORIZED_USER individual.
-
phoneNumber
final String phoneNumber()
Phone number of the individual.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.AccountHolder.Builder toBuilder()
-
validate
final Account.AccountHolder validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Account.AccountHolder.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolder.
The following fields are required:
.token() .businessAccountToken() .email() .phoneNumber()
-
-
-
-