Class AccountActivityListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class AccountActivityListPageAsync implements PageAsync<AccountActivityListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountActivityListPageAsync.BuilderA builder for AccountActivityListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<AccountActivityListResponse>data()Delegates to AccountActivityListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AccountActivityListPageResponse, but gracefully handles missing data. List<AccountActivityListResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AccountActivityListParamsnextPageParams()CompletableFuture<AccountActivityListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<AccountActivityListResponse>autoPager()final AccountActivityListParamsparams()The parameters that were used to request this page. final AccountActivityListPageResponseresponse()The response that this page was parsed from. final AccountActivityListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountActivityListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountActivityListPageAsync. -
-
Method Detail
-
data
final List<AccountActivityListResponse> data()
Delegates to AccountActivityListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AccountActivityListPageResponse, but gracefully handles missing data.
-
items
List<AccountActivityListResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AccountActivityListParams nextPageParams()
-
nextPage
CompletableFuture<AccountActivityListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<AccountActivityListResponse> autoPager()
-
params
final AccountActivityListParams params()
The parameters that were used to request this page.
-
response
final AccountActivityListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountActivityListPageAsync.Builder toBuilder()
-
builder
final static AccountActivityListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountActivityListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-