Package com.lithic.api.models
Class AccountActivityListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AccountActivityListPageAsync.BuilderA builder for AccountActivityListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AccountActivityListPageAsync.Builderservice(AccountActivityServiceAsync service)final AccountActivityListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AccountActivityListPageAsync.Builderparams(AccountActivityListParams params)The parameters that were used to request this page. final AccountActivityListPageAsync.Builderresponse(AccountActivityListPageResponse response)The response that this page was parsed from. final AccountActivityListPageAsyncbuild()Returns an immutable instance of AccountActivityListPageAsync. -
-
Method Detail
-
service
final AccountActivityListPageAsync.Builder service(AccountActivityServiceAsync service)
-
streamHandlerExecutor
final AccountActivityListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AccountActivityListPageAsync.Builder params(AccountActivityListParams params)
The parameters that were used to request this page.
-
response
final AccountActivityListPageAsync.Builder response(AccountActivityListPageResponse response)
The response that this page was parsed from.
-
build
final AccountActivityListPageAsync build()
Returns an immutable instance of AccountActivityListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-