Class AccountActivityListPageResponse.Builder
-
- All Implemented Interfaces:
public final class AccountActivityListPageResponse.BuilderA builder for AccountActivityListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final AccountActivityListPageResponse.Builder data(List<AccountActivityListResponse> data)
-
data
final AccountActivityListPageResponse.Builder data(JsonField<List<AccountActivityListResponse>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<AccountActivityListResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final AccountActivityListPageResponse.Builder addData(AccountActivityListResponse data)
Adds a single AccountActivityListResponse to Builder.data.
-
addData
final AccountActivityListPageResponse.Builder addData(AccountActivityListResponse.FinancialTransaction internal_)
Alias for calling addData with
AccountActivityListResponse.ofInternal(internal_).
-
addData
final AccountActivityListPageResponse.Builder addData(BookTransferResponse transfer)
Alias for calling addData with
AccountActivityListResponse.ofTransfer(transfer).
-
addData
final AccountActivityListPageResponse.Builder addData(AccountActivityListResponse.CardTransaction card)
Alias for calling addData with
AccountActivityListResponse.ofCard(card).
-
addData
final AccountActivityListPageResponse.Builder addData(Payment payment)
Alias for calling addData with
AccountActivityListResponse.ofPayment(payment).
-
addData
final AccountActivityListPageResponse.Builder addData(ExternalPayment externalPayment)
Alias for calling addData with
AccountActivityListResponse.ofExternalPayment(externalPayment).
-
addData
final AccountActivityListPageResponse.Builder addData(ManagementOperationTransaction managementOperation)
Alias for calling addData with
AccountActivityListResponse.ofManagementOperation(managementOperation).
-
addData
final AccountActivityListPageResponse.Builder addData(Hold hold)
Alias for calling addData with
AccountActivityListResponse.ofHold(hold).
-
hasMore
final AccountActivityListPageResponse.Builder hasMore(Boolean hasMore)
Indicates if there are more transactions available for pagination
-
hasMore
final AccountActivityListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountActivityListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountActivityListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountActivityListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountActivityListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountActivityListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountActivityListPageResponse build()
Returns an immutable instance of AccountActivityListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-