Class AccountActivityListResponse
-
- All Implemented Interfaces:
public final class AccountActivityListResponseResponse containing multiple transaction types. The
familyfield determines which transaction type is returned: INTERNAL returns FinancialTransaction, TRANSFER returns BookTransferTransaction, CARD returns CardTransaction, PAYMENT returns PaymentTransaction, EXTERNAL_PAYMENT returns ExternalPaymentResponse, MANAGEMENT_OPERATION returns ManagementOperationTransaction, and HOLD returns HoldTransaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountActivityListResponse.VisitorAn interface that defines how to map each variant of AccountActivityListResponse to a value of type T.
public final classAccountActivityListResponse.FinancialTransactionFinancial transaction with inheritance from unified base transaction
public final classAccountActivityListResponse.CardTransactionCard transaction with ledger base properties
-
Method Summary
Modifier and Type Method Description final Optional<AccountActivityListResponse.FinancialTransaction>internal_()Financial transaction with inheritance from unified base transaction final Optional<BookTransferResponse>transfer()Book transfer transaction final Optional<AccountActivityListResponse.CardTransaction>card()Card transaction with ledger base properties final Optional<Payment>payment()Payment transaction final Optional<ExternalPayment>externalPayment()final Optional<ManagementOperationTransaction>managementOperation()final Optional<Hold>hold()A hold transaction representing reserved funds on a financial account. final BooleanisInternal()final BooleanisTransfer()final BooleanisCard()final BooleanisPayment()final BooleanisExternalPayment()final BooleanisManagementOperation()final BooleanisHold()final AccountActivityListResponse.FinancialTransactionasInternal()Financial transaction with inheritance from unified base transaction final BookTransferResponseasTransfer()Book transfer transaction final AccountActivityListResponse.CardTransactionasCard()Card transaction with ledger base properties final PaymentasPayment()Payment transaction final ExternalPaymentasExternalPayment()final ManagementOperationTransactionasManagementOperation()final HoldasHold()A hold transaction representing reserved funds on a financial account. final Optional<JsonValue>_json()final <T extends Any> Taccept(AccountActivityListResponse.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final AccountActivityListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountActivityListResponseofInternal(AccountActivityListResponse.FinancialTransaction internal_)Financial transaction with inheritance from unified base transaction final static AccountActivityListResponseofTransfer(BookTransferResponse transfer)Book transfer transaction final static AccountActivityListResponseofCard(AccountActivityListResponse.CardTransaction card)Card transaction with ledger base properties final static AccountActivityListResponseofPayment(Payment payment)Payment transaction final static AccountActivityListResponseofExternalPayment(ExternalPayment externalPayment)final static AccountActivityListResponseofManagementOperation(ManagementOperationTransaction managementOperation)final static AccountActivityListResponseofHold(Hold hold)A hold transaction representing reserved funds on a financial account. -
-
Method Detail
-
internal_
final Optional<AccountActivityListResponse.FinancialTransaction> internal_()
Financial transaction with inheritance from unified base transaction
-
transfer
final Optional<BookTransferResponse> transfer()
Book transfer transaction
-
card
final Optional<AccountActivityListResponse.CardTransaction> card()
Card transaction with ledger base properties
-
externalPayment
final Optional<ExternalPayment> externalPayment()
-
managementOperation
final Optional<ManagementOperationTransaction> managementOperation()
-
hold
final Optional<Hold> hold()
A hold transaction representing reserved funds on a financial account. Holds move funds from available to pending balance in anticipation of future payments. They can be resolved via settlement (linked to payment), manual release, or expiration.
-
isInternal
final Boolean isInternal()
-
isTransfer
final Boolean isTransfer()
-
isExternalPayment
final Boolean isExternalPayment()
-
isManagementOperation
final Boolean isManagementOperation()
-
asInternal
final AccountActivityListResponse.FinancialTransaction asInternal()
Financial transaction with inheritance from unified base transaction
-
asTransfer
final BookTransferResponse asTransfer()
Book transfer transaction
-
asCard
final AccountActivityListResponse.CardTransaction asCard()
Card transaction with ledger base properties
-
asExternalPayment
final ExternalPayment asExternalPayment()
-
asManagementOperation
final ManagementOperationTransaction asManagementOperation()
-
asHold
final Hold asHold()
A hold transaction representing reserved funds on a financial account. Holds move funds from available to pending balance in anticipation of future payments. They can be resolved via settlement (linked to payment), manual release, or expiration.
-
accept
final <T extends Any> T accept(AccountActivityListResponse.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.lithic.api.core.JsonValue; import java.util.Optional; Optional<String> result = accountActivityListResponse.accept(new AccountActivityListResponse.Visitor<Optional<String>>() { @Override public Optional<String> visitInternal(FinancialTransaction internal_) { return Optional.of(internal_.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final AccountActivityListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofInternal
final static AccountActivityListResponse ofInternal(AccountActivityListResponse.FinancialTransaction internal_)
Financial transaction with inheritance from unified base transaction
-
ofTransfer
final static AccountActivityListResponse ofTransfer(BookTransferResponse transfer)
Book transfer transaction
-
ofCard
final static AccountActivityListResponse ofCard(AccountActivityListResponse.CardTransaction card)
Card transaction with ledger base properties
-
ofPayment
final static AccountActivityListResponse ofPayment(Payment payment)
Payment transaction
-
ofExternalPayment
final static AccountActivityListResponse ofExternalPayment(ExternalPayment externalPayment)
-
ofManagementOperation
final static AccountActivityListResponse ofManagementOperation(ManagementOperationTransaction managementOperation)
-
ofHold
final static AccountActivityListResponse ofHold(Hold hold)
A hold transaction representing reserved funds on a financial account. Holds move funds from available to pending balance in anticipation of future payments. They can be resolved via settlement (linked to payment), manual release, or expiration.
-
-
-
-