Class AccountActivityRetrieveTransactionResponse.FinancialTransaction
-
- All Implemented Interfaces:
public final class AccountActivityRetrieveTransactionResponse.FinancialTransactionFinancial transaction with inheritance from unified base transaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountActivityRetrieveTransactionResponse.FinancialTransaction.BuilderA builder for FinancialTransaction.
public final classAccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionCategoryTransaction category
public final classAccountActivityRetrieveTransactionResponse.FinancialTransaction.FamilyINTERNAL - Financial Transaction
public final classAccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionResultTransaction result
public final classAccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionStatusThe status of the transaction
-
Method Summary
-
-
Method Detail
-
category
final AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionCategory category()
Transaction category
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
descriptor
final String descriptor()
Transaction descriptor
-
events
final List<FinancialEvent> events()
List of transaction events
-
family
final AccountActivityRetrieveTransactionResponse.FinancialTransaction.Family family()
INTERNAL - Financial Transaction
-
financialAccountToken
final String financialAccountToken()
Financial account token associated with the transaction
-
pendingAmount
final Long pendingAmount()
Pending amount in cents
-
result
final AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionResult result()
Transaction result
-
settledAmount
final Long settledAmount()
Settled amount in cents
-
status
final AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionStatus status()
The status of the transaction
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<FinancialEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<AccountActivityRetrieveTransactionResponse.FinancialTransaction.Family> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountActivityRetrieveTransactionResponse.FinancialTransaction.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountActivityRetrieveTransactionResponse.FinancialTransaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountActivityRetrieveTransactionResponse.FinancialTransaction.Builder builder()
Returns a mutable builder for constructing an instance of FinancialTransaction.
The following fields are required:
.token() .category() .created() .currency() .descriptor() .events() .family() .financialAccountToken() .pendingAmount() .result() .settledAmount() .status() .updated()
-
-
-
-