Package com.lithic.api.models
Interface AccountActivityRetrieveTransactionResponse.Visitor
-
- All Implemented Interfaces:
public interface AccountActivityRetrieveTransactionResponse.Visitor<T extends Object>An interface that defines how to map each variant of AccountActivityRetrieveTransactionResponse to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitInternal(AccountActivityRetrieveTransactionResponse.FinancialTransaction internal_)Financial transaction with inheritance from unified base transaction abstract TvisitTransfer(BookTransferResponse transfer)Book transfer transaction abstract TvisitCard(AccountActivityRetrieveTransactionResponse.CardTransaction card)Card transaction with ledger base properties abstract TvisitPayment(Payment payment)Payment transaction abstract TvisitExternalPayment(ExternalPayment externalPayment)abstract TvisitManagementOperation(ManagementOperationTransaction managementOperation)Tunknown(JsonValue json)Maps an unknown variant of AccountActivityRetrieveTransactionResponse to a value of type T. -
-
Method Detail
-
visitInternal
abstract T visitInternal(AccountActivityRetrieveTransactionResponse.FinancialTransaction internal_)
Financial transaction with inheritance from unified base transaction
-
visitTransfer
abstract T visitTransfer(BookTransferResponse transfer)
Book transfer transaction
-
visitCard
abstract T visitCard(AccountActivityRetrieveTransactionResponse.CardTransaction card)
Card transaction with ledger base properties
-
visitPayment
abstract T visitPayment(Payment payment)
Payment transaction
-
visitExternalPayment
abstract T visitExternalPayment(ExternalPayment externalPayment)
-
visitManagementOperation
abstract T visitManagementOperation(ManagementOperationTransaction managementOperation)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of AccountActivityRetrieveTransactionResponse to a value of type T.
An instance of AccountActivityRetrieveTransactionResponse can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-