Class AccountHolder.Builder
-
- All Implemented Interfaces:
public final class AccountHolder.BuilderA builder for AccountHolder.
-
-
Method Summary
-
-
Method Detail
-
token
final AccountHolder.Builder token(String token)
Globally unique identifier for the account holder.
-
token
final AccountHolder.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AccountHolder.Builder created(OffsetDateTime created)
Timestamp of when the account holder was created.
-
created
final AccountHolder.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final AccountHolder.Builder accountToken(String accountToken)
Globally unique identifier for the account.
-
accountToken
final AccountHolder.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwnerIndividuals
final AccountHolder.Builder beneficialOwnerIndividuals(List<AccountHolder.AccountHolderIndividualResponse> beneficialOwnerIndividuals)
Only present when user_type == "BUSINESS". You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
beneficialOwnerIndividuals
final AccountHolder.Builder beneficialOwnerIndividuals(JsonField<List<AccountHolder.AccountHolderIndividualResponse>> beneficialOwnerIndividuals)
Sets Builder.beneficialOwnerIndividuals to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerIndividuals with a well-typed
List<AccountHolderIndividualResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwnerIndividual
final AccountHolder.Builder addBeneficialOwnerIndividual(AccountHolder.AccountHolderIndividualResponse beneficialOwnerIndividual)
Adds a single AccountHolderIndividualResponse to beneficialOwnerIndividuals.
-
businessAccountToken
final AccountHolder.Builder businessAccountToken(String businessAccountToken)
Only applicable for customers using the KYC-Exempt workflow to enroll authorized users of businesses. Pass the account_token of the enrolled business associated with the AUTHORIZED_USER in this field.
-
businessAccountToken
final AccountHolder.Builder businessAccountToken(JsonField<String> businessAccountToken)
Sets Builder.businessAccountToken to an arbitrary JSON value.
You should usually call Builder.businessAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
businessEntity
final AccountHolder.Builder businessEntity(AccountHolder.AccountHolderBusinessResponse businessEntity)
Only present when user_type == "BUSINESS". Information about the business for which the account is being opened and KYB is being run.
-
businessEntity
final AccountHolder.Builder businessEntity(JsonField<AccountHolder.AccountHolderBusinessResponse> businessEntity)
Sets Builder.businessEntity to an arbitrary JSON value.
You should usually call Builder.businessEntity with a well-typed AccountHolderBusinessResponse value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
controlPerson
final AccountHolder.Builder controlPerson(AccountHolder.AccountHolderIndividualResponse controlPerson)
Only present when user_type == "BUSINESS". An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above.
-
controlPerson
final AccountHolder.Builder controlPerson(JsonField<AccountHolder.AccountHolderIndividualResponse> controlPerson)
Sets Builder.controlPerson to an arbitrary JSON value.
You should usually call Builder.controlPerson with a well-typed AccountHolderIndividualResponse value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AccountHolder.Builder email(String email)
(Deprecated. Use control_person.email when user_type == "BUSINESS". Use individual.phone_number when user_type == "INDIVIDUAL".) Primary email of Account Holder.
-
email
final AccountHolder.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
exemptionType
final AccountHolder.Builder exemptionType(AccountHolder.ExemptionType exemptionType)
The type of KYC exemption for a KYC-Exempt Account Holder.
-
exemptionType
final AccountHolder.Builder exemptionType(JsonField<AccountHolder.ExemptionType> exemptionType)
Sets Builder.exemptionType to an arbitrary JSON value.
You should usually call Builder.exemptionType with a well-typed ExemptionType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final AccountHolder.Builder externalId(String externalId)
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
-
externalId
final AccountHolder.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individual
final AccountHolder.Builder individual(AccountHolder.AccountHolderIndividualResponse individual)
Only present when user_type == "INDIVIDUAL". Information about the individual for which the account is being opened and KYC is being run.
-
individual
final AccountHolder.Builder individual(JsonField<AccountHolder.AccountHolderIndividualResponse> individual)
Sets Builder.individual to an arbitrary JSON value.
You should usually call Builder.individual with a well-typed AccountHolderIndividualResponse value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naicsCode
final AccountHolder.Builder naicsCode(String naicsCode)
Only present when user_type == "BUSINESS". 6-digit North American Industry Classification System (NAICS) code for the business.
-
naicsCode
final AccountHolder.Builder naicsCode(JsonField<String> naicsCode)
Sets Builder.naicsCode to an arbitrary JSON value.
You should usually call Builder.naicsCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
natureOfBusiness
final AccountHolder.Builder natureOfBusiness(String natureOfBusiness)
Only present when user_type == "BUSINESS". User-submitted description of the business.
-
natureOfBusiness
final AccountHolder.Builder natureOfBusiness(JsonField<String> natureOfBusiness)
Sets Builder.natureOfBusiness to an arbitrary JSON value.
You should usually call Builder.natureOfBusiness with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final AccountHolder.Builder phoneNumber(String phoneNumber)
(Deprecated. Use control_person.phone_number when user_type == "BUSINESS". Use individual.phone_number when user_type == "INDIVIDUAL".) Primary phone of Account Holder, entered in E.164 format.
-
phoneNumber
final AccountHolder.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocuments
final AccountHolder.Builder requiredDocuments(List<RequiredDocument> requiredDocuments)
Only present for "KYB_BASIC" workflow. A list of documents required for the account holder to be approved.
-
requiredDocuments
final AccountHolder.Builder requiredDocuments(JsonField<List<RequiredDocument>> requiredDocuments)
Sets Builder.requiredDocuments to an arbitrary JSON value.
You should usually call Builder.requiredDocuments with a well-typed
List<RequiredDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocument
final AccountHolder.Builder addRequiredDocument(RequiredDocument requiredDocument)
Adds a single RequiredDocument to requiredDocuments.
-
status
final AccountHolder.Builder status(AccountHolder.Status status)
(Deprecated. Use verification_application.status instead)
KYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
-
status
final AccountHolder.Builder status(JsonField<AccountHolder.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReasons
final AccountHolder.Builder statusReasons(List<AccountHolder.StatusReason> statusReasons)
(Deprecated. Use verification_application.status_reasons)
Reason for the evaluation status.
-
statusReasons
final AccountHolder.Builder statusReasons(JsonField<List<AccountHolder.StatusReason>> statusReasons)
Sets Builder.statusReasons to an arbitrary JSON value.
You should usually call Builder.statusReasons with a well-typed
List<StatusReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final AccountHolder.Builder addStatusReason(AccountHolder.StatusReason statusReason)
Adds a single StatusReason to statusReasons.
-
userType
final AccountHolder.Builder userType(AccountHolder.UserType userType)
The type of Account Holder. If the type is "INDIVIDUAL", the "individual" attribute will be present. If the type is "BUSINESS" then the "business_entity", "control_person", "beneficial_owner_individuals", "naics_code", "nature_of_business", and "website_url" attributes will be present.
-
userType
final AccountHolder.Builder userType(JsonField<AccountHolder.UserType> userType)
Sets Builder.userType to an arbitrary JSON value.
You should usually call Builder.userType with a well-typed UserType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationApplication
final AccountHolder.Builder verificationApplication(AccountHolder.AccountHolderVerificationApplication verificationApplication)
Information about the most recent identity verification attempt
-
verificationApplication
final AccountHolder.Builder verificationApplication(JsonField<AccountHolder.AccountHolderVerificationApplication> verificationApplication)
Sets Builder.verificationApplication to an arbitrary JSON value.
You should usually call Builder.verificationApplication with a well-typed AccountHolderVerificationApplication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
websiteUrl
final AccountHolder.Builder websiteUrl(String websiteUrl)
Only present when user_type == "BUSINESS". Business's primary website.
-
websiteUrl
final AccountHolder.Builder websiteUrl(JsonField<String> websiteUrl)
Sets Builder.websiteUrl to an arbitrary JSON value.
You should usually call Builder.websiteUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountHolder.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolder.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolder.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolder.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolder.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolder build()
Returns an immutable instance of AccountHolder.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .created()
-
-
-
-