Package com.lithic.api.models
Interface AccountHolderCreateParams.Body.Visitor
-
- All Implemented Interfaces:
public interface AccountHolderCreateParams.Body.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitKyb(Kyb kyb)abstract TvisitKybDelegated(AccountHolderCreateParams.Body.KybDelegated kybDelegated)abstract TvisitKyc(Kyc kyc)abstract TvisitKycExempt(KycExempt kycExempt)Tunknown(JsonValue json)Maps an unknown variant of Body to a value of type T. -
-
Method Detail
-
visitKybDelegated
abstract T visitKybDelegated(AccountHolderCreateParams.Body.KybDelegated kybDelegated)
-
visitKycExempt
abstract T visitKycExempt(KycExempt kycExempt)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Body to a value of type T.
An instance of Body can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-