Class AccountHolderCreateResponse.Builder
-
- All Implemented Interfaces:
public final class AccountHolderCreateResponse.BuilderA builder for AccountHolderCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final AccountHolderCreateResponse.Builder token(String token)
Globally unique identifier for the account holder.
-
token
final AccountHolderCreateResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final AccountHolderCreateResponse.Builder accountToken(String accountToken)
Globally unique identifier for the account.
-
accountToken
final AccountHolderCreateResponse.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountHolderCreateResponse.Builder status(AccountHolderCreateResponse.Status status)
KYC and KYB evaluation states.
Note:
PENDING_REVIEWis only applicable for theKYB_BASICworkflow.
-
status
final AccountHolderCreateResponse.Builder status(JsonField<AccountHolderCreateResponse.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReasons
final AccountHolderCreateResponse.Builder statusReasons(List<AccountHolderCreateResponse.StatusReasons> statusReasons)
Reason for the evaluation status.
-
statusReasons
final AccountHolderCreateResponse.Builder statusReasons(JsonField<List<AccountHolderCreateResponse.StatusReasons>> statusReasons)
Sets Builder.statusReasons to an arbitrary JSON value.
You should usually call Builder.statusReasons with a well-typed
List<StatusReasons>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final AccountHolderCreateResponse.Builder addStatusReason(AccountHolderCreateResponse.StatusReasons statusReason)
Adds a single StatusReasons to statusReasons.
-
created
final AccountHolderCreateResponse.Builder created(OffsetDateTime created)
Timestamp of when the account holder was created.
-
created
final AccountHolderCreateResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final AccountHolderCreateResponse.Builder externalId(String externalId)
Customer-provided token that indicates a relationship with an object outside of the Lithic ecosystem.
-
externalId
final AccountHolderCreateResponse.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocuments
final AccountHolderCreateResponse.Builder requiredDocuments(List<RequiredDocument> requiredDocuments)
Only present for "KYB_BASIC" workflow. A list of documents required for the account holder to be approved.
-
requiredDocuments
final AccountHolderCreateResponse.Builder requiredDocuments(JsonField<List<RequiredDocument>> requiredDocuments)
Sets Builder.requiredDocuments to an arbitrary JSON value.
You should usually call Builder.requiredDocuments with a well-typed
List<RequiredDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocument
final AccountHolderCreateResponse.Builder addRequiredDocument(RequiredDocument requiredDocument)
Adds a single RequiredDocument to requiredDocuments.
-
additionalProperties
final AccountHolderCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderCreateResponse build()
Returns an immutable instance of AccountHolderCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .status() .statusReasons()
-
-
-
-