Class AccountHolderCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class AccountHolderCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderCreatedWebhookEvent.BuilderA builder for AccountHolderCreatedWebhookEvent.
public final classAccountHolderCreatedWebhookEvent.EventTypeThe type of event that occurred.
public final classAccountHolderCreatedWebhookEvent.StatusThe status of the account_holder that was created.
-
Method Summary
Modifier and Type Method Description final AccountHolderCreatedWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<String>token()The token of the account_holder that was created. final Optional<String>accountToken()The token of the account that was created. final Optional<OffsetDateTime>created()When the account_holder was created final Optional<List<RequiredDocument>>requiredDocuments()final Optional<AccountHolderCreatedWebhookEvent.Status>status()The status of the account_holder that was created. final Optional<List<String>>statusReason()final JsonField<AccountHolderCreatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<List<RequiredDocument>>_requiredDocuments()Returns the raw JSON value of requiredDocuments. final JsonField<AccountHolderCreatedWebhookEvent.Status>_status()Returns the raw JSON value of status. final JsonField<List<String>>_statusReason()Returns the raw JSON value of statusReason. final Map<String, JsonValue>_additionalProperties()final AccountHolderCreatedWebhookEvent.BuildertoBuilder()final AccountHolderCreatedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderCreatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderCreatedWebhookEvent. -
-
Method Detail
-
eventType
final AccountHolderCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
accountToken
final Optional<String> accountToken()
The token of the account that was created.
-
created
final Optional<OffsetDateTime> created()
When the account_holder was created
-
requiredDocuments
final Optional<List<RequiredDocument>> requiredDocuments()
-
status
final Optional<AccountHolderCreatedWebhookEvent.Status> status()
The status of the account_holder that was created.
-
statusReason
final Optional<List<String>> statusReason()
-
_eventType
final JsonField<AccountHolderCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_requiredDocuments
final JsonField<List<RequiredDocument>> _requiredDocuments()
Returns the raw JSON value of requiredDocuments.
Unlike requiredDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderCreatedWebhookEvent.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReason
final JsonField<List<String>> _statusReason()
Returns the raw JSON value of statusReason.
Unlike statusReason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderCreatedWebhookEvent.Builder toBuilder()
-
validate
final AccountHolderCreatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderCreatedWebhookEvent.
The following fields are required:
.eventType()
-
-
-
-