Class AccountHolderCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class AccountHolderCreatedWebhookEvent.BuilderA builder for AccountHolderCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
eventType
final AccountHolderCreatedWebhookEvent.Builder eventType(AccountHolderCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final AccountHolderCreatedWebhookEvent.Builder eventType(JsonField<AccountHolderCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
token
final AccountHolderCreatedWebhookEvent.Builder token(String token)
The token of the account_holder that was created.
-
token
final AccountHolderCreatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final AccountHolderCreatedWebhookEvent.Builder accountToken(String accountToken)
The token of the account that was created.
-
accountToken
final AccountHolderCreatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AccountHolderCreatedWebhookEvent.Builder created(OffsetDateTime created)
When the account_holder was created
-
created
final AccountHolderCreatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocuments
final AccountHolderCreatedWebhookEvent.Builder requiredDocuments(List<RequiredDocument> requiredDocuments)
-
requiredDocuments
final AccountHolderCreatedWebhookEvent.Builder requiredDocuments(JsonField<List<RequiredDocument>> requiredDocuments)
Sets Builder.requiredDocuments to an arbitrary JSON value.
You should usually call Builder.requiredDocuments with a well-typed
List<RequiredDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocument
final AccountHolderCreatedWebhookEvent.Builder addRequiredDocument(RequiredDocument requiredDocument)
Adds a single RequiredDocument to requiredDocuments.
-
status
final AccountHolderCreatedWebhookEvent.Builder status(AccountHolderCreatedWebhookEvent.Status status)
The status of the account_holder that was created.
-
status
final AccountHolderCreatedWebhookEvent.Builder status(JsonField<AccountHolderCreatedWebhookEvent.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReason
final AccountHolderCreatedWebhookEvent.Builder statusReason(List<String> statusReason)
-
statusReason
final AccountHolderCreatedWebhookEvent.Builder statusReason(JsonField<List<String>> statusReason)
Sets Builder.statusReason to an arbitrary JSON value.
You should usually call Builder.statusReason with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final AccountHolderCreatedWebhookEvent.Builder addStatusReason(String statusReason)
Adds a single String to Builder.statusReason.
-
additionalProperties
final AccountHolderCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderCreatedWebhookEvent build()
Returns an immutable instance of AccountHolderCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventType()
-
-
-
-