Class AccountHolderDocumentUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class AccountHolderDocumentUpdatedWebhookEvent.BuilderA builder for AccountHolderDocumentUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
eventType
final AccountHolderDocumentUpdatedWebhookEvent.Builder eventType(AccountHolderDocumentUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final AccountHolderDocumentUpdatedWebhookEvent.Builder eventType(JsonField<AccountHolderDocumentUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
token
final AccountHolderDocumentUpdatedWebhookEvent.Builder token(String token)
The token of the account holder document
-
token
final AccountHolderDocumentUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final AccountHolderDocumentUpdatedWebhookEvent.Builder accountHolderToken(String accountHolderToken)
The token of the account_holder that the document belongs to
-
accountHolderToken
final AccountHolderDocumentUpdatedWebhookEvent.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AccountHolderDocumentUpdatedWebhookEvent.Builder created(OffsetDateTime created)
When the account_holder was created
-
created
final AccountHolderDocumentUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentType
final AccountHolderDocumentUpdatedWebhookEvent.Builder documentType(AccountHolderDocumentUpdatedWebhookEvent.DocumentType documentType)
Type of documentation to be submitted for verification of an account holder
-
documentType
final AccountHolderDocumentUpdatedWebhookEvent.Builder documentType(JsonField<AccountHolderDocumentUpdatedWebhookEvent.DocumentType> documentType)
Sets Builder.documentType to an arbitrary JSON value.
You should usually call Builder.documentType with a well-typed DocumentType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityToken
final AccountHolderDocumentUpdatedWebhookEvent.Builder entityToken(String entityToken)
The token of the entity that the document belongs to
-
entityToken
final AccountHolderDocumentUpdatedWebhookEvent.Builder entityToken(JsonField<String> entityToken)
Sets Builder.entityToken to an arbitrary JSON value.
You should usually call Builder.entityToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocumentUploads
final AccountHolderDocumentUpdatedWebhookEvent.Builder requiredDocumentUploads(List<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload> requiredDocumentUploads)
-
requiredDocumentUploads
final AccountHolderDocumentUpdatedWebhookEvent.Builder requiredDocumentUploads(JsonField<List<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload>> requiredDocumentUploads)
Sets Builder.requiredDocumentUploads to an arbitrary JSON value.
You should usually call Builder.requiredDocumentUploads with a well-typed
List<RequiredDocumentUpload>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocumentUpload
final AccountHolderDocumentUpdatedWebhookEvent.Builder addRequiredDocumentUpload(AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload requiredDocumentUpload)
Adds a single RequiredDocumentUpload to requiredDocumentUploads.
-
additionalProperties
final AccountHolderDocumentUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderDocumentUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderDocumentUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderDocumentUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderDocumentUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderDocumentUpdatedWebhookEvent build()
Returns an immutable instance of AccountHolderDocumentUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventType()
-
-
-
-