Class AccountHolderEntity.Builder
-
- All Implemented Interfaces:
public final class AccountHolderEntity.BuilderA builder for AccountHolderEntity.
-
-
Method Summary
-
-
Method Detail
-
token
final AccountHolderEntity.Builder token(String token)
Globally unique identifier for the entity
-
token
final AccountHolderEntity.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final AccountHolderEntity.Builder accountHolderToken(String accountHolderToken)
Globally unique identifier for the account holder
-
accountHolderToken
final AccountHolderEntity.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address
final AccountHolderEntity.Builder address(AccountHolderEntity.Address address)
Individual's current address
-
address
final AccountHolderEntity.Builder address(JsonField<AccountHolderEntity.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final AccountHolderEntity.Builder dob(String dob)
Individual's date of birth, as an RFC 3339 date
-
dob
final AccountHolderEntity.Builder dob(Optional<String> dob)
Alias for calling Builder.dob with
dob.orElse(null).
-
dob
final AccountHolderEntity.Builder dob(JsonField<String> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AccountHolderEntity.Builder email(String email)
Individual's email address
-
email
final AccountHolderEntity.Builder email(Optional<String> email)
Alias for calling Builder.email with
email.orElse(null).
-
email
final AccountHolderEntity.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountHolderEntity.Builder firstName(String firstName)
Individual's first name, as it appears on government-issued identity documents
-
firstName
final AccountHolderEntity.Builder firstName(Optional<String> firstName)
Alias for calling Builder.firstName with
firstName.orElse(null).
-
firstName
final AccountHolderEntity.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountHolderEntity.Builder lastName(String lastName)
Individual's last name, as it appears on government-issued identity documents
-
lastName
final AccountHolderEntity.Builder lastName(Optional<String> lastName)
Alias for calling Builder.lastName with
lastName.orElse(null).
-
lastName
final AccountHolderEntity.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final AccountHolderEntity.Builder phoneNumber(String phoneNumber)
Individual's phone number, entered in E.164 format
-
phoneNumber
final AccountHolderEntity.Builder phoneNumber(Optional<String> phoneNumber)
Alias for calling Builder.phoneNumber with
phoneNumber.orElse(null).
-
phoneNumber
final AccountHolderEntity.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountHolderEntity.Builder status(AccountHolderEntity.EntityStatus status)
The status of the entity
-
status
final AccountHolderEntity.Builder status(JsonField<AccountHolderEntity.EntityStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed EntityStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountHolderEntity.Builder type(EntityType type)
The type of entity
-
type
final AccountHolderEntity.Builder type(JsonField<EntityType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed EntityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountHolderEntity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderEntity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderEntity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderEntity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderEntity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderEntity build()
Returns an immutable instance of AccountHolderEntity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountHolderToken() .address() .dob() .email() .firstName() .lastName() .phoneNumber() .status() .type()
-
-
-
-