Class AccountHolderEntityCreateParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class AccountHolderEntityCreateParams
     implements Params
                        

    Create a new beneficial owner individual or replace the control person entity on an existing KYB account holder. This endpoint is only applicable for account holders enrolled through a KYB workflow with the Persona KYB provider. A new control person can only replace the existing one. A maximum of 4 beneficial owners can be associated with an account holder.