Class AccountHolderEntityCreateParams.CreateEntityRequest.Builder
-
- All Implemented Interfaces:
public final class AccountHolderEntityCreateParams.CreateEntityRequest.BuilderA builder for CreateEntityRequest.
-
-
Method Summary
-
-
Method Detail
-
address
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder address(AccountHolderEntityCreateParams.Address address)
Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
address
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder address(JsonField<AccountHolderEntityCreateParams.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder dob(String dob)
Individual's date of birth, as an RFC 3339 date.
-
dob
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder dob(JsonField<String> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder email(String email)
Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
-
email
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder firstName(String firstName)
Individual's first name, as it appears on government-issued identity documents.
-
firstName
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentId
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder governmentId(String governmentId)
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
-
governmentId
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder governmentId(JsonField<String> governmentId)
Sets Builder.governmentId to an arbitrary JSON value.
You should usually call Builder.governmentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder lastName(String lastName)
Individual's last name, as it appears on government-issued identity documents.
-
lastName
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder phoneNumber(String phoneNumber)
Individual's phone number, entered in E.164 format.
-
phoneNumber
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder type(AccountHolderEntityCreateParams.EntityType type)
The type of entity to create on the account holder
-
type
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder type(JsonField<AccountHolderEntityCreateParams.EntityType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed EntityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderEntityCreateParams.CreateEntityRequest build()
Returns an immutable instance of CreateEntityRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .dob() .email() .firstName() .governmentId() .lastName() .phoneNumber() .type()
-
-
-
-