Class AccountHolderListDocumentsParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountHolderListDocumentsParams implements Params
Retrieve the status of account holder document uploads, or retrieve the upload URLs to process your image uploads.
Note that this is not equivalent to checking the status of the KYC evaluation overall (a document may be successfully uploaded but not be sufficient for KYC to pass).
In the event your upload URLs have expired, calling this endpoint will refresh them. Similarly, in the event a previous account holder document upload has failed, you can use this endpoint to get a new upload URL for the failed image upload.
When a new document upload is generated for a failed attempt, the response will show an additional entry in the
required_document_uploadslist in aPENDINGstate for the correspondingimage_type.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderListDocumentsParams.BuilderA builder for AccountHolderListDocumentsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountHolderToken()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountHolderListDocumentsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderListDocumentsParamsnone()final static AccountHolderListDocumentsParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderListDocumentsParams. -
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountHolderListDocumentsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountHolderListDocumentsParams none()
-
builder
final static AccountHolderListDocumentsParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderListDocumentsParams.
-
-
-
-