Package com.lithic.api.models
Class AccountHolderListDocumentsResponse
-
- All Implemented Interfaces:
public final class AccountHolderListDocumentsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderListDocumentsResponse.BuilderA builder for AccountHolderListDocumentsResponse.
-
Method Summary
Modifier and Type Method Description final Optional<List<Document>>data()final JsonField<List<Document>>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final AccountHolderListDocumentsResponse.BuildertoBuilder()final AccountHolderListDocumentsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderListDocumentsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderListDocumentsResponse. -
-
Method Detail
-
_data
final JsonField<List<Document>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderListDocumentsResponse.Builder toBuilder()
-
validate
final AccountHolderListDocumentsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderListDocumentsResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderListDocumentsResponse.
-
-
-
-