Package com.lithic.api.models
Class AccountHolderListPageResponse
-
- All Implemented Interfaces:
public final class AccountHolderListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderListPageResponse.BuilderA builder for AccountHolderListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<AccountHolder>data()final BooleanhasMore()Whether there are more accounts to be retrieved. final JsonField<List<AccountHolder>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final AccountHolderListPageResponse.BuildertoBuilder()final AccountHolderListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderListPageResponse. -
-
Method Detail
-
data
final List<AccountHolder> data()
-
_data
final JsonField<List<AccountHolder>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderListPageResponse.Builder toBuilder()
-
validate
final AccountHolderListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-