Class AccountHolderSimulateEnrollmentReviewParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountHolderSimulateEnrollmentReviewParams implements Params
Simulates an enrollment review for an account holder. This endpoint is only applicable for workflows that may required intervention such as
KYB_BASIC.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderSimulateEnrollmentReviewParams.BuilderA builder for AccountHolderSimulateEnrollmentReviewParams.
public final classAccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequestpublic final classAccountHolderSimulateEnrollmentReviewParams.StatusAn account holder's status for use within the simulation.
public final classAccountHolderSimulateEnrollmentReviewParams.StatusReason
-
Method Summary
-
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
The account holder which to perform the simulation upon.
-
status
final Optional<AccountHolderSimulateEnrollmentReviewParams.Status> status()
An account holder's status for use within the simulation.
-
statusReasons
final Optional<List<AccountHolderSimulateEnrollmentReviewParams.StatusReason>> statusReasons()
Status reason that will be associated with the simulated account holder status. Only required for a
REJECTEDstatus.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderSimulateEnrollmentReviewParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<AccountHolderSimulateEnrollmentReviewParams.StatusReason>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountHolderSimulateEnrollmentReviewParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountHolderSimulateEnrollmentReviewParams none()
-
builder
final static AccountHolderSimulateEnrollmentReviewParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderSimulateEnrollmentReviewParams.
-
-
-
-