Class AccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest
-
- All Implemented Interfaces:
public final class AccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest.BuilderA builder for SimulateEnrollmentReviewRequest.
-
Method Summary
-
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
The account holder which to perform the simulation upon.
-
status
final Optional<AccountHolderSimulateEnrollmentReviewParams.Status> status()
An account holder's status for use within the simulation.
-
statusReasons
final Optional<List<AccountHolderSimulateEnrollmentReviewParams.StatusReason>> statusReasons()
Status reason that will be associated with the simulated account holder status. Only required for a
REJECTEDstatus.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderSimulateEnrollmentReviewParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<AccountHolderSimulateEnrollmentReviewParams.StatusReason>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest.Builder toBuilder()
-
validate
final AccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderSimulateEnrollmentReviewParams.SimulateEnrollmentReviewRequest.Builder builder()
Returns a mutable builder for constructing an instance of SimulateEnrollmentReviewRequest.
-
-
-
-