Class AccountHolderUpdateParams.Body.KybPatchRequest
-
- All Implemented Interfaces:
public final class AccountHolderUpdateParams.Body.KybPatchRequestThe KYB request payload for updating a business.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdateParams.Body.KybPatchRequest.BuilderA builder for KybPatchRequest.
public final classAccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatchIndividuals associated with a KYB application. Phone number is optional.
public final classAccountHolderUpdateParams.Body.KybPatchRequest.KybBusinessEntityPatchInformation for business for which the account is being opened and KYB is being run.
-
Method Summary
Modifier and Type Method Description final Optional<List<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>>beneficialOwnerIndividuals()You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. final Optional<AccountHolderUpdateParams.Body.KybPatchRequest.KybBusinessEntityPatch>businessEntity()Information for business for which the account is being opened and KYB is being run. final Optional<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>controlPerson()An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<String>naicsCode()6-digit North American Industry Classification System (NAICS) code for the business. final Optional<String>natureOfBusiness()Short description of the company's line of business (i.e., what does the company do?). final Optional<String>websiteUrl()Company website URL. final JsonField<List<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>>_beneficialOwnerIndividuals()Returns the raw JSON value of beneficialOwnerIndividuals. final JsonField<AccountHolderUpdateParams.Body.KybPatchRequest.KybBusinessEntityPatch>_businessEntity()Returns the raw JSON value of businessEntity. final JsonField<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>_controlPerson()Returns the raw JSON value of controlPerson. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<String>_naicsCode()Returns the raw JSON value of naicsCode. final JsonField<String>_natureOfBusiness()Returns the raw JSON value of natureOfBusiness. final JsonField<String>_websiteUrl()Returns the raw JSON value of websiteUrl. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdateParams.Body.KybPatchRequest.BuildertoBuilder()final AccountHolderUpdateParams.Body.KybPatchRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateParams.Body.KybPatchRequest.Builderbuilder()Returns a mutable builder for constructing an instance of KybPatchRequest. -
-
Method Detail
-
beneficialOwnerIndividuals
final Optional<List<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>> beneficialOwnerIndividuals()
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
businessEntity
final Optional<AccountHolderUpdateParams.Body.KybPatchRequest.KybBusinessEntityPatch> businessEntity()
Information for business for which the account is being opened and KYB is being run.
-
controlPerson
final Optional<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch> controlPerson()
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
naicsCode
final Optional<String> naicsCode()
6-digit North American Industry Classification System (NAICS) code for the business.
-
natureOfBusiness
final Optional<String> natureOfBusiness()
Short description of the company's line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification
-
websiteUrl
final Optional<String> websiteUrl()
Company website URL.
-
_beneficialOwnerIndividuals
final JsonField<List<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch>> _beneficialOwnerIndividuals()
Returns the raw JSON value of beneficialOwnerIndividuals.
Unlike beneficialOwnerIndividuals, this method doesn't throw if the JSON field has an unexpected type.
-
_businessEntity
final JsonField<AccountHolderUpdateParams.Body.KybPatchRequest.KybBusinessEntityPatch> _businessEntity()
Returns the raw JSON value of businessEntity.
Unlike businessEntity, this method doesn't throw if the JSON field has an unexpected type.
-
_controlPerson
final JsonField<AccountHolderUpdateParams.Body.KybPatchRequest.IndividualPatch> _controlPerson()
Returns the raw JSON value of controlPerson.
Unlike controlPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_naicsCode
final JsonField<String> _naicsCode()
Returns the raw JSON value of naicsCode.
Unlike naicsCode, this method doesn't throw if the JSON field has an unexpected type.
-
_natureOfBusiness
final JsonField<String> _natureOfBusiness()
Returns the raw JSON value of natureOfBusiness.
Unlike natureOfBusiness, this method doesn't throw if the JSON field has an unexpected type.
-
_websiteUrl
final JsonField<String> _websiteUrl()
Returns the raw JSON value of websiteUrl.
Unlike websiteUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdateParams.Body.KybPatchRequest.Builder toBuilder()
-
validate
final AccountHolderUpdateParams.Body.KybPatchRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderUpdateParams.Body.KybPatchRequest.Builder builder()
Returns a mutable builder for constructing an instance of KybPatchRequest.
-
-
-
-