Class AccountHolderUpdateParams.Body.KycPatchRequest
-
- All Implemented Interfaces:
public final class AccountHolderUpdateParams.Body.KycPatchRequestThe KYC request payload for updating an account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdateParams.Body.KycPatchRequest.BuilderA builder for KycPatchRequest.
public final classAccountHolderUpdateParams.Body.KycPatchRequest.IndividualPatchInformation on the individual for whom the account is being opened and KYC is being run.
-
Method Summary
Modifier and Type Method Description final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<AccountHolderUpdateParams.Body.KycPatchRequest.IndividualPatch>individual()Information on the individual for whom the account is being opened and KYC is being run. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<AccountHolderUpdateParams.Body.KycPatchRequest.IndividualPatch>_individual()Returns the raw JSON value of individual. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdateParams.Body.KycPatchRequest.BuildertoBuilder()final AccountHolderUpdateParams.Body.KycPatchRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdateParams.Body.KycPatchRequest.Builderbuilder()Returns a mutable builder for constructing an instance of KycPatchRequest. -
-
Method Detail
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
individual
final Optional<AccountHolderUpdateParams.Body.KycPatchRequest.IndividualPatch> individual()
Information on the individual for whom the account is being opened and KYC is being run.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_individual
final JsonField<AccountHolderUpdateParams.Body.KycPatchRequest.IndividualPatch> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdateParams.Body.KycPatchRequest.Builder toBuilder()
-
validate
final AccountHolderUpdateParams.Body.KycPatchRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderUpdateParams.Body.KycPatchRequest.Builder builder()
Returns a mutable builder for constructing an instance of KycPatchRequest.
-
-
-
-