Package com.lithic.api.models
Class AccountHolderUpdateResponse
-
- All Implemented Interfaces:
public final class AccountHolderUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountHolderUpdateResponse.VisitorAn interface that defines how to map each variant of AccountHolderUpdateResponse to a value of type T.
public final classAccountHolderUpdateResponse.KybKycPatchResponsepublic final classAccountHolderUpdateResponse.PatchResponse
-
Method Summary
-
-
Method Detail
-
kybKycPatch
final Optional<AccountHolderUpdateResponse.KybKycPatchResponse> kybKycPatch()
-
patch
final Optional<AccountHolderUpdateResponse.PatchResponse> patch()
-
isKybKycPatch
final Boolean isKybKycPatch()
-
asKybKycPatch
final AccountHolderUpdateResponse.KybKycPatchResponse asKybKycPatch()
-
asPatch
final AccountHolderUpdateResponse.PatchResponse asPatch()
-
accept
final <T extends Any> T accept(AccountHolderUpdateResponse.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.lithic.api.core.JsonValue; import java.util.Optional; Optional<String> result = accountHolderUpdateResponse.accept(new AccountHolderUpdateResponse.Visitor<Optional<String>>() { @Override public Optional<String> visitKybKycPatch(KybKycPatchResponse kybKycPatch) { return Optional.of(kybKycPatch.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final AccountHolderUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofKybKycPatch
final static AccountHolderUpdateResponse ofKybKycPatch(AccountHolderUpdateResponse.KybKycPatchResponse kybKycPatch)
-
ofPatch
final static AccountHolderUpdateResponse ofPatch(AccountHolderUpdateResponse.PatchResponse patch)
-
-
-
-