Class AccountHolderUpdateResponse.PatchResponse.Builder
-
- All Implemented Interfaces:
public final class AccountHolderUpdateResponse.PatchResponse.BuilderA builder for PatchResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final AccountHolderUpdateResponse.PatchResponse.Builder token(String token)
The token for the account holder that was updated
-
token
final AccountHolderUpdateResponse.PatchResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address
final AccountHolderUpdateResponse.PatchResponse.Builder address(AccountHolderUpdateResponse.PatchResponse.Address address)
The address for the account holder
-
address
final AccountHolderUpdateResponse.PatchResponse.Builder address(JsonField<AccountHolderUpdateResponse.PatchResponse.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
businessAccountToken
final AccountHolderUpdateResponse.PatchResponse.Builder businessAccountToken(String businessAccountToken)
The token for the business account that the account holder is associated with
-
businessAccountToken
final AccountHolderUpdateResponse.PatchResponse.Builder businessAccountToken(Optional<String> businessAccountToken)
Alias for calling Builder.businessAccountToken with
businessAccountToken.orElse(null).
-
businessAccountToken
final AccountHolderUpdateResponse.PatchResponse.Builder businessAccountToken(JsonField<String> businessAccountToken)
Sets Builder.businessAccountToken to an arbitrary JSON value.
You should usually call Builder.businessAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AccountHolderUpdateResponse.PatchResponse.Builder email(String email)
The email for the account holder
-
email
final AccountHolderUpdateResponse.PatchResponse.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountHolderUpdateResponse.PatchResponse.Builder firstName(String firstName)
The first name for the account holder
-
firstName
final AccountHolderUpdateResponse.PatchResponse.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountHolderUpdateResponse.PatchResponse.Builder lastName(String lastName)
The last name for the account holder
-
lastName
final AccountHolderUpdateResponse.PatchResponse.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalBusinessName
final AccountHolderUpdateResponse.PatchResponse.Builder legalBusinessName(String legalBusinessName)
The legal business name for the account holder
-
legalBusinessName
final AccountHolderUpdateResponse.PatchResponse.Builder legalBusinessName(JsonField<String> legalBusinessName)
Sets Builder.legalBusinessName to an arbitrary JSON value.
You should usually call Builder.legalBusinessName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final AccountHolderUpdateResponse.PatchResponse.Builder phoneNumber(String phoneNumber)
The phone_number for the account holder
-
phoneNumber
final AccountHolderUpdateResponse.PatchResponse.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountHolderUpdateResponse.PatchResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderUpdateResponse.PatchResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderUpdateResponse.PatchResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderUpdateResponse.PatchResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderUpdateResponse.PatchResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderUpdateResponse.PatchResponse build()
Returns an immutable instance of PatchResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-