Class AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder
-
- All Implemented Interfaces:
public final class AccountHolderUpdatedWebhookEvent.LegacyPayload.BuilderA builder for LegacyPayload.
-
-
Method Summary
-
-
Method Detail
-
token
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder token(String token)
The token of the account_holder that was created.
-
token
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
businessAccountToken
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder businessAccountToken(String businessAccountToken)
If applicable, represents the business account token associated with the account_holder.
-
businessAccountToken
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder businessAccountToken(Optional<String> businessAccountToken)
Alias for calling Builder.businessAccountToken with
businessAccountToken.orElse(null).
-
businessAccountToken
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder businessAccountToken(JsonField<String> businessAccountToken)
Sets Builder.businessAccountToken to an arbitrary JSON value.
You should usually call Builder.businessAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder created(OffsetDateTime created)
When the account_holder updated event was created
-
created
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder email(String email)
If updated, the newly updated email associated with the account_holder otherwise the existing email is provided.
-
email
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder eventType(AccountHolderUpdatedWebhookEvent.LegacyPayload.EventType eventType)
The type of event that occurred.
-
eventType
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder eventType(JsonField<AccountHolderUpdatedWebhookEvent.LegacyPayload.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder externalId(String externalId)
If applicable, represents the external_id associated with the account_holder.
-
externalId
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder externalId(Optional<String> externalId)
Alias for calling Builder.externalId with
externalId.orElse(null).
-
externalId
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder firstName(String firstName)
If applicable, represents the account_holder's first name.
-
firstName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder lastName(String lastName)
If applicable, represents the account_holder's last name.
-
lastName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalBusinessName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder legalBusinessName(String legalBusinessName)
If applicable, represents the account_holder's business name.
-
legalBusinessName
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder legalBusinessName(JsonField<String> legalBusinessName)
Sets Builder.legalBusinessName to an arbitrary JSON value.
You should usually call Builder.legalBusinessName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder phoneNumber(String phoneNumber)
If updated, the newly updated phone_number associated with the account_holder otherwise the existing phone_number is provided.
-
phoneNumber
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderUpdatedWebhookEvent.LegacyPayload.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderUpdatedWebhookEvent.LegacyPayload build()
Returns an immutable instance of LegacyPayload.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token()
-
-
-
-