Class AccountHolderUploadDocumentParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountHolderUploadDocumentParams implements Params
Use this endpoint to identify which type of supported government-issued documentation you will upload for further verification. It will return two URLs to upload your document images to - one for the front image and one for the back image.
This endpoint is only valid for evaluations in a
PENDING_DOCUMENTstate.Supported file types include
jpg,png, andpdf. Each file must be less than 15 MiB. Once both required uploads have been successfully completed, your document will be run through KYC verification.If you have registered a webhook, you will receive evaluation updates for any document submission evaluations, as well as for any failed document uploads.
Two document submission attempts are permitted via this endpoint before a
REJECTEDstatus is returned and the account creation process is ended. Currently only one type of account holder document is supported per KYC verification.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUploadDocumentParams.BuilderA builder for AccountHolderUploadDocumentParams.
public final classAccountHolderUploadDocumentParams.Bodypublic final classAccountHolderUploadDocumentParams.DocumentTypeThe type of document to upload
-
Method Summary
Modifier and Type Method Description final Optional<String>accountHolderToken()final AccountHolderUploadDocumentParams.DocumentTypedocumentType()The type of document to upload final StringentityToken()Globally unique identifier for the entity. final JsonField<AccountHolderUploadDocumentParams.DocumentType>_documentType()Returns the raw JSON value of documentType. final JsonField<String>_entityToken()Returns the raw JSON value of entityToken. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountHolderUploadDocumentParams.BuildertoBuilder()final AccountHolderUploadDocumentParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUploadDocumentParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderUploadDocumentParams. -
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
-
documentType
final AccountHolderUploadDocumentParams.DocumentType documentType()
The type of document to upload
-
entityToken
final String entityToken()
Globally unique identifier for the entity.
-
_documentType
final JsonField<AccountHolderUploadDocumentParams.DocumentType> _documentType()
Returns the raw JSON value of documentType.
Unlike documentType, this method doesn't throw if the JSON field has an unexpected type.
-
_entityToken
final JsonField<String> _entityToken()
Returns the raw JSON value of entityToken.
Unlike entityToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountHolderUploadDocumentParams.Builder toBuilder()
-
_body
final AccountHolderUploadDocumentParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountHolderUploadDocumentParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderUploadDocumentParams.
The following fields are required:
.documentType() .entityToken()
-
-
-
-