Class AccountHolderVerificationWebhookEvent
-
- All Implemented Interfaces:
public final class AccountHolderVerificationWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderVerificationWebhookEvent.BuilderA builder for AccountHolderVerificationWebhookEvent.
public final classAccountHolderVerificationWebhookEvent.EventTypeThe type of event that occurred.
public final classAccountHolderVerificationWebhookEvent.StatusThe status of the account_holder that was created
-
Method Summary
Modifier and Type Method Description final AccountHolderVerificationWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<String>token()The token of the account_holder being verified. final Optional<String>accountToken()The token of the account being verified. final Optional<OffsetDateTime>created()When the account_holder verification status was updated final Optional<AccountHolderVerificationWebhookEvent.Status>status()The status of the account_holder that was created final Optional<List<String>>statusReasons()final JsonField<AccountHolderVerificationWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<AccountHolderVerificationWebhookEvent.Status>_status()Returns the raw JSON value of status. final JsonField<List<String>>_statusReasons()Returns the raw JSON value of statusReasons. final Map<String, JsonValue>_additionalProperties()final AccountHolderVerificationWebhookEvent.BuildertoBuilder()final AccountHolderVerificationWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderVerificationWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderVerificationWebhookEvent. -
-
Method Detail
-
eventType
final AccountHolderVerificationWebhookEvent.EventType eventType()
The type of event that occurred.
-
accountToken
final Optional<String> accountToken()
The token of the account being verified.
-
created
final Optional<OffsetDateTime> created()
When the account_holder verification status was updated
-
status
final Optional<AccountHolderVerificationWebhookEvent.Status> status()
The status of the account_holder that was created
-
statusReasons
final Optional<List<String>> statusReasons()
-
_eventType
final JsonField<AccountHolderVerificationWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderVerificationWebhookEvent.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<String>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderVerificationWebhookEvent.Builder toBuilder()
-
validate
final AccountHolderVerificationWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountHolderVerificationWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderVerificationWebhookEvent.
The following fields are required:
.eventType()
-
-
-
-