Class AccountHolderVerificationWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class AccountHolderVerificationWebhookEvent.BuilderA builder for AccountHolderVerificationWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
eventType
final AccountHolderVerificationWebhookEvent.Builder eventType(AccountHolderVerificationWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final AccountHolderVerificationWebhookEvent.Builder eventType(JsonField<AccountHolderVerificationWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
token
final AccountHolderVerificationWebhookEvent.Builder token(String token)
The token of the account_holder being verified.
-
token
final AccountHolderVerificationWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final AccountHolderVerificationWebhookEvent.Builder accountToken(String accountToken)
The token of the account being verified.
-
accountToken
final AccountHolderVerificationWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final AccountHolderVerificationWebhookEvent.Builder created(OffsetDateTime created)
When the account_holder verification status was updated
-
created
final AccountHolderVerificationWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountHolderVerificationWebhookEvent.Builder status(AccountHolderVerificationWebhookEvent.Status status)
The status of the account_holder that was created
-
status
final AccountHolderVerificationWebhookEvent.Builder status(JsonField<AccountHolderVerificationWebhookEvent.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReasons
final AccountHolderVerificationWebhookEvent.Builder statusReasons(List<String> statusReasons)
-
statusReasons
final AccountHolderVerificationWebhookEvent.Builder statusReasons(JsonField<List<String>> statusReasons)
Sets Builder.statusReasons to an arbitrary JSON value.
You should usually call Builder.statusReasons with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final AccountHolderVerificationWebhookEvent.Builder addStatusReason(String statusReason)
Adds a single String to statusReasons.
-
additionalProperties
final AccountHolderVerificationWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountHolderVerificationWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountHolderVerificationWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountHolderVerificationWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountHolderVerificationWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountHolderVerificationWebhookEvent build()
Returns an immutable instance of AccountHolderVerificationWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventType()
-
-
-
-