Package com.lithic.api.models
Class AccountSpendLimits
-
- All Implemented Interfaces:
public final class AccountSpendLimits
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountSpendLimits.BuilderA builder for AccountSpendLimits.
public final classAccountSpendLimits.AvailableSpendLimitpublic final classAccountSpendLimits.SpendLimitpublic final classAccountSpendLimits.SpendVelocity
-
Method Summary
-
-
Method Detail
-
availableSpendLimit
final AccountSpendLimits.AvailableSpendLimit availableSpendLimit()
-
spendLimit
final Optional<AccountSpendLimits.SpendLimit> spendLimit()
-
spendVelocity
final Optional<AccountSpendLimits.SpendVelocity> spendVelocity()
-
_availableSpendLimit
final JsonField<AccountSpendLimits.AvailableSpendLimit> _availableSpendLimit()
Returns the raw JSON value of availableSpendLimit.
Unlike availableSpendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimit
final JsonField<AccountSpendLimits.SpendLimit> _spendLimit()
Returns the raw JSON value of spendLimit.
Unlike spendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendVelocity
final JsonField<AccountSpendLimits.SpendVelocity> _spendVelocity()
Returns the raw JSON value of spendVelocity.
Unlike spendVelocity, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountSpendLimits.Builder toBuilder()
-
validate
final AccountSpendLimits validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountSpendLimits.Builder builder()
Returns a mutable builder for constructing an instance of AccountSpendLimits.
The following fields are required:
.availableSpendLimit()
-
-
-
-