Class AccountSpendLimits.SpendVelocity
-
- All Implemented Interfaces:
public final class AccountSpendLimits.SpendVelocity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountSpendLimits.SpendVelocity.BuilderA builder for SpendVelocity.
-
Method Summary
Modifier and Type Method Description final Optional<Long>daily()Current daily spend velocity (in cents) on the Account. final Optional<Long>lifetime()Current lifetime spend velocity (in cents) on the Account. final Optional<Long>monthly()Current monthly spend velocity (in cents) on the Account. final JsonField<Long>_daily()Returns the raw JSON value of daily. final JsonField<Long>_lifetime()Returns the raw JSON value of lifetime. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final AccountSpendLimits.SpendVelocity.BuildertoBuilder()final AccountSpendLimits.SpendVelocityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountSpendLimits.SpendVelocity.Builderbuilder()Returns a mutable builder for constructing an instance of SpendVelocity. -
-
Method Detail
-
daily
final Optional<Long> daily()
Current daily spend velocity (in cents) on the Account. Present if daily spend limit is set.
-
lifetime
final Optional<Long> lifetime()
Current lifetime spend velocity (in cents) on the Account. Present if lifetime spend limit is set.
-
monthly
final Optional<Long> monthly()
Current monthly spend velocity (in cents) on the Account. Present if monthly spend limit is set.
-
_daily
final JsonField<Long> _daily()
Returns the raw JSON value of daily.
Unlike daily, this method doesn't throw if the JSON field has an unexpected type.
-
_lifetime
final JsonField<Long> _lifetime()
Returns the raw JSON value of lifetime.
Unlike lifetime, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountSpendLimits.SpendVelocity.Builder toBuilder()
-
validate
final AccountSpendLimits.SpendVelocity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountSpendLimits.SpendVelocity.Builder builder()
Returns a mutable builder for constructing an instance of SpendVelocity.
-
-
-
-