Class AchPaymentUpdateAction.CreateCaseAction
-
- All Implemented Interfaces:
public final class AchPaymentUpdateAction.CreateCaseAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPaymentUpdateAction.CreateCaseAction.BuilderA builder for CreateCaseAction.
public final classAchPaymentUpdateAction.CreateCaseAction.ScopeThe scope of the case to create
public final classAchPaymentUpdateAction.CreateCaseAction.TypeCreate a case for the payment
-
Method Summary
-
-
Method Detail
-
queueToken
final String queueToken()
The token of the queue to create the case in
-
scope
final AchPaymentUpdateAction.CreateCaseAction.Scope scope()
The scope of the case to create
-
type
final AchPaymentUpdateAction.CreateCaseAction.Type type()
Create a case for the payment
-
_queueToken
final JsonField<String> _queueToken()
Returns the raw JSON value of queueToken.
Unlike queueToken, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<AchPaymentUpdateAction.CreateCaseAction.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AchPaymentUpdateAction.CreateCaseAction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchPaymentUpdateAction.CreateCaseAction.Builder toBuilder()
-
validate
final AchPaymentUpdateAction.CreateCaseAction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchPaymentUpdateAction.CreateCaseAction.Builder builder()
Returns a mutable builder for constructing an instance of CreateCaseAction.
The following fields are required:
.queueToken() .scope() .type()
-
-
-
-