Package com.lithic.api.models
Enum AchPaymentUpdateAction.CreateCaseAction.Scope.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AchPaymentUpdateAction.CreateCaseAction.Scope.Known extends Enum<AchPaymentUpdateAction.CreateCaseAction.Scope.Known>
An enum containing Scope's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AchPaymentUpdateAction.CreateCaseAction.Scope.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FINANCIAL_ACCOUNT
-
Method Summary
Modifier and Type Method Description final AchPaymentUpdateAction.CreateCaseAction.Scope.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AchPaymentUpdateAction.CreateCaseAction.Scope.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AchPaymentUpdateAction.CreateCaseAction.Scope.Known>getEntries()An enum containing Scope's known values. -
-
Method Detail
-
valueOf
final AchPaymentUpdateAction.CreateCaseAction.Scope.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AchPaymentUpdateAction.CreateCaseAction.Scope.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AchPaymentUpdateAction.CreateCaseAction.Scope.Known> getEntries()
An enum containing Scope's known values.
-
-
-
-