Class Address.Builder
-
- All Implemented Interfaces:
public final class Address.BuilderA builder for Address.
-
-
Method Summary
Modifier and Type Method Description final Address.Builderaddress1(String address1)Valid deliverable address (no PO boxes). final Address.Builderaddress1(JsonField<String> address1)Sets Builder.address1 to an arbitrary JSON value. final Address.Buildercity(String city)Name of city. final Address.Buildercity(JsonField<String> city)Sets Builder.city to an arbitrary JSON value. final Address.Buildercountry(String country)Valid country code, entered in uppercase ISO 3166-1 alpha-3 three-character format. final Address.Buildercountry(JsonField<String> country)Sets Builder.country to an arbitrary JSON value. final Address.BuilderpostalCode(String postalCode)Valid postal code. final Address.BuilderpostalCode(JsonField<String> postalCode)Sets Builder.postalCode to an arbitrary JSON value. final Address.Builderstate(String state)Valid state code. final Address.Builderstate(JsonField<String> state)Sets Builder.state to an arbitrary JSON value. final Address.Builderaddress2(String address2)Unit or apartment number (if applicable). final Address.Builderaddress2(JsonField<String> address2)Sets Builder.address2 to an arbitrary JSON value. final Address.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Address.BuilderputAdditionalProperty(String key, JsonValue value)final Address.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Address.BuilderremoveAdditionalProperty(String key)final Address.BuilderremoveAllAdditionalProperties(Set<String> keys)final Addressbuild()Returns an immutable instance of Address. -
-
Method Detail
-
address1
final Address.Builder address1(String address1)
Valid deliverable address (no PO boxes).
-
address1
final Address.Builder address1(JsonField<String> address1)
Sets Builder.address1 to an arbitrary JSON value.
You should usually call Builder.address1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final Address.Builder city(String city)
Name of city.
-
city
final Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final Address.Builder country(String country)
Valid country code, entered in uppercase ISO 3166-1 alpha-3 three-character format. Only USA is currently supported for all workflows. KYC_EXEMPT supports CAN additionally.
-
country
final Address.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final Address.Builder postalCode(String postalCode)
Valid postal code. USA postal codes (ZIP codes) are supported, entered as a five-digit postal code or nine-digit postal code (ZIP+4) using the format 12345-1234. KYC_EXEMPT supports Canadian postal codes.
-
postalCode
final Address.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Address.Builder state(String state)
Valid state code. USA state codes are supported, entered in uppercase ISO 3166-2 two-character format. KYC_EXEMPT supports Canadian province codes.
-
state
final Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address2
final Address.Builder address2(String address2)
Unit or apartment number (if applicable).
-
address2
final Address.Builder address2(JsonField<String> address2)
Sets Builder.address2 to an arbitrary JSON value.
You should usually call Builder.address2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-