Class AsaRequestWebhookEvent.AsaRequestFleetInfo.FleetRestrictionCode

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class AsaRequestWebhookEvent.AsaRequestFleetInfo.FleetRestrictionCode
     implements Enum
                        

    Code indicating which restrictions, if any, there are on purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis