Class AsaRequestWebhookEvent.Avs.AddressMatchResult

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class AsaRequestWebhookEvent.Avs.AddressMatchResult
     implements Enum
                        

    Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned