Class AsaRequestWebhookEvent.Pos.AsaPosTerminal
-
- All Implemented Interfaces:
public final class AsaRequestWebhookEvent.Pos.AsaPosTerminal
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAsaRequestWebhookEvent.Pos.AsaPosTerminal.BuilderA builder for AsaPosTerminal.
public final classAsaRequestWebhookEvent.Pos.AsaPosTerminal.OperatorThe person that is designated to swipe the card
public final classAsaRequestWebhookEvent.Pos.AsaPosTerminal.PinCapabilityStatus of whether the POS is able to accept PINs
public final classAsaRequestWebhookEvent.Pos.AsaPosTerminal.TypePOS Type
-
Method Summary
-
-
Method Detail
-
cardRetentionCapable
final Boolean cardRetentionCapable()
True if the terminal is capable of retaining the card.
-
onPremise
final Boolean onPremise()
True if the sale was made at the place of business (vs. mobile).
-
operator
final AsaRequestWebhookEvent.Pos.AsaPosTerminal.Operator operator()
The person that is designated to swipe the card
-
partialApprovalCapable
final Boolean partialApprovalCapable()
True if the terminal is capable of partial approval. Partial approval is when part of a transaction is approved and another payment must be used for the remainder. Example scenario: A
$40 transaction is attempted on a prepaid card with a $
25 balance. If partial approval is enabled,$25 can be authorized, at which point the POS will prompt the user for an additional payment of $
15.
-
pinCapability
final AsaRequestWebhookEvent.Pos.AsaPosTerminal.PinCapability pinCapability()
Status of whether the POS is able to accept PINs
-
type
final AsaRequestWebhookEvent.Pos.AsaPosTerminal.Type type()
POS Type
-
acceptorTerminalId
final Optional<String> acceptorTerminalId()
Uniquely identifies a terminal at the card acceptor location of acquiring institutions or merchant POS Systems. Left justified with trailing spaces.
-
_attended
final JsonField<Boolean> _attended()
Returns the raw JSON value of attended.
Unlike attended, this method doesn't throw if the JSON field has an unexpected type.
-
_cardRetentionCapable
final JsonField<Boolean> _cardRetentionCapable()
Returns the raw JSON value of cardRetentionCapable.
Unlike cardRetentionCapable, this method doesn't throw if the JSON field has an unexpected type.
-
_onPremise
final JsonField<Boolean> _onPremise()
Returns the raw JSON value of onPremise.
Unlike onPremise, this method doesn't throw if the JSON field has an unexpected type.
-
_operator
final JsonField<AsaRequestWebhookEvent.Pos.AsaPosTerminal.Operator> _operator()
Returns the raw JSON value of operator.
Unlike operator, this method doesn't throw if the JSON field has an unexpected type.
-
_partialApprovalCapable
final JsonField<Boolean> _partialApprovalCapable()
Returns the raw JSON value of partialApprovalCapable.
Unlike partialApprovalCapable, this method doesn't throw if the JSON field has an unexpected type.
-
_pinCapability
final JsonField<AsaRequestWebhookEvent.Pos.AsaPosTerminal.PinCapability> _pinCapability()
Returns the raw JSON value of pinCapability.
Unlike pinCapability, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AsaRequestWebhookEvent.Pos.AsaPosTerminal.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptorTerminalId
final JsonField<String> _acceptorTerminalId()
Returns the raw JSON value of acceptorTerminalId.
Unlike acceptorTerminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AsaRequestWebhookEvent.Pos.AsaPosTerminal.Builder toBuilder()
-
validate
final AsaRequestWebhookEvent.Pos.AsaPosTerminal validate()
-
builder
final static AsaRequestWebhookEvent.Pos.AsaPosTerminal.Builder builder()
Returns a mutable builder for constructing an instance of AsaPosTerminal.
The following fields are required:
.attended() .cardRetentionCapable() .onPremise() .operator() .partialApprovalCapable() .pinCapability() .type()
-
-
-
-