Class AuthRule.Builder
-
- All Implemented Interfaces:
public final class AuthRule.BuilderA builder for AuthRule.
-
-
Method Summary
-
-
Method Detail
-
token
final AuthRule.Builder token(String token)
Auth Rule Token
-
token
final AuthRule.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountTokens
final AuthRule.Builder accountTokens(List<String> accountTokens)
Account tokens to which the Auth Rule applies.
-
accountTokens
final AuthRule.Builder accountTokens(JsonField<List<String>> accountTokens)
Sets Builder.accountTokens to an arbitrary JSON value.
You should usually call Builder.accountTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAccountToken
final AuthRule.Builder addAccountToken(String accountToken)
Adds a single String to accountTokens.
-
businessAccountTokens
final AuthRule.Builder businessAccountTokens(List<String> businessAccountTokens)
Business Account tokens to which the Auth Rule applies.
-
businessAccountTokens
final AuthRule.Builder businessAccountTokens(JsonField<List<String>> businessAccountTokens)
Sets Builder.businessAccountTokens to an arbitrary JSON value.
You should usually call Builder.businessAccountTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBusinessAccountToken
final AuthRule.Builder addBusinessAccountToken(String businessAccountToken)
Adds a single String to businessAccountTokens.
-
cardTokens
final AuthRule.Builder cardTokens(List<String> cardTokens)
Card tokens to which the Auth Rule applies.
-
cardTokens
final AuthRule.Builder cardTokens(JsonField<List<String>> cardTokens)
Sets Builder.cardTokens to an arbitrary JSON value.
You should usually call Builder.cardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCardToken
final AuthRule.Builder addCardToken(String cardToken)
Adds a single String to cardTokens.
-
currentVersion
final AuthRule.Builder currentVersion(AuthRule.CurrentVersion currentVersion)
-
currentVersion
final AuthRule.Builder currentVersion(Optional<AuthRule.CurrentVersion> currentVersion)
Alias for calling Builder.currentVersion with
currentVersion.orElse(null).
-
currentVersion
final AuthRule.Builder currentVersion(JsonField<AuthRule.CurrentVersion> currentVersion)
Sets Builder.currentVersion to an arbitrary JSON value.
You should usually call Builder.currentVersion with a well-typed CurrentVersion value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
draftVersion
final AuthRule.Builder draftVersion(AuthRule.DraftVersion draftVersion)
-
draftVersion
final AuthRule.Builder draftVersion(Optional<AuthRule.DraftVersion> draftVersion)
Alias for calling Builder.draftVersion with
draftVersion.orElse(null).
-
draftVersion
final AuthRule.Builder draftVersion(JsonField<AuthRule.DraftVersion> draftVersion)
Sets Builder.draftVersion to an arbitrary JSON value.
You should usually call Builder.draftVersion with a well-typed DraftVersion value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventStream
final AuthRule.Builder eventStream(EventStream eventStream)
The event stream during which the rule will be evaluated.
-
eventStream
final AuthRule.Builder eventStream(JsonField<EventStream> eventStream)
Sets Builder.eventStream to an arbitrary JSON value.
You should usually call Builder.eventStream with a well-typed EventStream value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lithicManaged
final AuthRule.Builder lithicManaged(Boolean lithicManaged)
Indicates whether this auth rule is managed by Lithic. If true, the rule cannot be modified or deleted by the user
-
lithicManaged
final AuthRule.Builder lithicManaged(JsonField<Boolean> lithicManaged)
Sets Builder.lithicManaged to an arbitrary JSON value.
You should usually call Builder.lithicManaged with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AuthRule.Builder name(String name)
Auth Rule Name
-
name
final AuthRule.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final AuthRule.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programLevel
final AuthRule.Builder programLevel(Boolean programLevel)
Whether the Auth Rule applies to all authorizations on the card program.
-
programLevel
final AuthRule.Builder programLevel(JsonField<Boolean> programLevel)
Sets Builder.programLevel to an arbitrary JSON value.
You should usually call Builder.programLevel with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final AuthRule.Builder state(AuthRule.AuthRuleState state)
The state of the Auth Rule
-
state
final AuthRule.Builder state(JsonField<AuthRule.AuthRuleState> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed AuthRuleState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AuthRule.Builder type(AuthRule.AuthRuleType type)
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
type
final AuthRule.Builder type(JsonField<AuthRule.AuthRuleType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed AuthRuleType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
excludedCardTokens
final AuthRule.Builder excludedCardTokens(List<String> excludedCardTokens)
Card tokens to which the Auth Rule does not apply.
-
excludedCardTokens
final AuthRule.Builder excludedCardTokens(JsonField<List<String>> excludedCardTokens)
Sets Builder.excludedCardTokens to an arbitrary JSON value.
You should usually call Builder.excludedCardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExcludedCardToken
final AuthRule.Builder addExcludedCardToken(String excludedCardToken)
Adds a single String to excludedCardTokens.
-
additionalProperties
final AuthRule.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthRule.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthRule.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthRule.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthRule.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AuthRule build()
Returns an immutable instance of AuthRule.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountTokens() .businessAccountTokens() .cardTokens() .currentVersion() .draftVersion() .eventStream() .lithicManaged() .name() .programLevel() .state() .type()
-
-
-
-