Package com.lithic.api.models
Class AuthRule.CurrentVersion
-
- All Implemented Interfaces:
public final class AuthRule.CurrentVersion
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRule.CurrentVersion.BuilderA builder for CurrentVersion.
public final classAuthRule.CurrentVersion.ParametersParameters for the Auth Rule
-
Method Summary
Modifier and Type Method Description final AuthRule.CurrentVersion.Parametersparameters()Parameters for the Auth Rule final Longversion()The version of the rule, this is incremented whenever the rule's parameters change. final JsonField<AuthRule.CurrentVersion.Parameters>_parameters()Returns the raw JSON value of parameters. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final AuthRule.CurrentVersion.BuildertoBuilder()final AuthRule.CurrentVersionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRule.CurrentVersion.Builderbuilder()Returns a mutable builder for constructing an instance of CurrentVersion. -
-
Method Detail
-
parameters
final AuthRule.CurrentVersion.Parameters parameters()
Parameters for the Auth Rule
-
version
final Long version()
The version of the rule, this is incremented whenever the rule's parameters change.
-
_parameters
final JsonField<AuthRule.CurrentVersion.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRule.CurrentVersion.Builder toBuilder()
-
validate
final AuthRule.CurrentVersion validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRule.CurrentVersion.Builder builder()
Returns a mutable builder for constructing an instance of CurrentVersion.
The following fields are required:
.parameters() .version()
-
-
-
-