Class AuthRuleCondition
-
- All Implemented Interfaces:
public final class AuthRuleCondition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleCondition.BuilderA builder for AuthRuleCondition.
-
Method Summary
Modifier and Type Method Description final ConditionalAttributeattribute()The attribute to target. final ConditionalOperationoperation()The operation to apply to the attribute final ConditionalValuevalue()A regex string, to be used with MATCHESorDOES_NOT_MATCHfinal JsonField<ConditionalAttribute>_attribute()Returns the raw JSON value of attribute. final JsonField<ConditionalOperation>_operation()Returns the raw JSON value of operation. final JsonField<ConditionalValue>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final AuthRuleCondition.BuildertoBuilder()final AuthRuleConditionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleCondition.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleCondition. -
-
Method Detail
-
attribute
final ConditionalAttribute attribute()
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN,CREDENTIAL_ON_FILE, orECOMMERCE.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.CARD_TRANSACTION_COUNT_15M: The number of transactions on the card in the trailing 15 minutes before the authorization.CARD_TRANSACTION_COUNT_1H: The number of transactions on the card in the trailing hour up and until the authorization.CARD_TRANSACTION_COUNT_24H: The number of transactions on the card in the trailing 24 hours up and until the authorization.CARD_STATE: The current state of the card associated with the transaction. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.PIN_ENTERED: Indicates whether a PIN was entered during the transaction. Valid values areTRUE,FALSE.PIN_STATUS: The current state of card's PIN. Valid values areNOT_SET,OK,BLOCKED.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
_attribute
final JsonField<ConditionalAttribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleCondition.Builder toBuilder()
-
validate
final AuthRuleCondition validate()
-
builder
final static AuthRuleCondition.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleCondition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-