Package com.lithic.api.models
Class AuthRuleV2BacktestCreateParams.BacktestRequest
-
- All Implemented Interfaces:
public final class AuthRuleV2BacktestCreateParams.BacktestRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2BacktestCreateParams.BacktestRequest.BuilderA builder for BacktestRequest.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>end()The end time of the backtest. final Optional<OffsetDateTime>start()The start time of the backtest. final JsonField<OffsetDateTime>_end()Returns the raw JSON value of end. final JsonField<OffsetDateTime>_start()Returns the raw JSON value of start. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2BacktestCreateParams.BacktestRequest.BuildertoBuilder()final AuthRuleV2BacktestCreateParams.BacktestRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2BacktestCreateParams.BacktestRequest.Builderbuilder()Returns a mutable builder for constructing an instance of BacktestRequest. -
-
Method Detail
-
end
final Optional<OffsetDateTime> end()
The end time of the backtest.
-
start
final Optional<OffsetDateTime> start()
The start time of the backtest.
-
_end
final JsonField<OffsetDateTime> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_start
final JsonField<OffsetDateTime> _start()
Returns the raw JSON value of start.
Unlike start, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2BacktestCreateParams.BacktestRequest.Builder toBuilder()
-
validate
final AuthRuleV2BacktestCreateParams.BacktestRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2BacktestCreateParams.BacktestRequest.Builder builder()
Returns a mutable builder for constructing an instance of BacktestRequest.
-
-
-
-