Class AuthRuleV2CreateParams.Body.CardLevelRule
-
- All Implemented Interfaces:
public final class AuthRuleV2CreateParams.Body.CardLevelRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2CreateParams.Body.CardLevelRule.BuilderA builder for CardLevelRule.
public final classAuthRuleV2CreateParams.Body.CardLevelRule.ParametersParameters for the Auth Rule
public final classAuthRuleV2CreateParams.Body.CardLevelRule.AuthRuleTypeThe type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
Method Summary
-
-
Method Detail
-
cardTokens
final List<String> cardTokens()
Card tokens to which the Auth Rule applies.
-
parameters
final AuthRuleV2CreateParams.Body.CardLevelRule.Parameters parameters()
Parameters for the Auth Rule
-
type
final AuthRuleV2CreateParams.Body.CardLevelRule.AuthRuleType type()
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
eventStream
final Optional<EventStream> eventStream()
The event stream during which the rule will be evaluated.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Returns the raw JSON value of cardTokens.
Unlike cardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_parameters
final JsonField<AuthRuleV2CreateParams.Body.CardLevelRule.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AuthRuleV2CreateParams.Body.CardLevelRule.AuthRuleType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_eventStream
final JsonField<EventStream> _eventStream()
Returns the raw JSON value of eventStream.
Unlike eventStream, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2CreateParams.Body.CardLevelRule.Builder toBuilder()
-
validate
final AuthRuleV2CreateParams.Body.CardLevelRule validate()
-
builder
final static AuthRuleV2CreateParams.Body.CardLevelRule.Builder builder()
Returns a mutable builder for constructing an instance of CardLevelRule.
The following fields are required:
.cardTokens() .parameters() .type()
-
-
-
-