Class AuthRuleV2CreateParams.Body.ProgramLevelRule
-
- All Implemented Interfaces:
public final class AuthRuleV2CreateParams.Body.ProgramLevelRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2CreateParams.Body.ProgramLevelRule.BuilderA builder for ProgramLevelRule.
public final classAuthRuleV2CreateParams.Body.ProgramLevelRule.ParametersParameters for the Auth Rule
public final classAuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleTypeThe type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.TYPESCRIPT_CODE: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
Method Summary
Modifier and Type Method Description final AuthRuleV2CreateParams.Body.ProgramLevelRule.Parametersparameters()Parameters for the Auth Rule final BooleanprogramLevel()Whether the Auth Rule applies to all authorizations on the card program. final AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleTypetype()The type of Auth Rule. final Optional<EventStream>eventStream()The event stream during which the rule will be evaluated. final Optional<List<String>>excludedAccountTokens()Account tokens to which the Auth Rule does not apply. final Optional<List<String>>excludedBusinessAccountTokens()Business account tokens to which the Auth Rule does not apply. final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final Optional<String>name()Auth Rule Name final JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.Parameters>_parameters()Returns the raw JSON value of parameters. final JsonField<Boolean>_programLevel()Returns the raw JSON value of programLevel. final JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleType>_type()Returns the raw JSON value of type. final JsonField<EventStream>_eventStream()Returns the raw JSON value of eventStream. final JsonField<List<String>>_excludedAccountTokens()Returns the raw JSON value of excludedAccountTokens. final JsonField<List<String>>_excludedBusinessAccountTokens()Returns the raw JSON value of excludedBusinessAccountTokens. final JsonField<List<String>>_excludedCardTokens()Returns the raw JSON value of excludedCardTokens. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2CreateParams.Body.ProgramLevelRule.BuildertoBuilder()final AuthRuleV2CreateParams.Body.ProgramLevelRulevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2CreateParams.Body.ProgramLevelRule.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramLevelRule. -
-
Method Detail
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Parameters parameters()
Parameters for the Auth Rule
-
programLevel
final Boolean programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
type
final AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleType type()
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.TYPESCRIPT_CODE: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
eventStream
final Optional<EventStream> eventStream()
The event stream during which the rule will be evaluated.
-
excludedAccountTokens
final Optional<List<String>> excludedAccountTokens()
Account tokens to which the Auth Rule does not apply.
-
excludedBusinessAccountTokens
final Optional<List<String>> excludedBusinessAccountTokens()
Business account tokens to which the Auth Rule does not apply.
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
_parameters
final JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_programLevel
final JsonField<Boolean> _programLevel()
Returns the raw JSON value of programLevel.
Unlike programLevel, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_eventStream
final JsonField<EventStream> _eventStream()
Returns the raw JSON value of eventStream.
Unlike eventStream, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedAccountTokens
final JsonField<List<String>> _excludedAccountTokens()
Returns the raw JSON value of excludedAccountTokens.
Unlike excludedAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedBusinessAccountTokens
final JsonField<List<String>> _excludedBusinessAccountTokens()
Returns the raw JSON value of excludedBusinessAccountTokens.
Unlike excludedBusinessAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Returns the raw JSON value of excludedCardTokens.
Unlike excludedCardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder toBuilder()
-
validate
final AuthRuleV2CreateParams.Body.ProgramLevelRule validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder builder()
Returns a mutable builder for constructing an instance of ProgramLevelRule.
The following fields are required:
.parameters() .programLevel() .type()
-
-
-
-