Class AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder
-
- All Implemented Interfaces:
public final class AuthRuleV2CreateParams.Body.ProgramLevelRule.BuilderA builder for ProgramLevelRule.
-
-
Method Summary
-
-
Method Detail
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(AuthRuleV2CreateParams.Body.ProgramLevelRule.Parameters parameters)
Parameters for the Auth Rule
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.Parameters> parameters)
Sets Builder.parameters to an arbitrary JSON value.
You should usually call Builder.parameters with a well-typed Parameters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
parameters
@Deprecated(message = "deprecated") final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalBlockParameters conditionalBlock)
Alias for calling parameters with
Parameters.ofConditionalBlock(conditionalBlock).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(VelocityLimitParams velocityLimitParams)
Alias for calling parameters with
Parameters.ofVelocityLimitParams(velocityLimitParams).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(MerchantLockParameters merchantLock)
Alias for calling parameters with
Parameters.ofMerchantLock(merchantLock).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(Conditional3dsActionParameters conditional3dsAction)
Alias for calling parameters with
Parameters.ofConditional3dsAction(conditional3dsAction).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalAuthorizationActionParameters conditionalAuthorizationAction)
Alias for calling parameters with
Parameters.ofConditionalAuthorizationAction(conditionalAuthorizationAction).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalAchActionParameters conditionalAchAction)
Alias for calling parameters with
Parameters.ofConditionalAchAction(conditionalAchAction).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalTokenizationActionParameters conditionalTokenizationAction)
Alias for calling parameters with
Parameters.ofConditionalTokenizationAction(conditionalTokenizationAction).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalCardTransactionUpdateActionParameters conditionalCardTransactionUpdateAction)
Alias for calling parameters with
Parameters.ofConditionalCardTransactionUpdateAction(conditionalCardTransactionUpdateAction).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(TypescriptCodeParameters typescriptCode)
Alias for calling parameters with
Parameters.ofTypescriptCode(typescriptCode).
-
parameters
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder parameters(ConditionalAuthorizationAdjustmentParameters conditionalAuthorizationAdjustment)
Alias for calling parameters with
Parameters.ofConditionalAuthorizationAdjustment(conditionalAuthorizationAdjustment).
-
programLevel
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder programLevel(Boolean programLevel)
Whether the Auth Rule applies to all authorizations on the card program.
-
programLevel
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder programLevel(JsonField<Boolean> programLevel)
Sets Builder.programLevel to an arbitrary JSON value.
You should usually call Builder.programLevel with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder type(AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleType type)
The type of Auth Rule. For certain rule types, this determines the event stream during which it will be evaluated. For rules that can be applied to one of several event streams, the effective one is defined by the separate
event_streamfield.CONDITIONAL_BLOCK: Deprecated. UseCONDITIONAL_ACTIONinstead. AUTHORIZATION event stream.VELOCITY_LIMIT: AUTHORIZATION event stream.MERCHANT_LOCK: AUTHORIZATION event stream.CONDITIONAL_ACTION: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, ACH_DEBIT_RECEIPT, or CARD_TRANSACTION_UPDATE event stream.TYPESCRIPT_CODE: AUTHORIZATION, THREE_DS_AUTHENTICATION, TOKENIZATION, ACH_CREDIT_RECEIPT, or ACH_DEBIT_RECEIPT event stream.
-
type
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder type(JsonField<AuthRuleV2CreateParams.Body.ProgramLevelRule.AuthRuleType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed AuthRuleType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventStream
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder eventStream(EventStream eventStream)
The event stream during which the rule will be evaluated.
-
eventStream
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder eventStream(JsonField<EventStream> eventStream)
Sets Builder.eventStream to an arbitrary JSON value.
You should usually call Builder.eventStream with a well-typed EventStream value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
excludedAccountTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedAccountTokens(List<String> excludedAccountTokens)
Account tokens to which the Auth Rule does not apply.
-
excludedAccountTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedAccountTokens(JsonField<List<String>> excludedAccountTokens)
Sets Builder.excludedAccountTokens to an arbitrary JSON value.
You should usually call Builder.excludedAccountTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExcludedAccountToken
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder addExcludedAccountToken(String excludedAccountToken)
Adds a single String to excludedAccountTokens.
-
excludedBusinessAccountTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedBusinessAccountTokens(List<String> excludedBusinessAccountTokens)
Business account tokens to which the Auth Rule does not apply.
-
excludedBusinessAccountTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedBusinessAccountTokens(JsonField<List<String>> excludedBusinessAccountTokens)
Sets Builder.excludedBusinessAccountTokens to an arbitrary JSON value.
You should usually call Builder.excludedBusinessAccountTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExcludedBusinessAccountToken
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder addExcludedBusinessAccountToken(String excludedBusinessAccountToken)
Adds a single String to excludedBusinessAccountTokens.
-
excludedCardTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedCardTokens(List<String> excludedCardTokens)
Card tokens to which the Auth Rule does not apply.
-
excludedCardTokens
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder excludedCardTokens(JsonField<List<String>> excludedCardTokens)
Sets Builder.excludedCardTokens to an arbitrary JSON value.
You should usually call Builder.excludedCardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExcludedCardToken
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder addExcludedCardToken(String excludedCardToken)
Adds a single String to excludedCardTokens.
-
name
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder name(String name)
Auth Rule Name
-
name
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthRuleV2CreateParams.Body.ProgramLevelRule.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AuthRuleV2CreateParams.Body.ProgramLevelRule build()
Returns an immutable instance of ProgramLevelRule.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.parameters() .programLevel() .type()
-
-
-
-