Package com.lithic.api.models
Class AuthRuleV2DraftParams.Body
-
- All Implemented Interfaces:
public final class AuthRuleV2DraftParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2DraftParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<AuthRuleV2DraftParams.Parameters>parameters()Parameters for the Auth Rule final JsonField<AuthRuleV2DraftParams.Parameters>_parameters()Returns the raw JSON value of parameters. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2DraftParams.Body.BuildertoBuilder()final AuthRuleV2DraftParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2DraftParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
parameters
final Optional<AuthRuleV2DraftParams.Parameters> parameters()
Parameters for the Auth Rule
-
_parameters
final JsonField<AuthRuleV2DraftParams.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2DraftParams.Body.Builder toBuilder()
-
validate
final AuthRuleV2DraftParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2DraftParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-