Package com.lithic.api.models
Class AuthRuleV2ListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AuthRuleV2ListPageAsync.BuilderA builder for AuthRuleV2ListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AuthRuleV2ListPageAsync.Builderservice(V2ServiceAsync service)final AuthRuleV2ListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AuthRuleV2ListPageAsync.Builderparams(AuthRuleV2ListParams params)The parameters that were used to request this page. final AuthRuleV2ListPageAsync.Builderresponse(AuthRuleV2ListPageResponse response)The response that this page was parsed from. final AuthRuleV2ListPageAsyncbuild()Returns an immutable instance of AuthRuleV2ListPageAsync. -
-
Method Detail
-
service
final AuthRuleV2ListPageAsync.Builder service(V2ServiceAsync service)
-
streamHandlerExecutor
final AuthRuleV2ListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AuthRuleV2ListPageAsync.Builder params(AuthRuleV2ListParams params)
The parameters that were used to request this page.
-
response
final AuthRuleV2ListPageAsync.Builder response(AuthRuleV2ListPageResponse response)
The response that this page was parsed from.
-
build
final AuthRuleV2ListPageAsync build()
Returns an immutable instance of AuthRuleV2ListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-