Package com.lithic.api.models
Class AuthRuleV2ListPageResponse
-
- All Implemented Interfaces:
public final class AuthRuleV2ListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListPageResponse.BuilderA builder for AuthRuleV2ListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<AuthRule>data()final BooleanhasMore()Indicates whether there are more Auth Rules to be retrieved by paging through the results. final JsonField<List<AuthRule>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2ListPageResponse.BuildertoBuilder()final AuthRuleV2ListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListPageResponse. -
-
Method Detail
-
hasMore
final Boolean hasMore()
Indicates whether there are more Auth Rules to be retrieved by paging through the results.
-
_data
final JsonField<List<AuthRule>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2ListPageResponse.Builder toBuilder()
-
validate
final AuthRuleV2ListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2ListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-