Class AuthRuleV2ListResultsPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class AuthRuleV2ListResultsPage implements Page<V2ListResultsResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2ListResultsPage.BuilderA builder for AuthRuleV2ListResultsPage.
-
Method Summary
Modifier and Type Method Description final List<V2ListResultsResponse>data()Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data. List<V2ListResultsResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AuthRuleV2ListResultsParamsnextPageParams()AuthRuleV2ListResultsPagenextPage()Returns the page after this one by making another request. final AutoPager<V2ListResultsResponse>autoPager()final AuthRuleV2ListResultsParamsparams()The parameters that were used to request this page. final AuthRuleV2ListResultsPageResponseresponse()The response that this page was parsed from. final AuthRuleV2ListResultsPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2ListResultsPage.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleV2ListResultsPage. -
-
Method Detail
-
data
final List<V2ListResultsResponse> data()
Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to AuthRuleV2ListResultsPageResponse, but gracefully handles missing data.
-
items
List<V2ListResultsResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AuthRuleV2ListResultsParams nextPageParams()
-
nextPage
AuthRuleV2ListResultsPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<V2ListResultsResponse> autoPager()
-
params
final AuthRuleV2ListResultsParams params()
The parameters that were used to request this page.
-
response
final AuthRuleV2ListResultsPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AuthRuleV2ListResultsPage.Builder toBuilder()
-
builder
final static AuthRuleV2ListResultsPage.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleV2ListResultsPage.
The following fields are required:
.service() .params() .response()
-
-
-
-