Class AuthRuleV2UpdateParams.Body.AccountLevelRule
-
- All Implemented Interfaces:
public final class AuthRuleV2UpdateParams.Body.AccountLevelRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2UpdateParams.Body.AccountLevelRule.BuilderA builder for AccountLevelRule.
public final classAuthRuleV2UpdateParams.Body.AccountLevelRule.StateThe desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>accountTokens()Account tokens to which the Auth Rule applies. final Optional<List<String>>businessAccountTokens()Business Account tokens to which the Auth Rule applies. final Optional<String>name()Auth Rule Name final Optional<AuthRuleV2UpdateParams.Body.AccountLevelRule.State>state()The desired state of the Auth Rule. final JsonField<List<String>>_accountTokens()Returns the raw JSON value of accountTokens. final JsonField<List<String>>_businessAccountTokens()Returns the raw JSON value of businessAccountTokens. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AuthRuleV2UpdateParams.Body.AccountLevelRule.State>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2UpdateParams.Body.AccountLevelRule.BuildertoBuilder()final AuthRuleV2UpdateParams.Body.AccountLevelRulevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2UpdateParams.Body.AccountLevelRule.Builderbuilder()Returns a mutable builder for constructing an instance of AccountLevelRule. -
-
Method Detail
-
accountTokens
final Optional<List<String>> accountTokens()
Account tokens to which the Auth Rule applies.
-
businessAccountTokens
final Optional<List<String>> businessAccountTokens()
Business Account tokens to which the Auth Rule applies.
-
state
final Optional<AuthRuleV2UpdateParams.Body.AccountLevelRule.State> state()
The desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
_accountTokens
final JsonField<List<String>> _accountTokens()
Returns the raw JSON value of accountTokens.
Unlike accountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountTokens
final JsonField<List<String>> _businessAccountTokens()
Returns the raw JSON value of businessAccountTokens.
Unlike businessAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AuthRuleV2UpdateParams.Body.AccountLevelRule.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2UpdateParams.Body.AccountLevelRule.Builder toBuilder()
-
validate
final AuthRuleV2UpdateParams.Body.AccountLevelRule validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2UpdateParams.Body.AccountLevelRule.Builder builder()
Returns a mutable builder for constructing an instance of AccountLevelRule.
-
-
-
-