Class AuthRuleV2UpdateParams.Body.CardLevelRule
-
- All Implemented Interfaces:
public final class AuthRuleV2UpdateParams.Body.CardLevelRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2UpdateParams.Body.CardLevelRule.BuilderA builder for CardLevelRule.
public final classAuthRuleV2UpdateParams.Body.CardLevelRule.StateThe desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>cardTokens()Card tokens to which the Auth Rule applies. final Optional<String>name()Auth Rule Name final Optional<AuthRuleV2UpdateParams.Body.CardLevelRule.State>state()The desired state of the Auth Rule. final JsonField<List<String>>_cardTokens()Returns the raw JSON value of cardTokens. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AuthRuleV2UpdateParams.Body.CardLevelRule.State>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2UpdateParams.Body.CardLevelRule.BuildertoBuilder()final AuthRuleV2UpdateParams.Body.CardLevelRulevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2UpdateParams.Body.CardLevelRule.Builderbuilder()Returns a mutable builder for constructing an instance of CardLevelRule. -
-
Method Detail
-
cardTokens
final Optional<List<String>> cardTokens()
Card tokens to which the Auth Rule applies.
-
state
final Optional<AuthRuleV2UpdateParams.Body.CardLevelRule.State> state()
The desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Returns the raw JSON value of cardTokens.
Unlike cardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AuthRuleV2UpdateParams.Body.CardLevelRule.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2UpdateParams.Body.CardLevelRule.Builder toBuilder()
-
validate
final AuthRuleV2UpdateParams.Body.CardLevelRule validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2UpdateParams.Body.CardLevelRule.Builder builder()
Returns a mutable builder for constructing an instance of CardLevelRule.
-
-
-
-