Class AuthRuleV2UpdateParams.Body.ProgramLevelRule
-
- All Implemented Interfaces:
public final class AuthRuleV2UpdateParams.Body.ProgramLevelRule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleV2UpdateParams.Body.ProgramLevelRule.BuilderA builder for ProgramLevelRule.
public final classAuthRuleV2UpdateParams.Body.ProgramLevelRule.StateThe desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>excludedAccountTokens()Account tokens to which the Auth Rule does not apply. final Optional<List<String>>excludedBusinessAccountTokens()Business account tokens to which the Auth Rule does not apply. final Optional<List<String>>excludedCardTokens()Card tokens to which the Auth Rule does not apply. final Optional<String>name()Auth Rule Name final Optional<Boolean>programLevel()Whether the Auth Rule applies to all authorizations on the card program. final Optional<AuthRuleV2UpdateParams.Body.ProgramLevelRule.State>state()The desired state of the Auth Rule. final JsonField<List<String>>_excludedAccountTokens()Returns the raw JSON value of excludedAccountTokens. final JsonField<List<String>>_excludedBusinessAccountTokens()Returns the raw JSON value of excludedBusinessAccountTokens. final JsonField<List<String>>_excludedCardTokens()Returns the raw JSON value of excludedCardTokens. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_programLevel()Returns the raw JSON value of programLevel. final JsonField<AuthRuleV2UpdateParams.Body.ProgramLevelRule.State>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final AuthRuleV2UpdateParams.Body.ProgramLevelRule.BuildertoBuilder()final AuthRuleV2UpdateParams.Body.ProgramLevelRulevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleV2UpdateParams.Body.ProgramLevelRule.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramLevelRule. -
-
Method Detail
-
excludedAccountTokens
final Optional<List<String>> excludedAccountTokens()
Account tokens to which the Auth Rule does not apply.
-
excludedBusinessAccountTokens
final Optional<List<String>> excludedBusinessAccountTokens()
Business account tokens to which the Auth Rule does not apply.
-
excludedCardTokens
final Optional<List<String>> excludedCardTokens()
Card tokens to which the Auth Rule does not apply.
-
programLevel
final Optional<Boolean> programLevel()
Whether the Auth Rule applies to all authorizations on the card program.
-
state
final Optional<AuthRuleV2UpdateParams.Body.ProgramLevelRule.State> state()
The desired state of the Auth Rule.
Note that only deactivating an Auth Rule through this endpoint is supported at this time. If you need to (re-)activate an Auth Rule the /promote endpoint should be used to promote a draft to the currently active version.
-
_excludedAccountTokens
final JsonField<List<String>> _excludedAccountTokens()
Returns the raw JSON value of excludedAccountTokens.
Unlike excludedAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedBusinessAccountTokens
final JsonField<List<String>> _excludedBusinessAccountTokens()
Returns the raw JSON value of excludedBusinessAccountTokens.
Unlike excludedBusinessAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_excludedCardTokens
final JsonField<List<String>> _excludedCardTokens()
Returns the raw JSON value of excludedCardTokens.
Unlike excludedCardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_programLevel
final JsonField<Boolean> _programLevel()
Returns the raw JSON value of programLevel.
Unlike programLevel, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AuthRuleV2UpdateParams.Body.ProgramLevelRule.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleV2UpdateParams.Body.ProgramLevelRule.Builder toBuilder()
-
validate
final AuthRuleV2UpdateParams.Body.ProgramLevelRule validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleV2UpdateParams.Body.ProgramLevelRule.Builder builder()
Returns a mutable builder for constructing an instance of ProgramLevelRule.
-
-
-
-