Class AuthRuleVersion
-
- All Implemented Interfaces:
public final class AuthRuleVersion
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRuleVersion.BuilderA builder for AuthRuleVersion.
public final classAuthRuleVersion.ParametersParameters for the Auth Rule
public final classAuthRuleVersion.AuthRuleVersionStateThe current state of this version.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreated()Timestamp of when this version was created. final AuthRuleVersion.Parametersparameters()Parameters for the Auth Rule final AuthRuleVersion.AuthRuleVersionStatestate()The current state of this version. final Longversion()The version of the rule, this is incremented whenever the rule's parameters change. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<AuthRuleVersion.Parameters>_parameters()Returns the raw JSON value of parameters. final JsonField<AuthRuleVersion.AuthRuleVersionState>_state()Returns the raw JSON value of state. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final AuthRuleVersion.BuildertoBuilder()final AuthRuleVersionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRuleVersion.Builderbuilder()Returns a mutable builder for constructing an instance of AuthRuleVersion. -
-
Method Detail
-
created
final OffsetDateTime created()
Timestamp of when this version was created.
-
parameters
final AuthRuleVersion.Parameters parameters()
Parameters for the Auth Rule
-
state
final AuthRuleVersion.AuthRuleVersionState state()
The current state of this version.
-
version
final Long version()
The version of the rule, this is incremented whenever the rule's parameters change.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_parameters
final JsonField<AuthRuleVersion.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<AuthRuleVersion.AuthRuleVersionState> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRuleVersion.Builder toBuilder()
-
validate
final AuthRuleVersion validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthRuleVersion.Builder builder()
Returns a mutable builder for constructing an instance of AuthRuleVersion.
The following fields are required:
.created() .parameters() .state() .version()
-
-
-
-