Class AuthRulesBacktestReportCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class AuthRulesBacktestReportCreatedWebhookEvent.BuilderA builder for AuthRulesBacktestReportCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
backtestToken
final AuthRulesBacktestReportCreatedWebhookEvent.Builder backtestToken(String backtestToken)
Auth Rule Backtest Token
-
backtestToken
final AuthRulesBacktestReportCreatedWebhookEvent.Builder backtestToken(JsonField<String> backtestToken)
Sets Builder.backtestToken to an arbitrary JSON value.
You should usually call Builder.backtestToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
results
final AuthRulesBacktestReportCreatedWebhookEvent.Builder results(BacktestResults.Results results)
-
results
final AuthRulesBacktestReportCreatedWebhookEvent.Builder results(JsonField<BacktestResults.Results> results)
Sets Builder.results to an arbitrary JSON value.
You should usually call Builder.results with a well-typed BacktestResults.Results value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
simulationParameters
final AuthRulesBacktestReportCreatedWebhookEvent.Builder simulationParameters(BacktestResults.BacktestSimulationParameters simulationParameters)
-
simulationParameters
final AuthRulesBacktestReportCreatedWebhookEvent.Builder simulationParameters(JsonField<BacktestResults.BacktestSimulationParameters> simulationParameters)
Sets Builder.simulationParameters to an arbitrary JSON value.
You should usually call Builder.simulationParameters with a well-typed BacktestResults.BacktestSimulationParameters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final AuthRulesBacktestReportCreatedWebhookEvent.Builder eventType(AuthRulesBacktestReportCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final AuthRulesBacktestReportCreatedWebhookEvent.Builder eventType(JsonField<AuthRulesBacktestReportCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AuthRulesBacktestReportCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AuthRulesBacktestReportCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AuthRulesBacktestReportCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AuthRulesBacktestReportCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AuthRulesBacktestReportCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AuthRulesBacktestReportCreatedWebhookEvent build()
Returns an immutable instance of AuthRulesBacktestReportCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.backtestToken() .results() .simulationParameters() .eventType()
-
-
-
-