Package com.lithic.api.models
Class AuthStreamSecret
-
- All Implemented Interfaces:
public final class AuthStreamSecret
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthStreamSecret.BuilderA builder for AuthStreamSecret.
-
Method Summary
Modifier and Type Method Description final Optional<String>secret()The shared HMAC ASA secret final JsonField<String>_secret()Returns the raw JSON value of secret. final Map<String, JsonValue>_additionalProperties()final AuthStreamSecret.BuildertoBuilder()final AuthStreamSecretvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthStreamSecret.Builderbuilder()Returns a mutable builder for constructing an instance of AuthStreamSecret. -
-
Method Detail
-
_secret
final JsonField<String> _secret()
Returns the raw JSON value of secret.
Unlike secret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthStreamSecret.Builder toBuilder()
-
validate
final AuthStreamSecret validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AuthStreamSecret.Builder builder()
Returns a mutable builder for constructing an instance of AuthStreamSecret.
-
-
-
-