Package com.lithic.api.models
Class BacktestResults
-
- All Implemented Interfaces:
public final class BacktestResults
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestResults.BuilderA builder for BacktestResults.
public final classBacktestResults.Resultspublic final classBacktestResults.BacktestSimulationParameters
-
Method Summary
Modifier and Type Method Description final StringbacktestToken()Auth Rule Backtest Token final BacktestResults.Resultsresults()final BacktestResults.BacktestSimulationParameterssimulationParameters()final JsonField<String>_backtestToken()Returns the raw JSON value of backtestToken. final JsonField<BacktestResults.Results>_results()Returns the raw JSON value of results. final JsonField<BacktestResults.BacktestSimulationParameters>_simulationParameters()Returns the raw JSON value of simulationParameters. final Map<String, JsonValue>_additionalProperties()final BacktestResults.BuildertoBuilder()final BacktestResultsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestResults.Builderbuilder()Returns a mutable builder for constructing an instance of BacktestResults. -
-
Method Detail
-
backtestToken
final String backtestToken()
Auth Rule Backtest Token
-
results
final BacktestResults.Results results()
-
simulationParameters
final BacktestResults.BacktestSimulationParameters simulationParameters()
-
_backtestToken
final JsonField<String> _backtestToken()
Returns the raw JSON value of backtestToken.
Unlike backtestToken, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<BacktestResults.Results> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_simulationParameters
final JsonField<BacktestResults.BacktestSimulationParameters> _simulationParameters()
Returns the raw JSON value of simulationParameters.
Unlike simulationParameters, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestResults.Builder toBuilder()
-
validate
final BacktestResults validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BacktestResults.Builder builder()
Returns a mutable builder for constructing an instance of BacktestResults.
The following fields are required:
.backtestToken() .results() .simulationParameters()
-
-
-
-