Package com.lithic.api.models
Class BacktestResults.Results
-
- All Implemented Interfaces:
public final class BacktestResults.Results
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestResults.Results.BuilderA builder for Results.
-
Method Summary
Modifier and Type Method Description final Optional<BacktestStats>currentVersion()final Optional<BacktestStats>draftVersion()final JsonField<BacktestStats>_currentVersion()Returns the raw JSON value of currentVersion. final JsonField<BacktestStats>_draftVersion()Returns the raw JSON value of draftVersion. final Map<String, JsonValue>_additionalProperties()final BacktestResults.Results.BuildertoBuilder()final BacktestResults.Resultsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestResults.Results.Builderbuilder()Returns a mutable builder for constructing an instance of Results. -
-
Method Detail
-
currentVersion
final Optional<BacktestStats> currentVersion()
-
draftVersion
final Optional<BacktestStats> draftVersion()
-
_currentVersion
final JsonField<BacktestStats> _currentVersion()
Returns the raw JSON value of currentVersion.
Unlike currentVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_draftVersion
final JsonField<BacktestStats> _draftVersion()
Returns the raw JSON value of draftVersion.
Unlike draftVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestResults.Results.Builder toBuilder()
-
validate
final BacktestResults.Results validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BacktestResults.Results.Builder builder()
Returns a mutable builder for constructing an instance of Results.
-
-
-
-