Class BacktestStats
-
- All Implemented Interfaces:
public final class BacktestStats
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestStats.BuilderA builder for BacktestStats.
public final classBacktestStats.Example
-
Method Summary
Modifier and Type Method Description final Optional<Long>approved()The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode. final Optional<Long>challenged()The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. final Optional<Long>declined()The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode. final Optional<List<BacktestStats.Example>>examples()Example events and their outcomes. final Optional<Long>version()The version of the rule, this is incremented whenever the rule's parameters change. final JsonField<Long>_approved()Returns the raw JSON value of approved. final JsonField<Long>_challenged()Returns the raw JSON value of challenged. final JsonField<Long>_declined()Returns the raw JSON value of declined. final JsonField<List<BacktestStats.Example>>_examples()Returns the raw JSON value of examples. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final BacktestStats.BuildertoBuilder()final BacktestStatsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestStats.Builderbuilder()Returns a mutable builder for constructing an instance of BacktestStats. -
-
Method Detail
-
approved
final Optional<Long> approved()
The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
challenged
final Optional<Long> challenged()
The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
-
declined
final Optional<Long> declined()
The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
examples
final Optional<List<BacktestStats.Example>> examples()
Example events and their outcomes.
-
version
final Optional<Long> version()
The version of the rule, this is incremented whenever the rule's parameters change.
-
_approved
final JsonField<Long> _approved()
Returns the raw JSON value of approved.
Unlike approved, this method doesn't throw if the JSON field has an unexpected type.
-
_challenged
final JsonField<Long> _challenged()
Returns the raw JSON value of challenged.
Unlike challenged, this method doesn't throw if the JSON field has an unexpected type.
-
_declined
final JsonField<Long> _declined()
Returns the raw JSON value of declined.
Unlike declined, this method doesn't throw if the JSON field has an unexpected type.
-
_examples
final JsonField<List<BacktestStats.Example>> _examples()
Returns the raw JSON value of examples.
Unlike examples, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestStats.Builder toBuilder()
-
validate
final BacktestStats validate()
-
builder
final static BacktestStats.Builder builder()
Returns a mutable builder for constructing an instance of BacktestStats.
-
-
-
-