Class BacktestStats.Builder
-
- All Implemented Interfaces:
public final class BacktestStats.BuilderA builder for BacktestStats.
-
-
Method Summary
Modifier and Type Method Description final BacktestStats.Builderapproved(Long approved)The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode. final BacktestStats.Builderapproved(JsonField<Long> approved)Sets Builder.approved to an arbitrary JSON value. final BacktestStats.Builderchallenged(Long challenged)The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. final BacktestStats.Builderchallenged(JsonField<Long> challenged)Sets Builder.challenged to an arbitrary JSON value. final BacktestStats.Builderdeclined(Long declined)The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode. final BacktestStats.Builderdeclined(JsonField<Long> declined)Sets Builder.declined to an arbitrary JSON value. final BacktestStats.Builderexamples(List<BacktestStats.Example> examples)Example events and their outcomes. final BacktestStats.Builderexamples(JsonField<List<BacktestStats.Example>> examples)Sets Builder.examples to an arbitrary JSON value. final BacktestStats.BuilderaddExample(BacktestStats.Example example)Adds a single Example to examples. final BacktestStats.Builderversion(Long version)The version of the rule, this is incremented whenever the rule's parameters change. final BacktestStats.Builderversion(JsonField<Long> version)Sets Builder.version to an arbitrary JSON value. final BacktestStats.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BacktestStats.BuilderputAdditionalProperty(String key, JsonValue value)final BacktestStats.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BacktestStats.BuilderremoveAdditionalProperty(String key)final BacktestStats.BuilderremoveAllAdditionalProperties(Set<String> keys)final BacktestStatsbuild()Returns an immutable instance of BacktestStats. -
-
Method Detail
-
approved
final BacktestStats.Builder approved(Long approved)
The total number of historical transactions approved by this rule during the backtest period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
approved
final BacktestStats.Builder approved(JsonField<Long> approved)
Sets Builder.approved to an arbitrary JSON value.
You should usually call Builder.approved with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challenged
final BacktestStats.Builder challenged(Long challenged)
The total number of historical transactions challenged by this rule during the backtest period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
-
challenged
final BacktestStats.Builder challenged(JsonField<Long> challenged)
Sets Builder.challenged to an arbitrary JSON value.
You should usually call Builder.challenged with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declined
final BacktestStats.Builder declined(Long declined)
The total number of historical transactions declined by this rule during the backtest period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
declined
final BacktestStats.Builder declined(JsonField<Long> declined)
Sets Builder.declined to an arbitrary JSON value.
You should usually call Builder.declined with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
examples
final BacktestStats.Builder examples(List<BacktestStats.Example> examples)
Example events and their outcomes.
-
examples
final BacktestStats.Builder examples(JsonField<List<BacktestStats.Example>> examples)
Sets Builder.examples to an arbitrary JSON value.
You should usually call Builder.examples with a well-typed
List<Example>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExample
final BacktestStats.Builder addExample(BacktestStats.Example example)
-
version
final BacktestStats.Builder version(Long version)
The version of the rule, this is incremented whenever the rule's parameters change.
-
version
final BacktestStats.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BacktestStats.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BacktestStats.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BacktestStats.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BacktestStats.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BacktestStats.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BacktestStats build()
Returns an immutable instance of BacktestStats.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-