Package com.lithic.api.models
Class BalanceListPageAsync.Builder
-
- All Implemented Interfaces:
public final class BalanceListPageAsync.BuilderA builder for BalanceListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final BalanceListPageAsync.Builderservice(BalanceServiceAsync service)final BalanceListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final BalanceListPageAsync.Builderparams(BalanceListParams params)The parameters that were used to request this page. final BalanceListPageAsync.Builderresponse(BalanceListPageResponse response)The response that this page was parsed from. final BalanceListPageAsyncbuild()Returns an immutable instance of BalanceListPageAsync. -
-
Method Detail
-
service
final BalanceListPageAsync.Builder service(BalanceServiceAsync service)
-
streamHandlerExecutor
final BalanceListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final BalanceListPageAsync.Builder params(BalanceListParams params)
The parameters that were used to request this page.
-
response
final BalanceListPageAsync.Builder response(BalanceListPageResponse response)
The response that this page was parsed from.
-
build
final BalanceListPageAsync build()
Returns an immutable instance of BalanceListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-