Package com.lithic.api.models
Class BalanceListPageResponse
-
- All Implemented Interfaces:
public final class BalanceListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceListPageResponse.BuilderA builder for BalanceListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Balance>data()final BooleanhasMore()More data exists. final JsonField<List<Balance>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final BalanceListPageResponse.BuildertoBuilder()final BalanceListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Balance>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BalanceListPageResponse.Builder toBuilder()
-
validate
final BalanceListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BalanceListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of BalanceListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-