Class BalanceUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class BalanceUpdatedWebhookEvent.BuilderA builder for BalanceUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
data
final BalanceUpdatedWebhookEvent.Builder data(List<FinancialAccountBalance> data)
-
data
final BalanceUpdatedWebhookEvent.Builder data(JsonField<List<FinancialAccountBalance>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<FinancialAccountBalance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final BalanceUpdatedWebhookEvent.Builder addData(FinancialAccountBalance data)
Adds a single FinancialAccountBalance to Builder.data.
-
eventType
final BalanceUpdatedWebhookEvent.Builder eventType(BalanceUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final BalanceUpdatedWebhookEvent.Builder eventType(JsonField<BalanceUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BalanceUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BalanceUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BalanceUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BalanceUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BalanceUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BalanceUpdatedWebhookEvent build()
Returns an immutable instance of BalanceUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .eventType()
-
-
-
-