Class BookTransferCreateParams.CreateBookTransferRequest
-
- All Implemented Interfaces:
public final class BookTransferCreateParams.CreateBookTransferRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferCreateParams.CreateBookTransferRequest.BuilderA builder for CreateBookTransferRequest.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount to be transferred in the currency's smallest unit (e.g., cents for USD). final BookTransferCreateParams.BookTransferCategorycategory()final StringfromFinancialAccountToken()Globally unique identifier for the financial account or card that will send the funds. final Stringsubtype()The program specific subtype code for the specified category/type. final StringtoFinancialAccountToken()Globally unique identifier for the financial account or card that will receive the funds. final BookTransferCreateParams.BookTransferTypetype()Type of the book transfer final Optional<String>token()Customer-provided token that will serve as an idempotency token. final Optional<String>externalId()External ID defined by the customer final Optional<String>holdToken()Token of an existing hold to settle when this transfer is initiated final Optional<String>memo()Optional descriptor for the transfer. final Optional<BookTransferCreateParams.OnClosedAccount>onClosedAccount()What to do if the financial account is closed when posting an operation final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<BookTransferCreateParams.BookTransferCategory>_category()Returns the raw JSON value of category. final JsonField<String>_fromFinancialAccountToken()Returns the raw JSON value of fromFinancialAccountToken. final JsonField<String>_subtype()Returns the raw JSON value of subtype. final JsonField<String>_toFinancialAccountToken()Returns the raw JSON value of toFinancialAccountToken. final JsonField<BookTransferCreateParams.BookTransferType>_type()Returns the raw JSON value of type. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<String>_holdToken()Returns the raw JSON value of holdToken. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<BookTransferCreateParams.OnClosedAccount>_onClosedAccount()Returns the raw JSON value of onClosedAccount. final Map<String, JsonValue>_additionalProperties()final BookTransferCreateParams.CreateBookTransferRequest.BuildertoBuilder()final BookTransferCreateParams.CreateBookTransferRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferCreateParams.CreateBookTransferRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateBookTransferRequest. -
-
Method Detail
-
amount
final Long amount()
Amount to be transferred in the currency's smallest unit (e.g., cents for USD). This should always be a positive value.
-
category
final BookTransferCreateParams.BookTransferCategory category()
-
fromFinancialAccountToken
final String fromFinancialAccountToken()
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
toFinancialAccountToken
final String toFinancialAccountToken()
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case.
-
type
final BookTransferCreateParams.BookTransferType type()
Type of the book transfer
-
token
final Optional<String> token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
externalId
final Optional<String> externalId()
External ID defined by the customer
-
holdToken
final Optional<String> holdToken()
Token of an existing hold to settle when this transfer is initiated
-
onClosedAccount
final Optional<BookTransferCreateParams.OnClosedAccount> onClosedAccount()
What to do if the financial account is closed when posting an operation
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<BookTransferCreateParams.BookTransferCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_fromFinancialAccountToken
final JsonField<String> _fromFinancialAccountToken()
Returns the raw JSON value of fromFinancialAccountToken.
Unlike fromFinancialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_toFinancialAccountToken
final JsonField<String> _toFinancialAccountToken()
Returns the raw JSON value of toFinancialAccountToken.
Unlike toFinancialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BookTransferCreateParams.BookTransferType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_holdToken
final JsonField<String> _holdToken()
Returns the raw JSON value of holdToken.
Unlike holdToken, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_onClosedAccount
final JsonField<BookTransferCreateParams.OnClosedAccount> _onClosedAccount()
Returns the raw JSON value of onClosedAccount.
Unlike onClosedAccount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferCreateParams.CreateBookTransferRequest.Builder toBuilder()
-
validate
final BookTransferCreateParams.CreateBookTransferRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BookTransferCreateParams.CreateBookTransferRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateBookTransferRequest.
The following fields are required:
.amount() .category() .fromFinancialAccountToken() .subtype() .toFinancialAccountToken() .type()
-
-
-
-