Package com.lithic.api.models
Class BookTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class BookTransferListPageAsync.BuilderA builder for BookTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final BookTransferListPageAsync.Builderservice(BookTransferServiceAsync service)final BookTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final BookTransferListPageAsync.Builderparams(BookTransferListParams params)The parameters that were used to request this page. final BookTransferListPageAsync.Builderresponse(BookTransferListPageResponse response)The response that this page was parsed from. final BookTransferListPageAsyncbuild()Returns an immutable instance of BookTransferListPageAsync. -
-
Method Detail
-
service
final BookTransferListPageAsync.Builder service(BookTransferServiceAsync service)
-
streamHandlerExecutor
final BookTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final BookTransferListPageAsync.Builder params(BookTransferListParams params)
The parameters that were used to request this page.
-
response
final BookTransferListPageAsync.Builder response(BookTransferListPageResponse response)
The response that this page was parsed from.
-
build
final BookTransferListPageAsync build()
Returns an immutable instance of BookTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-