Class BookTransferResponse.TransactionSeries
-
- All Implemented Interfaces:
public final class BookTransferResponse.TransactionSeriesA series of transactions that are grouped together
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferResponse.TransactionSeries.BuilderA builder for TransactionSeries.
-
Method Summary
Modifier and Type Method Description final Optional<String>relatedTransactionEventToken()final Optional<String>relatedTransactionToken()final Stringtype()final JsonField<String>_relatedTransactionEventToken()Returns the raw JSON value of relatedTransactionEventToken. final JsonField<String>_relatedTransactionToken()Returns the raw JSON value of relatedTransactionToken. final JsonField<String>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BookTransferResponse.TransactionSeries.BuildertoBuilder()final BookTransferResponse.TransactionSeriesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferResponse.TransactionSeries.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSeries. -
-
Method Detail
-
relatedTransactionEventToken
final Optional<String> relatedTransactionEventToken()
-
relatedTransactionToken
final Optional<String> relatedTransactionToken()
-
_relatedTransactionEventToken
final JsonField<String> _relatedTransactionEventToken()
Returns the raw JSON value of relatedTransactionEventToken.
Unlike relatedTransactionEventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_relatedTransactionToken
final JsonField<String> _relatedTransactionToken()
Returns the raw JSON value of relatedTransactionToken.
Unlike relatedTransactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferResponse.TransactionSeries.Builder toBuilder()
-
validate
final BookTransferResponse.TransactionSeries validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BookTransferResponse.TransactionSeries.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSeries.
The following fields are required:
.relatedTransactionEventToken() .relatedTransactionToken() .type()
-
-
-
-