Package com.lithic.api.models
Class BookTransferRetryParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class BookTransferRetryParams implements Params
Retry a book transfer that has been declined
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferRetryParams.BuilderA builder for BookTransferRetryParams.
public final classBookTransferRetryParams.RetryBookTransferRequest
-
Method Summary
Modifier and Type Method Description final Optional<String>bookTransferToken()final StringretryToken()Customer-provided token that will serve as an idempotency token. final JsonField<String>_retryToken()Returns the raw JSON value of retryToken. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookTransferRetryParams.BuildertoBuilder()final BookTransferRetryParams.RetryBookTransferRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferRetryParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferRetryParams. -
-
Method Detail
-
bookTransferToken
final Optional<String> bookTransferToken()
-
retryToken
final String retryToken()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
_retryToken
final JsonField<String> _retryToken()
Returns the raw JSON value of retryToken.
Unlike retryToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookTransferRetryParams.Builder toBuilder()
-
_body
final BookTransferRetryParams.RetryBookTransferRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static BookTransferRetryParams.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferRetryParams.
The following fields are required:
.retryToken()
-
-
-
-