Package com.lithic.api.models
Class BookTransferRetryParams.RetryBookTransferRequest
-
- All Implemented Interfaces:
public final class BookTransferRetryParams.RetryBookTransferRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferRetryParams.RetryBookTransferRequest.BuilderA builder for RetryBookTransferRequest.
-
Method Summary
Modifier and Type Method Description final StringretryToken()Customer-provided token that will serve as an idempotency token. final JsonField<String>_retryToken()Returns the raw JSON value of retryToken. final Map<String, JsonValue>_additionalProperties()final BookTransferRetryParams.RetryBookTransferRequest.BuildertoBuilder()final BookTransferRetryParams.RetryBookTransferRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferRetryParams.RetryBookTransferRequest.Builderbuilder()Returns a mutable builder for constructing an instance of RetryBookTransferRequest. -
-
Method Detail
-
retryToken
final String retryToken()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
_retryToken
final JsonField<String> _retryToken()
Returns the raw JSON value of retryToken.
Unlike retryToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferRetryParams.RetryBookTransferRequest.Builder toBuilder()
-
validate
final BookTransferRetryParams.RetryBookTransferRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BookTransferRetryParams.RetryBookTransferRequest.Builder builder()
Returns a mutable builder for constructing an instance of RetryBookTransferRequest.
The following fields are required:
.retryToken()
-
-
-
-