Package com.lithic.api.models
Class BookTransferReverseParams.Body
-
- All Implemented Interfaces:
public final class BookTransferReverseParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferReverseParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>memo()Optional descriptor for the reversal. final JsonField<String>_memo()Returns the raw JSON value of memo. final Map<String, JsonValue>_additionalProperties()final BookTransferReverseParams.Body.BuildertoBuilder()final BookTransferReverseParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferReverseParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferReverseParams.Body.Builder toBuilder()
-
validate
final BookTransferReverseParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BookTransferReverseParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-