Class BookTransferTransactionCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class BookTransferTransactionCreatedWebhookEventBook transfer transaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookTransferTransactionCreatedWebhookEvent.BuilderA builder for BookTransferTransactionCreatedWebhookEvent.
public final classBookTransferTransactionCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final BookTransferResponsetoBookTransferResponse()final Stringtoken()Unique identifier for the transaction final BookTransferResponse.BookTransferCategorycategory()final OffsetDateTimecreated()ISO 8601 timestamp of when the transaction was created final Stringcurrency()3-character alphabetic ISO 4217 code for the settling currency of the transaction final List<BookTransferResponse.BookTransferEvent>events()A list of all financial events that have modified this transfer final BookTransferResponse.Familyfamily()TRANSFER - Book Transfer Transaction final StringfromFinancialAccountToken()Globally unique identifier for the financial account or card that will send the funds. final LongpendingAmount()Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final BookTransferResponse.TransactionResultresult()final LongsettledAmount()Amount of the transaction that has been settled in the currency's smallest unit (e.g. final BookTransferResponse.TransactionStatusstatus()The status of the transaction final StringtoFinancialAccountToken()Globally unique identifier for the financial account or card that will receive the funds. final OffsetDateTimeupdated()ISO 8601 timestamp of when the transaction was last updated final Optional<String>externalId()External ID defined by the customer final Optional<ExternalResource>externalResource()External resource associated with the management operation final Optional<BookTransferResponse.TransactionSeries>transactionSeries()A series of transactions that are grouped together final BookTransferTransactionCreatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<BookTransferResponse.BookTransferCategory>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<List<BookTransferResponse.BookTransferEvent>>_events()Returns the raw JSON value of events. final JsonField<BookTransferResponse.Family>_family()Returns the raw JSON value of family. final JsonField<String>_fromFinancialAccountToken()Returns the raw JSON value of fromFinancialAccountToken. final JsonField<Long>_pendingAmount()Returns the raw JSON value of pendingAmount. final JsonField<BookTransferResponse.TransactionResult>_result()Returns the raw JSON value of result. final JsonField<Long>_settledAmount()Returns the raw JSON value of settledAmount. final JsonField<BookTransferResponse.TransactionStatus>_status()Returns the raw JSON value of status. final JsonField<String>_toFinancialAccountToken()Returns the raw JSON value of toFinancialAccountToken. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<ExternalResource>_externalResource()Returns the raw JSON value of externalResource. final JsonField<BookTransferResponse.TransactionSeries>_transactionSeries()Returns the raw JSON value of transactionSeries. final JsonField<BookTransferTransactionCreatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final BookTransferTransactionCreatedWebhookEvent.BuildertoBuilder()final BookTransferTransactionCreatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookTransferTransactionCreatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BookTransferTransactionCreatedWebhookEvent. -
-
Method Detail
-
toBookTransferResponse
final BookTransferResponse toBookTransferResponse()
-
category
final BookTransferResponse.BookTransferCategory category()
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction
-
events
final List<BookTransferResponse.BookTransferEvent> events()
A list of all financial events that have modified this transfer
-
family
final BookTransferResponse.Family family()
TRANSFER - Book Transfer Transaction
-
fromFinancialAccountToken
final String fromFinancialAccountToken()
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case
-
pendingAmount
final Long pendingAmount()
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees.
The value of this field will go to zero over time once the financial transaction is settled.
-
result
final BookTransferResponse.TransactionResult result()
-
settledAmount
final Long settledAmount()
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents)
-
status
final BookTransferResponse.TransactionStatus status()
The status of the transaction
-
toFinancialAccountToken
final String toFinancialAccountToken()
Globally unique identifier for the financial account or card that will receive the funds. Accepted type dependent on the program's use case
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
externalId
final Optional<String> externalId()
External ID defined by the customer
-
externalResource
final Optional<ExternalResource> externalResource()
External resource associated with the management operation
-
transactionSeries
final Optional<BookTransferResponse.TransactionSeries> transactionSeries()
A series of transactions that are grouped together
-
eventType
final BookTransferTransactionCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<BookTransferResponse.BookTransferCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<BookTransferResponse.BookTransferEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<BookTransferResponse.Family> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_fromFinancialAccountToken
final JsonField<String> _fromFinancialAccountToken()
Returns the raw JSON value of fromFinancialAccountToken.
Unlike fromFinancialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<BookTransferResponse.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<BookTransferResponse.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_toFinancialAccountToken
final JsonField<String> _toFinancialAccountToken()
Returns the raw JSON value of toFinancialAccountToken.
Unlike toFinancialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_externalResource
final JsonField<ExternalResource> _externalResource()
Returns the raw JSON value of externalResource.
Unlike externalResource, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionSeries
final JsonField<BookTransferResponse.TransactionSeries> _transactionSeries()
Returns the raw JSON value of transactionSeries.
Unlike transactionSeries, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<BookTransferTransactionCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookTransferTransactionCreatedWebhookEvent.Builder toBuilder()
-
validate
final BookTransferTransactionCreatedWebhookEvent validate()
-
builder
final static BookTransferTransactionCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of BookTransferTransactionCreatedWebhookEvent.
The following fields are required:
.token() .category() .created() .currency() .events() .family() .fromFinancialAccountToken() .pendingAmount() .result() .settledAmount() .status() .toFinancialAccountToken() .updated() .eventType()
-
-
-
-