Class CardAuthorization.AsaNetworkSpecificData
-
- All Implemented Interfaces:
public final class CardAuthorization.AsaNetworkSpecificDataContains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.AsaNetworkSpecificData.BuilderA builder for AsaNetworkSpecificData.
public final classCardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercardpublic final classCardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa
-
Method Summary
-
-
Method Detail
-
mastercard
final Optional<CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> mastercard()
-
_mastercard
final JsonField<CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard> _mastercard()
Returns the raw JSON value of mastercard.
Unlike mastercard, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataVisa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.AsaNetworkSpecificData.Builder toBuilder()
-
validate
final CardAuthorization.AsaNetworkSpecificData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.AsaNetworkSpecificData.Builder builder()
Returns a mutable builder for constructing an instance of AsaNetworkSpecificData.
-
-
-
-