Package com.lithic.api.models
Class CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult
-
- All Implemented Interfaces:
public final class CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult.BuilderA builder for OnBehalfServiceResult.
-
Method Summary
Modifier and Type Method Description final Stringresult1()Indicates the results of the service processing. final Stringresult2()Identifies the results of the service processing. final Stringservice()Indicates the service performed on the transaction. final JsonField<String>_result1()Returns the raw JSON value of result1. final JsonField<String>_result2()Returns the raw JSON value of result2. final JsonField<String>_service()Returns the raw JSON value of service. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult.BuildertoBuilder()final CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult.Builderbuilder()Returns a mutable builder for constructing an instance of OnBehalfServiceResult. -
-
Method Detail
-
_result1
final JsonField<String> _result1()
Returns the raw JSON value of result1.
Unlike result1, this method doesn't throw if the JSON field has an unexpected type.
-
_result2
final JsonField<String> _result2()
Returns the raw JSON value of result2.
Unlike result2, this method doesn't throw if the JSON field has an unexpected type.
-
_service
final JsonField<String> _service()
Returns the raw JSON value of service.
Unlike service, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult.Builder toBuilder()
-
validate
final CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult.Builder builder()
Returns a mutable builder for constructing an instance of OnBehalfServiceResult.
The following fields are required:
.result1() .result2() .service()
-
-
-
-