Class CardAuthorization.AsaRequestCard
-
- All Implemented Interfaces:
public final class CardAuthorization.AsaRequestCardCard object in ASA
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.AsaRequestCard.BuilderA builder for AsaRequestCard.
public final classCardAuthorization.AsaRequestCard.SpendLimitDurationNote that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
public final classCardAuthorization.AsaRequestCard.Statepublic final classCardAuthorization.AsaRequestCard.CardType
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the card. final StringlastFour()Last four digits of the card number final Stringmemo()Customizable name to identify the card final LongspendLimit()Amount (in cents) to limit approved authorizations. final CardAuthorization.AsaRequestCard.SpendLimitDurationspendLimitDuration()Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior. final CardAuthorization.AsaRequestCard.Statestate()final CardAuthorization.AsaRequestCard.CardTypetype()final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_lastFour()Returns the raw JSON value of lastFour. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<Long>_spendLimit()Returns the raw JSON value of spendLimit. final JsonField<CardAuthorization.AsaRequestCard.SpendLimitDuration>_spendLimitDuration()Returns the raw JSON value of spendLimitDuration. final JsonField<CardAuthorization.AsaRequestCard.State>_state()Returns the raw JSON value of state. final JsonField<CardAuthorization.AsaRequestCard.CardType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.AsaRequestCard.BuildertoBuilder()final CardAuthorization.AsaRequestCardvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.AsaRequestCard.Builderbuilder()Returns a mutable builder for constructing an instance of AsaRequestCard. -
-
Method Detail
-
spendLimit
final Long spendLimit()
Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).
Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).
-
spendLimitDuration
final CardAuthorization.AsaRequestCard.SpendLimitDuration spendLimitDuration()
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
-
state
final CardAuthorization.AsaRequestCard.State state()
-
type
final CardAuthorization.AsaRequestCard.CardType type()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_lastFour
final JsonField<String> _lastFour()
Returns the raw JSON value of lastFour.
Unlike lastFour, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimit
final JsonField<Long> _spendLimit()
Returns the raw JSON value of spendLimit.
Unlike spendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimitDuration
final JsonField<CardAuthorization.AsaRequestCard.SpendLimitDuration> _spendLimitDuration()
Returns the raw JSON value of spendLimitDuration.
Unlike spendLimitDuration, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<CardAuthorization.AsaRequestCard.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardAuthorization.AsaRequestCard.CardType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.AsaRequestCard.Builder toBuilder()
-
validate
final CardAuthorization.AsaRequestCard validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.AsaRequestCard.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestCard.
The following fields are required:
.token() .lastFour() .memo() .spendLimit() .spendLimitDuration() .state() .type()
-
-
-
-