Class CardAuthorization.AsaRequestFleetInfo
-
- All Implemented Interfaces:
public final class CardAuthorization.AsaRequestFleetInfoOptional Object containing information if the Card is a part of a Fleet managed program
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.AsaRequestFleetInfo.BuilderA builder for AsaRequestFleetInfo.
public final classCardAuthorization.AsaRequestFleetInfo.FleetPromptCodeCode indicating what the driver was prompted to enter at time of purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis
public final classCardAuthorization.AsaRequestFleetInfo.FleetRestrictionCodeCode indicating which restrictions, if any, there are on purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis
-
Method Summary
-
-
Method Detail
-
fleetPromptCode
final CardAuthorization.AsaRequestFleetInfo.FleetPromptCode fleetPromptCode()
Code indicating what the driver was prompted to enter at time of purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis
-
fleetRestrictionCode
final CardAuthorization.AsaRequestFleetInfo.FleetRestrictionCode fleetRestrictionCode()
Code indicating which restrictions, if any, there are on purchase. This is configured at a program level and is a static configuration, and does not change on a request to request basis
-
driverNumber
final Optional<String> driverNumber()
Number representing the driver
-
vehicleNumber
final Optional<String> vehicleNumber()
Number associated with the vehicle
-
_fleetPromptCode
final JsonField<CardAuthorization.AsaRequestFleetInfo.FleetPromptCode> _fleetPromptCode()
Returns the raw JSON value of fleetPromptCode.
Unlike fleetPromptCode, this method doesn't throw if the JSON field has an unexpected type.
-
_fleetRestrictionCode
final JsonField<CardAuthorization.AsaRequestFleetInfo.FleetRestrictionCode> _fleetRestrictionCode()
Returns the raw JSON value of fleetRestrictionCode.
Unlike fleetRestrictionCode, this method doesn't throw if the JSON field has an unexpected type.
-
_driverNumber
final JsonField<String> _driverNumber()
Returns the raw JSON value of driverNumber.
Unlike driverNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_vehicleNumber
final JsonField<String> _vehicleNumber()
Returns the raw JSON value of vehicleNumber.
Unlike vehicleNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.AsaRequestFleetInfo.Builder toBuilder()
-
validate
final CardAuthorization.AsaRequestFleetInfo validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.AsaRequestFleetInfo.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestFleetInfo.
The following fields are required:
.fleetPromptCode() .fleetRestrictionCode()
-
-
-
-