Class CardAuthorization.LatestChallenge
-
- All Implemented Interfaces:
public final class CardAuthorization.LatestChallengeThe latest Authorization Challenge that was issued to the cardholder for this merchant.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.LatestChallenge.BuilderA builder for LatestChallenge.
public final classCardAuthorization.LatestChallenge.MethodThe method used to deliver the challenge to the cardholder
SMS- Challenge was delivered via SMSOUT_OF_BAND- Challenge was delivered via an out-of-band method
public final classCardAuthorization.LatestChallenge.StatusThe status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderDECLINED- Challenge was declined by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>completedAt()The date and time when the Authorization Challenge was completed in UTC. final OffsetDateTimecreated()The date and time when the Authorization Challenge was created in UTC final CardAuthorization.LatestChallenge.Methodmethod()The method used to deliver the challenge to the cardholder SMS- Challenge was delivered via SMSOUT_OF_BAND- Challenge was delivered via an out-of-band method
final Optional<String>phoneNumber()The phone number used for sending the Authorization Challenge. final CardAuthorization.LatestChallenge.Statusstatus()The status of the Authorization Challenge COMPLETED- Challenge was successfully completed by the cardholderDECLINED- Challenge was declined by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<CardAuthorization.LatestChallenge.Method>_method()Returns the raw JSON value of method. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<CardAuthorization.LatestChallenge.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.LatestChallenge.BuildertoBuilder()final CardAuthorization.LatestChallengevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.LatestChallenge.Builderbuilder()Returns a mutable builder for constructing an instance of LatestChallenge. -
-
Method Detail
-
completedAt
final Optional<OffsetDateTime> completedAt()
The date and time when the Authorization Challenge was completed in UTC. Filled only if the challenge has been completed.
-
created
final OffsetDateTime created()
The date and time when the Authorization Challenge was created in UTC
-
method
final CardAuthorization.LatestChallenge.Method method()
The method used to deliver the challenge to the cardholder
SMS- Challenge was delivered via SMSOUT_OF_BAND- Challenge was delivered via an out-of-band method
-
phoneNumber
final Optional<String> phoneNumber()
The phone number used for sending the Authorization Challenge. Present only when the challenge method is
SMS.
-
status
final CardAuthorization.LatestChallenge.Status status()
The status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderDECLINED- Challenge was declined by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<CardAuthorization.LatestChallenge.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardAuthorization.LatestChallenge.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.LatestChallenge.Builder toBuilder()
-
validate
final CardAuthorization.LatestChallenge validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.LatestChallenge.Builder builder()
Returns a mutable builder for constructing an instance of LatestChallenge.
The following fields are required:
.completedAt() .created() .method() .phoneNumber() .status()
-
-
-