Class CardAuthorization.LatestChallenge.Builder
-
- All Implemented Interfaces:
public final class CardAuthorization.LatestChallenge.BuilderA builder for LatestChallenge.
-
-
Method Summary
-
-
Method Detail
-
completedAt
final CardAuthorization.LatestChallenge.Builder completedAt(OffsetDateTime completedAt)
The date and time when the Authorization Challenge was completed in UTC. Filled only if the challenge has been completed.
-
completedAt
final CardAuthorization.LatestChallenge.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final CardAuthorization.LatestChallenge.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final CardAuthorization.LatestChallenge.Builder created(OffsetDateTime created)
The date and time when the Authorization Challenge was created in UTC
-
created
final CardAuthorization.LatestChallenge.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
method
final CardAuthorization.LatestChallenge.Builder method(CardAuthorization.LatestChallenge.Method method)
The method used to deliver the challenge to the cardholder
SMS- Challenge was delivered via SMSOUT_OF_BAND- Challenge was delivered via an out-of-band method
-
method
final CardAuthorization.LatestChallenge.Builder method(JsonField<CardAuthorization.LatestChallenge.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final CardAuthorization.LatestChallenge.Builder phoneNumber(String phoneNumber)
The phone number used for sending the Authorization Challenge. Present only when the challenge method is
SMS.
-
phoneNumber
final CardAuthorization.LatestChallenge.Builder phoneNumber(Optional<String> phoneNumber)
Alias for calling Builder.phoneNumber with
phoneNumber.orElse(null).
-
phoneNumber
final CardAuthorization.LatestChallenge.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardAuthorization.LatestChallenge.Builder status(CardAuthorization.LatestChallenge.Status status)
The status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderDECLINED- Challenge was declined by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
status
final CardAuthorization.LatestChallenge.Builder status(JsonField<CardAuthorization.LatestChallenge.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorization.LatestChallenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorization.LatestChallenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorization.LatestChallenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorization.LatestChallenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorization.LatestChallenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorization.LatestChallenge build()
Returns an immutable instance of LatestChallenge.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.completedAt() .created() .method() .phoneNumber() .status()
-
-
-
-