Class CardAuthorization.NameValidation

  • All Implemented Interfaces:

    
    public final class CardAuthorization.NameValidation
    
                        

    Network name validation data, present when the card network requested name validation for this transaction. Contains the cardholder name provided by the network and Lithic's computed match result against KYC data on file.