Package com.lithic.api.models
Class CardAuthorization.NameValidation.Name
-
- All Implemented Interfaces:
public final class CardAuthorization.NameValidation.NameCardholder name as provided by the card network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.NameValidation.Name.BuilderA builder for Name.
-
Method Summary
Modifier and Type Method Description final Stringfirst()First name final Stringlast()Last name final Optional<String>middle()Middle name final JsonField<String>_first()Returns the raw JSON value of first. final JsonField<String>_last()Returns the raw JSON value of last. final JsonField<String>_middle()Returns the raw JSON value of middle. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.NameValidation.Name.BuildertoBuilder()final CardAuthorization.NameValidation.Namevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.NameValidation.Name.Builderbuilder()Returns a mutable builder for constructing an instance of Name. -
-
Method Detail
-
_first
final JsonField<String> _first()
Returns the raw JSON value of first.
Unlike first, this method doesn't throw if the JSON field has an unexpected type.
-
_last
final JsonField<String> _last()
Returns the raw JSON value of last.
Unlike last, this method doesn't throw if the JSON field has an unexpected type.
-
_middle
final JsonField<String> _middle()
Returns the raw JSON value of middle.
Unlike middle, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.NameValidation.Name.Builder toBuilder()
-
validate
final CardAuthorization.NameValidation.Name validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.NameValidation.Name.Builder builder()
Returns a mutable builder for constructing an instance of Name.
The following fields are required:
.first() .last() .middle()
-
-
-
-