Class CardAuthorizationApprovalRequestWebhookEvent
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEventThe Auth Stream Access request payload that was sent to the ASA responder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.BuilderA builder for CardAuthorizationApprovalRequestWebhookEvent.
public final classCardAuthorizationApprovalRequestWebhookEvent.EventType
-
Method Summary
Modifier and Type Method Description final CardAuthorizationtoCardAuthorization()final Stringtoken()The provisional transaction group uuid associated with the authorization final LongacquirerFee()Fee (in cents) assessed by the merchant and paid for by the cardholder. final Longamount()Deprecated, use amounts.final CardAuthorization.Amountsamounts()Structured amounts for this authorization. final LongauthorizationAmount()Deprecated, use amounts.final CardAuthorization.Avsavs()final CardAuthorization.AsaRequestCardcard()Card object in ASA final StringcardholderCurrency()Deprecated, use amounts.final LongcashAmount()The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. final OffsetDateTimecreated()Date and time when the transaction first occurred in UTC. final CardAuthorization.TransactionMerchantmerchant()Merchant information including full location details. final LongmerchantAmount()Deprecated, use amounts.final StringmerchantCurrency()3-character alphabetic ISO 4217 code for the local currency of the transaction. final Optional<CardAuthorization.ServiceLocation>serviceLocation()Where the cardholder received the service, when different from the card acceptor location. final LongsettledAmount()Deprecated, use amounts.final CardAuthorization.AsaRequestStatusstatus()The type of authorization request that this request is for. final CardAuthorization.TransactionInitiatortransactionInitiator()The entity that initiated the transaction. final Optional<CardAuthorization.AccountType>accountType()final Optional<CardholderAuthentication>cardholderAuthentication()final Optional<Long>cashback()Deprecated, use cash_amount.final Optional<Double>conversionRate()Deprecated, use amounts.final Optional<String>eventToken()The event token associated with the authorization. final Optional<CardAuthorization.AsaRequestFleetInfo>fleetInfo()Optional Object containing information if the Card is a part of a Fleet managed program final Optional<CardAuthorization.LatestChallenge>latestChallenge()The latest Authorization Challenge that was issued to the cardholder for this merchant. final Optional<CardAuthorization.Network>network()Card network of the authorization. final Optional<Long>networkRiskScore()Network-provided score assessing risk level associated with a given authorization. final Optional<CardAuthorization.AsaNetworkSpecificData>networkSpecificData()Contains raw data provided by the card network, including attributes that provide further context about the authorization. final Optional<CardAuthorization.Pos>pos()final Optional<TokenInfo>tokenInfo()final Optional<OffsetDateTime>ttl()Deprecated: approximate time-to-live for the authorization. final CardAuthorizationApprovalRequestWebhookEvent.EventTypeeventType()final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_acquirerFee()Returns the raw JSON value of acquirerFee. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<CardAuthorization.Amounts>_amounts()Returns the raw JSON value of amounts. final JsonField<Long>_authorizationAmount()Returns the raw JSON value of authorizationAmount. final JsonField<CardAuthorization.Avs>_avs()Returns the raw JSON value of avs. final JsonField<CardAuthorization.AsaRequestCard>_card()Returns the raw JSON value of card. final JsonField<String>_cardholderCurrency()Returns the raw JSON value of cardholderCurrency. final JsonField<Long>_cashAmount()Returns the raw JSON value of cashAmount. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<CardAuthorization.TransactionMerchant>_merchant()Returns the raw JSON value of merchant. final JsonField<Long>_merchantAmount()Returns the raw JSON value of merchantAmount. final JsonField<String>_merchantCurrency()Returns the raw JSON value of merchantCurrency. final JsonField<CardAuthorization.ServiceLocation>_serviceLocation()Returns the raw JSON value of serviceLocation. final JsonField<Long>_settledAmount()Returns the raw JSON value of settledAmount. final JsonField<CardAuthorization.AsaRequestStatus>_status()Returns the raw JSON value of status. final JsonField<CardAuthorization.TransactionInitiator>_transactionInitiator()Returns the raw JSON value of transactionInitiator. final JsonField<CardAuthorization.AccountType>_accountType()Returns the raw JSON value of accountType. final JsonField<CardholderAuthentication>_cardholderAuthentication()Returns the raw JSON value of cardholderAuthentication. final JsonField<Long>_cashback()Returns the raw JSON value of cashback. final JsonField<Double>_conversionRate()Returns the raw JSON value of conversionRate. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<CardAuthorization.AsaRequestFleetInfo>_fleetInfo()Returns the raw JSON value of fleetInfo. final JsonField<CardAuthorization.LatestChallenge>_latestChallenge()Returns the raw JSON value of latestChallenge. final JsonField<CardAuthorization.Network>_network()Returns the raw JSON value of network. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<CardAuthorization.AsaNetworkSpecificData>_networkSpecificData()Returns the raw JSON value of networkSpecificData. final JsonField<CardAuthorization.Pos>_pos()Returns the raw JSON value of pos. final JsonField<TokenInfo>_tokenInfo()Returns the raw JSON value of tokenInfo. final JsonField<OffsetDateTime>_ttl()Returns the raw JSON value of ttl. final JsonField<CardAuthorizationApprovalRequestWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final CardAuthorizationApprovalRequestWebhookEvent.BuildertoBuilder()final CardAuthorizationApprovalRequestWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationApprovalRequestWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthorizationApprovalRequestWebhookEvent. -
-
Method Detail
-
toCardAuthorization
final CardAuthorization toCardAuthorization()
-
acquirerFee
final Long acquirerFee()
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
amount
@Deprecated(message = "deprecated") final Long amount()
Deprecated, use
amounts. Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical toauthorization_amount.
-
amounts
final CardAuthorization.Amounts amounts()
Structured amounts for this authorization. The
cardholderandmerchantamounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), theholdamount may exceed thecardholderandmerchantamounts to account for anticipated final transaction amounts such as tips or fuel fill-ups
-
authorizationAmount
@Deprecated(message = "deprecated") final Long authorizationAmount()
Deprecated, use
amounts. The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.
-
avs
final CardAuthorization.Avs avs()
-
card
final CardAuthorization.AsaRequestCard card()
Card object in ASA
-
cardholderCurrency
@Deprecated(message = "deprecated") final String cardholderCurrency()
Deprecated, use
amounts. 3-character alphabetic ISO 4217 code for cardholder's billing currency.
-
cashAmount
final Long cashAmount()
The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.
If no cash back was requested, the value of this field will be 0, and the field will always be present.
-
created
final OffsetDateTime created()
Date and time when the transaction first occurred in UTC.
-
merchant
final CardAuthorization.TransactionMerchant merchant()
Merchant information including full location details.
-
merchantAmount
@Deprecated(message = "deprecated") final Long merchantAmount()
Deprecated, use
amounts. The amount that the merchant will receive, denominated inmerchant_currencyand in the smallest currency unit. Note the amount includesacquirer_fee, similar toauthorization_amount. It will be different fromauthorization_amountif the merchant is taking payment in a different currency.
-
merchantCurrency
@Deprecated(message = "deprecated") final String merchantCurrency()
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
serviceLocation
final Optional<CardAuthorization.ServiceLocation> serviceLocation()
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
-
settledAmount
@Deprecated(message = "deprecated") final Long settledAmount()
Deprecated, use
amounts. Amount (in cents) of the transaction that has been settled, including any acquirer fees.
-
status
final CardAuthorization.AsaRequestStatus status()
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.
-
transactionInitiator
final CardAuthorization.TransactionInitiator transactionInitiator()
The entity that initiated the transaction.
-
accountType
final Optional<CardAuthorization.AccountType> accountType()
-
cardholderAuthentication
final Optional<CardholderAuthentication> cardholderAuthentication()
-
conversionRate
@Deprecated(message = "deprecated") final Optional<Double> conversionRate()
Deprecated, use
amounts. If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e.,merchant_amountxconversion_rate=amount). Note that themerchant_amountis in the local currency and the amount is in the settlement currency.
-
eventToken
final Optional<String> eventToken()
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
-
fleetInfo
final Optional<CardAuthorization.AsaRequestFleetInfo> fleetInfo()
Optional Object containing information if the Card is a part of a Fleet managed program
-
latestChallenge
final Optional<CardAuthorization.LatestChallenge> latestChallenge()
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
network
final Optional<CardAuthorization.Network> network()
Card network of the authorization.
-
networkRiskScore
final Optional<Long> networkRiskScore()
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkSpecificData
final Optional<CardAuthorization.AsaNetworkSpecificData> networkSpecificData()
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
pos
final Optional<CardAuthorization.Pos> pos()
-
ttl
final Optional<OffsetDateTime> ttl()
Deprecated: approximate time-to-live for the authorization.
-
eventType
final CardAuthorizationApprovalRequestWebhookEvent.EventType eventType()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_acquirerFee
final JsonField<Long> _acquirerFee()
Returns the raw JSON value of acquirerFee.
Unlike acquirerFee, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
@Deprecated(message = "deprecated") final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_amounts
final JsonField<CardAuthorization.Amounts> _amounts()
Returns the raw JSON value of amounts.
Unlike amounts, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationAmount
@Deprecated(message = "deprecated") final JsonField<Long> _authorizationAmount()
Returns the raw JSON value of authorizationAmount.
Unlike authorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_avs
final JsonField<CardAuthorization.Avs> _avs()
Returns the raw JSON value of avs.
Unlike avs, this method doesn't throw if the JSON field has an unexpected type.
-
_card
final JsonField<CardAuthorization.AsaRequestCard> _card()
Returns the raw JSON value of card.
Unlike card, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderCurrency
@Deprecated(message = "deprecated") final JsonField<String> _cardholderCurrency()
Returns the raw JSON value of cardholderCurrency.
Unlike cardholderCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAmount
final JsonField<Long> _cashAmount()
Returns the raw JSON value of cashAmount.
Unlike cashAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<CardAuthorization.TransactionMerchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAmount
@Deprecated(message = "deprecated") final JsonField<Long> _merchantAmount()
Returns the raw JSON value of merchantAmount.
Unlike merchantAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCurrency
@Deprecated(message = "deprecated") final JsonField<String> _merchantCurrency()
Returns the raw JSON value of merchantCurrency.
Unlike merchantCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_serviceLocation
final JsonField<CardAuthorization.ServiceLocation> _serviceLocation()
Returns the raw JSON value of serviceLocation.
Unlike serviceLocation, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
@Deprecated(message = "deprecated") final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardAuthorization.AsaRequestStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionInitiator
final JsonField<CardAuthorization.TransactionInitiator> _transactionInitiator()
Returns the raw JSON value of transactionInitiator.
Unlike transactionInitiator, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<CardAuthorization.AccountType> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderAuthentication
final JsonField<CardholderAuthentication> _cardholderAuthentication()
Returns the raw JSON value of cardholderAuthentication.
Unlike cardholderAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_cashback
final JsonField<Long> _cashback()
Returns the raw JSON value of cashback.
Unlike cashback, this method doesn't throw if the JSON field has an unexpected type.
-
_conversionRate
@Deprecated(message = "deprecated") final JsonField<Double> _conversionRate()
Returns the raw JSON value of conversionRate.
Unlike conversionRate, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_fleetInfo
final JsonField<CardAuthorization.AsaRequestFleetInfo> _fleetInfo()
Returns the raw JSON value of fleetInfo.
Unlike fleetInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_latestChallenge
final JsonField<CardAuthorization.LatestChallenge> _latestChallenge()
Returns the raw JSON value of latestChallenge.
Unlike latestChallenge, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardAuthorization.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_networkSpecificData
final JsonField<CardAuthorization.AsaNetworkSpecificData> _networkSpecificData()
Returns the raw JSON value of networkSpecificData.
Unlike networkSpecificData, this method doesn't throw if the JSON field has an unexpected type.
-
_pos
final JsonField<CardAuthorization.Pos> _pos()
Returns the raw JSON value of pos.
Unlike pos, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenInfo
final JsonField<TokenInfo> _tokenInfo()
Returns the raw JSON value of tokenInfo.
Unlike tokenInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_ttl
final JsonField<OffsetDateTime> _ttl()
Returns the raw JSON value of ttl.
Unlike ttl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationApprovalRequestWebhookEvent.
The following fields are required:
.token() .acquirerFee() .amount() .amounts() .authorizationAmount() .avs() .card() .cardholderCurrency() .cashAmount() .created() .merchant() .merchantAmount() .merchantCurrency() .serviceLocation() .settledAmount() .status() .transactionInitiator() .eventType()
-
-
-
-