Class CardAuthorizationApprovalRequestWebhookEvent.Amounts
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.AmountsStructured amounts for this authorization. The
cardholderandmerchantamounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), theholdamount may exceed thecardholderandmerchantamounts to account for anticipated final transaction amounts such as tips or fuel fill-ups
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.Amounts.BuilderA builder for Amounts.
public final classCardAuthorizationApprovalRequestWebhookEvent.Amounts.ConvertedAmountpublic final classCardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount
-
Method Summary
-
-
Method Detail
-
cardholder
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.ConvertedAmount cardholder()
-
merchant
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount merchant()
-
settlement
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> settlement()
-
_cardholder
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.ConvertedAmount> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_hold
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> _hold()
Returns the raw JSON value of hold.
Unlike hold, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_settlement
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts.Amount> _settlement()
Returns the raw JSON value of settlement.
Unlike settlement, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.Amounts validate()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Amounts.Builder builder()
Returns a mutable builder for constructing an instance of Amounts.
The following fields are required:
.cardholder() .hold() .merchant() .settlement()
-
-
-
-