Class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.BuilderA builder for AsaNetworkSpecificDataMastercard.
public final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult
-
Method Summary
-
-
Method Detail
-
ecommerceSecurityLevelIndicator
final Optional<String> ecommerceSecurityLevelIndicator()
Indicates the electronic commerce security level and UCAF collection.
-
onBehalfServiceResult
final Optional<List<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult>> onBehalfServiceResult()
The On-behalf Service performed on the transaction and the results. Contains all applicable, on-behalf service results that were performed on a given transaction.
-
transactionTypeIdentifier
final Optional<String> transactionTypeIdentifier()
Indicates the type of additional transaction purpose.
-
_ecommerceSecurityLevelIndicator
final JsonField<String> _ecommerceSecurityLevelIndicator()
Returns the raw JSON value of ecommerceSecurityLevelIndicator.
Unlike ecommerceSecurityLevelIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_onBehalfServiceResult
final JsonField<List<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.OnBehalfServiceResult>> _onBehalfServiceResult()
Returns the raw JSON value of onBehalfServiceResult.
Unlike onBehalfServiceResult, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionTypeIdentifier
final JsonField<String> _transactionTypeIdentifier()
Returns the raw JSON value of transactionTypeIdentifier.
Unlike transactionTypeIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData.AsaNetworkSpecificDataMastercard.Builder builder()
Returns a mutable builder for constructing an instance of AsaNetworkSpecificDataMastercard.
-
-
-
-