Class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.BuilderA builder for AsaRequestCard.
-
-
Method Summary
-
-
Method Detail
-
token
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder token(String token)
Globally unique identifier for the card.
-
token
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastFour
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder lastFour(String lastFour)
Last four digits of the card number
-
lastFour
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder lastFour(JsonField<String> lastFour)
Sets Builder.lastFour to an arbitrary JSON value.
You should usually call Builder.lastFour with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memo
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder memo(String memo)
Customizable name to identify the card
-
memo
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimit
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder spendLimit(Long spendLimit)
Amount (in cents) to limit approved authorizations. Purchase requests above the spend limit will be declined (refunds and credits will be approved).
Note that while spend limits are enforced based on authorized and settled volume on a card, they are not recommended to be used for balance or reconciliation-level accuracy. Spend limits also cannot block force posted charges (i.e., when a merchant sends a clearing message without a prior authorization).
-
spendLimit
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder spendLimit(JsonField<Long> spendLimit)
Sets Builder.spendLimit to an arbitrary JSON value.
You should usually call Builder.spendLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
spendLimitDuration
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder spendLimitDuration(CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.SpendLimitDuration spendLimitDuration)
Note that to support recurring monthly payments, which can occur on different day every month, the time window we consider for MONTHLY velocity starts 6 days after the current calendar date one month prior.
-
spendLimitDuration
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder spendLimitDuration(JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.SpendLimitDuration> spendLimitDuration)
Sets Builder.spendLimitDuration to an arbitrary JSON value.
You should usually call Builder.spendLimitDuration with a well-typed SpendLimitDuration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder state(CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.State state)
-
state
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder state(JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder type(CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.CardType type)
-
type
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder type(JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.CardType> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed CardType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard build()
Returns an immutable instance of AsaRequestCard.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .lastFour() .memo() .spendLimit() .spendLimitDuration() .state() .type()
-
-
-
-