Class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestStatus

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class CardAuthorizationApprovalRequestWebhookEvent.AsaRequestStatus
     implements Enum
                        

    The type of authorization request that this request is for. Note that CREDIT_AUTHORIZATION and FINANCIAL_CREDIT_AUTHORIZATION is only available to users with credit decisioning via ASA enabled.