Class CardAuthorizationApprovalRequestWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.BuilderA builder for CardAuthorizationApprovalRequestWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final CardAuthorizationApprovalRequestWebhookEvent.Builder token(String token)
The provisional transaction group uuid associated with the authorization
-
token
final CardAuthorizationApprovalRequestWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acquirerFee
final CardAuthorizationApprovalRequestWebhookEvent.Builder acquirerFee(Long acquirerFee)
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
acquirerFee
final CardAuthorizationApprovalRequestWebhookEvent.Builder acquirerFee(JsonField<Long> acquirerFee)
Sets Builder.acquirerFee to an arbitrary JSON value.
You should usually call Builder.acquirerFee with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder amount(Long amount)
Deprecated, use
amounts. Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical toauthorization_amount.
-
amount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amounts
final CardAuthorizationApprovalRequestWebhookEvent.Builder amounts(CardAuthorization.Amounts amounts)
Structured amounts for this authorization. The
cardholderandmerchantamounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), theholdamount may exceed thecardholderandmerchantamounts to account for anticipated final transaction amounts such as tips or fuel fill-ups
-
amounts
final CardAuthorizationApprovalRequestWebhookEvent.Builder amounts(JsonField<CardAuthorization.Amounts> amounts)
Sets Builder.amounts to an arbitrary JSON value.
You should usually call Builder.amounts with a well-typed CardAuthorization.Amounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder authorizationAmount(Long authorizationAmount)
Deprecated, use
amounts. The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.
-
authorizationAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder authorizationAmount(JsonField<Long> authorizationAmount)
Sets Builder.authorizationAmount to an arbitrary JSON value.
You should usually call Builder.authorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avs
final CardAuthorizationApprovalRequestWebhookEvent.Builder avs(JsonField<CardAuthorization.Avs> avs)
Sets Builder.avs to an arbitrary JSON value.
You should usually call Builder.avs with a well-typed CardAuthorization.Avs value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
card
final CardAuthorizationApprovalRequestWebhookEvent.Builder card(CardAuthorization.AsaRequestCard card)
Card object in ASA
-
card
final CardAuthorizationApprovalRequestWebhookEvent.Builder card(JsonField<CardAuthorization.AsaRequestCard> card)
Sets Builder.card to an arbitrary JSON value.
You should usually call Builder.card with a well-typed CardAuthorization.AsaRequestCard value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderCurrency
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder cardholderCurrency(String cardholderCurrency)
Deprecated, use
amounts. 3-character alphabetic ISO 4217 code for cardholder's billing currency.
-
cardholderCurrency
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder cardholderCurrency(JsonField<String> cardholderCurrency)
Sets Builder.cardholderCurrency to an arbitrary JSON value.
You should usually call Builder.cardholderCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashAmount
final CardAuthorizationApprovalRequestWebhookEvent.Builder cashAmount(Long cashAmount)
The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.
If no cash back was requested, the value of this field will be 0, and the field will always be present.
-
cashAmount
final CardAuthorizationApprovalRequestWebhookEvent.Builder cashAmount(JsonField<Long> cashAmount)
Sets Builder.cashAmount to an arbitrary JSON value.
You should usually call Builder.cashAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final CardAuthorizationApprovalRequestWebhookEvent.Builder created(OffsetDateTime created)
Date and time when the transaction first occurred in UTC.
-
created
final CardAuthorizationApprovalRequestWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final CardAuthorizationApprovalRequestWebhookEvent.Builder merchant(CardAuthorization.TransactionMerchant merchant)
Merchant information including full location details.
-
merchant
final CardAuthorizationApprovalRequestWebhookEvent.Builder merchant(JsonField<CardAuthorization.TransactionMerchant> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed CardAuthorization.TransactionMerchant value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder merchantAmount(Long merchantAmount)
Deprecated, use
amounts. The amount that the merchant will receive, denominated inmerchant_currencyand in the smallest currency unit. Note the amount includesacquirer_fee, similar toauthorization_amount. It will be different fromauthorization_amountif the merchant is taking payment in a different currency.
-
merchantAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder merchantAmount(JsonField<Long> merchantAmount)
Sets Builder.merchantAmount to an arbitrary JSON value.
You should usually call Builder.merchantAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCurrency
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder merchantCurrency(String merchantCurrency)
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
merchantCurrency
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder merchantCurrency(JsonField<String> merchantCurrency)
Sets Builder.merchantCurrency to an arbitrary JSON value.
You should usually call Builder.merchantCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
serviceLocation
final CardAuthorizationApprovalRequestWebhookEvent.Builder serviceLocation(CardAuthorization.ServiceLocation serviceLocation)
Where the cardholder received the service, when different from the card acceptor location. This is populated from network data elements such as Mastercard DE-122 SE1 SF9-14 and Visa F34 DS02.
-
serviceLocation
final CardAuthorizationApprovalRequestWebhookEvent.Builder serviceLocation(Optional<CardAuthorization.ServiceLocation> serviceLocation)
Alias for calling Builder.serviceLocation with
serviceLocation.orElse(null).
-
serviceLocation
final CardAuthorizationApprovalRequestWebhookEvent.Builder serviceLocation(JsonField<CardAuthorization.ServiceLocation> serviceLocation)
Sets Builder.serviceLocation to an arbitrary JSON value.
You should usually call Builder.serviceLocation with a well-typed CardAuthorization.ServiceLocation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder settledAmount(Long settledAmount)
Deprecated, use
amounts. Amount (in cents) of the transaction that has been settled, including any acquirer fees.
-
settledAmount
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardAuthorizationApprovalRequestWebhookEvent.Builder status(CardAuthorization.AsaRequestStatus status)
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.
-
status
final CardAuthorizationApprovalRequestWebhookEvent.Builder status(JsonField<CardAuthorization.AsaRequestStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed CardAuthorization.AsaRequestStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionInitiator
final CardAuthorizationApprovalRequestWebhookEvent.Builder transactionInitiator(CardAuthorization.TransactionInitiator transactionInitiator)
The entity that initiated the transaction.
-
transactionInitiator
final CardAuthorizationApprovalRequestWebhookEvent.Builder transactionInitiator(JsonField<CardAuthorization.TransactionInitiator> transactionInitiator)
Sets Builder.transactionInitiator to an arbitrary JSON value.
You should usually call Builder.transactionInitiator with a well-typed CardAuthorization.TransactionInitiator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountType
final CardAuthorizationApprovalRequestWebhookEvent.Builder accountType(CardAuthorization.AccountType accountType)
-
accountType
final CardAuthorizationApprovalRequestWebhookEvent.Builder accountType(JsonField<CardAuthorization.AccountType> accountType)
Sets Builder.accountType to an arbitrary JSON value.
You should usually call Builder.accountType with a well-typed CardAuthorization.AccountType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderAuthentication
final CardAuthorizationApprovalRequestWebhookEvent.Builder cardholderAuthentication(CardholderAuthentication cardholderAuthentication)
-
cardholderAuthentication
final CardAuthorizationApprovalRequestWebhookEvent.Builder cardholderAuthentication(JsonField<CardholderAuthentication> cardholderAuthentication)
Sets Builder.cardholderAuthentication to an arbitrary JSON value.
You should usually call Builder.cardholderAuthentication with a well-typed CardholderAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashback
final CardAuthorizationApprovalRequestWebhookEvent.Builder cashback(Long cashback)
Deprecated, use
cash_amount.
-
cashback
final CardAuthorizationApprovalRequestWebhookEvent.Builder cashback(JsonField<Long> cashback)
Sets Builder.cashback to an arbitrary JSON value.
You should usually call Builder.cashback with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
conversionRate
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder conversionRate(Double conversionRate)
Deprecated, use
amounts. If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e.,merchant_amountxconversion_rate=amount). Note that themerchant_amountis in the local currency and the amount is in the settlement currency.
-
conversionRate
@Deprecated(message = "deprecated") final CardAuthorizationApprovalRequestWebhookEvent.Builder conversionRate(JsonField<Double> conversionRate)
Sets Builder.conversionRate to an arbitrary JSON value.
You should usually call Builder.conversionRate with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventToken
final CardAuthorizationApprovalRequestWebhookEvent.Builder eventToken(String eventToken)
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
-
eventToken
final CardAuthorizationApprovalRequestWebhookEvent.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fleetInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder fleetInfo(CardAuthorization.AsaRequestFleetInfo fleetInfo)
Optional Object containing information if the Card is a part of a Fleet managed program
-
fleetInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder fleetInfo(Optional<CardAuthorization.AsaRequestFleetInfo> fleetInfo)
Alias for calling Builder.fleetInfo with
fleetInfo.orElse(null).
-
fleetInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder fleetInfo(JsonField<CardAuthorization.AsaRequestFleetInfo> fleetInfo)
Sets Builder.fleetInfo to an arbitrary JSON value.
You should usually call Builder.fleetInfo with a well-typed CardAuthorization.AsaRequestFleetInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
latestChallenge
final CardAuthorizationApprovalRequestWebhookEvent.Builder latestChallenge(CardAuthorization.LatestChallenge latestChallenge)
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
latestChallenge
final CardAuthorizationApprovalRequestWebhookEvent.Builder latestChallenge(JsonField<CardAuthorization.LatestChallenge> latestChallenge)
Sets Builder.latestChallenge to an arbitrary JSON value.
You should usually call Builder.latestChallenge with a well-typed CardAuthorization.LatestChallenge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final CardAuthorizationApprovalRequestWebhookEvent.Builder network(CardAuthorization.Network network)
Card network of the authorization.
-
network
final CardAuthorizationApprovalRequestWebhookEvent.Builder network(JsonField<CardAuthorization.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed CardAuthorization.Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkRiskScore
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkSpecificData
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkSpecificData(CardAuthorization.AsaNetworkSpecificData networkSpecificData)
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
networkSpecificData
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkSpecificData(Optional<CardAuthorization.AsaNetworkSpecificData> networkSpecificData)
Alias for calling Builder.networkSpecificData with
networkSpecificData.orElse(null).
-
networkSpecificData
final CardAuthorizationApprovalRequestWebhookEvent.Builder networkSpecificData(JsonField<CardAuthorization.AsaNetworkSpecificData> networkSpecificData)
Sets Builder.networkSpecificData to an arbitrary JSON value.
You should usually call Builder.networkSpecificData with a well-typed CardAuthorization.AsaNetworkSpecificData value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pos
final CardAuthorizationApprovalRequestWebhookEvent.Builder pos(JsonField<CardAuthorization.Pos> pos)
Sets Builder.pos to an arbitrary JSON value.
You should usually call Builder.pos with a well-typed CardAuthorization.Pos value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder tokenInfo(TokenInfo tokenInfo)
-
tokenInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder tokenInfo(Optional<TokenInfo> tokenInfo)
Alias for calling Builder.tokenInfo with
tokenInfo.orElse(null).
-
tokenInfo
final CardAuthorizationApprovalRequestWebhookEvent.Builder tokenInfo(JsonField<TokenInfo> tokenInfo)
Sets Builder.tokenInfo to an arbitrary JSON value.
You should usually call Builder.tokenInfo with a well-typed TokenInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ttl
final CardAuthorizationApprovalRequestWebhookEvent.Builder ttl(OffsetDateTime ttl)
Deprecated: approximate time-to-live for the authorization.
-
ttl
final CardAuthorizationApprovalRequestWebhookEvent.Builder ttl(JsonField<OffsetDateTime> ttl)
Sets Builder.ttl to an arbitrary JSON value.
You should usually call Builder.ttl with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final CardAuthorizationApprovalRequestWebhookEvent.Builder eventType(CardAuthorizationApprovalRequestWebhookEvent.EventType eventType)
-
eventType
final CardAuthorizationApprovalRequestWebhookEvent.Builder eventType(JsonField<CardAuthorizationApprovalRequestWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent build()
Returns an immutable instance of CardAuthorizationApprovalRequestWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .acquirerFee() .amount() .amounts() .authorizationAmount() .avs() .card() .cardholderCurrency() .cashAmount() .created() .merchant() .merchantAmount() .merchantCurrency() .serviceLocation() .settledAmount() .status() .transactionInitiator() .eventType()
-
-
-
-