Class CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.BuilderA builder for LatestChallenge.
-
-
Method Summary
-
-
Method Detail
-
phoneNumber
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder phoneNumber(String phoneNumber)
The phone number used for sending Authorization Challenge SMS.
-
phoneNumber
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder status(CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Status status)
The status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
status
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder status(JsonField<CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder completedAt(OffsetDateTime completedAt)
The date and time when the Authorization Challenge was completed in UTC. Present only if the status is
COMPLETED.
-
completedAt
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge build()
Returns an immutable instance of LatestChallenge.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.phoneNumber() .status()
-
-
-
-