Class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.BuilderA builder for AsaRequestPosEntryMode.
-
-
Method Summary
-
-
Method Detail
-
card
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder card(CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card card)
Card Presence Indicator
-
card
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder card(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card> card)
Sets Builder.card to an arbitrary JSON value.
You should usually call Builder.card with a well-typed Card value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholder
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder cardholder(CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardholder cardholder)
Cardholder Presence Indicator
-
cardholder
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder cardholder(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardholder> cardholder)
Sets Builder.cardholder to an arbitrary JSON value.
You should usually call Builder.cardholder with a well-typed Cardholder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pan
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder pan(CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Pan pan)
Method of entry for the PAN
-
pan
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder pan(JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Pan> pan)
Sets Builder.pan to an arbitrary JSON value.
You should usually call Builder.pan with a well-typed Pan value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pinEntered
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder pinEntered(Boolean pinEntered)
Indicates whether the cardholder entered the PIN. True if the PIN was entered.
-
pinEntered
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder pinEntered(JsonField<Boolean> pinEntered)
Sets Builder.pinEntered to an arbitrary JSON value.
You should usually call Builder.pinEntered with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode build()
Returns an immutable instance of AsaRequestPosEntryMode.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-