Class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card implements EnumCard Presence Indicator
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.KnownAn enum containing Card's known values.
public enumCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.ValueAn enum containing Card's known values, as well as an _UNKNOWN member.
An instance of Card can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.CardPRESENTpublic final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.CardNOT_PRESENTpublic final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.CardUNKNOWN
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card validate()
-
of
final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card of(String value)
-
-
-
-