Package com.lithic.api.models
Class CardAuthorizationChallengeResponseParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeResponseParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
response
final CardAuthorizationChallengeResponseParams.Body.Builder response(CardAuthorizationChallengeResponseParams.Response response)
Whether the cardholder has approved or declined the issued challenge
-
response
final CardAuthorizationChallengeResponseParams.Body.Builder response(JsonField<CardAuthorizationChallengeResponseParams.Response> response)
Sets Builder.response to an arbitrary JSON value.
You should usually call Builder.response with a well-typed Response value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationChallengeResponseParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationChallengeResponseParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationChallengeResponseParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationChallengeResponseParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationChallengeResponseParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationChallengeResponseParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.response()
-
-
-
-