Class CardAuthorizationChallengeResponseWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeResponseWebhookEvent.BuilderA builder for CardAuthorizationChallengeResponseWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
cardToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder cardToken(String cardToken)
The token of the card associated with the challenge
-
cardToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder cardToken(Optional<String> cardToken)
Alias for calling Builder.cardToken with
cardToken.orElse(null).
-
cardToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challengeMethod
final CardAuthorizationChallengeResponseWebhookEvent.Builder challengeMethod(CardAuthorizationChallengeResponseWebhookEvent.ChallengeMethod challengeMethod)
The method used to deliver the challenge to the cardholder
-
challengeMethod
final CardAuthorizationChallengeResponseWebhookEvent.Builder challengeMethod(JsonField<CardAuthorizationChallengeResponseWebhookEvent.ChallengeMethod> challengeMethod)
Sets Builder.challengeMethod to an arbitrary JSON value.
You should usually call Builder.challengeMethod with a well-typed ChallengeMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completed
final CardAuthorizationChallengeResponseWebhookEvent.Builder completed(OffsetDateTime completed)
The timestamp of when the challenge was completed
-
completed
final CardAuthorizationChallengeResponseWebhookEvent.Builder completed(Optional<OffsetDateTime> completed)
Alias for calling Builder.completed with
completed.orElse(null).
-
completed
final CardAuthorizationChallengeResponseWebhookEvent.Builder completed(JsonField<OffsetDateTime> completed)
Sets Builder.completed to an arbitrary JSON value.
You should usually call Builder.completed with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final CardAuthorizationChallengeResponseWebhookEvent.Builder created(OffsetDateTime created)
The timestamp of when the challenge was created
-
created
final CardAuthorizationChallengeResponseWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder eventToken(String eventToken)
Globally unique identifier for the event
-
eventToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final CardAuthorizationChallengeResponseWebhookEvent.Builder eventType(CardAuthorizationChallengeResponseWebhookEvent.EventType eventType)
Event type
-
eventType
final CardAuthorizationChallengeResponseWebhookEvent.Builder eventType(JsonField<CardAuthorizationChallengeResponseWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
response
final CardAuthorizationChallengeResponseWebhookEvent.Builder response(CardAuthorizationChallengeResponseWebhookEvent.Response response)
The cardholder's response to the challenge
-
response
final CardAuthorizationChallengeResponseWebhookEvent.Builder response(JsonField<CardAuthorizationChallengeResponseWebhookEvent.Response> response)
Sets Builder.response to an arbitrary JSON value.
You should usually call Builder.response with a well-typed Response value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder transactionToken(String transactionToken)
The token of the transaction associated with the authorization event being challenged
-
transactionToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder transactionToken(Optional<String> transactionToken)
Alias for calling Builder.transactionToken with
transactionToken.orElse(null).
-
transactionToken
final CardAuthorizationChallengeResponseWebhookEvent.Builder transactionToken(JsonField<String> transactionToken)
Sets Builder.transactionToken to an arbitrary JSON value.
You should usually call Builder.transactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationChallengeResponseWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationChallengeResponseWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationChallengeResponseWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationChallengeResponseWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationChallengeResponseWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationChallengeResponseWebhookEvent build()
Returns an immutable instance of CardAuthorizationChallengeResponseWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardToken() .challengeMethod() .completed() .created() .eventToken() .eventType() .response() .transactionToken()
-
-
-
-