Class CardAuthorizationChallengeWebhookEvent
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationChallengeWebhookEvent.BuilderA builder for CardAuthorizationChallengeWebhookEvent.
public final classCardAuthorizationChallengeWebhookEvent.AuthorizationChallengeDetails of the Authorization Challenge issued during card authorization
public final classCardAuthorizationChallengeWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
authorization
final CardAuthorization authorization()
The authorization that triggered the challenge
-
challenge
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge challenge()
Details of the Authorization Challenge issued during card authorization
-
eventType
final CardAuthorizationChallengeWebhookEvent.EventType eventType()
The type of event that occurred.
-
_authorization
final JsonField<CardAuthorization> _authorization()
Returns the raw JSON value of authorization.
Unlike authorization, this method doesn't throw if the JSON field has an unexpected type.
-
_challenge
final JsonField<CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge> _challenge()
Returns the raw JSON value of challenge.
Unlike challenge, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardAuthorizationChallengeWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationChallengeWebhookEvent.Builder toBuilder()
-
validate
final CardAuthorizationChallengeWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationChallengeWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationChallengeWebhookEvent.
The following fields are required:
.authorization() .challenge() .eventType()
-
-
-
-