Class CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeWebhookEvent.AuthorizationChallengeDetails of the Authorization Challenge issued during card authorization
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.BuilderA builder for AuthorizationChallenge.
-
Method Summary
Modifier and Type Method Description final StringeventToken()Globally unique identifier for the event that triggered the challenge. final OffsetDateTimeexpiryTime()ISO-8601 time at which the challenge expires final OffsetDateTimestartTime()ISO-8601 time at which the challenge was issued final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<OffsetDateTime>_expiryTime()Returns the raw JSON value of expiryTime. final JsonField<OffsetDateTime>_startTime()Returns the raw JSON value of startTime. final Map<String, JsonValue>_additionalProperties()final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.BuildertoBuilder()final CardAuthorizationChallengeWebhookEvent.AuthorizationChallengevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builderbuilder()Returns a mutable builder for constructing an instance of AuthorizationChallenge. -
-
Method Detail
-
eventToken
final String eventToken()
Globally unique identifier for the event that triggered the challenge. Use this token when calling the challenge response endpoint
-
expiryTime
final OffsetDateTime expiryTime()
ISO-8601 time at which the challenge expires
-
startTime
final OffsetDateTime startTime()
ISO-8601 time at which the challenge was issued
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_expiryTime
final JsonField<OffsetDateTime> _expiryTime()
Returns the raw JSON value of expiryTime.
Unlike expiryTime, this method doesn't throw if the JSON field has an unexpected type.
-
_startTime
final JsonField<OffsetDateTime> _startTime()
Returns the raw JSON value of startTime.
Unlike startTime, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder builder()
Returns a mutable builder for constructing an instance of AuthorizationChallenge.
The following fields are required:
.eventToken() .expiryTime() .startTime()
-
-
-
-