Class CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.BuilderA builder for AuthorizationChallenge.
-
-
Method Summary
-
-
Method Detail
-
eventToken
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder eventToken(String eventToken)
Globally unique identifier for the event that triggered the challenge. Use this token when calling the challenge response endpoint
-
eventToken
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiryTime
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder expiryTime(OffsetDateTime expiryTime)
ISO-8601 time at which the challenge expires
-
expiryTime
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder expiryTime(JsonField<OffsetDateTime> expiryTime)
Sets Builder.expiryTime to an arbitrary JSON value.
You should usually call Builder.expiryTime with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startTime
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder startTime(OffsetDateTime startTime)
ISO-8601 time at which the challenge was issued
-
startTime
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder startTime(JsonField<OffsetDateTime> startTime)
Sets Builder.startTime to an arbitrary JSON value.
You should usually call Builder.startTime with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge build()
Returns an immutable instance of AuthorizationChallenge.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventToken() .expiryTime() .startTime()
-
-
-
-