Class CardAuthorizationChallengeWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationChallengeWebhookEvent.BuilderA builder for CardAuthorizationChallengeWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
authorization
final CardAuthorizationChallengeWebhookEvent.Builder authorization(CardAuthorization authorization)
The authorization that triggered the challenge
-
authorization
final CardAuthorizationChallengeWebhookEvent.Builder authorization(JsonField<CardAuthorization> authorization)
Sets Builder.authorization to an arbitrary JSON value.
You should usually call Builder.authorization with a well-typed CardAuthorization value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challenge
final CardAuthorizationChallengeWebhookEvent.Builder challenge(CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge challenge)
Details of the Authorization Challenge issued during card authorization
-
challenge
final CardAuthorizationChallengeWebhookEvent.Builder challenge(JsonField<CardAuthorizationChallengeWebhookEvent.AuthorizationChallenge> challenge)
Sets Builder.challenge to an arbitrary JSON value.
You should usually call Builder.challenge with a well-typed AuthorizationChallenge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final CardAuthorizationChallengeWebhookEvent.Builder eventType(CardAuthorizationChallengeWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardAuthorizationChallengeWebhookEvent.Builder eventType(JsonField<CardAuthorizationChallengeWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationChallengeWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationChallengeWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationChallengeWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationChallengeWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationChallengeWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationChallengeWebhookEvent build()
Returns an immutable instance of CardAuthorizationChallengeWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authorization() .challenge() .eventType()
-
-
-
-