Package com.lithic.api.models
Class CardBalanceListPage.Builder
-
- All Implemented Interfaces:
public final class CardBalanceListPage.BuilderA builder for CardBalanceListPage.
-
-
Method Summary
Modifier and Type Method Description final CardBalanceListPage.Builderservice(BalanceService service)final CardBalanceListPage.Builderparams(CardBalanceListParams params)The parameters that were used to request this page. final CardBalanceListPage.Builderresponse(CardBalanceListPageResponse response)The response that this page was parsed from. final CardBalanceListPagebuild()Returns an immutable instance of CardBalanceListPage. -
-
Method Detail
-
service
final CardBalanceListPage.Builder service(BalanceService service)
-
params
final CardBalanceListPage.Builder params(CardBalanceListParams params)
The parameters that were used to request this page.
-
response
final CardBalanceListPage.Builder response(CardBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final CardBalanceListPage build()
Returns an immutable instance of CardBalanceListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-