Package com.lithic.api.models
Class CardBalanceListPageResponse
-
- All Implemented Interfaces:
public final class CardBalanceListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceListPageResponse.BuilderA builder for CardBalanceListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<FinancialAccountBalance>data()final BooleanhasMore()More data exists. final JsonField<List<FinancialAccountBalance>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final CardBalanceListPageResponse.BuildertoBuilder()final CardBalanceListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBalanceListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardBalanceListPageResponse. -
-
Method Detail
-
data
final List<FinancialAccountBalance> data()
-
_data
final JsonField<List<FinancialAccountBalance>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardBalanceListPageResponse.Builder toBuilder()
-
validate
final CardBalanceListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardBalanceListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardBalanceListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-