Class CardBulkOrder
-
- All Implemented Interfaces:
public final class CardBulkOrderRepresents a bulk order for physical card shipments
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBulkOrder.BuilderA builder for CardBulkOrder.
public final classCardBulkOrder.ShippingMethodShipping method for all cards in this bulk order
public final classCardBulkOrder.StatusStatus of the bulk order. OPEN indicates the order is accepting cards. LOCKED indicates the order is finalized and no more cards can be added
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the bulk order final List<String>cardTokens()List of card tokens associated with this bulk order final OffsetDateTimecreated()An RFC 3339 timestamp for when the bulk order was created. final Optional<String>customerProductId()Customer-specified product configuration for physical card manufacturing. final JsonValue_shippingAddress()Shipping address for all cards in this bulk orderThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = cardBulkOrder.shippingAddress().convert(MyClass.class);final CardBulkOrder.ShippingMethodshippingMethod()Shipping method for all cards in this bulk order final CardBulkOrder.Statusstatus()Status of the bulk order. final OffsetDateTimeupdated()An RFC 3339 timestamp for when the bulk order was last updated. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<List<String>>_cardTokens()Returns the raw JSON value of cardTokens. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_customerProductId()Returns the raw JSON value of customerProductId. final JsonField<CardBulkOrder.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final JsonField<CardBulkOrder.Status>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final Map<String, JsonValue>_additionalProperties()final CardBulkOrder.BuildertoBuilder()final CardBulkOrdervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBulkOrder.Builderbuilder()Returns a mutable builder for constructing an instance of CardBulkOrder. -
-
Method Detail
-
cardTokens
final List<String> cardTokens()
List of card tokens associated with this bulk order
-
created
final OffsetDateTime created()
An RFC 3339 timestamp for when the bulk order was created. UTC time zone
-
customerProductId
final Optional<String> customerProductId()
Customer-specified product configuration for physical card manufacturing. This must be configured with Lithic before use
-
_shippingAddress
final JsonValue _shippingAddress()
Shipping address for all cards in this bulk order
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = cardBulkOrder.shippingAddress().convert(MyClass.class);
-
shippingMethod
final CardBulkOrder.ShippingMethod shippingMethod()
Shipping method for all cards in this bulk order
-
status
final CardBulkOrder.Status status()
Status of the bulk order. OPEN indicates the order is accepting cards. LOCKED indicates the order is finalized and no more cards can be added
-
updated
final OffsetDateTime updated()
An RFC 3339 timestamp for when the bulk order was last updated. UTC time zone
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Returns the raw JSON value of cardTokens.
Unlike cardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_customerProductId
final JsonField<String> _customerProductId()
Returns the raw JSON value of customerProductId.
Unlike customerProductId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardBulkOrder.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardBulkOrder.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardBulkOrder.Builder toBuilder()
-
validate
final CardBulkOrder validate()
-
builder
final static CardBulkOrder.Builder builder()
Returns a mutable builder for constructing an instance of CardBulkOrder.
The following fields are required:
.token() .cardTokens() .created() .customerProductId() .shippingAddress() .shippingMethod() .status() .updated()
-
-
-
-