Class CardBulkOrder.Builder
-
- All Implemented Interfaces:
public final class CardBulkOrder.BuilderA builder for CardBulkOrder.
-
-
Method Summary
Modifier and Type Method Description final CardBulkOrder.Buildertoken(String token)Globally unique identifier for the bulk order final CardBulkOrder.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final CardBulkOrder.BuildercardTokens(List<String> cardTokens)List of card tokens associated with this bulk order final CardBulkOrder.BuildercardTokens(JsonField<List<String>> cardTokens)Sets Builder.cardTokens to an arbitrary JSON value. final CardBulkOrder.BuilderaddCardToken(String cardToken)Adds a single String to cardTokens. final CardBulkOrder.Buildercreated(OffsetDateTime created)An RFC 3339 timestamp for when the bulk order was created. final CardBulkOrder.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final CardBulkOrder.BuildercustomerProductId(String customerProductId)Customer-specified product configuration for physical card manufacturing. final CardBulkOrder.BuildercustomerProductId(Optional<String> customerProductId)Alias for calling Builder.customerProductId with customerProductId.orElse(null).final CardBulkOrder.BuildercustomerProductId(JsonField<String> customerProductId)Sets Builder.customerProductId to an arbitrary JSON value. final CardBulkOrder.BuildershippingAddress(JsonValue shippingAddress)Shipping address for all cards in this bulk order final CardBulkOrder.BuildershippingMethod(CardBulkOrder.ShippingMethod shippingMethod)Shipping method for all cards in this bulk order final CardBulkOrder.BuildershippingMethod(JsonField<CardBulkOrder.ShippingMethod> shippingMethod)Sets Builder.shippingMethod to an arbitrary JSON value. final CardBulkOrder.Builderstatus(CardBulkOrder.Status status)Status of the bulk order. final CardBulkOrder.Builderstatus(JsonField<CardBulkOrder.Status> status)Sets Builder.status to an arbitrary JSON value. final CardBulkOrder.Builderupdated(OffsetDateTime updated)An RFC 3339 timestamp for when the bulk order was last updated. final CardBulkOrder.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final CardBulkOrder.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardBulkOrder.BuilderputAdditionalProperty(String key, JsonValue value)final CardBulkOrder.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardBulkOrder.BuilderremoveAdditionalProperty(String key)final CardBulkOrder.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardBulkOrderbuild()Returns an immutable instance of CardBulkOrder. -
-
Method Detail
-
token
final CardBulkOrder.Builder token(String token)
Globally unique identifier for the bulk order
-
token
final CardBulkOrder.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokens
final CardBulkOrder.Builder cardTokens(List<String> cardTokens)
List of card tokens associated with this bulk order
-
cardTokens
final CardBulkOrder.Builder cardTokens(JsonField<List<String>> cardTokens)
Sets Builder.cardTokens to an arbitrary JSON value.
You should usually call Builder.cardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCardToken
final CardBulkOrder.Builder addCardToken(String cardToken)
Adds a single String to cardTokens.
-
created
final CardBulkOrder.Builder created(OffsetDateTime created)
An RFC 3339 timestamp for when the bulk order was created. UTC time zone
-
created
final CardBulkOrder.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerProductId
final CardBulkOrder.Builder customerProductId(String customerProductId)
Customer-specified product configuration for physical card manufacturing. This must be configured with Lithic before use
-
customerProductId
final CardBulkOrder.Builder customerProductId(Optional<String> customerProductId)
Alias for calling Builder.customerProductId with
customerProductId.orElse(null).
-
customerProductId
final CardBulkOrder.Builder customerProductId(JsonField<String> customerProductId)
Sets Builder.customerProductId to an arbitrary JSON value.
You should usually call Builder.customerProductId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddress
final CardBulkOrder.Builder shippingAddress(JsonValue shippingAddress)
Shipping address for all cards in this bulk order
-
shippingMethod
final CardBulkOrder.Builder shippingMethod(CardBulkOrder.ShippingMethod shippingMethod)
Shipping method for all cards in this bulk order
-
shippingMethod
final CardBulkOrder.Builder shippingMethod(JsonField<CardBulkOrder.ShippingMethod> shippingMethod)
Sets Builder.shippingMethod to an arbitrary JSON value.
You should usually call Builder.shippingMethod with a well-typed ShippingMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardBulkOrder.Builder status(CardBulkOrder.Status status)
Status of the bulk order. OPEN indicates the order is accepting cards. LOCKED indicates the order is finalized and no more cards can be added
-
status
final CardBulkOrder.Builder status(JsonField<CardBulkOrder.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final CardBulkOrder.Builder updated(OffsetDateTime updated)
An RFC 3339 timestamp for when the bulk order was last updated. UTC time zone
-
updated
final CardBulkOrder.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardBulkOrder.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardBulkOrder.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardBulkOrder.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardBulkOrder.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardBulkOrder.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardBulkOrder build()
Returns an immutable instance of CardBulkOrder.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .cardTokens() .created() .customerProductId() .shippingAddress() .shippingMethod() .status() .updated()
-
-
-
-