Package com.lithic.api.models
Enum CardBulkOrder.ShippingMethod.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardBulkOrder.ShippingMethod.Known extends Enum<CardBulkOrder.ShippingMethod.Known>
An enum containing ShippingMethod's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardBulkOrder.ShippingMethod.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description BULK_EXPEDITED
-
Method Summary
Modifier and Type Method Description final CardBulkOrder.ShippingMethod.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardBulkOrder.ShippingMethod.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardBulkOrder.ShippingMethod.Known>getEntries()An enum containing ShippingMethod's known values. -
-
Method Detail
-
valueOf
final CardBulkOrder.ShippingMethod.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardBulkOrder.ShippingMethod.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardBulkOrder.ShippingMethod.Known> getEntries()
An enum containing ShippingMethod's known values.
-
-
-
-