Class CardBulkOrderCreateParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class CardBulkOrderCreateParams
     implements Params
                        

    Create a new bulk order for physical card shipments BETA. Cards can be added to the order via the POST /v1/cards endpoint by specifying the bulk_order_token. Lock the order via PATCH /v1/card_bulk_orders/{bulk_order_token} to prepare for shipment. Please work with your Customer Success Manager and card personalization bureau to ensure bulk shipping is supported for your program.