Class CardBulkOrderCreateParams.CreateBulkOrderRequest
-
- All Implemented Interfaces:
public final class CardBulkOrderCreateParams.CreateBulkOrderRequestRequest to create a new bulk order for physical card shipments. Please work with your Customer Success Manager and card personalization bureau to ensure bulk shipping is supported for your program.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBulkOrderCreateParams.CreateBulkOrderRequest.BuilderA builder for CreateBulkOrderRequest.
-
Method Summary
Modifier and Type Method Description final StringcustomerProductId()Customer-specified product configuration for physical card manufacturing. final JsonValue_shippingAddress()Shipping address for all cards in this bulk orderThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = createBulkOrderRequest.shippingAddress().convert(MyClass.class);final CardBulkOrderCreateParams.ShippingMethodshippingMethod()Shipping method for all cards in this bulk order. final JsonField<String>_customerProductId()Returns the raw JSON value of customerProductId. final JsonField<CardBulkOrderCreateParams.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final Map<String, JsonValue>_additionalProperties()final CardBulkOrderCreateParams.CreateBulkOrderRequest.BuildertoBuilder()final CardBulkOrderCreateParams.CreateBulkOrderRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBulkOrderCreateParams.CreateBulkOrderRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateBulkOrderRequest. -
-
Method Detail
-
customerProductId
final String customerProductId()
Customer-specified product configuration for physical card manufacturing. This must be configured with Lithic before use
-
_shippingAddress
final JsonValue _shippingAddress()
Shipping address for all cards in this bulk order
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = createBulkOrderRequest.shippingAddress().convert(MyClass.class);
-
shippingMethod
final CardBulkOrderCreateParams.ShippingMethod shippingMethod()
Shipping method for all cards in this bulk order. BULK_PRIORITY, BULK_2_DAY, and BULK_EXPRESS are only available with Perfect Plastic Printing
-
_customerProductId
final JsonField<String> _customerProductId()
Returns the raw JSON value of customerProductId.
Unlike customerProductId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardBulkOrderCreateParams.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder toBuilder()
-
validate
final CardBulkOrderCreateParams.CreateBulkOrderRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateBulkOrderRequest.
The following fields are required:
.customerProductId() .shippingAddress() .shippingMethod()
-
-
-
-