Class CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder
-
- All Implemented Interfaces:
public final class CardBulkOrderCreateParams.CreateBulkOrderRequest.BuilderA builder for CreateBulkOrderRequest.
-
-
Method Summary
-
-
Method Detail
-
customerProductId
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder customerProductId(String customerProductId)
Customer-specified product configuration for physical card manufacturing. This must be configured with Lithic before use
-
customerProductId
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder customerProductId(JsonField<String> customerProductId)
Sets Builder.customerProductId to an arbitrary JSON value.
You should usually call Builder.customerProductId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddress
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder shippingAddress(JsonValue shippingAddress)
Shipping address for all cards in this bulk order
-
shippingMethod
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder shippingMethod(CardBulkOrderCreateParams.ShippingMethod shippingMethod)
Shipping method for all cards in this bulk order
-
shippingMethod
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder shippingMethod(JsonField<CardBulkOrderCreateParams.ShippingMethod> shippingMethod)
Sets Builder.shippingMethod to an arbitrary JSON value.
You should usually call Builder.shippingMethod with a well-typed ShippingMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardBulkOrderCreateParams.CreateBulkOrderRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardBulkOrderCreateParams.CreateBulkOrderRequest build()
Returns an immutable instance of CreateBulkOrderRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.customerProductId() .shippingAddress() .shippingMethod()
-
-
-
-