Class CardConvertPhysicalParams.Body
-
- All Implemented Interfaces:
public final class CardConvertPhysicalParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardConvertPhysicalParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final ShippingAddressshippingAddress()The shipping address this card will be sent to. final Optional<Carrier>carrier()If omitted, the previous carrier will be used. final Optional<String>productId()Specifies the configuration (e.g. final Optional<CardConvertPhysicalParams.ShippingMethod>shippingMethod()Shipping method for the card. final JsonField<ShippingAddress>_shippingAddress()Returns the raw JSON value of shippingAddress. final JsonField<Carrier>_carrier()Returns the raw JSON value of carrier. final JsonField<String>_productId()Returns the raw JSON value of productId. final JsonField<CardConvertPhysicalParams.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final Map<String, JsonValue>_additionalProperties()final CardConvertPhysicalParams.Body.BuildertoBuilder()final CardConvertPhysicalParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardConvertPhysicalParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
shippingAddress
final ShippingAddress shippingAddress()
The shipping address this card will be sent to.
-
productId
final Optional<String> productId()
Specifies the configuration (e.g. physical card art) that the card should be manufactured with, and only applies to cards of type
PHYSICAL. This must be configured with Lithic before use.
-
shippingMethod
final Optional<CardConvertPhysicalParams.ShippingMethod> shippingMethod()
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides
STANDARDrequire additional permissions.STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with trackingBULK- Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.
-
_shippingAddress
final JsonField<ShippingAddress> _shippingAddress()
Returns the raw JSON value of shippingAddress.
Unlike shippingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_carrier
final JsonField<Carrier> _carrier()
Returns the raw JSON value of carrier.
Unlike carrier, this method doesn't throw if the JSON field has an unexpected type.
-
_productId
final JsonField<String> _productId()
Returns the raw JSON value of productId.
Unlike productId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardConvertPhysicalParams.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardConvertPhysicalParams.Body.Builder toBuilder()
-
validate
final CardConvertPhysicalParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardConvertPhysicalParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.shippingAddress()
-
-
-
-