Package com.lithic.api.models
Class CardConvertedWebhookEvent
-
- All Implemented Interfaces:
public final class CardConvertedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardConvertedWebhookEvent.BuilderA builder for CardConvertedWebhookEvent.
public final classCardConvertedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final StringcardToken()The token of the card that was created. final CardConvertedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<CardConvertedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final CardConvertedWebhookEvent.BuildertoBuilder()final CardConvertedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardConvertedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardConvertedWebhookEvent. -
-
Method Detail
-
eventType
final CardConvertedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardConvertedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardConvertedWebhookEvent.Builder toBuilder()
-
validate
final CardConvertedWebhookEvent validate()
-
builder
final static CardConvertedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardConvertedWebhookEvent.
The following fields are required:
.cardToken() .eventType()
-
-
-
-