Package com.lithic.api.models
Class CardConvertedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardConvertedWebhookEvent.BuilderA builder for CardConvertedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
cardToken
final CardConvertedWebhookEvent.Builder cardToken(String cardToken)
The token of the card that was created.
-
cardToken
final CardConvertedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final CardConvertedWebhookEvent.Builder eventType(CardConvertedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardConvertedWebhookEvent.Builder eventType(JsonField<CardConvertedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardConvertedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardConvertedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardConvertedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardConvertedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardConvertedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardConvertedWebhookEvent build()
Returns an immutable instance of CardConvertedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardToken() .eventType()
-
-
-
-