Package com.lithic.api.models
Class CardCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class CardCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreatedWebhookEvent.BuilderA builder for CardCreatedWebhookEvent.
public final classCardCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final StringcardToken()The token of the card that was created. final CardCreatedWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<String>replacementFor()The token of the card that was replaced, if the new card is a replacement card. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<CardCreatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_replacementFor()Returns the raw JSON value of replacementFor. final Map<String, JsonValue>_additionalProperties()final CardCreatedWebhookEvent.BuildertoBuilder()final CardCreatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardCreatedWebhookEvent. -
-
Method Detail
-
eventType
final CardCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
replacementFor
final Optional<String> replacementFor()
The token of the card that was replaced, if the new card is a replacement card.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_replacementFor
final JsonField<String> _replacementFor()
Returns the raw JSON value of replacementFor.
Unlike replacementFor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreatedWebhookEvent.Builder toBuilder()
-
validate
final CardCreatedWebhookEvent validate()
-
builder
final static CardCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardCreatedWebhookEvent.
The following fields are required:
.cardToken() .eventType()
-
-
-
-