Class CardCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardCreatedWebhookEvent.BuilderA builder for CardCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
cardToken
final CardCreatedWebhookEvent.Builder cardToken(String cardToken)
The token of the card that was created.
-
cardToken
final CardCreatedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final CardCreatedWebhookEvent.Builder eventType(CardCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardCreatedWebhookEvent.Builder eventType(JsonField<CardCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
replacementFor
final CardCreatedWebhookEvent.Builder replacementFor(String replacementFor)
The token of the card that was replaced, if the new card is a replacement card.
-
replacementFor
final CardCreatedWebhookEvent.Builder replacementFor(Optional<String> replacementFor)
Alias for calling Builder.replacementFor with
replacementFor.orElse(null).
-
replacementFor
final CardCreatedWebhookEvent.Builder replacementFor(JsonField<String> replacementFor)
Sets Builder.replacementFor to an arbitrary JSON value.
You should usually call Builder.replacementFor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardCreatedWebhookEvent build()
Returns an immutable instance of CardCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardToken() .eventType()
-
-
-
-