Package com.lithic.api.models
Class CardFinancialTransactionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardFinancialTransactionListPageAsync.BuilderA builder for CardFinancialTransactionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardFinancialTransactionListPageAsync.Builderservice(FinancialTransactionServiceAsync service)final CardFinancialTransactionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardFinancialTransactionListPageAsync.Builderparams(CardFinancialTransactionListParams params)The parameters that were used to request this page. final CardFinancialTransactionListPageAsync.Builderresponse(CardFinancialTransactionListPageResponse response)The response that this page was parsed from. final CardFinancialTransactionListPageAsyncbuild()Returns an immutable instance of CardFinancialTransactionListPageAsync. -
-
Method Detail
-
service
final CardFinancialTransactionListPageAsync.Builder service(FinancialTransactionServiceAsync service)
-
streamHandlerExecutor
final CardFinancialTransactionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardFinancialTransactionListPageAsync.Builder params(CardFinancialTransactionListParams params)
The parameters that were used to request this page.
-
response
final CardFinancialTransactionListPageAsync.Builder response(CardFinancialTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final CardFinancialTransactionListPageAsync build()
Returns an immutable instance of CardFinancialTransactionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-