Package com.lithic.api.models
Class CardFinancialTransactionListPageResponse
-
- All Implemented Interfaces:
public final class CardFinancialTransactionListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFinancialTransactionListPageResponse.BuilderA builder for CardFinancialTransactionListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<FinancialTransaction>data()final BooleanhasMore()More data exists. final JsonField<List<FinancialTransaction>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final CardFinancialTransactionListPageResponse.BuildertoBuilder()final CardFinancialTransactionListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardFinancialTransactionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardFinancialTransactionListPageResponse. -
-
Method Detail
-
data
final List<FinancialTransaction> data()
-
_data
final JsonField<List<FinancialTransaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardFinancialTransactionListPageResponse.Builder toBuilder()
-
validate
final CardFinancialTransactionListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardFinancialTransactionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardFinancialTransactionListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-