Package com.lithic.api.models
Class CardProgramListPageResponse
-
- All Implemented Interfaces:
public final class CardProgramListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardProgramListPageResponse.BuilderA builder for CardProgramListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CardProgram>data()final BooleanhasMore()More data exists. final JsonField<List<CardProgram>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final CardProgramListPageResponse.BuildertoBuilder()final CardProgramListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardProgramListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardProgramListPageResponse. -
-
Method Detail
-
data
final List<CardProgram> data()
-
_data
final JsonField<List<CardProgram>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardProgramListPageResponse.Builder toBuilder()
-
validate
final CardProgramListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardProgramListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardProgramListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-