Package com.lithic.api.models
Class CardReissuedWebhookEvent
-
- All Implemented Interfaces:
public final class CardReissuedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardReissuedWebhookEvent.BuilderA builder for CardReissuedWebhookEvent.
public final classCardReissuedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final CardReissuedWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<String>cardToken()The token of the card that was reissued. final JsonField<CardReissuedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final Map<String, JsonValue>_additionalProperties()final CardReissuedWebhookEvent.BuildertoBuilder()final CardReissuedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardReissuedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardReissuedWebhookEvent. -
-
Method Detail
-
eventType
final CardReissuedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_eventType
final JsonField<CardReissuedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardReissuedWebhookEvent.Builder toBuilder()
-
validate
final CardReissuedWebhookEvent validate()
-
builder
final static CardReissuedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardReissuedWebhookEvent.
The following fields are required:
.eventType()
-
-
-
-