Package com.lithic.api.models
Class CardReissuedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardReissuedWebhookEvent.BuilderA builder for CardReissuedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
eventType
final CardReissuedWebhookEvent.Builder eventType(CardReissuedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardReissuedWebhookEvent.Builder eventType(JsonField<CardReissuedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final CardReissuedWebhookEvent.Builder cardToken(String cardToken)
The token of the card that was reissued.
-
cardToken
final CardReissuedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardReissuedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardReissuedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardReissuedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardReissuedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardReissuedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardReissuedWebhookEvent build()
Returns an immutable instance of CardReissuedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventType()
-
-
-
-