Class CardRenewParams.Body
-
- All Implemented Interfaces:
public final class CardRenewParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRenewParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final ShippingAddressshippingAddress()The shipping address this card will be sent to. final Optional<Carrier>carrier()If omitted, the previous carrier will be used. final Optional<String>expMonth()Two digit (MM) expiry month. final Optional<String>expYear()Four digit (yyyy) expiry year. final Optional<String>productId()Specifies the configuration (e.g. final Optional<CardRenewParams.ShippingMethod>shippingMethod()Shipping method for the card. final JsonField<ShippingAddress>_shippingAddress()Returns the raw JSON value of shippingAddress. final JsonField<Carrier>_carrier()Returns the raw JSON value of carrier. final JsonField<String>_expMonth()Returns the raw JSON value of expMonth. final JsonField<String>_expYear()Returns the raw JSON value of expYear. final JsonField<String>_productId()Returns the raw JSON value of productId. final JsonField<CardRenewParams.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final Map<String, JsonValue>_additionalProperties()final CardRenewParams.Body.BuildertoBuilder()final CardRenewParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRenewParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
shippingAddress
final ShippingAddress shippingAddress()
The shipping address this card will be sent to.
-
expMonth
final Optional<String> expMonth()
Two digit (MM) expiry month. If neither
exp_monthnorexp_yearis provided, an expiration date five years in the future will be generated. Five years is the maximum expiration date.
-
expYear
final Optional<String> expYear()
Four digit (yyyy) expiry year. If neither
exp_monthnorexp_yearis provided, an expiration date five years in the future will be generated. Five years is the maximum expiration date.
-
productId
final Optional<String> productId()
Specifies the configuration (e.g. physical card art) that the card should be manufactured with, and only applies to cards of type
PHYSICAL. This must be configured with Lithic before use.
-
shippingMethod
final Optional<CardRenewParams.ShippingMethod> shippingMethod()
Shipping method for the card. Only applies to cards of type PHYSICAL. Use of options besides
STANDARDrequire additional permissions.STANDARD- USPS regular mail or similar international option, with no trackingSTANDARD_WITH_TRACKING- USPS regular mail or similar international option, with trackingPRIORITY- USPS Priority, 1-3 day shipping, with trackingEXPRESS- FedEx or UPS depending on card manufacturer, Express, 3-day shipping, with tracking2_DAY- FedEx or UPS depending on card manufacturer, 2-day shipping, with trackingEXPEDITED- FedEx or UPS depending on card manufacturer, Standard Overnight or similar international option, with trackingBULK- Card will be shipped as part of a bulk fulfillment order. The shipping method and timeline are inherited from the parent bulk order.
-
_shippingAddress
final JsonField<ShippingAddress> _shippingAddress()
Returns the raw JSON value of shippingAddress.
Unlike shippingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_carrier
final JsonField<Carrier> _carrier()
Returns the raw JSON value of carrier.
Unlike carrier, this method doesn't throw if the JSON field has an unexpected type.
-
_expMonth
final JsonField<String> _expMonth()
Returns the raw JSON value of expMonth.
Unlike expMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_expYear
final JsonField<String> _expYear()
Returns the raw JSON value of expYear.
Unlike expYear, this method doesn't throw if the JSON field has an unexpected type.
-
_productId
final JsonField<String> _productId()
Returns the raw JSON value of productId.
Unlike productId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardRenewParams.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardRenewParams.Body.Builder toBuilder()
-
validate
final CardRenewParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardRenewParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.shippingAddress()
-
-
-
-