Class CardRenewedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class CardRenewedWebhookEvent.BuilderA builder for CardRenewedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
eventType
final CardRenewedWebhookEvent.Builder eventType(CardRenewedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final CardRenewedWebhookEvent.Builder eventType(JsonField<CardRenewedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final CardRenewedWebhookEvent.Builder cardToken(String cardToken)
The token of the card that was renewed.
-
cardToken
final CardRenewedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expMonth
final CardRenewedWebhookEvent.Builder expMonth(String expMonth)
The new expiration month of the card.
-
expMonth
final CardRenewedWebhookEvent.Builder expMonth(JsonField<String> expMonth)
Sets Builder.expMonth to an arbitrary JSON value.
You should usually call Builder.expMonth with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expYear
final CardRenewedWebhookEvent.Builder expYear(String expYear)
The new expiration year of the card.
-
expYear
final CardRenewedWebhookEvent.Builder expYear(JsonField<String> expYear)
Sets Builder.expYear to an arbitrary JSON value.
You should usually call Builder.expYear with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousExpMonth
final CardRenewedWebhookEvent.Builder previousExpMonth(String previousExpMonth)
The previous expiration month of the card.
-
previousExpMonth
final CardRenewedWebhookEvent.Builder previousExpMonth(JsonField<String> previousExpMonth)
Sets Builder.previousExpMonth to an arbitrary JSON value.
You should usually call Builder.previousExpMonth with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousExpYear
final CardRenewedWebhookEvent.Builder previousExpYear(String previousExpYear)
The previous expiration year of the card.
-
previousExpYear
final CardRenewedWebhookEvent.Builder previousExpYear(JsonField<String> previousExpYear)
Sets Builder.previousExpYear to an arbitrary JSON value.
You should usually call Builder.previousExpYear with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardRenewedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardRenewedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardRenewedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardRenewedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardRenewedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardRenewedWebhookEvent build()
Returns an immutable instance of CardRenewedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventType()
-
-
-
-