Package com.lithic.api.models
Class CardSearchByPanParams.Body
-
- All Implemented Interfaces:
public final class CardSearchByPanParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSearchByPanParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringpan()The PAN for the card being retrieved. final JsonField<String>_pan()Returns the raw JSON value of pan. final Map<String, JsonValue>_additionalProperties()final CardSearchByPanParams.Body.BuildertoBuilder()final CardSearchByPanParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSearchByPanParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSearchByPanParams.Body.Builder toBuilder()
-
validate
final CardSearchByPanParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardSearchByPanParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.pan()
-
-
-
-