Class CardShippedWebhookEvent
-
- All Implemented Interfaces:
public final class CardShippedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardShippedWebhookEvent.BuilderA builder for CardShippedWebhookEvent.
public final classCardShippedWebhookEvent.EventTypeThe type of event that occurred.
public final classCardShippedWebhookEvent.ShippingMethodThe specific shipping method used to ship the card.
-
Method Summary
Modifier and Type Method Description final Optional<String>bulkOrderToken()The token of the bulk order associated with this card shipment, if applicable. final StringcardToken()The token of the card that was shipped. final CardShippedWebhookEvent.EventTypeeventType()The type of event that occurred. final CardShippedWebhookEvent.ShippingMethodshippingMethod()The specific shipping method used to ship the card. final Optional<String>trackingNumber()The tracking number of the shipment. final JsonField<String>_bulkOrderToken()Returns the raw JSON value of bulkOrderToken. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<CardShippedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<CardShippedWebhookEvent.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final JsonField<String>_trackingNumber()Returns the raw JSON value of trackingNumber. final Map<String, JsonValue>_additionalProperties()final CardShippedWebhookEvent.BuildertoBuilder()final CardShippedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardShippedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardShippedWebhookEvent. -
-
Method Detail
-
bulkOrderToken
final Optional<String> bulkOrderToken()
The token of the bulk order associated with this card shipment, if applicable.
-
eventType
final CardShippedWebhookEvent.EventType eventType()
The type of event that occurred.
-
shippingMethod
final CardShippedWebhookEvent.ShippingMethod shippingMethod()
The specific shipping method used to ship the card.
-
trackingNumber
final Optional<String> trackingNumber()
The tracking number of the shipment.
-
_bulkOrderToken
final JsonField<String> _bulkOrderToken()
Returns the raw JSON value of bulkOrderToken.
Unlike bulkOrderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardShippedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardShippedWebhookEvent.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_trackingNumber
final JsonField<String> _trackingNumber()
Returns the raw JSON value of trackingNumber.
Unlike trackingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardShippedWebhookEvent.Builder toBuilder()
-
validate
final CardShippedWebhookEvent validate()
-
builder
final static CardShippedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardShippedWebhookEvent.
The following fields are required:
.bulkOrderToken() .cardToken() .eventType() .shippingMethod() .trackingNumber()
-
-
-
-