Package com.lithic.api.models
Class CardSpendLimits
-
- All Implemented Interfaces:
public final class CardSpendLimits
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSpendLimits.BuilderA builder for CardSpendLimits.
public final classCardSpendLimits.AvailableSpendLimitpublic final classCardSpendLimits.SpendLimitpublic final classCardSpendLimits.SpendVelocity
-
Method Summary
Modifier and Type Method Description final CardSpendLimits.AvailableSpendLimitavailableSpendLimit()final Optional<CardSpendLimits.SpendLimit>spendLimit()final Optional<CardSpendLimits.SpendVelocity>spendVelocity()final JsonField<CardSpendLimits.AvailableSpendLimit>_availableSpendLimit()Returns the raw JSON value of availableSpendLimit. final JsonField<CardSpendLimits.SpendLimit>_spendLimit()Returns the raw JSON value of spendLimit. final JsonField<CardSpendLimits.SpendVelocity>_spendVelocity()Returns the raw JSON value of spendVelocity. final Map<String, JsonValue>_additionalProperties()final CardSpendLimits.BuildertoBuilder()final CardSpendLimitsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSpendLimits.Builderbuilder()Returns a mutable builder for constructing an instance of CardSpendLimits. -
-
Method Detail
-
availableSpendLimit
final CardSpendLimits.AvailableSpendLimit availableSpendLimit()
-
spendLimit
final Optional<CardSpendLimits.SpendLimit> spendLimit()
-
spendVelocity
final Optional<CardSpendLimits.SpendVelocity> spendVelocity()
-
_availableSpendLimit
final JsonField<CardSpendLimits.AvailableSpendLimit> _availableSpendLimit()
Returns the raw JSON value of availableSpendLimit.
Unlike availableSpendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendLimit
final JsonField<CardSpendLimits.SpendLimit> _spendLimit()
Returns the raw JSON value of spendLimit.
Unlike spendLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_spendVelocity
final JsonField<CardSpendLimits.SpendVelocity> _spendVelocity()
Returns the raw JSON value of spendVelocity.
Unlike spendVelocity, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSpendLimits.Builder toBuilder()
-
validate
final CardSpendLimits validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardSpendLimits.Builder builder()
Returns a mutable builder for constructing an instance of CardSpendLimits.
The following fields are required:
.availableSpendLimit()
-
-
-
-