Class CardSpendLimits.AvailableSpendLimit
-
- All Implemented Interfaces:
public final class CardSpendLimits.AvailableSpendLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSpendLimits.AvailableSpendLimit.BuilderA builder for AvailableSpendLimit.
-
Method Summary
Modifier and Type Method Description final Optional<Long>annually()The available spend limit (in cents) relative to the annual limit configured on the Card (e.g. final Optional<Long>forever()The available spend limit (in cents) relative to the forever limit configured on the Card. final Optional<Long>monthly()The available spend limit (in cents) relative to the monthly limit configured on the Card. final JsonField<Long>_annually()Returns the raw JSON value of annually. final JsonField<Long>_forever()Returns the raw JSON value of forever. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final CardSpendLimits.AvailableSpendLimit.BuildertoBuilder()final CardSpendLimits.AvailableSpendLimitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSpendLimits.AvailableSpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of AvailableSpendLimit. -
-
Method Detail
-
annually
final Optional<Long> annually()
The available spend limit (in cents) relative to the annual limit configured on the Card (e.g. 100000 would be a $1,000 limit).
-
forever
final Optional<Long> forever()
The available spend limit (in cents) relative to the forever limit configured on the Card.
-
monthly
final Optional<Long> monthly()
The available spend limit (in cents) relative to the monthly limit configured on the Card.
-
_annually
final JsonField<Long> _annually()
Returns the raw JSON value of annually.
Unlike annually, this method doesn't throw if the JSON field has an unexpected type.
-
_forever
final JsonField<Long> _forever()
Returns the raw JSON value of forever.
Unlike forever, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSpendLimits.AvailableSpendLimit.Builder toBuilder()
-
validate
final CardSpendLimits.AvailableSpendLimit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardSpendLimits.AvailableSpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of AvailableSpendLimit.
-
-
-
-