Class CardSpendLimits.AvailableSpendLimit.Builder
-
- All Implemented Interfaces:
public final class CardSpendLimits.AvailableSpendLimit.BuilderA builder for AvailableSpendLimit.
-
-
Method Summary
-
-
Method Detail
-
annually
final CardSpendLimits.AvailableSpendLimit.Builder annually(Long annually)
The available spend limit (in cents) relative to the annual limit configured on the Card (e.g. 100000 would be a $1,000 limit).
-
annually
final CardSpendLimits.AvailableSpendLimit.Builder annually(JsonField<Long> annually)
Sets Builder.annually to an arbitrary JSON value.
You should usually call Builder.annually with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
forever
final CardSpendLimits.AvailableSpendLimit.Builder forever(Long forever)
The available spend limit (in cents) relative to the forever limit configured on the Card.
-
forever
final CardSpendLimits.AvailableSpendLimit.Builder forever(JsonField<Long> forever)
Sets Builder.forever to an arbitrary JSON value.
You should usually call Builder.forever with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
monthly
final CardSpendLimits.AvailableSpendLimit.Builder monthly(Long monthly)
The available spend limit (in cents) relative to the monthly limit configured on the Card.
-
monthly
final CardSpendLimits.AvailableSpendLimit.Builder monthly(JsonField<Long> monthly)
Sets Builder.monthly to an arbitrary JSON value.
You should usually call Builder.monthly with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardSpendLimits.AvailableSpendLimit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardSpendLimits.AvailableSpendLimit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardSpendLimits.AvailableSpendLimit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardSpendLimits.AvailableSpendLimit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardSpendLimits.AvailableSpendLimit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardSpendLimits.AvailableSpendLimit build()
Returns an immutable instance of AvailableSpendLimit.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-