Class CardSpendLimits.SpendLimit.Builder
-
- All Implemented Interfaces:
public final class CardSpendLimits.SpendLimit.BuilderA builder for SpendLimit.
-
-
Method Summary
-
-
Method Detail
-
annually
final CardSpendLimits.SpendLimit.Builder annually(Long annually)
The configured annual spend limit (in cents) on the Card.
-
annually
final CardSpendLimits.SpendLimit.Builder annually(JsonField<Long> annually)
Sets Builder.annually to an arbitrary JSON value.
You should usually call Builder.annually with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
forever
final CardSpendLimits.SpendLimit.Builder forever(Long forever)
The configured forever spend limit (in cents) on the Card.
-
forever
final CardSpendLimits.SpendLimit.Builder forever(JsonField<Long> forever)
Sets Builder.forever to an arbitrary JSON value.
You should usually call Builder.forever with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
monthly
final CardSpendLimits.SpendLimit.Builder monthly(Long monthly)
The configured monthly spend limit (in cents) on the Card.
-
monthly
final CardSpendLimits.SpendLimit.Builder monthly(JsonField<Long> monthly)
Sets Builder.monthly to an arbitrary JSON value.
You should usually call Builder.monthly with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardSpendLimits.SpendLimit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardSpendLimits.SpendLimit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardSpendLimits.SpendLimit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardSpendLimits.SpendLimit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardSpendLimits.SpendLimit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardSpendLimits.SpendLimit build()
Returns an immutable instance of SpendLimit.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-