Class CardSpendLimits.SpendVelocity
-
- All Implemented Interfaces:
public final class CardSpendLimits.SpendVelocity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSpendLimits.SpendVelocity.BuilderA builder for SpendVelocity.
-
Method Summary
Modifier and Type Method Description final Optional<Long>annually()Current annual spend velocity (in cents) on the Card. final Optional<Long>forever()Current forever spend velocity (in cents) on the Card. final Optional<Long>monthly()Current monthly spend velocity (in cents) on the Card. final JsonField<Long>_annually()Returns the raw JSON value of annually. final JsonField<Long>_forever()Returns the raw JSON value of forever. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final CardSpendLimits.SpendVelocity.BuildertoBuilder()final CardSpendLimits.SpendVelocityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSpendLimits.SpendVelocity.Builderbuilder()Returns a mutable builder for constructing an instance of SpendVelocity. -
-
Method Detail
-
annually
final Optional<Long> annually()
Current annual spend velocity (in cents) on the Card. Present if annual spend limit is set.
-
forever
final Optional<Long> forever()
Current forever spend velocity (in cents) on the Card. Present if forever spend limit is set.
-
monthly
final Optional<Long> monthly()
Current monthly spend velocity (in cents) on the Card. Present if monthly spend limit is set.
-
_annually
final JsonField<Long> _annually()
Returns the raw JSON value of annually.
Unlike annually, this method doesn't throw if the JSON field has an unexpected type.
-
_forever
final JsonField<Long> _forever()
Returns the raw JSON value of forever.
Unlike forever, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSpendLimits.SpendVelocity.Builder toBuilder()
-
validate
final CardSpendLimits.SpendVelocity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardSpendLimits.SpendVelocity.Builder builder()
Returns a mutable builder for constructing an instance of SpendVelocity.
-
-
-
-