Class CardTransactionUpdateAction.CreateCaseAction.Builder
-
- All Implemented Interfaces:
public final class CardTransactionUpdateAction.CreateCaseAction.BuilderA builder for CreateCaseAction.
-
-
Method Summary
-
-
Method Detail
-
queueToken
final CardTransactionUpdateAction.CreateCaseAction.Builder queueToken(String queueToken)
The token of the queue to create the case in
-
queueToken
final CardTransactionUpdateAction.CreateCaseAction.Builder queueToken(JsonField<String> queueToken)
Sets Builder.queueToken to an arbitrary JSON value.
You should usually call Builder.queueToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
scope
final CardTransactionUpdateAction.CreateCaseAction.Builder scope(CardTransactionUpdateAction.CreateCaseAction.Scope scope)
The scope of the case to create
-
scope
final CardTransactionUpdateAction.CreateCaseAction.Builder scope(JsonField<CardTransactionUpdateAction.CreateCaseAction.Scope> scope)
Sets Builder.scope to an arbitrary JSON value.
You should usually call Builder.scope with a well-typed Scope value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardTransactionUpdateAction.CreateCaseAction.Builder type(CardTransactionUpdateAction.CreateCaseAction.Type type)
Create a case for the transaction
-
type
final CardTransactionUpdateAction.CreateCaseAction.Builder type(JsonField<CardTransactionUpdateAction.CreateCaseAction.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardTransactionUpdateAction.CreateCaseAction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardTransactionUpdateAction.CreateCaseAction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardTransactionUpdateAction.CreateCaseAction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardTransactionUpdateAction.CreateCaseAction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardTransactionUpdateAction.CreateCaseAction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardTransactionUpdateAction.CreateCaseAction build()
Returns an immutable instance of CreateCaseAction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.queueToken() .scope() .type()
-
-
-
-