Package com.lithic.api.models
Interface CardTransactionUpdateAction.Visitor
-
- All Implemented Interfaces:
public interface CardTransactionUpdateAction.Visitor<T extends Object>An interface that defines how to map each variant of CardTransactionUpdateAction to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitTag(CardTransactionUpdateAction.TagAction tag)abstract TvisitCreateCase(CardTransactionUpdateAction.CreateCaseAction createCase)Tunknown(JsonValue json)Maps an unknown variant of CardTransactionUpdateAction to a value of type T. -
-
Method Detail
-
visitTag
abstract T visitTag(CardTransactionUpdateAction.TagAction tag)
-
visitCreateCase
abstract T visitCreateCase(CardTransactionUpdateAction.CreateCaseAction createCase)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of CardTransactionUpdateAction to a value of type T.
An instance of CardTransactionUpdateAction can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-