Class CardUpdateParams.Substatus

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class CardUpdateParams.Substatus
     implements Enum
                        

    Card state substatus values:

    • LOST - The physical card is no longer in the cardholder's possession due to being lost or never received by the cardholder.

    • COMPROMISED - Card information has been exposed, potentially leading to unauthorized access. This may involve physical card theft, cloning, or online data breaches.

    • DAMAGED - The physical card is not functioning properly, such as having chip failures or a demagnetized magnetic stripe.

    • END_USER_REQUEST - The cardholder requested the closure of the card for reasons unrelated to fraud or damage, such as switching to a different product or closing the account.

    • ISSUER_REQUEST - The issuer closed the card for reasons unrelated to fraud or damage, such as account inactivity, product or policy changes, or technology upgrades.

    • NOT_ACTIVE - The card hasn’t had any transaction activity for a specified period, applicable to statuses like PAUSED or CLOSED.

    • SUSPICIOUS_ACTIVITY - The card has one or more suspicious transactions or activities that require review. This can involve prompting the cardholder to confirm legitimate use or report confirmed fraud.

    • INTERNAL_REVIEW - The card is temporarily paused pending further internal review.

    • EXPIRED - The card has expired and has been closed without being reissued.

    • UNDELIVERABLE - The card cannot be delivered to the cardholder and has been returned.

    • OTHER - The reason for the status does not fall into any of the above categories. A comment should be provided to specify the reason.

    • Constructor Detail

    • Method Detail

      • _value

         final JsonField<String> _value()

        Returns this class instance's raw value.

        This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

      • value

         final CardUpdateParams.Substatus.Value value()

        Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.

        Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.

      • known

         final CardUpdateParams.Substatus.Known known()

        Returns an enum member corresponding to this class instance's value.

        Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.

      • asString

         final String asString()

        Returns this class instance's primitive wire representation.

        This differs from the toString method because that method is primarily for debugging and generally doesn't throw.

      • validate

         final CardUpdateParams.Substatus validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.