Package com.lithic.api.models
Class CardUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class CardUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdatedWebhookEvent.BuilderA builder for CardUpdatedWebhookEvent.
public final classCardUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final StringcardToken()The token of the card that was updated. final CardUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonValue_previousFields()The previous values of the fields that were updated. final Stringstate()The current state of the card. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<CardUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final CardUpdatedWebhookEvent.BuildertoBuilder()final CardUpdatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardUpdatedWebhookEvent. -
-
Method Detail
-
eventType
final CardUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_previousFields
final JsonValue _previousFields()
The previous values of the fields that were updated.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = cardUpdatedWebhookEvent.previousFields().convert(MyClass.class);
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdatedWebhookEvent.Builder toBuilder()
-
validate
final CardUpdatedWebhookEvent validate()
-
builder
final static CardUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardUpdatedWebhookEvent.
The following fields are required:
.cardToken() .eventType() .previousFields() .state()
-
-
-
-