Class CardWebProvisionParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardWebProvisionParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
clientDeviceId
final CardWebProvisionParams.Body.Builder clientDeviceId(String clientDeviceId)
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning device identifier required for the tokenization flow
-
clientDeviceId
final CardWebProvisionParams.Body.Builder clientDeviceId(JsonField<String> clientDeviceId)
Sets Builder.clientDeviceId to an arbitrary JSON value.
You should usually call Builder.clientDeviceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientWalletAccountId
final CardWebProvisionParams.Body.Builder clientWalletAccountId(String clientWalletAccountId)
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning wallet account identifier required for the tokenization flow
-
clientWalletAccountId
final CardWebProvisionParams.Body.Builder clientWalletAccountId(JsonField<String> clientWalletAccountId)
Sets Builder.clientWalletAccountId to an arbitrary JSON value.
You should usually call Builder.clientWalletAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final CardWebProvisionParams.Body.Builder digitalWallet(CardWebProvisionParams.DigitalWallet digitalWallet)
Name of digital wallet provider.
-
digitalWallet
final CardWebProvisionParams.Body.Builder digitalWallet(JsonField<CardWebProvisionParams.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
serverSessionId
final CardWebProvisionParams.Body.Builder serverSessionId(String serverSessionId)
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning session identifier required for the FPAN flow.
-
serverSessionId
final CardWebProvisionParams.Body.Builder serverSessionId(JsonField<String> serverSessionId)
Sets Builder.serverSessionId to an arbitrary JSON value.
You should usually call Builder.serverSessionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardWebProvisionParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardWebProvisionParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardWebProvisionParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardWebProvisionParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardWebProvisionParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardWebProvisionParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-