Package com.lithic.api.models
Interface CardWebProvisionResponse.Visitor
-
- All Implemented Interfaces:
public interface CardWebProvisionResponse.Visitor<T extends Object>An interface that defines how to map each variant of CardWebProvisionResponse to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitAppleWebPushProvisioning(CardWebProvisionResponse.AppleWebPushProvisioningResponse appleWebPushProvisioning)abstract TvisitGoogleWebPushProvisioning(CardWebProvisionResponse.GoogleWebPushProvisioningResponse googleWebPushProvisioning)Tunknown(JsonValue json)Maps an unknown variant of CardWebProvisionResponse to a value of type T. -
-
Method Detail
-
visitAppleWebPushProvisioning
abstract T visitAppleWebPushProvisioning(CardWebProvisionResponse.AppleWebPushProvisioningResponse appleWebPushProvisioning)
-
visitGoogleWebPushProvisioning
abstract T visitGoogleWebPushProvisioning(CardWebProvisionResponse.GoogleWebPushProvisioningResponse googleWebPushProvisioning)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of CardWebProvisionResponse to a value of type T.
An instance of CardWebProvisionResponse can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-