Class CaseActivityEntry
-
- All Implemented Interfaces:
public final class CaseActivityEntryA single entry in a case's activity feed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCaseActivityEntry.BuilderA builder for CaseActivityEntry.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the activity entry final Optional<String>actorToken()Identifier of the actor that produced the activity entry final OffsetDateTimecreated()Date and time at which the activity entry was created final CaseActivityTypeentryType()The case field that changed, or the action that was taken, in an activity entry: STATUS- The case status changedTITLE- The case title changedASSIGNED_TO- The case assignee changedRESOLUTION_OUTCOME- The resolution outcome was set or changedRESOLUTION_NOTES- The resolution notes were set or changedTAGS- The case tags changedPRIORITY- The case priority changedCOMMENT- A comment was added or editedFILE- A file was attached to the case
final Optional<String>newValue()New value of the changed field, when applicable final Optional<String>previousValue()Previous value of the changed field, when applicable final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_actorToken()Returns the raw JSON value of actorToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<CaseActivityType>_entryType()Returns the raw JSON value of entryType. final JsonField<String>_newValue()Returns the raw JSON value of newValue. final JsonField<String>_previousValue()Returns the raw JSON value of previousValue. final Map<String, JsonValue>_additionalProperties()final CaseActivityEntry.BuildertoBuilder()final CaseActivityEntryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CaseActivityEntry.Builderbuilder()Returns a mutable builder for constructing an instance of CaseActivityEntry. -
-
Method Detail
-
actorToken
final Optional<String> actorToken()
Identifier of the actor that produced the activity entry
-
created
final OffsetDateTime created()
Date and time at which the activity entry was created
-
entryType
final CaseActivityType entryType()
The case field that changed, or the action that was taken, in an activity entry:
STATUS- The case status changedTITLE- The case title changedASSIGNED_TO- The case assignee changedRESOLUTION_OUTCOME- The resolution outcome was set or changedRESOLUTION_NOTES- The resolution notes were set or changedTAGS- The case tags changedPRIORITY- The case priority changedCOMMENT- A comment was added or editedFILE- A file was attached to the case
-
previousValue
final Optional<String> previousValue()
Previous value of the changed field, when applicable
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_actorToken
final JsonField<String> _actorToken()
Returns the raw JSON value of actorToken.
Unlike actorToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_entryType
final JsonField<CaseActivityType> _entryType()
Returns the raw JSON value of entryType.
Unlike entryType, this method doesn't throw if the JSON field has an unexpected type.
-
_newValue
final JsonField<String> _newValue()
Returns the raw JSON value of newValue.
Unlike newValue, this method doesn't throw if the JSON field has an unexpected type.
-
_previousValue
final JsonField<String> _previousValue()
Returns the raw JSON value of previousValue.
Unlike previousValue, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CaseActivityEntry.Builder toBuilder()
-
validate
final CaseActivityEntry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CaseActivityEntry.Builder builder()
Returns a mutable builder for constructing an instance of CaseActivityEntry.
The following fields are required:
.token() .actorToken() .created() .entryType() .newValue() .previousValue()
-
-
-