Class CaseActivityEntry.Builder
-
- All Implemented Interfaces:
public final class CaseActivityEntry.BuilderA builder for CaseActivityEntry.
-
-
Method Summary
Modifier and Type Method Description final CaseActivityEntry.Buildertoken(String token)Globally unique identifier for the activity entry final CaseActivityEntry.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final CaseActivityEntry.BuilderactorToken(String actorToken)Identifier of the actor that produced the activity entry final CaseActivityEntry.BuilderactorToken(Optional<String> actorToken)Alias for calling Builder.actorToken with actorToken.orElse(null).final CaseActivityEntry.BuilderactorToken(JsonField<String> actorToken)Sets Builder.actorToken to an arbitrary JSON value. final CaseActivityEntry.Buildercreated(OffsetDateTime created)Date and time at which the activity entry was created final CaseActivityEntry.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final CaseActivityEntry.BuilderentryType(CaseActivityType entryType)The case field that changed, or the action that was taken, in an activity entry: STATUS- The case status changedTITLE- The case title changedASSIGNED_TO- The case assignee changedRESOLUTION_OUTCOME- The resolution outcome was set or changedRESOLUTION_NOTES- The resolution notes were set or changedTAGS- The case tags changedPRIORITY- The case priority changedCOMMENT- A comment was added or editedFILE- A file was attached to the case
final CaseActivityEntry.BuilderentryType(JsonField<CaseActivityType> entryType)Sets Builder.entryType to an arbitrary JSON value. final CaseActivityEntry.BuildernewValue(String newValue)New value of the changed field, when applicable final CaseActivityEntry.BuildernewValue(Optional<String> newValue)Alias for calling Builder.newValue with newValue.orElse(null).final CaseActivityEntry.BuildernewValue(JsonField<String> newValue)Sets Builder.newValue to an arbitrary JSON value. final CaseActivityEntry.BuilderpreviousValue(String previousValue)Previous value of the changed field, when applicable final CaseActivityEntry.BuilderpreviousValue(Optional<String> previousValue)Alias for calling Builder.previousValue with previousValue.orElse(null).final CaseActivityEntry.BuilderpreviousValue(JsonField<String> previousValue)Sets Builder.previousValue to an arbitrary JSON value. final CaseActivityEntry.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CaseActivityEntry.BuilderputAdditionalProperty(String key, JsonValue value)final CaseActivityEntry.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CaseActivityEntry.BuilderremoveAdditionalProperty(String key)final CaseActivityEntry.BuilderremoveAllAdditionalProperties(Set<String> keys)final CaseActivityEntrybuild()Returns an immutable instance of CaseActivityEntry. -
-
Method Detail
-
token
final CaseActivityEntry.Builder token(String token)
Globally unique identifier for the activity entry
-
token
final CaseActivityEntry.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actorToken
final CaseActivityEntry.Builder actorToken(String actorToken)
Identifier of the actor that produced the activity entry
-
actorToken
final CaseActivityEntry.Builder actorToken(Optional<String> actorToken)
Alias for calling Builder.actorToken with
actorToken.orElse(null).
-
actorToken
final CaseActivityEntry.Builder actorToken(JsonField<String> actorToken)
Sets Builder.actorToken to an arbitrary JSON value.
You should usually call Builder.actorToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final CaseActivityEntry.Builder created(OffsetDateTime created)
Date and time at which the activity entry was created
-
created
final CaseActivityEntry.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entryType
final CaseActivityEntry.Builder entryType(CaseActivityType entryType)
The case field that changed, or the action that was taken, in an activity entry:
STATUS- The case status changedTITLE- The case title changedASSIGNED_TO- The case assignee changedRESOLUTION_OUTCOME- The resolution outcome was set or changedRESOLUTION_NOTES- The resolution notes were set or changedTAGS- The case tags changedPRIORITY- The case priority changedCOMMENT- A comment was added or editedFILE- A file was attached to the case
-
entryType
final CaseActivityEntry.Builder entryType(JsonField<CaseActivityType> entryType)
Sets Builder.entryType to an arbitrary JSON value.
You should usually call Builder.entryType with a well-typed CaseActivityType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
newValue
final CaseActivityEntry.Builder newValue(String newValue)
New value of the changed field, when applicable
-
newValue
final CaseActivityEntry.Builder newValue(Optional<String> newValue)
Alias for calling Builder.newValue with
newValue.orElse(null).
-
newValue
final CaseActivityEntry.Builder newValue(JsonField<String> newValue)
Sets Builder.newValue to an arbitrary JSON value.
You should usually call Builder.newValue with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousValue
final CaseActivityEntry.Builder previousValue(String previousValue)
Previous value of the changed field, when applicable
-
previousValue
final CaseActivityEntry.Builder previousValue(Optional<String> previousValue)
Alias for calling Builder.previousValue with
previousValue.orElse(null).
-
previousValue
final CaseActivityEntry.Builder previousValue(JsonField<String> previousValue)
Sets Builder.previousValue to an arbitrary JSON value.
You should usually call Builder.previousValue with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CaseActivityEntry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CaseActivityEntry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CaseActivityEntry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CaseActivityEntry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CaseActivityEntry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CaseActivityEntry build()
Returns an immutable instance of CaseActivityEntry.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .actorToken() .created() .entryType() .newValue() .previousValue()
-
-
-