Class CaseCard
-
- All Implemented Interfaces:
public final class CaseCardSummary of a card's involvement in a case, aggregated across the case's transactions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCaseCard.BuilderA builder for CaseCard.
-
Method Summary
Modifier and Type Method Description final StringaccountToken()Token of the account the card belongs to final StringcardToken()Token of the card final LongtransactionCount()Number of the card's transactions associated with the case final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<Long>_transactionCount()Returns the raw JSON value of transactionCount. final Map<String, JsonValue>_additionalProperties()final CaseCard.BuildertoBuilder()final CaseCardvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CaseCard.Builderbuilder()Returns a mutable builder for constructing an instance of CaseCard. -
-
Method Detail
-
accountToken
final String accountToken()
Token of the account the card belongs to
-
transactionCount
final Long transactionCount()
Number of the card's transactions associated with the case
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCount
final JsonField<Long> _transactionCount()
Returns the raw JSON value of transactionCount.
Unlike transactionCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CaseCard.Builder toBuilder()
-
validate
final CaseCard validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CaseCard.Builder builder()
Returns a mutable builder for constructing an instance of CaseCard.
The following fields are required:
.accountToken() .cardToken() .transactionCount()
-
-
-
-