Class CaseCard.Builder
-
- All Implemented Interfaces:
public final class CaseCard.BuilderA builder for CaseCard.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final CaseCard.Builder accountToken(String accountToken)
Token of the account the card belongs to
-
accountToken
final CaseCard.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final CaseCard.Builder cardToken(String cardToken)
Token of the card
-
cardToken
final CaseCard.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionCount
final CaseCard.Builder transactionCount(Long transactionCount)
Number of the card's transactions associated with the case
-
transactionCount
final CaseCard.Builder transactionCount(JsonField<Long> transactionCount)
Sets Builder.transactionCount to an arbitrary JSON value.
You should usually call Builder.transactionCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CaseCard.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CaseCard.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CaseCard.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CaseCard.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CaseCard.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-