Class CaseEntity
-
- All Implemented Interfaces:
public final class CaseEntityThe entity a case is associated with
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCaseEntity.BuilderA builder for CaseEntity.
public final classCaseEntity.EntityType2The type of entity a case is associated with:
CARD- The case is associated with a cardACCOUNT- The case is associated with an account
-
Method Summary
Modifier and Type Method Description final StringentityToken()Globally unique identifier for the associated entity final CaseEntity.EntityType2entityType()The type of entity a case is associated with: CARD- The case is associated with a cardACCOUNT- The case is associated with an account
final JsonField<String>_entityToken()Returns the raw JSON value of entityToken. final JsonField<CaseEntity.EntityType2>_entityType()Returns the raw JSON value of entityType. final Map<String, JsonValue>_additionalProperties()final CaseEntity.BuildertoBuilder()final CaseEntityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CaseEntity.Builderbuilder()Returns a mutable builder for constructing an instance of CaseEntity. -
-
Method Detail
-
entityToken
final String entityToken()
Globally unique identifier for the associated entity
-
entityType
final CaseEntity.EntityType2 entityType()
The type of entity a case is associated with:
CARD- The case is associated with a cardACCOUNT- The case is associated with an account
-
_entityToken
final JsonField<String> _entityToken()
Returns the raw JSON value of entityToken.
Unlike entityToken, this method doesn't throw if the JSON field has an unexpected type.
-
_entityType
final JsonField<CaseEntity.EntityType2> _entityType()
Returns the raw JSON value of entityType.
Unlike entityType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CaseEntity.Builder toBuilder()
-
validate
final CaseEntity validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CaseEntity.Builder builder()
Returns a mutable builder for constructing an instance of CaseEntity.
The following fields are required:
.entityToken() .entityType()
-
-
-