Class CaseTransaction.Builder
-
- All Implemented Interfaces:
public final class CaseTransaction.BuilderA builder for CaseTransaction.
-
-
Method Summary
-
-
Method Detail
-
token
final CaseTransaction.Builder token(String token)
Globally unique identifier for the transaction
-
token
final CaseTransaction.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final CaseTransaction.Builder accountToken(String accountToken)
Token of the account the transaction belongs to
-
accountToken
final CaseTransaction.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addedAt
final CaseTransaction.Builder addedAt(OffsetDateTime addedAt)
Date and time at which the transaction was added to the case
-
addedAt
final CaseTransaction.Builder addedAt(JsonField<OffsetDateTime> addedAt)
Sets Builder.addedAt to an arbitrary JSON value.
You should usually call Builder.addedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final CaseTransaction.Builder cardToken(String cardToken)
Token of the card the transaction was made on
-
cardToken
final CaseTransaction.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionCreatedAt
final CaseTransaction.Builder transactionCreatedAt(OffsetDateTime transactionCreatedAt)
Date and time at which the transaction was created
-
transactionCreatedAt
final CaseTransaction.Builder transactionCreatedAt(JsonField<OffsetDateTime> transactionCreatedAt)
Sets Builder.transactionCreatedAt to an arbitrary JSON value.
You should usually call Builder.transactionCreatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CaseTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CaseTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CaseTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CaseTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CaseTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CaseTransaction build()
Returns an immutable instance of CaseTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .addedAt() .cardToken() .transactionCreatedAt()
-
-
-
-