Class CaseTransaction.CardCaseTransaction
-
- All Implemented Interfaces:
public final class CaseTransaction.CardCaseTransactionA card transaction associated with a case
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCaseTransaction.CardCaseTransaction.BuilderA builder for CardCaseTransaction.
public final classCaseTransaction.CardCaseTransaction.Category
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the card transaction final StringaccountToken()Token of the account the transaction belongs to final OffsetDateTimeaddedAt()Date and time at which the transaction was added to the case final StringcardToken()Token of the card the transaction was made on final CaseTransaction.CardCaseTransaction.Categorycategory()final OffsetDateTimetransactionCreatedAt()Date and time at which the transaction was created final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<OffsetDateTime>_addedAt()Returns the raw JSON value of addedAt. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<CaseTransaction.CardCaseTransaction.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_transactionCreatedAt()Returns the raw JSON value of transactionCreatedAt. final Map<String, JsonValue>_additionalProperties()final CaseTransaction.CardCaseTransaction.BuildertoBuilder()final CaseTransaction.CardCaseTransactionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CaseTransaction.CardCaseTransaction.Builderbuilder()Returns a mutable builder for constructing an instance of CardCaseTransaction. -
-
Method Detail
-
accountToken
final String accountToken()
Token of the account the transaction belongs to
-
addedAt
final OffsetDateTime addedAt()
Date and time at which the transaction was added to the case
-
category
final CaseTransaction.CardCaseTransaction.Category category()
-
transactionCreatedAt
final OffsetDateTime transactionCreatedAt()
Date and time at which the transaction was created
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_addedAt
final JsonField<OffsetDateTime> _addedAt()
Returns the raw JSON value of addedAt.
Unlike addedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CaseTransaction.CardCaseTransaction.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCreatedAt
final JsonField<OffsetDateTime> _transactionCreatedAt()
Returns the raw JSON value of transactionCreatedAt.
Unlike transactionCreatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CaseTransaction.CardCaseTransaction.Builder toBuilder()
-
validate
final CaseTransaction.CardCaseTransaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CaseTransaction.CardCaseTransaction.Builder builder()
Returns a mutable builder for constructing an instance of CardCaseTransaction.
The following fields are required:
.token() .accountToken() .addedAt() .cardToken() .category() .transactionCreatedAt()
-
-
-
-