Class CaseTransaction.PaymentCaseTransaction
-
- All Implemented Interfaces:
public final class CaseTransaction.PaymentCaseTransactionA payment (ACH) transaction associated with a case
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCaseTransaction.PaymentCaseTransaction.BuilderA builder for PaymentCaseTransaction.
public final classCaseTransaction.PaymentCaseTransaction.Category
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the payment transaction final OffsetDateTimeaddedAt()Date and time at which the transaction was added to the case final CaseTransaction.PaymentCaseTransaction.Categorycategory()final StringfinancialAccountToken()Token of the financial account the payment belongs to final OffsetDateTimetransactionCreatedAt()Date and time at which the transaction was created final Optional<String>accountToken()Token of the account the payment belongs to, if applicable final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_addedAt()Returns the raw JSON value of addedAt. final JsonField<CaseTransaction.PaymentCaseTransaction.Category>_category()Returns the raw JSON value of category. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<OffsetDateTime>_transactionCreatedAt()Returns the raw JSON value of transactionCreatedAt. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final Map<String, JsonValue>_additionalProperties()final CaseTransaction.PaymentCaseTransaction.BuildertoBuilder()final CaseTransaction.PaymentCaseTransactionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CaseTransaction.PaymentCaseTransaction.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentCaseTransaction. -
-
Method Detail
-
addedAt
final OffsetDateTime addedAt()
Date and time at which the transaction was added to the case
-
category
final CaseTransaction.PaymentCaseTransaction.Category category()
-
financialAccountToken
final String financialAccountToken()
Token of the financial account the payment belongs to
-
transactionCreatedAt
final OffsetDateTime transactionCreatedAt()
Date and time at which the transaction was created
-
accountToken
final Optional<String> accountToken()
Token of the account the payment belongs to, if applicable
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_addedAt
final JsonField<OffsetDateTime> _addedAt()
Returns the raw JSON value of addedAt.
Unlike addedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CaseTransaction.PaymentCaseTransaction.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCreatedAt
final JsonField<OffsetDateTime> _transactionCreatedAt()
Returns the raw JSON value of transactionCreatedAt.
Unlike transactionCreatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CaseTransaction.PaymentCaseTransaction.Builder toBuilder()
-
validate
final CaseTransaction.PaymentCaseTransaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CaseTransaction.PaymentCaseTransaction.Builder builder()
Returns a mutable builder for constructing an instance of PaymentCaseTransaction.
The following fields are required:
.token() .addedAt() .category() .financialAccountToken() .transactionCreatedAt()
-
-
-
-