Class CaseTransaction.PaymentCaseTransaction.Builder
-
- All Implemented Interfaces:
public final class CaseTransaction.PaymentCaseTransaction.BuilderA builder for PaymentCaseTransaction.
-
-
Method Summary
-
-
Method Detail
-
token
final CaseTransaction.PaymentCaseTransaction.Builder token(String token)
Globally unique identifier for the payment transaction
-
token
final CaseTransaction.PaymentCaseTransaction.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addedAt
final CaseTransaction.PaymentCaseTransaction.Builder addedAt(OffsetDateTime addedAt)
Date and time at which the transaction was added to the case
-
addedAt
final CaseTransaction.PaymentCaseTransaction.Builder addedAt(JsonField<OffsetDateTime> addedAt)
Sets Builder.addedAt to an arbitrary JSON value.
You should usually call Builder.addedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final CaseTransaction.PaymentCaseTransaction.Builder category(CaseTransaction.PaymentCaseTransaction.Category category)
-
category
final CaseTransaction.PaymentCaseTransaction.Builder category(JsonField<CaseTransaction.PaymentCaseTransaction.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final CaseTransaction.PaymentCaseTransaction.Builder financialAccountToken(String financialAccountToken)
Token of the financial account the payment belongs to
-
financialAccountToken
final CaseTransaction.PaymentCaseTransaction.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionCreatedAt
final CaseTransaction.PaymentCaseTransaction.Builder transactionCreatedAt(OffsetDateTime transactionCreatedAt)
Date and time at which the transaction was created
-
transactionCreatedAt
final CaseTransaction.PaymentCaseTransaction.Builder transactionCreatedAt(JsonField<OffsetDateTime> transactionCreatedAt)
Sets Builder.transactionCreatedAt to an arbitrary JSON value.
You should usually call Builder.transactionCreatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final CaseTransaction.PaymentCaseTransaction.Builder accountToken(String accountToken)
Token of the account the payment belongs to, if applicable
-
accountToken
final CaseTransaction.PaymentCaseTransaction.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CaseTransaction.PaymentCaseTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CaseTransaction.PaymentCaseTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CaseTransaction.PaymentCaseTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CaseTransaction.PaymentCaseTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CaseTransaction.PaymentCaseTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CaseTransaction.PaymentCaseTransaction build()
Returns an immutable instance of PaymentCaseTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .addedAt() .category() .financialAccountToken() .transactionCreatedAt()
-
-
-
-