Package com.lithic.api.models
Interface CaseTransaction.Visitor
-
- All Implemented Interfaces:
public interface CaseTransaction.Visitor<T extends Object>An interface that defines how to map each variant of CaseTransaction to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitCard(CaseTransaction.CardCaseTransaction card)A card transaction associated with a case abstract TvisitPayment(CaseTransaction.PaymentCaseTransaction payment)A payment (ACH) transaction associated with a case Tunknown(JsonValue json)Maps an unknown variant of CaseTransaction to a value of type T. -
-
Method Detail
-
visitCard
abstract T visitCard(CaseTransaction.CardCaseTransaction card)
A card transaction associated with a case
-
visitPayment
abstract T visitPayment(CaseTransaction.PaymentCaseTransaction payment)
A payment (ACH) transaction associated with a case
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of CaseTransaction to a value of type T.
An instance of CaseTransaction can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-