Package com.lithic.api.models
Class CategoryBalances
-
- All Implemented Interfaces:
public final class CategoryBalances
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCategoryBalances.BuilderA builder for CategoryBalances.
-
Method Summary
Modifier and Type Method Description final Longfees()final Longinterest()final Longprincipal()final JsonField<Long>_fees()Returns the raw JSON value of fees. final JsonField<Long>_interest()Returns the raw JSON value of interest. final JsonField<Long>_principal()Returns the raw JSON value of principal. final Map<String, JsonValue>_additionalProperties()final CategoryBalances.BuildertoBuilder()final CategoryBalancesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CategoryBalances.Builderbuilder()Returns a mutable builder for constructing an instance of CategoryBalances. -
-
Method Detail
-
_fees
final JsonField<Long> _fees()
Returns the raw JSON value of fees.
Unlike fees, this method doesn't throw if the JSON field has an unexpected type.
-
_interest
final JsonField<Long> _interest()
Returns the raw JSON value of interest.
Unlike interest, this method doesn't throw if the JSON field has an unexpected type.
-
_principal
final JsonField<Long> _principal()
Returns the raw JSON value of principal.
Unlike principal, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CategoryBalances.Builder toBuilder()
-
validate
final CategoryBalances validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CategoryBalances.Builder builder()
Returns a mutable builder for constructing an instance of CategoryBalances.
The following fields are required:
.fees() .interest() .principal()
-
-
-
-