Package com.lithic.api.models
Class CategoryDetails
-
- All Implemented Interfaces:
public final class CategoryDetails
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCategoryDetails.BuilderA builder for CategoryDetails.
-
Method Summary
Modifier and Type Method Description final StringbalanceTransfers()final StringcashAdvances()final Stringpurchases()final JsonField<String>_balanceTransfers()Returns the raw JSON value of balanceTransfers. final JsonField<String>_cashAdvances()Returns the raw JSON value of cashAdvances. final JsonField<String>_purchases()Returns the raw JSON value of purchases. final Map<String, JsonValue>_additionalProperties()final CategoryDetails.BuildertoBuilder()final CategoryDetailsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CategoryDetails.Builderbuilder()Returns a mutable builder for constructing an instance of CategoryDetails. -
-
Method Detail
-
balanceTransfers
final String balanceTransfers()
-
cashAdvances
final String cashAdvances()
-
_balanceTransfers
final JsonField<String> _balanceTransfers()
Returns the raw JSON value of balanceTransfers.
Unlike balanceTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAdvances
final JsonField<String> _cashAdvances()
Returns the raw JSON value of cashAdvances.
Unlike cashAdvances, this method doesn't throw if the JSON field has an unexpected type.
-
_purchases
final JsonField<String> _purchases()
Returns the raw JSON value of purchases.
Unlike purchases, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CategoryDetails.Builder toBuilder()
-
validate
final CategoryDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CategoryDetails.Builder builder()
Returns a mutable builder for constructing an instance of CategoryDetails.
The following fields are required:
.balanceTransfers() .cashAdvances() .purchases()
-
-
-
-