Package com.lithic.api.models
Class CategoryTier
-
- All Implemented Interfaces:
public final class CategoryTierRate and rate cap for interest on a category
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCategoryTier.BuilderA builder for CategoryTier.
-
Method Summary
Modifier and Type Method Description final Optional<String>capRate()Maximum interest rate for this category, e.g. final Optional<String>rate()Interest rate for this category, e.g. final JsonField<String>_capRate()Returns the raw JSON value of capRate. final JsonField<String>_rate()Returns the raw JSON value of rate. final Map<String, JsonValue>_additionalProperties()final CategoryTier.BuildertoBuilder()final CategoryTiervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CategoryTier.Builderbuilder()Returns a mutable builder for constructing an instance of CategoryTier. -
-
Method Detail
-
capRate
final Optional<String> capRate()
Maximum interest rate for this category, e.g. '0.0525' for 5.25%
-
_capRate
final JsonField<String> _capRate()
Returns the raw JSON value of capRate.
Unlike capRate, this method doesn't throw if the JSON field has an unexpected type.
-
_rate
final JsonField<String> _rate()
Returns the raw JSON value of rate.
Unlike rate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CategoryTier.Builder toBuilder()
-
validate
final CategoryTier validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CategoryTier.Builder builder()
Returns a mutable builder for constructing an instance of CategoryTier.
-
-
-
-