Class ChallengeResponse.Builder
-
- All Implemented Interfaces:
public final class ChallengeResponse.BuilderA builder for ChallengeResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final ChallengeResponse.Builder token(String token)
Globally unique identifier for 3DS Authentication that resulted in PENDING_CHALLENGE authentication result.
-
token
final ChallengeResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challengeResponse
final ChallengeResponse.Builder challengeResponse(ChallengeResult challengeResponse)
Whether the Cardholder has approved or declined the issued Challenge
-
challengeResponse
final ChallengeResponse.Builder challengeResponse(JsonField<ChallengeResult> challengeResponse)
Sets Builder.challengeResponse to an arbitrary JSON value.
You should usually call Builder.challengeResponse with a well-typed ChallengeResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ChallengeResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ChallengeResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ChallengeResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ChallengeResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ChallengeResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ChallengeResponse build()
Returns an immutable instance of ChallengeResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .challengeResponse()
-
-
-
-