Class ChallengeResult
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class ChallengeResult implements EnumWhether the Cardholder has approved or declined the issued Challenge
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumChallengeResult.KnownAn enum containing ChallengeResult's known values.
public enumChallengeResult.ValueAn enum containing ChallengeResult's known values, as well as an _UNKNOWN member.
An instance of ChallengeResult can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static ChallengeResultAPPROVEpublic final static ChallengeResultDECLINE_BY_CUSTOMER
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ChallengeResult.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ChallengeResult.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ChallengeResultvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChallengeResultof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ChallengeResult.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ChallengeResult.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ChallengeResult validate()
-
of
final static ChallengeResult of(String value)
-
-
-
-