Class ClaimCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class ClaimCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClaimCreatedWebhookEvent.BuilderA builder for ClaimCreatedWebhookEvent.
public final classClaimCreatedWebhookEvent.DisputedTransactionA transaction included in a claim, along with the specific events being disputed.
public final classClaimCreatedWebhookEvent.EventTypeThe type of event that occurred.
public final classClaimCreatedWebhookEvent.OutstandingRequirementpublic final classClaimCreatedWebhookEvent.ReasonDispute reason code provided when creating the claim
public final classClaimCreatedWebhookEvent.StatusCurrent lifecycle status of the claim
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique identifier for the claim, in UUID format final Optional<String>accountHolderToken()Token for the account holder that filed the claim final Optional<String>accountToken()Token for the account associated with the claim final List<String>cardTokens()Tokens for the cards associated with the disputed transactions final OffsetDateTimecreated()When the claim was created final List<ClaimCreatedWebhookEvent.DisputedTransaction>disputedTransactions()Transactions included in this claim final ClaimCreatedWebhookEvent.EventTypeeventType()The type of event that occurred. final List<ClaimCreatedWebhookEvent.OutstandingRequirement>outstandingRequirements()Requirements that must be fulfilled before the claim can be submitted final ClaimCreatedWebhookEvent.Reasonreason()Dispute reason code provided when creating the claim final ClaimCreatedWebhookEvent.Statusstatus()Current lifecycle status of the claim final Optional<OffsetDateTime>submitted()When the claim was submitted. final OffsetDateTimeupdated()When the claim was last updated final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountHolderToken()Returns the raw JSON value of accountHolderToken. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<List<String>>_cardTokens()Returns the raw JSON value of cardTokens. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<List<ClaimCreatedWebhookEvent.DisputedTransaction>>_disputedTransactions()Returns the raw JSON value of disputedTransactions. final JsonField<ClaimCreatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<List<ClaimCreatedWebhookEvent.OutstandingRequirement>>_outstandingRequirements()Returns the raw JSON value of outstandingRequirements. final JsonField<ClaimCreatedWebhookEvent.Reason>_reason()Returns the raw JSON value of reason. final JsonField<ClaimCreatedWebhookEvent.Status>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_submitted()Returns the raw JSON value of submitted. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final Map<String, JsonValue>_additionalProperties()final ClaimCreatedWebhookEvent.BuildertoBuilder()final ClaimCreatedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClaimCreatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of ClaimCreatedWebhookEvent. -
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
Token for the account holder that filed the claim
-
accountToken
final Optional<String> accountToken()
Token for the account associated with the claim
-
cardTokens
final List<String> cardTokens()
Tokens for the cards associated with the disputed transactions
-
created
final OffsetDateTime created()
When the claim was created
-
disputedTransactions
final List<ClaimCreatedWebhookEvent.DisputedTransaction> disputedTransactions()
Transactions included in this claim
-
eventType
final ClaimCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
outstandingRequirements
final List<ClaimCreatedWebhookEvent.OutstandingRequirement> outstandingRequirements()
Requirements that must be fulfilled before the claim can be submitted
-
reason
final ClaimCreatedWebhookEvent.Reason reason()
Dispute reason code provided when creating the claim
-
status
final ClaimCreatedWebhookEvent.Status status()
Current lifecycle status of the claim
-
submitted
final Optional<OffsetDateTime> submitted()
When the claim was submitted. Null until the claim reaches
SUBMITTEDstatus
-
updated
final OffsetDateTime updated()
When the claim was last updated
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokens
final JsonField<List<String>> _cardTokens()
Returns the raw JSON value of cardTokens.
Unlike cardTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_disputedTransactions
final JsonField<List<ClaimCreatedWebhookEvent.DisputedTransaction>> _disputedTransactions()
Returns the raw JSON value of disputedTransactions.
Unlike disputedTransactions, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ClaimCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_outstandingRequirements
final JsonField<List<ClaimCreatedWebhookEvent.OutstandingRequirement>> _outstandingRequirements()
Returns the raw JSON value of outstandingRequirements.
Unlike outstandingRequirements, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<ClaimCreatedWebhookEvent.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ClaimCreatedWebhookEvent.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submitted
final JsonField<OffsetDateTime> _submitted()
Returns the raw JSON value of submitted.
Unlike submitted, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClaimCreatedWebhookEvent.Builder toBuilder()
-
validate
final ClaimCreatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClaimCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of ClaimCreatedWebhookEvent.
The following fields are required:
.token() .accountHolderToken() .accountToken() .cardTokens() .created() .disputedTransactions() .eventType() .outstandingRequirements() .reason() .status() .submitted() .updated()
-
-
-
-