Class ClaimCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class ClaimCreatedWebhookEvent.BuilderA builder for ClaimCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final ClaimCreatedWebhookEvent.Builder token(String token)
Unique identifier for the claim, in UUID format
-
token
final ClaimCreatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final ClaimCreatedWebhookEvent.Builder accountHolderToken(String accountHolderToken)
Token for the account holder that filed the claim
-
accountHolderToken
final ClaimCreatedWebhookEvent.Builder accountHolderToken(Optional<String> accountHolderToken)
Alias for calling Builder.accountHolderToken with
accountHolderToken.orElse(null).
-
accountHolderToken
final ClaimCreatedWebhookEvent.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final ClaimCreatedWebhookEvent.Builder accountToken(String accountToken)
Token for the account associated with the claim
-
accountToken
final ClaimCreatedWebhookEvent.Builder accountToken(Optional<String> accountToken)
Alias for calling Builder.accountToken with
accountToken.orElse(null).
-
accountToken
final ClaimCreatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokens
final ClaimCreatedWebhookEvent.Builder cardTokens(List<String> cardTokens)
Tokens for the cards associated with the disputed transactions
-
cardTokens
final ClaimCreatedWebhookEvent.Builder cardTokens(JsonField<List<String>> cardTokens)
Sets Builder.cardTokens to an arbitrary JSON value.
You should usually call Builder.cardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCardToken
final ClaimCreatedWebhookEvent.Builder addCardToken(String cardToken)
Adds a single String to cardTokens.
-
created
final ClaimCreatedWebhookEvent.Builder created(OffsetDateTime created)
When the claim was created
-
created
final ClaimCreatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disputedTransactions
final ClaimCreatedWebhookEvent.Builder disputedTransactions(List<ClaimCreatedWebhookEvent.DisputedTransaction> disputedTransactions)
Transactions included in this claim
-
disputedTransactions
final ClaimCreatedWebhookEvent.Builder disputedTransactions(JsonField<List<ClaimCreatedWebhookEvent.DisputedTransaction>> disputedTransactions)
Sets Builder.disputedTransactions to an arbitrary JSON value.
You should usually call Builder.disputedTransactions with a well-typed
List<DisputedTransaction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisputedTransaction
final ClaimCreatedWebhookEvent.Builder addDisputedTransaction(ClaimCreatedWebhookEvent.DisputedTransaction disputedTransaction)
Adds a single DisputedTransaction to disputedTransactions.
-
eventType
final ClaimCreatedWebhookEvent.Builder eventType(ClaimCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final ClaimCreatedWebhookEvent.Builder eventType(JsonField<ClaimCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outstandingRequirements
final ClaimCreatedWebhookEvent.Builder outstandingRequirements(List<ClaimCreatedWebhookEvent.OutstandingRequirement> outstandingRequirements)
Requirements that must be fulfilled before the claim can be submitted
-
outstandingRequirements
final ClaimCreatedWebhookEvent.Builder outstandingRequirements(JsonField<List<ClaimCreatedWebhookEvent.OutstandingRequirement>> outstandingRequirements)
Sets Builder.outstandingRequirements to an arbitrary JSON value.
You should usually call Builder.outstandingRequirements with a well-typed
List<OutstandingRequirement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addOutstandingRequirement
final ClaimCreatedWebhookEvent.Builder addOutstandingRequirement(ClaimCreatedWebhookEvent.OutstandingRequirement outstandingRequirement)
Adds a single OutstandingRequirement to outstandingRequirements.
-
reason
final ClaimCreatedWebhookEvent.Builder reason(ClaimCreatedWebhookEvent.Reason reason)
Dispute reason code provided when creating the claim
-
reason
final ClaimCreatedWebhookEvent.Builder reason(JsonField<ClaimCreatedWebhookEvent.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ClaimCreatedWebhookEvent.Builder status(ClaimCreatedWebhookEvent.Status status)
Current lifecycle status of the claim
-
status
final ClaimCreatedWebhookEvent.Builder status(JsonField<ClaimCreatedWebhookEvent.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submitted
final ClaimCreatedWebhookEvent.Builder submitted(OffsetDateTime submitted)
When the claim was submitted. Null until the claim reaches
SUBMITTEDstatus
-
submitted
final ClaimCreatedWebhookEvent.Builder submitted(Optional<OffsetDateTime> submitted)
Alias for calling Builder.submitted with
submitted.orElse(null).
-
submitted
final ClaimCreatedWebhookEvent.Builder submitted(JsonField<OffsetDateTime> submitted)
Sets Builder.submitted to an arbitrary JSON value.
You should usually call Builder.submitted with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final ClaimCreatedWebhookEvent.Builder updated(OffsetDateTime updated)
When the claim was last updated
-
updated
final ClaimCreatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClaimCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClaimCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClaimCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClaimCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClaimCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClaimCreatedWebhookEvent build()
Returns an immutable instance of ClaimCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountHolderToken() .accountToken() .cardTokens() .created() .disputedTransactions() .eventType() .outstandingRequirements() .reason() .status() .submitted() .updated()
-
-
-
-