Class ClaimCreatedWebhookEvent.DisputedTransaction
-
- All Implemented Interfaces:
public final class ClaimCreatedWebhookEvent.DisputedTransactionA transaction included in a claim, along with the specific events being disputed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClaimCreatedWebhookEvent.DisputedTransaction.BuilderA builder for DisputedTransaction.
-
Method Summary
Modifier and Type Method Description final List<String>eventTokens()Tokens for the specific events within the transaction being disputed. final StringtransactionToken()Token for the transaction being disputed, in UUID format final JsonField<List<String>>_eventTokens()Returns the raw JSON value of eventTokens. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final Map<String, JsonValue>_additionalProperties()final ClaimCreatedWebhookEvent.DisputedTransaction.BuildertoBuilder()final ClaimCreatedWebhookEvent.DisputedTransactionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClaimCreatedWebhookEvent.DisputedTransaction.Builderbuilder()Returns a mutable builder for constructing an instance of DisputedTransaction. -
-
Method Detail
-
eventTokens
final List<String> eventTokens()
Tokens for the specific events within the transaction being disputed. Lithic creates one dispute per event token
-
transactionToken
final String transactionToken()
Token for the transaction being disputed, in UUID format
-
_eventTokens
final JsonField<List<String>> _eventTokens()
Returns the raw JSON value of eventTokens.
Unlike eventTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClaimCreatedWebhookEvent.DisputedTransaction.Builder toBuilder()
-
validate
final ClaimCreatedWebhookEvent.DisputedTransaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClaimCreatedWebhookEvent.DisputedTransaction.Builder builder()
Returns a mutable builder for constructing an instance of DisputedTransaction.
The following fields are required:
.eventTokens() .transactionToken()
-
-
-
-