Class ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder
-
- All Implemented Interfaces:
public final class ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.BuilderA builder for UploadConstraints2.
-
-
Method Summary
-
-
Method Detail
-
acceptedMimeTypes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder acceptedMimeTypes(List<String> acceptedMimeTypes)
MIME types accepted for upload
-
acceptedMimeTypes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder acceptedMimeTypes(JsonField<List<String>> acceptedMimeTypes)
Sets Builder.acceptedMimeTypes to an arbitrary JSON value.
You should usually call Builder.acceptedMimeTypes with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAcceptedMimeType
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder addAcceptedMimeType(String acceptedMimeType)
Adds a single String to acceptedMimeTypes.
-
maxSizeBytes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder maxSizeBytes(Long maxSizeBytes)
Maximum file size in bytes. Null if there is no enforced size limit
-
maxSizeBytes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder maxSizeBytes(Long maxSizeBytes)
Alias for Builder.maxSizeBytes.
This unboxed primitive overload exists for backwards compatibility.
-
maxSizeBytes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder maxSizeBytes(Optional<Long> maxSizeBytes)
Alias for calling Builder.maxSizeBytes with
maxSizeBytes.orElse(null).
-
maxSizeBytes
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder maxSizeBytes(JsonField<Long> maxSizeBytes)
Sets Builder.maxSizeBytes to an arbitrary JSON value.
You should usually call Builder.maxSizeBytes with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClaimDocumentAcceptedWebhookEvent.UploadConstraints2 build()
Returns an immutable instance of UploadConstraints2.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.acceptedMimeTypes() .maxSizeBytes()
-
-
-
-