Class ClaimDocumentRejectedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class ClaimDocumentRejectedWebhookEvent.BuilderA builder for ClaimDocumentRejectedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final ClaimDocumentRejectedWebhookEvent.Builder token(String token)
Unique identifier for the document, in UUID format
-
token
final ClaimDocumentRejectedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final ClaimDocumentRejectedWebhookEvent.Builder created(OffsetDateTime created)
When the document was created
-
created
final ClaimDocumentRejectedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
downloadUrl
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrl(String downloadUrl)
Presigned URL for downloading the uploaded document. Available once the document is being validated or has been accepted (
VALIDATINGorACCEPTED)
-
downloadUrl
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrl(Optional<String> downloadUrl)
Alias for calling Builder.downloadUrl with
downloadUrl.orElse(null).
-
downloadUrl
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrl(JsonField<String> downloadUrl)
Sets Builder.downloadUrl to an arbitrary JSON value.
You should usually call Builder.downloadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
downloadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrlExpiresAt(OffsetDateTime downloadUrlExpiresAt)
When the download URL expires
-
downloadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrlExpiresAt(Optional<OffsetDateTime> downloadUrlExpiresAt)
Alias for calling Builder.downloadUrlExpiresAt with
downloadUrlExpiresAt.orElse(null).
-
downloadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder downloadUrlExpiresAt(JsonField<OffsetDateTime> downloadUrlExpiresAt)
Sets Builder.downloadUrlExpiresAt to an arbitrary JSON value.
You should usually call Builder.downloadUrlExpiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final ClaimDocumentRejectedWebhookEvent.Builder eventType(ClaimDocumentRejectedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final ClaimDocumentRejectedWebhookEvent.Builder eventType(JsonField<ClaimDocumentRejectedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
failureReason
final ClaimDocumentRejectedWebhookEvent.Builder failureReason(ClaimDocumentRejectedWebhookEvent.FailureReason failureReason)
Reason the document failed validation. Null unless
statusisREJECTED
-
failureReason
final ClaimDocumentRejectedWebhookEvent.Builder failureReason(Optional<ClaimDocumentRejectedWebhookEvent.FailureReason> failureReason)
Alias for calling Builder.failureReason with
failureReason.orElse(null).
-
failureReason
final ClaimDocumentRejectedWebhookEvent.Builder failureReason(JsonField<ClaimDocumentRejectedWebhookEvent.FailureReason> failureReason)
Sets Builder.failureReason to an arbitrary JSON value.
You should usually call Builder.failureReason with a well-typed FailureReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final ClaimDocumentRejectedWebhookEvent.Builder name(String name)
Name provided when the upload intent was created
-
name
final ClaimDocumentRejectedWebhookEvent.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requirementId
final ClaimDocumentRejectedWebhookEvent.Builder requirementId(String requirementId)
Identifier of the document requirement this document satisfies. Null for supplemental documents not tied to a specific requirement
-
requirementId
final ClaimDocumentRejectedWebhookEvent.Builder requirementId(Optional<String> requirementId)
Alias for calling Builder.requirementId with
requirementId.orElse(null).
-
requirementId
final ClaimDocumentRejectedWebhookEvent.Builder requirementId(JsonField<String> requirementId)
Sets Builder.requirementId to an arbitrary JSON value.
You should usually call Builder.requirementId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ClaimDocumentRejectedWebhookEvent.Builder status(ClaimDocumentRejectedWebhookEvent.Status status)
Current validation status of the document
-
status
final ClaimDocumentRejectedWebhookEvent.Builder status(JsonField<ClaimDocumentRejectedWebhookEvent.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final ClaimDocumentRejectedWebhookEvent.Builder updated(OffsetDateTime updated)
When the document was last updated
-
updated
final ClaimDocumentRejectedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadConstraints
final ClaimDocumentRejectedWebhookEvent.Builder uploadConstraints(ClaimDocumentRejectedWebhookEvent.UploadConstraints2 uploadConstraints)
Constraints that an uploaded file must satisfy.
-
uploadConstraints
final ClaimDocumentRejectedWebhookEvent.Builder uploadConstraints(Optional<ClaimDocumentRejectedWebhookEvent.UploadConstraints2> uploadConstraints)
Alias for calling Builder.uploadConstraints with
uploadConstraints.orElse(null).
-
uploadConstraints
final ClaimDocumentRejectedWebhookEvent.Builder uploadConstraints(JsonField<ClaimDocumentRejectedWebhookEvent.UploadConstraints2> uploadConstraints)
Sets Builder.uploadConstraints to an arbitrary JSON value.
You should usually call Builder.uploadConstraints with a well-typed UploadConstraints2 value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrl
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrl(String uploadUrl)
Presigned URL for uploading the file via HTTP PUT. Null after the upload window expires or after the document has been validated
-
uploadUrl
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrl(Optional<String> uploadUrl)
Alias for calling Builder.uploadUrl with
uploadUrl.orElse(null).
-
uploadUrl
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrl(JsonField<String> uploadUrl)
Sets Builder.uploadUrl to an arbitrary JSON value.
You should usually call Builder.uploadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrlExpiresAt(OffsetDateTime uploadUrlExpiresAt)
When the upload URL expires
-
uploadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrlExpiresAt(Optional<OffsetDateTime> uploadUrlExpiresAt)
Alias for calling Builder.uploadUrlExpiresAt with
uploadUrlExpiresAt.orElse(null).
-
uploadUrlExpiresAt
final ClaimDocumentRejectedWebhookEvent.Builder uploadUrlExpiresAt(JsonField<OffsetDateTime> uploadUrlExpiresAt)
Sets Builder.uploadUrlExpiresAt to an arbitrary JSON value.
You should usually call Builder.uploadUrlExpiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClaimDocumentRejectedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClaimDocumentRejectedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClaimDocumentRejectedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClaimDocumentRejectedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClaimDocumentRejectedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClaimDocumentRejectedWebhookEvent build()
Returns an immutable instance of ClaimDocumentRejectedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .created() .downloadUrl() .downloadUrlExpiresAt() .eventType() .failureReason() .name() .requirementId() .status() .updated() .uploadConstraints() .uploadUrl() .uploadUrlExpiresAt()
-
-
-
-