Package com.lithic.api.models
Class ClaimDocumentRejectedWebhookEvent.UploadConstraints2
-
- All Implemented Interfaces:
public final class ClaimDocumentRejectedWebhookEvent.UploadConstraints2Constraints that an uploaded file must satisfy.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClaimDocumentRejectedWebhookEvent.UploadConstraints2.BuilderA builder for UploadConstraints2.
-
Method Summary
Modifier and Type Method Description final List<String>acceptedMimeTypes()MIME types accepted for upload final Optional<Long>maxSizeBytes()Maximum file size in bytes. final JsonField<List<String>>_acceptedMimeTypes()Returns the raw JSON value of acceptedMimeTypes. final JsonField<Long>_maxSizeBytes()Returns the raw JSON value of maxSizeBytes. final Map<String, JsonValue>_additionalProperties()final ClaimDocumentRejectedWebhookEvent.UploadConstraints2.BuildertoBuilder()final ClaimDocumentRejectedWebhookEvent.UploadConstraints2validate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClaimDocumentRejectedWebhookEvent.UploadConstraints2.Builderbuilder()Returns a mutable builder for constructing an instance of UploadConstraints2. -
-
Method Detail
-
acceptedMimeTypes
final List<String> acceptedMimeTypes()
MIME types accepted for upload
-
maxSizeBytes
final Optional<Long> maxSizeBytes()
Maximum file size in bytes. Null if there is no enforced size limit
-
_acceptedMimeTypes
final JsonField<List<String>> _acceptedMimeTypes()
Returns the raw JSON value of acceptedMimeTypes.
Unlike acceptedMimeTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_maxSizeBytes
final JsonField<Long> _maxSizeBytes()
Returns the raw JSON value of maxSizeBytes.
Unlike maxSizeBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClaimDocumentRejectedWebhookEvent.UploadConstraints2.Builder toBuilder()
-
validate
final ClaimDocumentRejectedWebhookEvent.UploadConstraints2 validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClaimDocumentRejectedWebhookEvent.UploadConstraints2.Builder builder()
Returns a mutable builder for constructing an instance of UploadConstraints2.
The following fields are required:
.acceptedMimeTypes() .maxSizeBytes()
-
-
-
-