Class ClaimDocumentUploadedWebhookEvent
-
- All Implemented Interfaces:
public final class ClaimDocumentUploadedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classClaimDocumentUploadedWebhookEvent.BuilderA builder for ClaimDocumentUploadedWebhookEvent.
public final classClaimDocumentUploadedWebhookEvent.EventTypeThe type of event that occurred.
public final classClaimDocumentUploadedWebhookEvent.FailureReasonReason the document failed validation. Null unless
statusisREJECTEDpublic final classClaimDocumentUploadedWebhookEvent.StatusCurrent validation status of the document
public final classClaimDocumentUploadedWebhookEvent.UploadConstraints2Constraints that an uploaded file must satisfy.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique identifier for the document, in UUID format final OffsetDateTimecreated()When the document was created final Optional<String>downloadUrl()Presigned URL for downloading the uploaded document. final Optional<OffsetDateTime>downloadUrlExpiresAt()When the download URL expires final ClaimDocumentUploadedWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<ClaimDocumentUploadedWebhookEvent.FailureReason>failureReason()Reason the document failed validation. final Stringname()Name provided when the upload intent was created final Optional<String>requirementId()Identifier of the document requirement this document satisfies. final ClaimDocumentUploadedWebhookEvent.Statusstatus()Current validation status of the document final OffsetDateTimeupdated()When the document was last updated final Optional<ClaimDocumentUploadedWebhookEvent.UploadConstraints2>uploadConstraints()Constraints that an uploaded file must satisfy. final Optional<String>uploadUrl()Presigned URL for uploading the file via HTTP PUT. final Optional<OffsetDateTime>uploadUrlExpiresAt()When the upload URL expires final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_downloadUrl()Returns the raw JSON value of downloadUrl. final JsonField<OffsetDateTime>_downloadUrlExpiresAt()Returns the raw JSON value of downloadUrlExpiresAt. final JsonField<ClaimDocumentUploadedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<ClaimDocumentUploadedWebhookEvent.FailureReason>_failureReason()Returns the raw JSON value of failureReason. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_requirementId()Returns the raw JSON value of requirementId. final JsonField<ClaimDocumentUploadedWebhookEvent.Status>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<ClaimDocumentUploadedWebhookEvent.UploadConstraints2>_uploadConstraints()Returns the raw JSON value of uploadConstraints. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final JsonField<OffsetDateTime>_uploadUrlExpiresAt()Returns the raw JSON value of uploadUrlExpiresAt. final Map<String, JsonValue>_additionalProperties()final ClaimDocumentUploadedWebhookEvent.BuildertoBuilder()final ClaimDocumentUploadedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ClaimDocumentUploadedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of ClaimDocumentUploadedWebhookEvent. -
-
Method Detail
-
created
final OffsetDateTime created()
When the document was created
-
downloadUrl
final Optional<String> downloadUrl()
Presigned URL for downloading the uploaded document. Available once the document is being validated or has been accepted (
VALIDATINGorACCEPTED)
-
downloadUrlExpiresAt
final Optional<OffsetDateTime> downloadUrlExpiresAt()
When the download URL expires
-
eventType
final ClaimDocumentUploadedWebhookEvent.EventType eventType()
The type of event that occurred.
-
failureReason
final Optional<ClaimDocumentUploadedWebhookEvent.FailureReason> failureReason()
Reason the document failed validation. Null unless
statusisREJECTED
-
requirementId
final Optional<String> requirementId()
Identifier of the document requirement this document satisfies. Null for supplemental documents not tied to a specific requirement
-
status
final ClaimDocumentUploadedWebhookEvent.Status status()
Current validation status of the document
-
updated
final OffsetDateTime updated()
When the document was last updated
-
uploadConstraints
final Optional<ClaimDocumentUploadedWebhookEvent.UploadConstraints2> uploadConstraints()
Constraints that an uploaded file must satisfy.
-
uploadUrl
final Optional<String> uploadUrl()
Presigned URL for uploading the file via HTTP PUT. Null after the upload window expires or after the document has been validated
-
uploadUrlExpiresAt
final Optional<OffsetDateTime> uploadUrlExpiresAt()
When the upload URL expires
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_downloadUrl
final JsonField<String> _downloadUrl()
Returns the raw JSON value of downloadUrl.
Unlike downloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_downloadUrlExpiresAt
final JsonField<OffsetDateTime> _downloadUrlExpiresAt()
Returns the raw JSON value of downloadUrlExpiresAt.
Unlike downloadUrlExpiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ClaimDocumentUploadedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_failureReason
final JsonField<ClaimDocumentUploadedWebhookEvent.FailureReason> _failureReason()
Returns the raw JSON value of failureReason.
Unlike failureReason, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_requirementId
final JsonField<String> _requirementId()
Returns the raw JSON value of requirementId.
Unlike requirementId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ClaimDocumentUploadedWebhookEvent.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadConstraints
final JsonField<ClaimDocumentUploadedWebhookEvent.UploadConstraints2> _uploadConstraints()
Returns the raw JSON value of uploadConstraints.
Unlike uploadConstraints, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrlExpiresAt
final JsonField<OffsetDateTime> _uploadUrlExpiresAt()
Returns the raw JSON value of uploadUrlExpiresAt.
Unlike uploadUrlExpiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ClaimDocumentUploadedWebhookEvent.Builder toBuilder()
-
validate
final ClaimDocumentUploadedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ClaimDocumentUploadedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of ClaimDocumentUploadedWebhookEvent.
The following fields are required:
.token() .created() .downloadUrl() .downloadUrlExpiresAt() .eventType() .failureReason() .name() .requirementId() .status() .updated() .uploadConstraints() .uploadUrl() .uploadUrlExpiresAt()
-
-
-
-