Class ClaimUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class ClaimUpdatedWebhookEvent.BuilderA builder for ClaimUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final ClaimUpdatedWebhookEvent.Builder token(String token)
Unique identifier for the claim, in UUID format
-
token
final ClaimUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final ClaimUpdatedWebhookEvent.Builder accountHolderToken(String accountHolderToken)
Token for the account holder that filed the claim
-
accountHolderToken
final ClaimUpdatedWebhookEvent.Builder accountHolderToken(Optional<String> accountHolderToken)
Alias for calling Builder.accountHolderToken with
accountHolderToken.orElse(null).
-
accountHolderToken
final ClaimUpdatedWebhookEvent.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final ClaimUpdatedWebhookEvent.Builder accountToken(String accountToken)
Token for the account associated with the claim
-
accountToken
final ClaimUpdatedWebhookEvent.Builder accountToken(Optional<String> accountToken)
Alias for calling Builder.accountToken with
accountToken.orElse(null).
-
accountToken
final ClaimUpdatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokens
final ClaimUpdatedWebhookEvent.Builder cardTokens(List<String> cardTokens)
Tokens for the cards associated with the disputed transactions
-
cardTokens
final ClaimUpdatedWebhookEvent.Builder cardTokens(JsonField<List<String>> cardTokens)
Sets Builder.cardTokens to an arbitrary JSON value.
You should usually call Builder.cardTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCardToken
final ClaimUpdatedWebhookEvent.Builder addCardToken(String cardToken)
Adds a single String to cardTokens.
-
created
final ClaimUpdatedWebhookEvent.Builder created(OffsetDateTime created)
When the claim was created
-
created
final ClaimUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disputedTransactions
final ClaimUpdatedWebhookEvent.Builder disputedTransactions(List<ClaimUpdatedWebhookEvent.DisputedTransaction> disputedTransactions)
Transactions included in this claim
-
disputedTransactions
final ClaimUpdatedWebhookEvent.Builder disputedTransactions(JsonField<List<ClaimUpdatedWebhookEvent.DisputedTransaction>> disputedTransactions)
Sets Builder.disputedTransactions to an arbitrary JSON value.
You should usually call Builder.disputedTransactions with a well-typed
List<DisputedTransaction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDisputedTransaction
final ClaimUpdatedWebhookEvent.Builder addDisputedTransaction(ClaimUpdatedWebhookEvent.DisputedTransaction disputedTransaction)
Adds a single DisputedTransaction to disputedTransactions.
-
eventType
final ClaimUpdatedWebhookEvent.Builder eventType(ClaimUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final ClaimUpdatedWebhookEvent.Builder eventType(JsonField<ClaimUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outstandingRequirements
final ClaimUpdatedWebhookEvent.Builder outstandingRequirements(List<ClaimUpdatedWebhookEvent.OutstandingRequirement> outstandingRequirements)
Requirements that must be fulfilled before the claim can be submitted
-
outstandingRequirements
final ClaimUpdatedWebhookEvent.Builder outstandingRequirements(JsonField<List<ClaimUpdatedWebhookEvent.OutstandingRequirement>> outstandingRequirements)
Sets Builder.outstandingRequirements to an arbitrary JSON value.
You should usually call Builder.outstandingRequirements with a well-typed
List<OutstandingRequirement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addOutstandingRequirement
final ClaimUpdatedWebhookEvent.Builder addOutstandingRequirement(ClaimUpdatedWebhookEvent.OutstandingRequirement outstandingRequirement)
Adds a single OutstandingRequirement to outstandingRequirements.
-
reason
final ClaimUpdatedWebhookEvent.Builder reason(ClaimUpdatedWebhookEvent.Reason reason)
Dispute reason code provided when creating the claim
-
reason
final ClaimUpdatedWebhookEvent.Builder reason(JsonField<ClaimUpdatedWebhookEvent.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ClaimUpdatedWebhookEvent.Builder status(ClaimUpdatedWebhookEvent.Status status)
Current lifecycle status of the claim
-
status
final ClaimUpdatedWebhookEvent.Builder status(JsonField<ClaimUpdatedWebhookEvent.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submitted
final ClaimUpdatedWebhookEvent.Builder submitted(OffsetDateTime submitted)
When the claim was submitted. Null until the claim reaches
SUBMITTEDstatus
-
submitted
final ClaimUpdatedWebhookEvent.Builder submitted(Optional<OffsetDateTime> submitted)
Alias for calling Builder.submitted with
submitted.orElse(null).
-
submitted
final ClaimUpdatedWebhookEvent.Builder submitted(JsonField<OffsetDateTime> submitted)
Sets Builder.submitted to an arbitrary JSON value.
You should usually call Builder.submitted with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final ClaimUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
When the claim was last updated
-
updated
final ClaimUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClaimUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClaimUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClaimUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClaimUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClaimUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClaimUpdatedWebhookEvent build()
Returns an immutable instance of ClaimUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountHolderToken() .accountToken() .cardTokens() .created() .disputedTransactions() .eventType() .outstandingRequirements() .reason() .status() .submitted() .updated()
-
-
-
-