Class ClaimUpdatedWebhookEvent.DisputedTransaction.Builder
-
- All Implemented Interfaces:
public final class ClaimUpdatedWebhookEvent.DisputedTransaction.BuilderA builder for DisputedTransaction.
-
-
Method Summary
-
-
Method Detail
-
eventTokens
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder eventTokens(List<String> eventTokens)
Tokens for the specific events within the transaction being disputed. Lithic creates one dispute per event token
-
eventTokens
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder eventTokens(JsonField<List<String>> eventTokens)
Sets Builder.eventTokens to an arbitrary JSON value.
You should usually call Builder.eventTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEventToken
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder addEventToken(String eventToken)
Adds a single String to eventTokens.
-
transactionToken
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder transactionToken(String transactionToken)
Token for the transaction being disputed, in UUID format
-
transactionToken
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder transactionToken(JsonField<String> transactionToken)
Sets Builder.transactionToken to an arbitrary JSON value.
You should usually call Builder.transactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ClaimUpdatedWebhookEvent.DisputedTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ClaimUpdatedWebhookEvent.DisputedTransaction build()
Returns an immutable instance of DisputedTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventTokens() .transactionToken()
-
-
-
-