Class Conditional3dsActionParameters.Condition

    • Constructor Detail

    • Method Detail

      • attribute

         final Conditional3dsActionParameters.Condition.Attribute attribute()

        The attribute to target.

        The following attributes may be targeted:

        • MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.

        • COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.

        • CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.

        • MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).

        • DESCRIPTOR: Short description of card acceptor.

        • TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.

        • RISK_SCORE: Mastercard only: Assessment by the network of the authentication risk level, with a higher value indicating a higher amount of risk. Use an integer value.

        • MESSAGE_CATEGORY: The category of the authentication being processed.

        • ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values are MATCH, MATCH_ADDRESS_ONLY, MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.

      • validate

         final Conditional3dsActionParameters.Condition validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.