Class ConditionalAchActionParameters.Action.ReturnAction
-
- All Implemented Interfaces:
public final class ConditionalAchActionParameters.Action.ReturnAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAchActionParameters.Action.ReturnAction.BuilderA builder for ReturnAction.
public final classConditionalAchActionParameters.Action.ReturnAction.CodeNACHA return code to use when returning the transaction. Note that the list of available return codes is subject to an allowlist configured at the program level
public final classConditionalAchActionParameters.Action.ReturnAction.TypeReturn the ACH transaction
-
Method Summary
-
-
Method Detail
-
code
final ConditionalAchActionParameters.Action.ReturnAction.Code code()
NACHA return code to use when returning the transaction. Note that the list of available return codes is subject to an allowlist configured at the program level
-
type
final ConditionalAchActionParameters.Action.ReturnAction.Type type()
Return the ACH transaction
-
_code
final JsonField<ConditionalAchActionParameters.Action.ReturnAction.Code> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ConditionalAchActionParameters.Action.ReturnAction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAchActionParameters.Action.ReturnAction.Builder toBuilder()
-
validate
final ConditionalAchActionParameters.Action.ReturnAction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAchActionParameters.Action.ReturnAction.Builder builder()
Returns a mutable builder for constructing an instance of ReturnAction.
The following fields are required:
.code() .type()
-
-
-
-