Class ConditionalAchActionParameters.Action.ReturnAction.Code

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class ConditionalAchActionParameters.Action.ReturnAction.Code
     implements Enum
                        

    NACHA return code to use when returning the transaction. Note that the list of available return codes is subject to an allowlist configured at the program level