Enum ConditionalAchActionParameters.Action.ReturnAction.Code.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ConditionalAchActionParameters.Action.ReturnAction.Code.Value extends Enum<ConditionalAchActionParameters.Action.ReturnAction.Code.Value>
An enum containing Code's known values, as well as an _UNKNOWN member.
An instance of Code can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ConditionalAchActionParameters.Action.ReturnAction.Code.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description R01R02R03R04R05R06R07R08R09R10R11R12R13R14R15R16R17R18R19R20R21R22R23R24R25R26R27R28R29R30R31R32R33R34R35R36R37R38R39R40R41R42R43R44R45R46R47R50R51R52R53R61R62R67R68R69R70R71R72R73R74R75R76R77R80R81R82R83R84R85_UNKNOWNAn enum member indicating that Code was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final ConditionalAchActionParameters.Action.ReturnAction.Code.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ConditionalAchActionParameters.Action.ReturnAction.Code.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ConditionalAchActionParameters.Action.ReturnAction.Code.Value>getEntries()An enum containing Code's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final ConditionalAchActionParameters.Action.ReturnAction.Code.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ConditionalAchActionParameters.Action.ReturnAction.Code.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ConditionalAchActionParameters.Action.ReturnAction.Code.Value> getEntries()
An enum containing Code's known values, as well as an _UNKNOWN member.
An instance of Code can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-