Class ConditionalAchPaymentUpdateActionParameters.Condition.Attribute
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class ConditionalAchPaymentUpdateActionParameters.Condition.Attribute implements EnumThe attribute to target.
The following attributes may be targeted:
TRANSACTION_AMOUNT: The total amount of the ACH payment in minor units (cents), calculated as the sum of the settled and pending amounts. Use an integer value.SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.RETURN_REASON_CODE: NACHA return reason code associated with the payment (for example,R01).ACCOUNT_AGE: The age of the account in seconds at the time of the payment. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.EXTERNAL_BANK_ACCOUNT_AGE: The age of the external bank account in seconds at the time of the payment. Use an integer value.EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD: The method used to verify the external bank account. Valid values areMANUAL,MICRO_DEPOSIT,PRENOTE,EXTERNALLY_VERIFIED, orUNVERIFIED.EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE: The verification state of the external bank account. Valid values arePENDING,ENABLED,FAILED_VERIFICATION, orINSUFFICIENT_FUNDS.EXTERNAL_BANK_ACCOUNT_OWNER_TYPE: The owner type of the external bank account. Valid values areINDIVIDUALorBUSINESS.ACH_EVENT_TYPE: The type of ACH payment event being evaluated. Valid values includeACH_ORIGINATION_INITIATED,ACH_ORIGINATION_REVIEWED,ACH_ORIGINATION_CANCELLED,ACH_ORIGINATION_PROCESSED,ACH_ORIGINATION_SETTLED,ACH_ORIGINATION_RELEASED,ACH_ORIGINATION_REJECTED,ACH_RECEIPT_PROCESSED,ACH_RECEIPT_SETTLED,ACH_RECEIPT_RELEASED,ACH_RECEIPT_RELEASED_EARLY,ACH_RETURN_INITIATED,ACH_RETURN_PROCESSED,ACH_RETURN_SETTLED, andACH_RETURN_REJECTED.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumConditionalAchPaymentUpdateActionParameters.Condition.Attribute.KnownAn enum containing Attribute's known values.
public enumConditionalAchPaymentUpdateActionParameters.Condition.Attribute.ValueAn enum containing Attribute's known values, as well as an _UNKNOWN member.
An instance of Attribute can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ConditionalAchPaymentUpdateActionParameters.Condition.Attributevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConditionalAchPaymentUpdateActionParameters.Condition.Attributeof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static ConditionalAchPaymentUpdateActionParameters.Condition.Attribute of(String value)
-
-
-
-