Class ConditionalAchPaymentUpdateActionParameters.Condition.Builder
-
- All Implemented Interfaces:
public final class ConditionalAchPaymentUpdateActionParameters.Condition.BuilderA builder for Condition.
-
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder attribute(ConditionalAchPaymentUpdateActionParameters.Condition.Attribute attribute)
The attribute to target.
The following attributes may be targeted:
TRANSACTION_AMOUNT: The total amount of the ACH payment in minor units (cents), calculated as the sum of the settled and pending amounts. Use an integer value.SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.RETURN_REASON_CODE: NACHA return reason code associated with the payment (for example,R01).ACCOUNT_AGE: The age of the account in seconds at the time of the payment. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.EXTERNAL_BANK_ACCOUNT_AGE: The age of the external bank account in seconds at the time of the payment. Use an integer value.EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD: The method used to verify the external bank account. Valid values areMANUAL,MICRO_DEPOSIT,PRENOTE,EXTERNALLY_VERIFIED, orUNVERIFIED.EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE: The verification state of the external bank account. Valid values arePENDING,ENABLED,FAILED_VERIFICATION, orINSUFFICIENT_FUNDS.EXTERNAL_BANK_ACCOUNT_OWNER_TYPE: The owner type of the external bank account. Valid values areINDIVIDUALorBUSINESS.ACH_EVENT_TYPE: The type of ACH payment event being evaluated. Valid values includeACH_ORIGINATION_INITIATED,ACH_ORIGINATION_REVIEWED,ACH_ORIGINATION_CANCELLED,ACH_ORIGINATION_PROCESSED,ACH_ORIGINATION_SETTLED,ACH_ORIGINATION_RELEASED,ACH_ORIGINATION_REJECTED,ACH_RECEIPT_PROCESSED,ACH_RECEIPT_SETTLED,ACH_RECEIPT_RELEASED,ACH_RECEIPT_RELEASED_EARLY,ACH_RETURN_INITIATED,ACH_RETURN_PROCESSED,ACH_RETURN_SETTLED, andACH_RETURN_REJECTED.
-
attribute
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder attribute(JsonField<ConditionalAchPaymentUpdateActionParameters.Condition.Attribute> attribute)
Sets Builder.attribute to an arbitrary JSON value.
You should usually call Builder.attribute with a well-typed Attribute value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder operation(ConditionalOperation operation)
The operation to apply to the attribute
-
operation
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder operation(JsonField<ConditionalOperation> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed ConditionalOperation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(ConditionalValue value)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(JsonField<ConditionalValue> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed ConditionalValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(String regex)
Alias for calling value with
ConditionalValue.ofRegex(regex).
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(Long integer)
Alias for calling value with
ConditionalValue.ofInteger(integer).
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(Double number)
Alias for calling value with
ConditionalValue.ofNumber(number).
-
value
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder value(OffsetDateTime timestamp)
Alias for calling value with
ConditionalValue.ofTimestamp(timestamp).
-
valueOfListOfStrings
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder valueOfListOfStrings(List<String> listOfStrings)
Alias for calling value with
ConditionalValue.ofListOfStrings(listOfStrings).
-
additionalProperties
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConditionalAchPaymentUpdateActionParameters.Condition build()
Returns an immutable instance of Condition.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-