Package com.lithic.api.models
Class ConditionalAuthorizationAdjustmentParameters
-
- All Implemented Interfaces:
public final class ConditionalAuthorizationAdjustmentParameters
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAuthorizationAdjustmentParameters.BuilderA builder for ConditionalAuthorizationAdjustmentParameters.
public final classConditionalAuthorizationAdjustmentParameters.HoldAdjustmentActionThe hold adjustment to apply if the conditions are met.
public final classConditionalAuthorizationAdjustmentParameters.Condition
-
Method Summary
-
-
Method Detail
-
action
final ConditionalAuthorizationAdjustmentParameters.HoldAdjustmentAction action()
The hold adjustment to apply if the conditions are met.
-
conditions
final List<ConditionalAuthorizationAdjustmentParameters.Condition> conditions()
-
_action
final JsonField<ConditionalAuthorizationAdjustmentParameters.HoldAdjustmentAction> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_conditions
final JsonField<List<ConditionalAuthorizationAdjustmentParameters.Condition>> _conditions()
Returns the raw JSON value of conditions.
Unlike conditions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAuthorizationAdjustmentParameters.Builder toBuilder()
-
validate
final ConditionalAuthorizationAdjustmentParameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAuthorizationAdjustmentParameters.Builder builder()
Returns a mutable builder for constructing an instance of ConditionalAuthorizationAdjustmentParameters.
The following fields are required:
.action() .conditions()
-
-
-
-