Class ConditionalAuthorizationAdjustmentParameters.Adjustment.Mode

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class ConditionalAuthorizationAdjustmentParameters.Adjustment.Mode
     implements Enum
                        

    The mode of the hold adjustment, determining how the value is interpreted:

    • REPLACE_WITH_AMOUNT: The value is the approved hold amount in cents.

    • ADD_PERCENTAGE: The value adjusts the hold amount by a percentage. 1000 represents a 10% increase, 0 represents no change.

    • ADD_AMOUNT: The value is added to the hold amount in cents.