Class ConditionalAuthorizationAdjustmentParameters.Condition.Parameters
-
- All Implemented Interfaces:
public final class ConditionalAuthorizationAdjustmentParameters.Condition.ParametersAdditional parameters for certain attributes. Required when
attributeis one ofAMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT(requirescope); orTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION(requireunit). Not used for other attributes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAuthorizationAdjustmentParameters.Condition.Parameters.BuilderA builder for Parameters.
public final classConditionalAuthorizationAdjustmentParameters.Condition.Parameters.IntervalThe time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).public final classConditionalAuthorizationAdjustmentParameters.Condition.Parameters.ScopeThe entity scope to evaluate the attribute against.
public final classConditionalAuthorizationAdjustmentParameters.Condition.Parameters.UnitThe unit for impossible travel attributes. Required when
attributeisTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION.For
TRAVEL_SPEED:MPH(miles per hour) orKPH(kilometers per hour).For
DISTANCE_FROM_LAST_TRANSACTION:MILESorKILOMETERS.
-
Method Summary
-
-
Method Detail
-
interval
final Optional<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Interval> interval()
The time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).
-
scope
final Optional<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Scope> scope()
The entity scope to evaluate the attribute against.
-
unit
final Optional<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Unit> unit()
The unit for impossible travel attributes. Required when
attributeisTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION.For
TRAVEL_SPEED:MPH(miles per hour) orKPH(kilometers per hour).For
DISTANCE_FROM_LAST_TRANSACTION:MILESorKILOMETERS.
-
_interval
final JsonField<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Interval> _interval()
Returns the raw JSON value of interval.
Unlike interval, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_unit
final JsonField<ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Unit> _unit()
Returns the raw JSON value of unit.
Unlike unit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Builder toBuilder()
-
validate
final ConditionalAuthorizationAdjustmentParameters.Condition.Parameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAuthorizationAdjustmentParameters.Condition.Parameters.Builder builder()
Returns a mutable builder for constructing an instance of Parameters.
-
-
-
-