Class ConditionalCardTransactionUpdateActionParameters.Condition.Parameters
-
- All Implemented Interfaces:
public final class ConditionalCardTransactionUpdateActionParameters.Condition.ParametersAdditional parameters for certain attributes. Required when
attributeisSPEND_VELOCITY_COUNTorSPEND_VELOCITY_AMOUNT(requirescope,period, and optionalfilters);AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT(requirescope, and additionallyintervalfor the statistical attributes); orTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION(requireunit). Not used for other attributes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.BuilderA builder for Parameters.
public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.IntervalThe time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.ScopeThe entity scope to evaluate the attribute against.
GLOBALis only valid for spend velocity attributes.public final classConditionalCardTransactionUpdateActionParameters.Condition.Parameters.UnitThe unit for impossible travel attributes. Required when
attributeisTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION.For
TRAVEL_SPEED:MPH(miles per hour) orKPH(kilometers per hour).For
DISTANCE_FROM_LAST_TRANSACTION:MILESorKILOMETERS.
-
Method Summary
-
-
Method Detail
-
filters
final Optional<SpendVelocityFilters> filters()
-
interval
final Optional<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Interval> interval()
The time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).
-
period
final Optional<VelocityLimitPeriod> period()
The time period over which to calculate the spend velocity.
-
scope
final Optional<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Scope> scope()
The entity scope to evaluate the attribute against.
GLOBALis only valid for spend velocity attributes.
-
unit
final Optional<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Unit> unit()
The unit for impossible travel attributes. Required when
attributeisTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION.For
TRAVEL_SPEED:MPH(miles per hour) orKPH(kilometers per hour).For
DISTANCE_FROM_LAST_TRANSACTION:MILESorKILOMETERS.
-
_filters
final JsonField<SpendVelocityFilters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_interval
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Interval> _interval()
Returns the raw JSON value of interval.
Unlike interval, this method doesn't throw if the JSON field has an unexpected type.
-
_period
final JsonField<VelocityLimitPeriod> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_unit
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Unit> _unit()
Returns the raw JSON value of unit.
Unlike unit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Builder toBuilder()
-
validate
final ConditionalCardTransactionUpdateActionParameters.Condition.Parameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalCardTransactionUpdateActionParameters.Condition.Parameters.Builder builder()
Returns a mutable builder for constructing an instance of Parameters.
-
-
-
-