Class ConditionalTokenizationActionParameters.Condition.Attribute

  • All Implemented Interfaces:
    com.lithic.api.core.Enum

    
    public final class ConditionalTokenizationActionParameters.Condition.Attribute
     implements Enum
                        

    The attribute to target.

    The following attributes may be targeted:

    • TIMESTAMP: The timestamp of the tokenization request in ISO 8601 format.

    • TOKENIZATION_CHANNEL: The channel through which the tokenization request was initiated. Valid values are DIGITAL_WALLET, MERCHANT.

    • TOKENIZATION_SOURCE: The source of the tokenization request. Valid values are ACCOUNT_ON_FILE, MANUAL_PROVISION, PUSH_PROVISION, CHIP_DIP, CONTACTLESS_TAP, TOKEN, UNKNOWN.

    • TOKEN_REQUESTOR_NAME: The name of the entity requesting the token. Valid values are ALT_ID, AMAZON_ONE, AMERICAN_EXPRESS_TOKEN_SERVICE, ANDROID_PAY, APPLE_PAY, FACEBOOK, FITBIT_PAY, GARMIN_PAY, GOOGLE_PAY, GOOGLE_VCN, ISSUER_HCE, MICROSOFT_PAY, NETFLIX, SAMSUNG_PAY, UNKNOWN, VISA_CHECKOUT.

    • WALLET_ACCOUNT_SCORE: Risk score for the account in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).

    • WALLET_DEVICE_SCORE: Risk score for the device in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).

    • WALLET_RECOMMENDED_DECISION: The decision recommended by the digital wallet provider. Valid values include APPROVE, DECLINE, REQUIRE_ADDITIONAL_AUTHENTICATION.

    • WALLET_RECOMMENDATION_REASONS: List of reasons provided by the digital wallet provider for the recommended decision. Valid values are:

    • TOKEN_REQUESTOR_ID: Unique identifier for the entity requesting the token.

    • WALLET_TOKEN_STATUS: The current status of the wallet token.

    • CARD_STATE: The state of the card being tokenized. Valid values are CLOSED, OPEN, PAUSED, PENDING_ACTIVATION, PENDING_FULFILLMENT.