Package com.lithic.api.models
Interface ConditionalValue.Visitor
-
- All Implemented Interfaces:
public interface ConditionalValue.Visitor<T extends Object>An interface that defines how to map each variant of ConditionalValue to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitRegex(String regex)A regex string, to be used with MATCHESorDOES_NOT_MATCHabstract TvisitNumber(Long number)A number, to be used with IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TOabstract TvisitListOfStrings(List<String> listOfStrings)An array of strings, to be used with IS_ONE_OForIS_NOT_ONE_OFabstract TvisitTimestamp(OffsetDateTime timestamp)A timestamp, to be used with IS_AFTERorIS_BEFORETunknown(JsonValue json)Maps an unknown variant of ConditionalValue to a value of type T. -
-
Method Detail
-
visitRegex
abstract T visitRegex(String regex)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
visitNumber
abstract T visitNumber(Long number)
A number, to be used with
IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TO
-
visitListOfStrings
abstract T visitListOfStrings(List<String> listOfStrings)
An array of strings, to be used with
IS_ONE_OForIS_NOT_ONE_OF
-
visitTimestamp
abstract T visitTimestamp(OffsetDateTime timestamp)
A timestamp, to be used with
IS_AFTERorIS_BEFORE
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of ConditionalValue to a value of type T.
An instance of ConditionalValue can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-