Class Device
-
- All Implemented Interfaces:
public final class Device
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDevice.BuilderA builder for Device.
-
Method Summary
Modifier and Type Method Description final Optional<String>imei()The IMEI number of the device being provisioned. final Optional<String>ipAddress()The IP address of the device initiating the request final Optional<String>location()Latitude and longitude where the device is located during the authorization attempt final JsonField<String>_imei()Returns the raw JSON value of imei. final JsonField<String>_ipAddress()Returns the raw JSON value of ipAddress. final JsonField<String>_location()Returns the raw JSON value of location. final Map<String, JsonValue>_additionalProperties()final Device.BuildertoBuilder()final Devicevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Device.Builderbuilder()Returns a mutable builder for constructing an instance of Device. -
-
Method Detail
-
imei
final Optional<String> imei()
The IMEI number of the device being provisioned. For Amex, this field contains device ID instead as IMEI is not provided
-
location
final Optional<String> location()
Latitude and longitude where the device is located during the authorization attempt
-
_imei
final JsonField<String> _imei()
Returns the raw JSON value of imei.
Unlike imei, this method doesn't throw if the JSON field has an unexpected type.
-
_ipAddress
final JsonField<String> _ipAddress()
Returns the raw JSON value of ipAddress.
Unlike ipAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_location
final JsonField<String> _location()
Returns the raw JSON value of location.
Unlike location, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Device.Builder toBuilder()
-
validate
final Device validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Device.Builder builder()
Returns a mutable builder for constructing an instance of Device.
The following fields are required:
.imei() .ipAddress() .location()
-
-
-
-