Class DigitalCardArt.Builder
-
- All Implemented Interfaces:
public final class DigitalCardArt.BuilderA builder for DigitalCardArt.
-
-
Method Summary
-
-
Method Detail
-
token
final DigitalCardArt.Builder token(String token)
Globally unique identifier for the card art.
-
token
final DigitalCardArt.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardProgramToken
final DigitalCardArt.Builder cardProgramToken(String cardProgramToken)
Globally unique identifier for the card program.
-
cardProgramToken
final DigitalCardArt.Builder cardProgramToken(JsonField<String> cardProgramToken)
Sets Builder.cardProgramToken to an arbitrary JSON value.
You should usually call Builder.cardProgramToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DigitalCardArt.Builder created(OffsetDateTime created)
Timestamp of when card art was created.
-
created
final DigitalCardArt.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final DigitalCardArt.Builder description(String description)
Description of the card art.
-
description
final DigitalCardArt.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isEnabled
final DigitalCardArt.Builder isEnabled(Boolean isEnabled)
Whether the card art is enabled.
-
isEnabled
final DigitalCardArt.Builder isEnabled(JsonField<Boolean> isEnabled)
Sets Builder.isEnabled to an arbitrary JSON value.
You should usually call Builder.isEnabled with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final DigitalCardArt.Builder network(DigitalCardArt.Network network)
Card network.
-
network
final DigitalCardArt.Builder network(JsonField<DigitalCardArt.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isCardProgramDefault
final DigitalCardArt.Builder isCardProgramDefault(Boolean isCardProgramDefault)
Whether the card art is the default card art to be added upon tokenization.
-
isCardProgramDefault
final DigitalCardArt.Builder isCardProgramDefault(JsonField<Boolean> isCardProgramDefault)
Sets Builder.isCardProgramDefault to an arbitrary JSON value.
You should usually call Builder.isCardProgramDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalCardArt.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalCardArt.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalCardArt.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalCardArt.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalCardArt.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalCardArt build()
Returns an immutable instance of DigitalCardArt.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .cardProgramToken() .created() .description() .isEnabled() .network()
-
-
-
-