Package com.lithic.api.models
Class DigitalCardArtListPageAsync.Builder
-
- All Implemented Interfaces:
public final class DigitalCardArtListPageAsync.BuilderA builder for DigitalCardArtListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final DigitalCardArtListPageAsync.Builderservice(DigitalCardArtServiceAsync service)final DigitalCardArtListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final DigitalCardArtListPageAsync.Builderparams(DigitalCardArtListParams params)The parameters that were used to request this page. final DigitalCardArtListPageAsync.Builderresponse(DigitalCardArtListPageResponse response)The response that this page was parsed from. final DigitalCardArtListPageAsyncbuild()Returns an immutable instance of DigitalCardArtListPageAsync. -
-
Method Detail
-
service
final DigitalCardArtListPageAsync.Builder service(DigitalCardArtServiceAsync service)
-
streamHandlerExecutor
final DigitalCardArtListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final DigitalCardArtListPageAsync.Builder params(DigitalCardArtListParams params)
The parameters that were used to request this page.
-
response
final DigitalCardArtListPageAsync.Builder response(DigitalCardArtListPageResponse response)
The response that this page was parsed from.
-
build
final DigitalCardArtListPageAsync build()
Returns an immutable instance of DigitalCardArtListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-