Class DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationApprovalRequestWebhookEvent.BuilderA builder for DigitalWalletTokenizationApprovalRequestWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerTokenizationDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision customerTokenizationDecision)
Contains the metadata for the customer tokenization decision.
-
customerTokenizationDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(Optional<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision)
Alias for calling Builder.customerTokenizationDecision with
customerTokenizationDecision.orElse(null).
-
customerTokenizationDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision)
Sets Builder.customerTokenizationDecision to an arbitrary JSON value.
You should usually call Builder.customerTokenizationDecision with a well-typed CustomerTokenizationDecision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenMetadata
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder digitalWalletTokenMetadata(TokenMetadata digitalWalletTokenMetadata)
Contains the metadata for the digital wallet being tokenized.
-
digitalWalletTokenMetadata
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder digitalWalletTokenMetadata(JsonField<TokenMetadata> digitalWalletTokenMetadata)
Sets Builder.digitalWalletTokenMetadata to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenMetadata with a well-typed TokenMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder eventType(DigitalWalletTokenizationApprovalRequestWebhookEvent.EventType eventType)
The name of this event
-
eventType
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder eventType(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
issuerDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder issuerDecision(DigitalWalletTokenizationApprovalRequestWebhookEvent.IssuerDecision issuerDecision)
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
issuerDecision
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder issuerDecision(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.IssuerDecision> issuerDecision)
Sets Builder.issuerDecision to an arbitrary JSON value.
You should usually call Builder.issuerDecision with a well-typed IssuerDecision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationChannel
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationChannel(DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel tokenizationChannel)
The channel through which the tokenization was made.
-
tokenizationChannel
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationChannel(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel> tokenizationChannel)
Sets Builder.tokenizationChannel to an arbitrary JSON value.
You should usually call Builder.tokenizationChannel with a well-typed TokenizationChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the digital wallet token attempt
-
tokenizationToken
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
walletDecisioningInfo
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder walletDecisioningInfo(WalletDecisioningInfo walletDecisioningInfo)
-
walletDecisioningInfo
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder walletDecisioningInfo(JsonField<WalletDecisioningInfo> walletDecisioningInfo)
Sets Builder.walletDecisioningInfo to an arbitrary JSON value.
You should usually call Builder.walletDecisioningInfo with a well-typed WalletDecisioningInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
device
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder device(Device device)
-
device
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder device(JsonField<Device> device)
Sets Builder.device to an arbitrary JSON value.
You should usually call Builder.device with a well-typed Device value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ruleResults
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder ruleResults(List<TokenizationRuleResult> ruleResults)
Results from rules that were evaluated for this tokenization
-
ruleResults
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder ruleResults(JsonField<List<TokenizationRuleResult>> ruleResults)
Sets Builder.ruleResults to an arbitrary JSON value.
You should usually call Builder.ruleResults with a well-typed
List<TokenizationRuleResult>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRuleResult
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder addRuleResult(TokenizationRuleResult ruleResult)
Adds a single TokenizationRuleResult to ruleResults.
-
tokenizationDeclineReasons
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationDeclineReasons(List<TokenizationDeclineReason> tokenizationDeclineReasons)
List of reasons why the tokenization was declined
-
tokenizationDeclineReasons
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationDeclineReasons(JsonField<List<TokenizationDeclineReason>> tokenizationDeclineReasons)
Sets Builder.tokenizationDeclineReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationDeclineReasons with a well-typed
List<TokenizationDeclineReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationDeclineReason
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder addTokenizationDeclineReason(TokenizationDeclineReason tokenizationDeclineReason)
Adds a single TokenizationDeclineReason to tokenizationDeclineReasons.
-
tokenizationSource
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationSource(DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationSource tokenizationSource)
The source of the tokenization.
-
tokenizationSource
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationSource(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationSource> tokenizationSource)
Sets Builder.tokenizationSource to an arbitrary JSON value.
You should usually call Builder.tokenizationSource with a well-typed TokenizationSource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationTfaReasons
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationTfaReasons(List<TokenizationTfaReason> tokenizationTfaReasons)
List of reasons why two-factor authentication was required
-
tokenizationTfaReasons
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder tokenizationTfaReasons(JsonField<List<TokenizationTfaReason>> tokenizationTfaReasons)
Sets Builder.tokenizationTfaReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationTfaReasons with a well-typed
List<TokenizationTfaReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationTfaReason
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder addTokenizationTfaReason(TokenizationTfaReason tokenizationTfaReason)
Adds a single TokenizationTfaReason to tokenizationTfaReasons.
-
additionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationApprovalRequestWebhookEvent build()
Returns an immutable instance of DigitalWalletTokenizationApprovalRequestWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .cardToken() .created() .customerTokenizationDecision() .digitalWalletTokenMetadata() .eventType() .issuerDecision() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-