Class DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.BuilderA builder for CustomerTokenizationDecision.
-
-
Method Summary
-
-
Method Detail
-
outcome
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder outcome(DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Outcome outcome)
The outcome of the customer's decision
-
outcome
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder outcome(JsonField<DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Outcome> outcome)
Sets Builder.outcome to an arbitrary JSON value.
You should usually call Builder.outcome with a well-typed Outcome value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
responderUrl
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder responderUrl(String responderUrl)
The customer's subscribed URL
-
responderUrl
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder responderUrl(JsonField<String> responderUrl)
Sets Builder.responderUrl to an arbitrary JSON value.
You should usually call Builder.responderUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
latency
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder latency(String latency)
Time in ms it took for the customer's URL to respond
-
latency
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder latency(JsonField<String> latency)
Sets Builder.latency to an arbitrary JSON value.
You should usually call Builder.latency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
responseCode
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder responseCode(String responseCode)
The response code that the customer provided
-
responseCode
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder responseCode(JsonField<String> responseCode)
Sets Builder.responseCode to an arbitrary JSON value.
You should usually call Builder.responseCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision build()
Returns an immutable instance of CustomerTokenizationDecision.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.outcome() .responderUrl()
-
-
-
-