Package com.lithic.api.models
Enum DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known extends Enum<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known>
An enum containing TokenizationChannel's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description DIGITAL_WALLETMERCHANT
-
Method Summary
Modifier and Type Method Description final DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known>getEntries()An enum containing TokenizationChannel's known values. -
-
Method Detail
-
valueOf
final DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DigitalWalletTokenizationApprovalRequestWebhookEvent.TokenizationChannel.Known> getEntries()
An enum containing TokenizationChannel's known values.
-
-
-
-