Class DigitalWalletTokenizationResultWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationResultWebhookEvent.BuilderA builder for DigitalWalletTokenizationResultWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final DigitalWalletTokenizationResultWebhookEvent.Builder accountToken(String accountToken)
Account token
-
accountToken
final DigitalWalletTokenizationResultWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final DigitalWalletTokenizationResultWebhookEvent.Builder cardToken(String cardToken)
Card token
-
cardToken
final DigitalWalletTokenizationResultWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DigitalWalletTokenizationResultWebhookEvent.Builder created(OffsetDateTime created)
Created date
-
created
final DigitalWalletTokenizationResultWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DigitalWalletTokenizationResultWebhookEvent.Builder eventType(DigitalWalletTokenizationResultWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final DigitalWalletTokenizationResultWebhookEvent.Builder eventType(JsonField<DigitalWalletTokenizationResultWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationResultDetails
final DigitalWalletTokenizationResultWebhookEvent.Builder tokenizationResultDetails(DigitalWalletTokenizationResultWebhookEvent.TokenizationResultDetails tokenizationResultDetails)
The result of the tokenization request.
-
tokenizationResultDetails
final DigitalWalletTokenizationResultWebhookEvent.Builder tokenizationResultDetails(JsonField<DigitalWalletTokenizationResultWebhookEvent.TokenizationResultDetails> tokenizationResultDetails)
Sets Builder.tokenizationResultDetails to an arbitrary JSON value.
You should usually call Builder.tokenizationResultDetails with a well-typed TokenizationResultDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final DigitalWalletTokenizationResultWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Tokenization token
-
tokenizationToken
final DigitalWalletTokenizationResultWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenizationResultWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationResultWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationResultWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationResultWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationResultWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationResultWebhookEvent build()
Returns an immutable instance of DigitalWalletTokenizationResultWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .cardToken() .created() .eventType() .tokenizationResultDetails() .tokenizationToken()
-
-
-
-