Class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.BuilderA builder for DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.
public final classDigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethodpublic final classDigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Unique identifier for the user tokenizing a card
-
activationMethod
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod activationMethod()
-
authenticationCode
final String authenticationCode()
Authentication code to provide to the user tokenizing a card.
-
created
final OffsetDateTime created()
Indicate when the request was received from Mastercard or Visa
-
eventType
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType eventType()
The type of event that occurred.
-
tokenizationToken
final String tokenizationToken()
Unique identifier for the tokenization
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_activationMethod
final JsonField<DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod> _activationMethod()
Returns the raw JSON value of activationMethod.
Unlike activationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationCode
final JsonField<String> _authenticationCode()
Returns the raw JSON value of authenticationCode.
Unlike authenticationCode, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder toBuilder()
-
validate
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent validate()
-
builder
final static DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.
The following fields are required:
.accountToken() .activationMethod() .authenticationCode() .cardToken() .created() .eventType() .tokenizationToken()
-
-
-
-