Class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.BuilderA builder for ActivationMethod.
-
-
Method Summary
-
-
Method Detail
-
type
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder type(DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Type type)
The communication method that the user has selected to use to receive the authentication code. Supported Values: Sms = "TEXT_TO_CARDHOLDER_NUMBER". Email = "EMAIL_TO_CARDHOLDER_ADDRESS"
-
type
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder type(JsonField<DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder value(String value)
The location where the user wants to receive the authentication code. The format depends on the ActivationMethod.Type field. If Type is Email, the Value will be the email address. If the Type is Sms, the Value will be the phone number.
-
value
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod build()
Returns an immutable instance of ActivationMethod.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type() .value()
-
-
-
-