Class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder
-
-
Method Summary
-
-
Method Detail
-
accountToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
activationMethod
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder activationMethod(DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod activationMethod)
-
activationMethod
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder activationMethod(JsonField<DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod> activationMethod)
Sets Builder.activationMethod to an arbitrary JSON value.
You should usually call Builder.activationMethod with a well-typed ActivationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationCode
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder authenticationCode(String authenticationCode)
Authentication code to provide to the user tokenizing a card.
-
authenticationCode
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder authenticationCode(JsonField<String> authenticationCode)
Sets Builder.authenticationCode to an arbitrary JSON value.
You should usually call Builder.authenticationCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder eventType(DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder eventType(JsonField<DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the tokenization
-
tokenizationToken
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent build()
Returns an immutable instance of DigitalWalletTokenizationTwoFactorAuthenticationCodeWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .activationMethod() .authenticationCode() .cardToken() .created() .eventType() .tokenizationToken()
-
-
-
-