Class DigitalWalletTokenizationUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenizationUpdatedWebhookEvent.BuilderA builder for DigitalWalletTokenizationUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder accountToken(String accountToken)
Account token
-
accountToken
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder cardToken(String cardToken)
Card token
-
cardToken
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Created date
-
created
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder eventType(DigitalWalletTokenizationUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder eventType(JsonField<DigitalWalletTokenizationUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenization
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder tokenization(Tokenization tokenization)
-
tokenization
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder tokenization(JsonField<Tokenization> tokenization)
Sets Builder.tokenization to an arbitrary JSON value.
You should usually call Builder.tokenization with a well-typed Tokenization value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenizationUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenizationUpdatedWebhookEvent build()
Returns an immutable instance of DigitalWalletTokenizationUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .cardToken() .created() .eventType() .tokenization()
-
-
-
-