Class DisputeCreateParams.Body
-
- All Implemented Interfaces:
public final class DisputeCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount for chargeback final DisputeCreateParams.Reasonreason()Reason for chargeback final StringtransactionToken()Transaction for chargeback final Optional<OffsetDateTime>customerFiledDate()Date the customer filed the chargeback request final Optional<String>customerNote()Customer description final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<DisputeCreateParams.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final JsonField<OffsetDateTime>_customerFiledDate()Returns the raw JSON value of customerFiledDate. final JsonField<String>_customerNote()Returns the raw JSON value of customerNote. final Map<String, JsonValue>_additionalProperties()final DisputeCreateParams.Body.BuildertoBuilder()final DisputeCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
reason
final DisputeCreateParams.Reason reason()
Reason for chargeback
-
transactionToken
final String transactionToken()
Transaction for chargeback
-
customerFiledDate
final Optional<OffsetDateTime> customerFiledDate()
Date the customer filed the chargeback request
-
customerNote
final Optional<String> customerNote()
Customer description
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DisputeCreateParams.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_customerFiledDate
final JsonField<OffsetDateTime> _customerFiledDate()
Returns the raw JSON value of customerFiledDate.
Unlike customerFiledDate, this method doesn't throw if the JSON field has an unexpected type.
-
_customerNote
final JsonField<String> _customerNote()
Returns the raw JSON value of customerNote.
Unlike customerNote, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeCreateParams.Body.Builder toBuilder()
-
validate
final DisputeCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .reason() .transactionToken()
-
-
-
-