Class DisputeEvidence.Builder
-
- All Implemented Interfaces:
public final class DisputeEvidence.BuilderA builder for DisputeEvidence.
-
-
Method Summary
-
-
Method Detail
-
token
final DisputeEvidence.Builder token(String token)
Globally unique identifier.
-
token
final DisputeEvidence.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DisputeEvidence.Builder created(OffsetDateTime created)
Timestamp of when dispute evidence was created.
-
created
final DisputeEvidence.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disputeToken
final DisputeEvidence.Builder disputeToken(String disputeToken)
Dispute token evidence is attached to.
-
disputeToken
final DisputeEvidence.Builder disputeToken(JsonField<String> disputeToken)
Sets Builder.disputeToken to an arbitrary JSON value.
You should usually call Builder.disputeToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadStatus
final DisputeEvidence.Builder uploadStatus(DisputeEvidence.UploadStatus uploadStatus)
Upload status types:
DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
-
uploadStatus
final DisputeEvidence.Builder uploadStatus(JsonField<DisputeEvidence.UploadStatus> uploadStatus)
Sets Builder.uploadStatus to an arbitrary JSON value.
You should usually call Builder.uploadStatus with a well-typed UploadStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
downloadUrl
final DisputeEvidence.Builder downloadUrl(String downloadUrl)
URL to download evidence. Only shown when
upload_statusisUPLOADED.
-
downloadUrl
final DisputeEvidence.Builder downloadUrl(JsonField<String> downloadUrl)
Sets Builder.downloadUrl to an arbitrary JSON value.
You should usually call Builder.downloadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filename
final DisputeEvidence.Builder filename(String filename)
File name of evidence. Recommended to give the dispute evidence a human-readable identifier.
-
filename
final DisputeEvidence.Builder filename(JsonField<String> filename)
Sets Builder.filename to an arbitrary JSON value.
You should usually call Builder.filename with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrl
final DisputeEvidence.Builder uploadUrl(String uploadUrl)
URL to upload evidence. Only shown when
upload_statusisPENDING.
-
uploadUrl
final DisputeEvidence.Builder uploadUrl(JsonField<String> uploadUrl)
Sets Builder.uploadUrl to an arbitrary JSON value.
You should usually call Builder.uploadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeEvidence.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeEvidence.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeEvidence.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeEvidence.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeEvidence.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeEvidence build()
Returns an immutable instance of DisputeEvidence.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .created() .disputeToken() .uploadStatus()
-
-
-
-