Class DisputeEvidenceUploadFailedWebhookEvent
-
- All Implemented Interfaces:
public final class DisputeEvidenceUploadFailedWebhookEventDispute evidence.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeEvidenceUploadFailedWebhookEvent.BuilderA builder for DisputeEvidenceUploadFailedWebhookEvent.
public final classDisputeEvidenceUploadFailedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final DisputeEvidencetoDisputeEvidence()final Stringtoken()Globally unique identifier. final OffsetDateTimecreated()Timestamp of when dispute evidence was created. final StringdisputeToken()Dispute token evidence is attached to. final DisputeEvidence.UploadStatusuploadStatus()Upload status types: DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
final Optional<String>downloadUrl()URL to download evidence. final Optional<String>filename()File name of evidence. final Optional<String>uploadUrl()URL to upload evidence. final DisputeEvidenceUploadFailedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_disputeToken()Returns the raw JSON value of disputeToken. final JsonField<DisputeEvidence.UploadStatus>_uploadStatus()Returns the raw JSON value of uploadStatus. final JsonField<String>_downloadUrl()Returns the raw JSON value of downloadUrl. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final JsonField<DisputeEvidenceUploadFailedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final DisputeEvidenceUploadFailedWebhookEvent.BuildertoBuilder()final DisputeEvidenceUploadFailedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeEvidenceUploadFailedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeEvidenceUploadFailedWebhookEvent. -
-
Method Detail
-
toDisputeEvidence
final DisputeEvidence toDisputeEvidence()
-
created
final OffsetDateTime created()
Timestamp of when dispute evidence was created.
-
disputeToken
final String disputeToken()
Dispute token evidence is attached to.
-
uploadStatus
final DisputeEvidence.UploadStatus uploadStatus()
Upload status types:
DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
-
downloadUrl
final Optional<String> downloadUrl()
URL to download evidence. Only shown when
upload_statusisUPLOADED.
-
filename
final Optional<String> filename()
File name of evidence. Recommended to give the dispute evidence a human-readable identifier.
-
uploadUrl
final Optional<String> uploadUrl()
URL to upload evidence. Only shown when
upload_statusisPENDING.
-
eventType
final DisputeEvidenceUploadFailedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_disputeToken
final JsonField<String> _disputeToken()
Returns the raw JSON value of disputeToken.
Unlike disputeToken, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadStatus
final JsonField<DisputeEvidence.UploadStatus> _uploadStatus()
Returns the raw JSON value of uploadStatus.
Unlike uploadStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_downloadUrl
final JsonField<String> _downloadUrl()
Returns the raw JSON value of downloadUrl.
Unlike downloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DisputeEvidenceUploadFailedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeEvidenceUploadFailedWebhookEvent.Builder toBuilder()
-
validate
final DisputeEvidenceUploadFailedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeEvidenceUploadFailedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DisputeEvidenceUploadFailedWebhookEvent.
The following fields are required:
.token() .created() .disputeToken() .uploadStatus() .eventType()
-
-
-