Package com.lithic.api.models
Class DisputeListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class DisputeListPageAsync implements PageAsync<Dispute>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeListPageAsync.BuilderA builder for DisputeListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<Dispute>data()Delegates to DisputeListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to DisputeListPageResponse, but gracefully handles missing data. List<Dispute>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final DisputeListParamsnextPageParams()CompletableFuture<DisputeListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Dispute>autoPager()final DisputeListParamsparams()The parameters that were used to request this page. final DisputeListPageResponseresponse()The response that this page was parsed from. final DisputeListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeListPageAsync. -
-
Method Detail
-
data
final List<Dispute> data()
Delegates to DisputeListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to DisputeListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final DisputeListParams nextPageParams()
-
nextPage
CompletableFuture<DisputeListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Dispute> autoPager()
-
params
final DisputeListParams params()
The parameters that were used to request this page.
-
response
final DisputeListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DisputeListPageAsync.Builder toBuilder()
-
builder
final static DisputeListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of DisputeListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-