Package com.lithic.api.models
Class DisputeListPageAsync.Builder
-
- All Implemented Interfaces:
public final class DisputeListPageAsync.BuilderA builder for DisputeListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final DisputeListPageAsync.Builderservice(DisputeServiceAsync service)final DisputeListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final DisputeListPageAsync.Builderparams(DisputeListParams params)The parameters that were used to request this page. final DisputeListPageAsync.Builderresponse(DisputeListPageResponse response)The response that this page was parsed from. final DisputeListPageAsyncbuild()Returns an immutable instance of DisputeListPageAsync. -
-
Method Detail
-
service
final DisputeListPageAsync.Builder service(DisputeServiceAsync service)
-
streamHandlerExecutor
final DisputeListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final DisputeListPageAsync.Builder params(DisputeListParams params)
The parameters that were used to request this page.
-
response
final DisputeListPageAsync.Builder response(DisputeListPageResponse response)
The response that this page was parsed from.
-
build
final DisputeListPageAsync build()
Returns an immutable instance of DisputeListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-