Package com.lithic.api.models
Class DisputeListPageResponse
-
- All Implemented Interfaces:
public final class DisputeListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeListPageResponse.BuilderA builder for DisputeListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Dispute>data()final BooleanhasMore()More data exists. final JsonField<List<Dispute>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final DisputeListPageResponse.BuildertoBuilder()final DisputeListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Dispute>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeListPageResponse.Builder toBuilder()
-
validate
final DisputeListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of DisputeListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-