Class DisputeTransactionCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class DisputeTransactionCreatedWebhookEventThe Dispute object tracks the progression of a dispute throughout its lifecycle.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeTransactionCreatedWebhookEvent.BuilderA builder for DisputeTransactionCreatedWebhookEvent.
public final classDisputeTransactionCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final DisputeV2toDisputeV2()final Stringtoken()Token assigned by Lithic for the dispute, in UUID format. final StringaccountToken()Token for the account associated with the dispute, in UUID format. final StringcardToken()Token for the card used in the dispute, in UUID format. final Optional<String>caseId()Identifier assigned by the network for this dispute. final OffsetDateTimecreated()When the dispute was created. final Stringcurrency()Three-letter ISO 4217 currency code. final Optional<DisputeV2.Disposition>disposition()Dispute resolution outcome final List<DisputeV2.Event>events()Chronological list of events that have occurred in the dispute lifecycle final DisputeV2.LiabilityAllocationliabilityAllocation()Current breakdown of how liability is allocated for the disputed amount final Merchantmerchant()final DisputeV2.Networknetwork()Card network handling the dispute. final Optional<DisputeV2.Status>status()Current status of the dispute. final Optional<DisputeV2.TransactionSeries>transactionSeries()Contains identifiers for the transaction and specific event within being disputed; null if no transaction can be identified final OffsetDateTimeupdated()When the dispute was last updated. final DisputeTransactionCreatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<String>_caseId()Returns the raw JSON value of caseId. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<DisputeV2.Disposition>_disposition()Returns the raw JSON value of disposition. final JsonField<List<DisputeV2.Event>>_events()Returns the raw JSON value of events. final JsonField<DisputeV2.LiabilityAllocation>_liabilityAllocation()Returns the raw JSON value of liabilityAllocation. final JsonField<Merchant>_merchant()Returns the raw JSON value of merchant. final JsonField<DisputeV2.Network>_network()Returns the raw JSON value of network. final JsonField<DisputeV2.Status>_status()Returns the raw JSON value of status. final JsonField<DisputeV2.TransactionSeries>_transactionSeries()Returns the raw JSON value of transactionSeries. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<DisputeTransactionCreatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final DisputeTransactionCreatedWebhookEvent.BuildertoBuilder()final DisputeTransactionCreatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeTransactionCreatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeTransactionCreatedWebhookEvent. -
-
Method Detail
-
toDisputeV2
final DisputeV2 toDisputeV2()
-
accountToken
final String accountToken()
Token for the account associated with the dispute, in UUID format.
-
created
final OffsetDateTime created()
When the dispute was created.
-
disposition
final Optional<DisputeV2.Disposition> disposition()
Dispute resolution outcome
-
events
final List<DisputeV2.Event> events()
Chronological list of events that have occurred in the dispute lifecycle
-
liabilityAllocation
final DisputeV2.LiabilityAllocation liabilityAllocation()
Current breakdown of how liability is allocated for the disputed amount
-
network
final DisputeV2.Network network()
Card network handling the dispute.
-
status
final Optional<DisputeV2.Status> status()
Current status of the dispute.
-
transactionSeries
final Optional<DisputeV2.TransactionSeries> transactionSeries()
Contains identifiers for the transaction and specific event within being disputed; null if no transaction can be identified
-
updated
final OffsetDateTime updated()
When the dispute was last updated.
-
eventType
final DisputeTransactionCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_caseId
final JsonField<String> _caseId()
Returns the raw JSON value of caseId.
Unlike caseId, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_disposition
final JsonField<DisputeV2.Disposition> _disposition()
Returns the raw JSON value of disposition.
Unlike disposition, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<DisputeV2.Event>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_liabilityAllocation
final JsonField<DisputeV2.LiabilityAllocation> _liabilityAllocation()
Returns the raw JSON value of liabilityAllocation.
Unlike liabilityAllocation, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<DisputeV2.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DisputeV2.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionSeries
final JsonField<DisputeV2.TransactionSeries> _transactionSeries()
Returns the raw JSON value of transactionSeries.
Unlike transactionSeries, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DisputeTransactionCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeTransactionCreatedWebhookEvent.Builder toBuilder()
-
validate
final DisputeTransactionCreatedWebhookEvent validate()
-
builder
final static DisputeTransactionCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DisputeTransactionCreatedWebhookEvent.
The following fields are required:
.token() .accountToken() .cardToken() .caseId() .created() .currency() .disposition() .events() .liabilityAllocation() .merchant() .network() .status() .transactionSeries() .updated() .eventType()
-
-
-
-