Class DisputeTransactionUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DisputeTransactionUpdatedWebhookEvent.BuilderA builder for DisputeTransactionUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final DisputeTransactionUpdatedWebhookEvent.Builder token(String token)
Token assigned by Lithic for the dispute, in UUID format.
-
token
final DisputeTransactionUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final DisputeTransactionUpdatedWebhookEvent.Builder accountToken(String accountToken)
Token for the account associated with the dispute, in UUID format.
-
accountToken
final DisputeTransactionUpdatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final DisputeTransactionUpdatedWebhookEvent.Builder cardToken(String cardToken)
Token for the card used in the dispute, in UUID format.
-
cardToken
final DisputeTransactionUpdatedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caseId
final DisputeTransactionUpdatedWebhookEvent.Builder caseId(String caseId)
Identifier assigned by the network for this dispute.
-
caseId
final DisputeTransactionUpdatedWebhookEvent.Builder caseId(Optional<String> caseId)
Alias for calling Builder.caseId with
caseId.orElse(null).
-
caseId
final DisputeTransactionUpdatedWebhookEvent.Builder caseId(JsonField<String> caseId)
Sets Builder.caseId to an arbitrary JSON value.
You should usually call Builder.caseId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DisputeTransactionUpdatedWebhookEvent.Builder created(OffsetDateTime created)
When the dispute was created.
-
created
final DisputeTransactionUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final DisputeTransactionUpdatedWebhookEvent.Builder currency(String currency)
Three-letter ISO 4217 currency code.
-
currency
final DisputeTransactionUpdatedWebhookEvent.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disposition
final DisputeTransactionUpdatedWebhookEvent.Builder disposition(DisputeV2.Disposition disposition)
Dispute resolution outcome
-
disposition
final DisputeTransactionUpdatedWebhookEvent.Builder disposition(Optional<DisputeV2.Disposition> disposition)
Alias for calling Builder.disposition with
disposition.orElse(null).
-
disposition
final DisputeTransactionUpdatedWebhookEvent.Builder disposition(JsonField<DisputeV2.Disposition> disposition)
Sets Builder.disposition to an arbitrary JSON value.
You should usually call Builder.disposition with a well-typed DisputeV2.Disposition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final DisputeTransactionUpdatedWebhookEvent.Builder events(List<DisputeV2.Event> events)
Chronological list of events that have occurred in the dispute lifecycle
-
events
final DisputeTransactionUpdatedWebhookEvent.Builder events(JsonField<List<DisputeV2.Event>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<DisputeV2.Event>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final DisputeTransactionUpdatedWebhookEvent.Builder addEvent(DisputeV2.Event event)
Adds a single DisputeV2.Event to events.
-
liabilityAllocation
final DisputeTransactionUpdatedWebhookEvent.Builder liabilityAllocation(DisputeV2.LiabilityAllocation liabilityAllocation)
Current breakdown of how liability is allocated for the disputed amount
-
liabilityAllocation
final DisputeTransactionUpdatedWebhookEvent.Builder liabilityAllocation(JsonField<DisputeV2.LiabilityAllocation> liabilityAllocation)
Sets Builder.liabilityAllocation to an arbitrary JSON value.
You should usually call Builder.liabilityAllocation with a well-typed DisputeV2.LiabilityAllocation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final DisputeTransactionUpdatedWebhookEvent.Builder merchant(Merchant merchant)
-
merchant
final DisputeTransactionUpdatedWebhookEvent.Builder merchant(JsonField<Merchant> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed Merchant value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final DisputeTransactionUpdatedWebhookEvent.Builder network(DisputeV2.Network network)
Card network handling the dispute.
-
network
final DisputeTransactionUpdatedWebhookEvent.Builder network(JsonField<DisputeV2.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed DisputeV2.Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final DisputeTransactionUpdatedWebhookEvent.Builder status(DisputeV2.Status status)
Current status of the dispute.
-
status
final DisputeTransactionUpdatedWebhookEvent.Builder status(Optional<DisputeV2.Status> status)
Alias for calling Builder.status with
status.orElse(null).
-
status
final DisputeTransactionUpdatedWebhookEvent.Builder status(JsonField<DisputeV2.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed DisputeV2.Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionSeries
final DisputeTransactionUpdatedWebhookEvent.Builder transactionSeries(DisputeV2.TransactionSeries transactionSeries)
Contains identifiers for the transaction and specific event within being disputed; null if no transaction can be identified
-
transactionSeries
final DisputeTransactionUpdatedWebhookEvent.Builder transactionSeries(Optional<DisputeV2.TransactionSeries> transactionSeries)
Alias for calling Builder.transactionSeries with
transactionSeries.orElse(null).
-
transactionSeries
final DisputeTransactionUpdatedWebhookEvent.Builder transactionSeries(JsonField<DisputeV2.TransactionSeries> transactionSeries)
Sets Builder.transactionSeries to an arbitrary JSON value.
You should usually call Builder.transactionSeries with a well-typed DisputeV2.TransactionSeries value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final DisputeTransactionUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
When the dispute was last updated.
-
updated
final DisputeTransactionUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DisputeTransactionUpdatedWebhookEvent.Builder eventType(DisputeTransactionUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final DisputeTransactionUpdatedWebhookEvent.Builder eventType(JsonField<DisputeTransactionUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeTransactionUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeTransactionUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeTransactionUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeTransactionUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeTransactionUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeTransactionUpdatedWebhookEvent build()
Returns an immutable instance of DisputeTransactionUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .cardToken() .caseId() .created() .currency() .disposition() .events() .liabilityAllocation() .merchant() .network() .status() .transactionSeries() .updated() .eventType()
-
-
-
-