Class DisputeUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class DisputeUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final DisputeUpdateParams.Body.Builder amount(Long amount)
Amount for chargeback
-
amount
final DisputeUpdateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerFiledDate
final DisputeUpdateParams.Body.Builder customerFiledDate(OffsetDateTime customerFiledDate)
Date the customer filed the chargeback request
-
customerFiledDate
final DisputeUpdateParams.Body.Builder customerFiledDate(JsonField<OffsetDateTime> customerFiledDate)
Sets Builder.customerFiledDate to an arbitrary JSON value.
You should usually call Builder.customerFiledDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerNote
final DisputeUpdateParams.Body.Builder customerNote(String customerNote)
Customer description
-
customerNote
final DisputeUpdateParams.Body.Builder customerNote(JsonField<String> customerNote)
Sets Builder.customerNote to an arbitrary JSON value.
You should usually call Builder.customerNote with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DisputeUpdateParams.Body.Builder reason(DisputeUpdateParams.Reason reason)
Reason for chargeback
-
reason
final DisputeUpdateParams.Body.Builder reason(JsonField<DisputeUpdateParams.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-