Class DisputeUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class DisputeUpdatedWebhookEventDispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeUpdatedWebhookEvent.BuilderA builder for DisputeUpdatedWebhookEvent.
public final classDisputeUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final DisputetoDispute()final Stringtoken()Globally unique identifier. final Longamount()Amount under dispute. final Optional<OffsetDateTime>arbitrationDate()Date dispute entered arbitration. final OffsetDateTimecreated()Timestamp of when first Dispute was reported. final Optional<OffsetDateTime>customerFiledDate()Date that the dispute was filed by the customer making the dispute. final Optional<String>customerNote()End customer description of the reason for the dispute. final Optional<List<String>>networkClaimIds()Unique identifiers for the dispute from the network. final Optional<OffsetDateTime>networkFiledDate()Date that the dispute was submitted to the network. final Optional<String>networkReasonCode()Network reason code used to file the dispute. final Optional<OffsetDateTime>prearbitrationDate()Date dispute entered pre-arbitration. final Optional<String>primaryClaimId()Unique identifier for the dispute from the network. final Dispute.Reasonreason()Dispute reason: ATM_CASH_MISDISPENSE: ATM cash misdispense.CANCELLED: Transaction was cancelled by the customer.DUPLICATED: The transaction was a duplicate.FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.FRAUD_CARD_PRESENT: Fraudulent transaction, card present.FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.INCORRECT_AMOUNT: The transaction amount was incorrect.MISSING_AUTH: The transaction was missing authorization.OTHER: Other reason.PROCESSING_ERROR: Processing error.REFUND_NOT_PROCESSED: The refund was not processed.RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.
final Optional<OffsetDateTime>representmentDate()Date the representment was received. final Optional<OffsetDateTime>resolutionDate()Date that the dispute was resolved. final Optional<String>resolutionNote()Note by Dispute team on the case resolution. final Optional<Dispute.ResolutionReason>resolutionReason()Reason for the dispute resolution: CASE_LOST: This case was lost at final arbitration.NETWORK_REJECTED: Network rejected.NO_DISPUTE_RIGHTS_3DS: No dispute rights, 3DS.NO_DISPUTE_RIGHTS_BELOW_THRESHOLD: No dispute rights, below threshold.NO_DISPUTE_RIGHTS_CONTACTLESS: No dispute rights, contactless.NO_DISPUTE_RIGHTS_HYBRID: No dispute rights, hybrid.NO_DISPUTE_RIGHTS_MAX_CHARGEBACKS: No dispute rights, max chargebacks.NO_DISPUTE_RIGHTS_OTHER: No dispute rights, other.PAST_FILING_DATE: Past filing date.PREARBITRATION_REJECTED: Prearbitration rejected.PROCESSOR_REJECTED_OTHER: Processor rejected, other.REFUNDED: Refunded.REFUNDED_AFTER_CHARGEBACK: Refunded after chargeback.WITHDRAWN: Withdrawn.WON_ARBITRATION: Won arbitration.WON_FIRST_CHARGEBACK: Won first chargeback.WON_PREARBITRATION: Won prearbitration.
final Dispute.Statusstatus()Status types: NEW- New dispute case is opened.PENDING_CUSTOMER- Lithic is waiting for customer to provide more information.SUBMITTED- Dispute is submitted to the card network.REPRESENTMENT- Case has entered second presentment.PREARBITRATION- Case has entered prearbitration.ARBITRATION- Case has entered arbitration.CASE_WON- Case was won and credit will be issued.CASE_CLOSED- Case was lost or withdrawn.
final StringtransactionToken()The transaction that is being disputed. final DisputeUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_arbitrationDate()Returns the raw JSON value of arbitrationDate. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<OffsetDateTime>_customerFiledDate()Returns the raw JSON value of customerFiledDate. final JsonField<String>_customerNote()Returns the raw JSON value of customerNote. final JsonField<List<String>>_networkClaimIds()Returns the raw JSON value of networkClaimIds. final JsonField<OffsetDateTime>_networkFiledDate()Returns the raw JSON value of networkFiledDate. final JsonField<String>_networkReasonCode()Returns the raw JSON value of networkReasonCode. final JsonField<OffsetDateTime>_prearbitrationDate()Returns the raw JSON value of prearbitrationDate. final JsonField<String>_primaryClaimId()Returns the raw JSON value of primaryClaimId. final JsonField<Dispute.Reason>_reason()Returns the raw JSON value of reason. final JsonField<OffsetDateTime>_representmentDate()Returns the raw JSON value of representmentDate. final JsonField<OffsetDateTime>_resolutionDate()Returns the raw JSON value of resolutionDate. final JsonField<String>_resolutionNote()Returns the raw JSON value of resolutionNote. final JsonField<Dispute.ResolutionReason>_resolutionReason()Returns the raw JSON value of resolutionReason. final JsonField<Dispute.Status>_status()Returns the raw JSON value of status. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final JsonField<DisputeUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final DisputeUpdatedWebhookEvent.BuildertoBuilder()final DisputeUpdatedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeUpdatedWebhookEvent. -
-
Method Detail
-
amount
final Long amount()
Amount under dispute. May be different from the original transaction amount.
-
arbitrationDate
final Optional<OffsetDateTime> arbitrationDate()
Date dispute entered arbitration.
-
created
final OffsetDateTime created()
Timestamp of when first Dispute was reported.
-
customerFiledDate
final Optional<OffsetDateTime> customerFiledDate()
Date that the dispute was filed by the customer making the dispute.
-
customerNote
final Optional<String> customerNote()
End customer description of the reason for the dispute.
-
networkClaimIds
final Optional<List<String>> networkClaimIds()
Unique identifiers for the dispute from the network.
-
networkFiledDate
final Optional<OffsetDateTime> networkFiledDate()
Date that the dispute was submitted to the network.
-
networkReasonCode
final Optional<String> networkReasonCode()
Network reason code used to file the dispute.
-
prearbitrationDate
final Optional<OffsetDateTime> prearbitrationDate()
Date dispute entered pre-arbitration.
-
primaryClaimId
final Optional<String> primaryClaimId()
Unique identifier for the dispute from the network. If there are multiple, this will be the first claim id set by the network
-
reason
final Dispute.Reason reason()
Dispute reason:
ATM_CASH_MISDISPENSE: ATM cash misdispense.CANCELLED: Transaction was cancelled by the customer.DUPLICATED: The transaction was a duplicate.FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.FRAUD_CARD_PRESENT: Fraudulent transaction, card present.FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.INCORRECT_AMOUNT: The transaction amount was incorrect.MISSING_AUTH: The transaction was missing authorization.OTHER: Other reason.PROCESSING_ERROR: Processing error.REFUND_NOT_PROCESSED: The refund was not processed.RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.
-
representmentDate
final Optional<OffsetDateTime> representmentDate()
Date the representment was received.
-
resolutionDate
final Optional<OffsetDateTime> resolutionDate()
Date that the dispute was resolved.
-
resolutionNote
final Optional<String> resolutionNote()
Note by Dispute team on the case resolution.
-
resolutionReason
final Optional<Dispute.ResolutionReason> resolutionReason()
Reason for the dispute resolution:
CASE_LOST: This case was lost at final arbitration.NETWORK_REJECTED: Network rejected.NO_DISPUTE_RIGHTS_3DS: No dispute rights, 3DS.NO_DISPUTE_RIGHTS_BELOW_THRESHOLD: No dispute rights, below threshold.NO_DISPUTE_RIGHTS_CONTACTLESS: No dispute rights, contactless.NO_DISPUTE_RIGHTS_HYBRID: No dispute rights, hybrid.NO_DISPUTE_RIGHTS_MAX_CHARGEBACKS: No dispute rights, max chargebacks.NO_DISPUTE_RIGHTS_OTHER: No dispute rights, other.PAST_FILING_DATE: Past filing date.PREARBITRATION_REJECTED: Prearbitration rejected.PROCESSOR_REJECTED_OTHER: Processor rejected, other.REFUNDED: Refunded.REFUNDED_AFTER_CHARGEBACK: Refunded after chargeback.WITHDRAWN: Withdrawn.WON_ARBITRATION: Won arbitration.WON_FIRST_CHARGEBACK: Won first chargeback.WON_PREARBITRATION: Won prearbitration.
-
status
final Dispute.Status status()
Status types:
NEW- New dispute case is opened.PENDING_CUSTOMER- Lithic is waiting for customer to provide more information.SUBMITTED- Dispute is submitted to the card network.REPRESENTMENT- Case has entered second presentment.PREARBITRATION- Case has entered prearbitration.ARBITRATION- Case has entered arbitration.CASE_WON- Case was won and credit will be issued.CASE_CLOSED- Case was lost or withdrawn.
-
transactionToken
final String transactionToken()
The transaction that is being disputed. A transaction can only be disputed once but may have multiple dispute cases.
-
eventType
final DisputeUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_arbitrationDate
final JsonField<OffsetDateTime> _arbitrationDate()
Returns the raw JSON value of arbitrationDate.
Unlike arbitrationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_customerFiledDate
final JsonField<OffsetDateTime> _customerFiledDate()
Returns the raw JSON value of customerFiledDate.
Unlike customerFiledDate, this method doesn't throw if the JSON field has an unexpected type.
-
_customerNote
final JsonField<String> _customerNote()
Returns the raw JSON value of customerNote.
Unlike customerNote, this method doesn't throw if the JSON field has an unexpected type.
-
_networkClaimIds
final JsonField<List<String>> _networkClaimIds()
Returns the raw JSON value of networkClaimIds.
Unlike networkClaimIds, this method doesn't throw if the JSON field has an unexpected type.
-
_networkFiledDate
final JsonField<OffsetDateTime> _networkFiledDate()
Returns the raw JSON value of networkFiledDate.
Unlike networkFiledDate, this method doesn't throw if the JSON field has an unexpected type.
-
_networkReasonCode
final JsonField<String> _networkReasonCode()
Returns the raw JSON value of networkReasonCode.
Unlike networkReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_prearbitrationDate
final JsonField<OffsetDateTime> _prearbitrationDate()
Returns the raw JSON value of prearbitrationDate.
Unlike prearbitrationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryClaimId
final JsonField<String> _primaryClaimId()
Returns the raw JSON value of primaryClaimId.
Unlike primaryClaimId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<Dispute.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_representmentDate
final JsonField<OffsetDateTime> _representmentDate()
Returns the raw JSON value of representmentDate.
Unlike representmentDate, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionDate
final JsonField<OffsetDateTime> _resolutionDate()
Returns the raw JSON value of resolutionDate.
Unlike resolutionDate, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionNote
final JsonField<String> _resolutionNote()
Returns the raw JSON value of resolutionNote.
Unlike resolutionNote, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionReason
final JsonField<Dispute.ResolutionReason> _resolutionReason()
Returns the raw JSON value of resolutionReason.
Unlike resolutionReason, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Dispute.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<DisputeUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeUpdatedWebhookEvent.Builder toBuilder()
-
validate
final DisputeUpdatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of DisputeUpdatedWebhookEvent.
The following fields are required:
.token() .amount() .arbitrationDate() .created() .customerFiledDate() .customerNote() .networkClaimIds() .networkFiledDate() .networkReasonCode() .prearbitrationDate() .primaryClaimId() .reason() .representmentDate() .resolutionDate() .resolutionNote() .resolutionReason() .status() .transactionToken() .eventType()
-
-
-