Class DisputeUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class DisputeUpdatedWebhookEvent.BuilderA builder for DisputeUpdatedWebhookEvent.
-
-
Method Summary
Modifier and Type Method Description final DisputeUpdatedWebhookEvent.Buildertoken(String token)Globally unique identifier. final DisputeUpdatedWebhookEvent.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.Builderamount(Long amount)Amount under dispute. final DisputeUpdatedWebhookEvent.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderarbitrationDate(OffsetDateTime arbitrationDate)Date dispute entered arbitration. final DisputeUpdatedWebhookEvent.BuilderarbitrationDate(Optional<OffsetDateTime> arbitrationDate)Alias for calling Builder.arbitrationDate with arbitrationDate.orElse(null).final DisputeUpdatedWebhookEvent.BuilderarbitrationDate(JsonField<OffsetDateTime> arbitrationDate)Sets Builder.arbitrationDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.Buildercreated(OffsetDateTime created)Timestamp of when first Dispute was reported. final DisputeUpdatedWebhookEvent.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildercustomerFiledDate(OffsetDateTime customerFiledDate)Date that the dispute was filed by the customer making the dispute. final DisputeUpdatedWebhookEvent.BuildercustomerFiledDate(Optional<OffsetDateTime> customerFiledDate)Alias for calling Builder.customerFiledDate with customerFiledDate.orElse(null).final DisputeUpdatedWebhookEvent.BuildercustomerFiledDate(JsonField<OffsetDateTime> customerFiledDate)Sets Builder.customerFiledDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildercustomerNote(String customerNote)End customer description of the reason for the dispute. final DisputeUpdatedWebhookEvent.BuildercustomerNote(Optional<String> customerNote)Alias for calling Builder.customerNote with customerNote.orElse(null).final DisputeUpdatedWebhookEvent.BuildercustomerNote(JsonField<String> customerNote)Sets Builder.customerNote to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildernetworkClaimIds(List<String> networkClaimIds)Unique identifiers for the dispute from the network. final DisputeUpdatedWebhookEvent.BuildernetworkClaimIds(Optional<List<String>> networkClaimIds)Alias for calling Builder.networkClaimIds with networkClaimIds.orElse(null).final DisputeUpdatedWebhookEvent.BuildernetworkClaimIds(JsonField<List<String>> networkClaimIds)Sets Builder.networkClaimIds to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderaddNetworkClaimId(String networkClaimId)Adds a single String to networkClaimIds. final DisputeUpdatedWebhookEvent.BuildernetworkFiledDate(OffsetDateTime networkFiledDate)Date that the dispute was submitted to the network. final DisputeUpdatedWebhookEvent.BuildernetworkFiledDate(Optional<OffsetDateTime> networkFiledDate)Alias for calling Builder.networkFiledDate with networkFiledDate.orElse(null).final DisputeUpdatedWebhookEvent.BuildernetworkFiledDate(JsonField<OffsetDateTime> networkFiledDate)Sets Builder.networkFiledDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildernetworkReasonCode(String networkReasonCode)Network reason code used to file the dispute. final DisputeUpdatedWebhookEvent.BuildernetworkReasonCode(Optional<String> networkReasonCode)Alias for calling Builder.networkReasonCode with networkReasonCode.orElse(null).final DisputeUpdatedWebhookEvent.BuildernetworkReasonCode(JsonField<String> networkReasonCode)Sets Builder.networkReasonCode to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderprearbitrationDate(OffsetDateTime prearbitrationDate)Date dispute entered pre-arbitration. final DisputeUpdatedWebhookEvent.BuilderprearbitrationDate(Optional<OffsetDateTime> prearbitrationDate)Alias for calling Builder.prearbitrationDate with prearbitrationDate.orElse(null).final DisputeUpdatedWebhookEvent.BuilderprearbitrationDate(JsonField<OffsetDateTime> prearbitrationDate)Sets Builder.prearbitrationDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderprimaryClaimId(String primaryClaimId)Unique identifier for the dispute from the network. final DisputeUpdatedWebhookEvent.BuilderprimaryClaimId(Optional<String> primaryClaimId)Alias for calling Builder.primaryClaimId with primaryClaimId.orElse(null).final DisputeUpdatedWebhookEvent.BuilderprimaryClaimId(JsonField<String> primaryClaimId)Sets Builder.primaryClaimId to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.Builderreason(Dispute.Reason reason)Dispute reason: ATM_CASH_MISDISPENSE: ATM cash misdispense.CANCELLED: Transaction was cancelled by the customer.DUPLICATED: The transaction was a duplicate.FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.FRAUD_CARD_PRESENT: Fraudulent transaction, card present.FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.INCORRECT_AMOUNT: The transaction amount was incorrect.MISSING_AUTH: The transaction was missing authorization.OTHER: Other reason.PROCESSING_ERROR: Processing error.REFUND_NOT_PROCESSED: The refund was not processed.RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.
final DisputeUpdatedWebhookEvent.Builderreason(JsonField<Dispute.Reason> reason)Sets Builder.reason to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderrepresentmentDate(OffsetDateTime representmentDate)Date the representment was received. final DisputeUpdatedWebhookEvent.BuilderrepresentmentDate(Optional<OffsetDateTime> representmentDate)Alias for calling Builder.representmentDate with representmentDate.orElse(null).final DisputeUpdatedWebhookEvent.BuilderrepresentmentDate(JsonField<OffsetDateTime> representmentDate)Sets Builder.representmentDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderresolutionDate(OffsetDateTime resolutionDate)Date that the dispute was resolved. final DisputeUpdatedWebhookEvent.BuilderresolutionDate(Optional<OffsetDateTime> resolutionDate)Alias for calling Builder.resolutionDate with resolutionDate.orElse(null).final DisputeUpdatedWebhookEvent.BuilderresolutionDate(JsonField<OffsetDateTime> resolutionDate)Sets Builder.resolutionDate to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderresolutionNote(String resolutionNote)Note by Dispute team on the case resolution. final DisputeUpdatedWebhookEvent.BuilderresolutionNote(Optional<String> resolutionNote)Alias for calling Builder.resolutionNote with resolutionNote.orElse(null).final DisputeUpdatedWebhookEvent.BuilderresolutionNote(JsonField<String> resolutionNote)Sets Builder.resolutionNote to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderresolutionReason(Dispute.ResolutionReason resolutionReason)Reason for the dispute resolution: CASE_LOST: This case was lost at final arbitration.NETWORK_REJECTED: Network rejected.NO_DISPUTE_RIGHTS_3DS: No dispute rights, 3DS.NO_DISPUTE_RIGHTS_BELOW_THRESHOLD: No dispute rights, below threshold.NO_DISPUTE_RIGHTS_CONTACTLESS: No dispute rights, contactless.NO_DISPUTE_RIGHTS_HYBRID: No dispute rights, hybrid.NO_DISPUTE_RIGHTS_MAX_CHARGEBACKS: No dispute rights, max chargebacks.NO_DISPUTE_RIGHTS_OTHER: No dispute rights, other.PAST_FILING_DATE: Past filing date.PREARBITRATION_REJECTED: Prearbitration rejected.PROCESSOR_REJECTED_OTHER: Processor rejected, other.REFUNDED: Refunded.REFUNDED_AFTER_CHARGEBACK: Refunded after chargeback.WITHDRAWN: Withdrawn.WON_ARBITRATION: Won arbitration.WON_FIRST_CHARGEBACK: Won first chargeback.WON_PREARBITRATION: Won prearbitration.
final DisputeUpdatedWebhookEvent.BuilderresolutionReason(Optional<Dispute.ResolutionReason> resolutionReason)Alias for calling Builder.resolutionReason with resolutionReason.orElse(null).final DisputeUpdatedWebhookEvent.BuilderresolutionReason(JsonField<Dispute.ResolutionReason> resolutionReason)Sets Builder.resolutionReason to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.Builderstatus(Dispute.Status status)Status types: NEW- New dispute case is opened.PENDING_CUSTOMER- Lithic is waiting for customer to provide more information.SUBMITTED- Dispute is submitted to the card network.REPRESENTMENT- Case has entered second presentment.PREARBITRATION- Case has entered prearbitration.ARBITRATION- Case has entered arbitration.CASE_WON- Case was won and credit will be issued.CASE_CLOSED- Case was lost or withdrawn.
final DisputeUpdatedWebhookEvent.Builderstatus(JsonField<Dispute.Status> status)Sets Builder.status to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildertransactionToken(String transactionToken)The transaction that is being disputed. final DisputeUpdatedWebhookEvent.BuildertransactionToken(JsonField<String> transactionToken)Sets Builder.transactionToken to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuildereventType(DisputeUpdatedWebhookEvent.EventType eventType)The type of event that occurred. final DisputeUpdatedWebhookEvent.BuildereventType(JsonField<DisputeUpdatedWebhookEvent.EventType> eventType)Sets Builder.eventType to an arbitrary JSON value. final DisputeUpdatedWebhookEvent.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final DisputeUpdatedWebhookEvent.BuilderputAdditionalProperty(String key, JsonValue value)final DisputeUpdatedWebhookEvent.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final DisputeUpdatedWebhookEvent.BuilderremoveAdditionalProperty(String key)final DisputeUpdatedWebhookEvent.BuilderremoveAllAdditionalProperties(Set<String> keys)final DisputeUpdatedWebhookEventbuild()Returns an immutable instance of DisputeUpdatedWebhookEvent. -
-
Method Detail
-
token
final DisputeUpdatedWebhookEvent.Builder token(String token)
Globally unique identifier.
-
token
final DisputeUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final DisputeUpdatedWebhookEvent.Builder amount(Long amount)
Amount under dispute. May be different from the original transaction amount.
-
amount
final DisputeUpdatedWebhookEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
arbitrationDate
final DisputeUpdatedWebhookEvent.Builder arbitrationDate(OffsetDateTime arbitrationDate)
Date dispute entered arbitration.
-
arbitrationDate
final DisputeUpdatedWebhookEvent.Builder arbitrationDate(Optional<OffsetDateTime> arbitrationDate)
Alias for calling Builder.arbitrationDate with
arbitrationDate.orElse(null).
-
arbitrationDate
final DisputeUpdatedWebhookEvent.Builder arbitrationDate(JsonField<OffsetDateTime> arbitrationDate)
Sets Builder.arbitrationDate to an arbitrary JSON value.
You should usually call Builder.arbitrationDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final DisputeUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Timestamp of when first Dispute was reported.
-
created
final DisputeUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerFiledDate
final DisputeUpdatedWebhookEvent.Builder customerFiledDate(OffsetDateTime customerFiledDate)
Date that the dispute was filed by the customer making the dispute.
-
customerFiledDate
final DisputeUpdatedWebhookEvent.Builder customerFiledDate(Optional<OffsetDateTime> customerFiledDate)
Alias for calling Builder.customerFiledDate with
customerFiledDate.orElse(null).
-
customerFiledDate
final DisputeUpdatedWebhookEvent.Builder customerFiledDate(JsonField<OffsetDateTime> customerFiledDate)
Sets Builder.customerFiledDate to an arbitrary JSON value.
You should usually call Builder.customerFiledDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerNote
final DisputeUpdatedWebhookEvent.Builder customerNote(String customerNote)
End customer description of the reason for the dispute.
-
customerNote
final DisputeUpdatedWebhookEvent.Builder customerNote(Optional<String> customerNote)
Alias for calling Builder.customerNote with
customerNote.orElse(null).
-
customerNote
final DisputeUpdatedWebhookEvent.Builder customerNote(JsonField<String> customerNote)
Sets Builder.customerNote to an arbitrary JSON value.
You should usually call Builder.customerNote with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkClaimIds
final DisputeUpdatedWebhookEvent.Builder networkClaimIds(List<String> networkClaimIds)
Unique identifiers for the dispute from the network.
-
networkClaimIds
final DisputeUpdatedWebhookEvent.Builder networkClaimIds(Optional<List<String>> networkClaimIds)
Alias for calling Builder.networkClaimIds with
networkClaimIds.orElse(null).
-
networkClaimIds
final DisputeUpdatedWebhookEvent.Builder networkClaimIds(JsonField<List<String>> networkClaimIds)
Sets Builder.networkClaimIds to an arbitrary JSON value.
You should usually call Builder.networkClaimIds with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addNetworkClaimId
final DisputeUpdatedWebhookEvent.Builder addNetworkClaimId(String networkClaimId)
Adds a single String to networkClaimIds.
-
networkFiledDate
final DisputeUpdatedWebhookEvent.Builder networkFiledDate(OffsetDateTime networkFiledDate)
Date that the dispute was submitted to the network.
-
networkFiledDate
final DisputeUpdatedWebhookEvent.Builder networkFiledDate(Optional<OffsetDateTime> networkFiledDate)
Alias for calling Builder.networkFiledDate with
networkFiledDate.orElse(null).
-
networkFiledDate
final DisputeUpdatedWebhookEvent.Builder networkFiledDate(JsonField<OffsetDateTime> networkFiledDate)
Sets Builder.networkFiledDate to an arbitrary JSON value.
You should usually call Builder.networkFiledDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkReasonCode
final DisputeUpdatedWebhookEvent.Builder networkReasonCode(String networkReasonCode)
Network reason code used to file the dispute.
-
networkReasonCode
final DisputeUpdatedWebhookEvent.Builder networkReasonCode(Optional<String> networkReasonCode)
Alias for calling Builder.networkReasonCode with
networkReasonCode.orElse(null).
-
networkReasonCode
final DisputeUpdatedWebhookEvent.Builder networkReasonCode(JsonField<String> networkReasonCode)
Sets Builder.networkReasonCode to an arbitrary JSON value.
You should usually call Builder.networkReasonCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prearbitrationDate
final DisputeUpdatedWebhookEvent.Builder prearbitrationDate(OffsetDateTime prearbitrationDate)
Date dispute entered pre-arbitration.
-
prearbitrationDate
final DisputeUpdatedWebhookEvent.Builder prearbitrationDate(Optional<OffsetDateTime> prearbitrationDate)
Alias for calling Builder.prearbitrationDate with
prearbitrationDate.orElse(null).
-
prearbitrationDate
final DisputeUpdatedWebhookEvent.Builder prearbitrationDate(JsonField<OffsetDateTime> prearbitrationDate)
Sets Builder.prearbitrationDate to an arbitrary JSON value.
You should usually call Builder.prearbitrationDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryClaimId
final DisputeUpdatedWebhookEvent.Builder primaryClaimId(String primaryClaimId)
Unique identifier for the dispute from the network. If there are multiple, this will be the first claim id set by the network
-
primaryClaimId
final DisputeUpdatedWebhookEvent.Builder primaryClaimId(Optional<String> primaryClaimId)
Alias for calling Builder.primaryClaimId with
primaryClaimId.orElse(null).
-
primaryClaimId
final DisputeUpdatedWebhookEvent.Builder primaryClaimId(JsonField<String> primaryClaimId)
Sets Builder.primaryClaimId to an arbitrary JSON value.
You should usually call Builder.primaryClaimId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DisputeUpdatedWebhookEvent.Builder reason(Dispute.Reason reason)
Dispute reason:
ATM_CASH_MISDISPENSE: ATM cash misdispense.CANCELLED: Transaction was cancelled by the customer.DUPLICATED: The transaction was a duplicate.FRAUD_CARD_NOT_PRESENT: Fraudulent transaction, card not present.FRAUD_CARD_PRESENT: Fraudulent transaction, card present.FRAUD_OTHER: Fraudulent transaction, other types such as questionable merchant activity.GOODS_SERVICES_NOT_AS_DESCRIBED: The goods or services were not as described.GOODS_SERVICES_NOT_RECEIVED: The goods or services were not received.INCORRECT_AMOUNT: The transaction amount was incorrect.MISSING_AUTH: The transaction was missing authorization.OTHER: Other reason.PROCESSING_ERROR: Processing error.REFUND_NOT_PROCESSED: The refund was not processed.RECURRING_TRANSACTION_NOT_CANCELLED: The recurring transaction was not cancelled.
-
reason
final DisputeUpdatedWebhookEvent.Builder reason(JsonField<Dispute.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Dispute.Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
representmentDate
final DisputeUpdatedWebhookEvent.Builder representmentDate(OffsetDateTime representmentDate)
Date the representment was received.
-
representmentDate
final DisputeUpdatedWebhookEvent.Builder representmentDate(Optional<OffsetDateTime> representmentDate)
Alias for calling Builder.representmentDate with
representmentDate.orElse(null).
-
representmentDate
final DisputeUpdatedWebhookEvent.Builder representmentDate(JsonField<OffsetDateTime> representmentDate)
Sets Builder.representmentDate to an arbitrary JSON value.
You should usually call Builder.representmentDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolutionDate
final DisputeUpdatedWebhookEvent.Builder resolutionDate(OffsetDateTime resolutionDate)
Date that the dispute was resolved.
-
resolutionDate
final DisputeUpdatedWebhookEvent.Builder resolutionDate(Optional<OffsetDateTime> resolutionDate)
Alias for calling Builder.resolutionDate with
resolutionDate.orElse(null).
-
resolutionDate
final DisputeUpdatedWebhookEvent.Builder resolutionDate(JsonField<OffsetDateTime> resolutionDate)
Sets Builder.resolutionDate to an arbitrary JSON value.
You should usually call Builder.resolutionDate with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolutionNote
final DisputeUpdatedWebhookEvent.Builder resolutionNote(String resolutionNote)
Note by Dispute team on the case resolution.
-
resolutionNote
final DisputeUpdatedWebhookEvent.Builder resolutionNote(Optional<String> resolutionNote)
Alias for calling Builder.resolutionNote with
resolutionNote.orElse(null).
-
resolutionNote
final DisputeUpdatedWebhookEvent.Builder resolutionNote(JsonField<String> resolutionNote)
Sets Builder.resolutionNote to an arbitrary JSON value.
You should usually call Builder.resolutionNote with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolutionReason
final DisputeUpdatedWebhookEvent.Builder resolutionReason(Dispute.ResolutionReason resolutionReason)
Reason for the dispute resolution:
CASE_LOST: This case was lost at final arbitration.NETWORK_REJECTED: Network rejected.NO_DISPUTE_RIGHTS_3DS: No dispute rights, 3DS.NO_DISPUTE_RIGHTS_BELOW_THRESHOLD: No dispute rights, below threshold.NO_DISPUTE_RIGHTS_CONTACTLESS: No dispute rights, contactless.NO_DISPUTE_RIGHTS_HYBRID: No dispute rights, hybrid.NO_DISPUTE_RIGHTS_MAX_CHARGEBACKS: No dispute rights, max chargebacks.NO_DISPUTE_RIGHTS_OTHER: No dispute rights, other.PAST_FILING_DATE: Past filing date.PREARBITRATION_REJECTED: Prearbitration rejected.PROCESSOR_REJECTED_OTHER: Processor rejected, other.REFUNDED: Refunded.REFUNDED_AFTER_CHARGEBACK: Refunded after chargeback.WITHDRAWN: Withdrawn.WON_ARBITRATION: Won arbitration.WON_FIRST_CHARGEBACK: Won first chargeback.WON_PREARBITRATION: Won prearbitration.
-
resolutionReason
final DisputeUpdatedWebhookEvent.Builder resolutionReason(Optional<Dispute.ResolutionReason> resolutionReason)
Alias for calling Builder.resolutionReason with
resolutionReason.orElse(null).
-
resolutionReason
final DisputeUpdatedWebhookEvent.Builder resolutionReason(JsonField<Dispute.ResolutionReason> resolutionReason)
Sets Builder.resolutionReason to an arbitrary JSON value.
You should usually call Builder.resolutionReason with a well-typed Dispute.ResolutionReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final DisputeUpdatedWebhookEvent.Builder status(Dispute.Status status)
Status types:
NEW- New dispute case is opened.PENDING_CUSTOMER- Lithic is waiting for customer to provide more information.SUBMITTED- Dispute is submitted to the card network.REPRESENTMENT- Case has entered second presentment.PREARBITRATION- Case has entered prearbitration.ARBITRATION- Case has entered arbitration.CASE_WON- Case was won and credit will be issued.CASE_CLOSED- Case was lost or withdrawn.
-
status
final DisputeUpdatedWebhookEvent.Builder status(JsonField<Dispute.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Dispute.Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionToken
final DisputeUpdatedWebhookEvent.Builder transactionToken(String transactionToken)
The transaction that is being disputed. A transaction can only be disputed once but may have multiple dispute cases.
-
transactionToken
final DisputeUpdatedWebhookEvent.Builder transactionToken(JsonField<String> transactionToken)
Sets Builder.transactionToken to an arbitrary JSON value.
You should usually call Builder.transactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final DisputeUpdatedWebhookEvent.Builder eventType(DisputeUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final DisputeUpdatedWebhookEvent.Builder eventType(JsonField<DisputeUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeUpdatedWebhookEvent build()
Returns an immutable instance of DisputeUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .amount() .arbitrationDate() .created() .customerFiledDate() .customerNote() .networkClaimIds() .networkFiledDate() .networkReasonCode() .prearbitrationDate() .primaryClaimId() .reason() .representmentDate() .resolutionDate() .resolutionNote() .resolutionReason() .status() .transactionToken() .eventType()
-
-
-