Class DisputeV2.Event.Data.FinancialEventData
-
- All Implemented Interfaces:
public final class DisputeV2.Event.Data.FinancialEventDataDetails specific to financial events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeV2.Event.Data.FinancialEventData.BuilderA builder for FinancialEventData.
public final classDisputeV2.Event.Data.FinancialEventData.PolarityDirection of funds flow
public final classDisputeV2.Event.Data.FinancialEventData.StageStage at which the financial event occurred
public final classDisputeV2.Event.Data.FinancialEventData.TypeEvent type discriminator
-
Method Summary
-
-
Method Detail
-
polarity
final DisputeV2.Event.Data.FinancialEventData.Polarity polarity()
Direction of funds flow
-
stage
final DisputeV2.Event.Data.FinancialEventData.Stage stage()
Stage at which the financial event occurred
-
type
final DisputeV2.Event.Data.FinancialEventData.Type type()
Event type discriminator
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_polarity
final JsonField<DisputeV2.Event.Data.FinancialEventData.Polarity> _polarity()
Returns the raw JSON value of polarity.
Unlike polarity, this method doesn't throw if the JSON field has an unexpected type.
-
_stage
final JsonField<DisputeV2.Event.Data.FinancialEventData.Stage> _stage()
Returns the raw JSON value of stage.
Unlike stage, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DisputeV2.Event.Data.FinancialEventData.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeV2.Event.Data.FinancialEventData.Builder toBuilder()
-
validate
final DisputeV2.Event.Data.FinancialEventData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeV2.Event.Data.FinancialEventData.Builder builder()
Returns a mutable builder for constructing an instance of FinancialEventData.
The following fields are required:
.amount() .polarity() .stage() .type()
-
-
-
-