Class DisputeV2.Event.Data.WorkflowEventData.Builder
-
- All Implemented Interfaces:
public final class DisputeV2.Event.Data.WorkflowEventData.BuilderA builder for WorkflowEventData.
-
-
Method Summary
-
-
Method Detail
-
action
final DisputeV2.Event.Data.WorkflowEventData.Builder action(DisputeV2.Event.Data.WorkflowEventData.Action action)
Action taken in this stage
-
action
final DisputeV2.Event.Data.WorkflowEventData.Builder action(JsonField<DisputeV2.Event.Data.WorkflowEventData.Action> action)
Sets Builder.action to an arbitrary JSON value.
You should usually call Builder.action with a well-typed Action value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final DisputeV2.Event.Data.WorkflowEventData.Builder amount(Long amount)
Amount in minor units
-
amount
final DisputeV2.Event.Data.WorkflowEventData.Builder amount(Long amount)
Alias for Builder.amount.
This unboxed primitive overload exists for backwards compatibility.
-
amount
final DisputeV2.Event.Data.WorkflowEventData.Builder amount(Optional<Long> amount)
Alias for calling Builder.amount with
amount.orElse(null).
-
amount
final DisputeV2.Event.Data.WorkflowEventData.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
disposition
final DisputeV2.Event.Data.WorkflowEventData.Builder disposition(DisputeV2.Event.Data.WorkflowEventData.Disposition disposition)
Dispute resolution outcome
-
disposition
final DisputeV2.Event.Data.WorkflowEventData.Builder disposition(Optional<DisputeV2.Event.Data.WorkflowEventData.Disposition> disposition)
Alias for calling Builder.disposition with
disposition.orElse(null).
-
disposition
final DisputeV2.Event.Data.WorkflowEventData.Builder disposition(JsonField<DisputeV2.Event.Data.WorkflowEventData.Disposition> disposition)
Sets Builder.disposition to an arbitrary JSON value.
You should usually call Builder.disposition with a well-typed Disposition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DisputeV2.Event.Data.WorkflowEventData.Builder reason(String reason)
Reason for the action
-
reason
final DisputeV2.Event.Data.WorkflowEventData.Builder reason(Optional<String> reason)
Alias for calling Builder.reason with
reason.orElse(null).
-
reason
final DisputeV2.Event.Data.WorkflowEventData.Builder reason(JsonField<String> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stage
final DisputeV2.Event.Data.WorkflowEventData.Builder stage(DisputeV2.Event.Data.WorkflowEventData.Stage stage)
Current stage of the dispute workflow
-
stage
final DisputeV2.Event.Data.WorkflowEventData.Builder stage(JsonField<DisputeV2.Event.Data.WorkflowEventData.Stage> stage)
Sets Builder.stage to an arbitrary JSON value.
You should usually call Builder.stage with a well-typed Stage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DisputeV2.Event.Data.WorkflowEventData.Builder type(DisputeV2.Event.Data.WorkflowEventData.Type type)
Event type discriminator
-
type
final DisputeV2.Event.Data.WorkflowEventData.Builder type(JsonField<DisputeV2.Event.Data.WorkflowEventData.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeV2.Event.Data.WorkflowEventData.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeV2.Event.Data.WorkflowEventData.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeV2.Event.Data.WorkflowEventData.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeV2.Event.Data.WorkflowEventData.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeV2.Event.Data.WorkflowEventData.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeV2.Event.Data.WorkflowEventData build()
Returns an immutable instance of WorkflowEventData.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.action() .amount() .disposition() .reason() .stage() .type()
-
-
-
-