Package com.lithic.api.models
Enum DisputeV2.Event.Data.WorkflowEventData.Disposition.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DisputeV2.Event.Data.WorkflowEventData.Disposition.Known extends Enum<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known>
An enum containing Disposition's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description WONLOSTPARTIALLY_WONWITHDRAWNDENIED
-
Method Summary
Modifier and Type Method Description final DisputeV2.Event.Data.WorkflowEventData.Disposition.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known>getEntries()An enum containing Disposition's known values. -
-
Method Detail
-
valueOf
final DisputeV2.Event.Data.WorkflowEventData.Disposition.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DisputeV2.Event.Data.WorkflowEventData.Disposition.Known> getEntries()
An enum containing Disposition's known values.
-
-
-
-