Class DisputeV2.LiabilityAllocation.Builder
-
- All Implemented Interfaces:
public final class DisputeV2.LiabilityAllocation.BuilderA builder for LiabilityAllocation.
-
-
Method Summary
-
-
Method Detail
-
deniedAmount
final DisputeV2.LiabilityAllocation.Builder deniedAmount(Long deniedAmount)
The amount that has been denied to the cardholder
-
deniedAmount
final DisputeV2.LiabilityAllocation.Builder deniedAmount(JsonField<Long> deniedAmount)
Sets Builder.deniedAmount to an arbitrary JSON value.
You should usually call Builder.deniedAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originalAmount
final DisputeV2.LiabilityAllocation.Builder originalAmount(Long originalAmount)
The initial amount disputed
-
originalAmount
final DisputeV2.LiabilityAllocation.Builder originalAmount(JsonField<Long> originalAmount)
Sets Builder.originalAmount to an arbitrary JSON value.
You should usually call Builder.originalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recoveredAmount
final DisputeV2.LiabilityAllocation.Builder recoveredAmount(Long recoveredAmount)
The amount that has been recovered from the merchant through the dispute process
-
recoveredAmount
final DisputeV2.LiabilityAllocation.Builder recoveredAmount(JsonField<Long> recoveredAmount)
Sets Builder.recoveredAmount to an arbitrary JSON value.
You should usually call Builder.recoveredAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remainingAmount
final DisputeV2.LiabilityAllocation.Builder remainingAmount(Long remainingAmount)
Any disputed amount that is still outstanding, i.e. has not been recovered, written off, or denied
-
remainingAmount
final DisputeV2.LiabilityAllocation.Builder remainingAmount(JsonField<Long> remainingAmount)
Sets Builder.remainingAmount to an arbitrary JSON value.
You should usually call Builder.remainingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
writtenOffAmount
final DisputeV2.LiabilityAllocation.Builder writtenOffAmount(Long writtenOffAmount)
The amount the issuer has chosen to write off
-
writtenOffAmount
final DisputeV2.LiabilityAllocation.Builder writtenOffAmount(JsonField<Long> writtenOffAmount)
Sets Builder.writtenOffAmount to an arbitrary JSON value.
You should usually call Builder.writtenOffAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DisputeV2.LiabilityAllocation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DisputeV2.LiabilityAllocation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DisputeV2.LiabilityAllocation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DisputeV2.LiabilityAllocation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DisputeV2.LiabilityAllocation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DisputeV2.LiabilityAllocation build()
Returns an immutable instance of LiabilityAllocation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.deniedAmount() .originalAmount() .recoveredAmount() .remainingAmount() .writtenOffAmount()
-
-
-
-