Class DisputeV2.TransactionSeries
-
- All Implemented Interfaces:
public final class DisputeV2.TransactionSeriesContains identifiers for the transaction and specific event within being disputed; null if no transaction can be identified
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeV2.TransactionSeries.BuilderA builder for TransactionSeries.
public final classDisputeV2.TransactionSeries.TypeThe type of transaction series associating the dispute and the original transaction. Always set to DISPUTE
-
Method Summary
Modifier and Type Method Description final Optional<String>relatedTransactionEventToken()Token of the specific event in the original transaction being disputed, in UUID format; null if no event can be identified final StringrelatedTransactionToken()Token of the original transaction being disputed, in UUID format final DisputeV2.TransactionSeries.Typetype()The type of transaction series associating the dispute and the original transaction. final JsonField<String>_relatedTransactionEventToken()Returns the raw JSON value of relatedTransactionEventToken. final JsonField<String>_relatedTransactionToken()Returns the raw JSON value of relatedTransactionToken. final JsonField<DisputeV2.TransactionSeries.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DisputeV2.TransactionSeries.BuildertoBuilder()final DisputeV2.TransactionSeriesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeV2.TransactionSeries.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSeries. -
-
Method Detail
-
relatedTransactionEventToken
final Optional<String> relatedTransactionEventToken()
Token of the specific event in the original transaction being disputed, in UUID format; null if no event can be identified
-
relatedTransactionToken
final String relatedTransactionToken()
Token of the original transaction being disputed, in UUID format
-
type
final DisputeV2.TransactionSeries.Type type()
The type of transaction series associating the dispute and the original transaction. Always set to DISPUTE
-
_relatedTransactionEventToken
final JsonField<String> _relatedTransactionEventToken()
Returns the raw JSON value of relatedTransactionEventToken.
Unlike relatedTransactionEventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_relatedTransactionToken
final JsonField<String> _relatedTransactionToken()
Returns the raw JSON value of relatedTransactionToken.
Unlike relatedTransactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DisputeV2.TransactionSeries.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeV2.TransactionSeries.Builder toBuilder()
-
validate
final DisputeV2.TransactionSeries validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DisputeV2.TransactionSeries.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSeries.
The following fields are required:
.relatedTransactionEventToken() .relatedTransactionToken() .type()
-
-
-
-