Class Document.Builder
-
- All Implemented Interfaces:
public final class Document.BuilderA builder for Document.
-
-
Method Summary
-
-
Method Detail
-
token
final Document.Builder token(String token)
Globally unique identifier for the document.
-
token
final Document.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final Document.Builder accountHolderToken(String accountHolderToken)
Globally unique identifier for the account holder.
-
accountHolderToken
final Document.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
documentType
final Document.Builder documentType(Document.DocumentType documentType)
Type of documentation to be submitted for verification of an account holder
-
documentType
final Document.Builder documentType(JsonField<Document.DocumentType> documentType)
Sets Builder.documentType to an arbitrary JSON value.
You should usually call Builder.documentType with a well-typed DocumentType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityToken
final Document.Builder entityToken(String entityToken)
Globally unique identifier for an entity.
-
entityToken
final Document.Builder entityToken(JsonField<String> entityToken)
Sets Builder.entityToken to an arbitrary JSON value.
You should usually call Builder.entityToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocumentUploads
final Document.Builder requiredDocumentUploads(List<Document.RequiredDocumentUpload> requiredDocumentUploads)
Represents a single image of the document to upload.
-
requiredDocumentUploads
final Document.Builder requiredDocumentUploads(JsonField<List<Document.RequiredDocumentUpload>> requiredDocumentUploads)
Sets Builder.requiredDocumentUploads to an arbitrary JSON value.
You should usually call Builder.requiredDocumentUploads with a well-typed
List<RequiredDocumentUpload>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocumentUpload
final Document.Builder addRequiredDocumentUpload(Document.RequiredDocumentUpload requiredDocumentUpload)
Adds a single RequiredDocumentUpload to requiredDocumentUploads.
-
additionalProperties
final Document.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Document.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Document.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Document.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Document.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-