Class Document.RequiredDocumentUpload.Builder
-
- All Implemented Interfaces:
public final class Document.RequiredDocumentUpload.BuilderA builder for RequiredDocumentUpload.
-
-
Method Summary
-
-
Method Detail
-
token
final Document.RequiredDocumentUpload.Builder token(String token)
Globally unique identifier for the document upload.
-
token
final Document.RequiredDocumentUpload.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acceptedEntityStatusReasons
final Document.RequiredDocumentUpload.Builder acceptedEntityStatusReasons(List<String> acceptedEntityStatusReasons)
A list of status reasons associated with a KYB account holder that have been satisfied by the document upload
-
acceptedEntityStatusReasons
final Document.RequiredDocumentUpload.Builder acceptedEntityStatusReasons(JsonField<List<String>> acceptedEntityStatusReasons)
Sets Builder.acceptedEntityStatusReasons to an arbitrary JSON value.
You should usually call Builder.acceptedEntityStatusReasons with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAcceptedEntityStatusReason
final Document.RequiredDocumentUpload.Builder addAcceptedEntityStatusReason(String acceptedEntityStatusReason)
Adds a single String to acceptedEntityStatusReasons.
-
created
final Document.RequiredDocumentUpload.Builder created(OffsetDateTime created)
When the document upload was created
-
created
final Document.RequiredDocumentUpload.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
imageType
final Document.RequiredDocumentUpload.Builder imageType(Document.RequiredDocumentUpload.ImageType imageType)
Type of image to upload.
-
imageType
final Document.RequiredDocumentUpload.Builder imageType(JsonField<Document.RequiredDocumentUpload.ImageType> imageType)
Sets Builder.imageType to an arbitrary JSON value.
You should usually call Builder.imageType with a well-typed ImageType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rejectedEntityStatusReasons
final Document.RequiredDocumentUpload.Builder rejectedEntityStatusReasons(List<String> rejectedEntityStatusReasons)
A list of status reasons associated with a KYB account holder that have not been satisfied by the document upload
-
rejectedEntityStatusReasons
final Document.RequiredDocumentUpload.Builder rejectedEntityStatusReasons(JsonField<List<String>> rejectedEntityStatusReasons)
Sets Builder.rejectedEntityStatusReasons to an arbitrary JSON value.
You should usually call Builder.rejectedEntityStatusReasons with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRejectedEntityStatusReason
final Document.RequiredDocumentUpload.Builder addRejectedEntityStatusReason(String rejectedEntityStatusReason)
Adds a single String to rejectedEntityStatusReasons.
-
status
final Document.RequiredDocumentUpload.Builder status(Document.RequiredDocumentUpload.DocumentUploadStatus status)
Status of an account holder's document upload.
-
status
final Document.RequiredDocumentUpload.Builder status(JsonField<Document.RequiredDocumentUpload.DocumentUploadStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed DocumentUploadStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReasons
final Document.RequiredDocumentUpload.Builder statusReasons(List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons> statusReasons)
Reasons for document image upload status.
-
statusReasons
final Document.RequiredDocumentUpload.Builder statusReasons(JsonField<List<Document.RequiredDocumentUpload.DocumentUploadStatusReasons>> statusReasons)
Sets Builder.statusReasons to an arbitrary JSON value.
You should usually call Builder.statusReasons with a well-typed
List<DocumentUploadStatusReasons>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final Document.RequiredDocumentUpload.Builder addStatusReason(Document.RequiredDocumentUpload.DocumentUploadStatusReasons statusReason)
Adds a single DocumentUploadStatusReasons to statusReasons.
-
updated
final Document.RequiredDocumentUpload.Builder updated(OffsetDateTime updated)
When the document upload was last updated
-
updated
final Document.RequiredDocumentUpload.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uploadUrl
final Document.RequiredDocumentUpload.Builder uploadUrl(String uploadUrl)
URL to upload document image to.
Note that the upload URLs expire after 7 days. If an upload URL expires, you can refresh the URLs by retrieving the document upload from
GET /account_holders/{account_holder_token}/documents.
-
uploadUrl
final Document.RequiredDocumentUpload.Builder uploadUrl(JsonField<String> uploadUrl)
Sets Builder.uploadUrl to an arbitrary JSON value.
You should usually call Builder.uploadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Document.RequiredDocumentUpload.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Document.RequiredDocumentUpload.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Document.RequiredDocumentUpload.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Document.RequiredDocumentUpload.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Document.RequiredDocumentUpload.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Document.RequiredDocumentUpload build()
Returns an immutable instance of RequiredDocumentUpload.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .acceptedEntityStatusReasons() .created() .imageType() .rejectedEntityStatusReasons() .status() .statusReasons() .updated() .uploadUrl()
-
-
-
-