Class EnhancedData.CommonData
-
- All Implemented Interfaces:
public final class EnhancedData.CommonData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.CommonData.BuilderA builder for CommonData.
public final classEnhancedData.CommonData.LineItemAn L2/L3 enhanced commercial data line item.
public final classEnhancedData.CommonData.TaxData
-
Method Summary
-
-
Method Detail
-
lineItems
final List<EnhancedData.CommonData.LineItem> lineItems()
-
tax
final EnhancedData.CommonData.TaxData tax()
-
customerReferenceNumber
final Optional<String> customerReferenceNumber()
A customer identifier.
-
merchantReferenceNumber
final Optional<String> merchantReferenceNumber()
A merchant identifier.
-
_lineItems
final JsonField<List<EnhancedData.CommonData.LineItem>> _lineItems()
Returns the raw JSON value of lineItems.
Unlike lineItems, this method doesn't throw if the JSON field has an unexpected type.
-
_tax
final JsonField<EnhancedData.CommonData.TaxData> _tax()
Returns the raw JSON value of tax.
Unlike tax, this method doesn't throw if the JSON field has an unexpected type.
-
_customerReferenceNumber
final JsonField<String> _customerReferenceNumber()
Returns the raw JSON value of customerReferenceNumber.
Unlike customerReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantReferenceNumber
final JsonField<String> _merchantReferenceNumber()
Returns the raw JSON value of merchantReferenceNumber.
Unlike merchantReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_orderDate
final JsonField<LocalDate> _orderDate()
Returns the raw JSON value of orderDate.
Unlike orderDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.CommonData.Builder toBuilder()
-
validate
final EnhancedData.CommonData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedData.CommonData.Builder builder()
Returns a mutable builder for constructing an instance of CommonData.
The following fields are required:
.lineItems() .tax()
-
-
-
-