Class EnhancedData.CommonData.LineItem
-
- All Implemented Interfaces:
public final class EnhancedData.CommonData.LineItemAn L2/L3 enhanced commercial data line item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.CommonData.LineItem.BuilderA builder for LineItem.
-
Method Summary
Modifier and Type Method Description final Optional<String>amount()The price of the item purchased in merchant currency. final Optional<String>description()A human-readable description of the item. final Optional<String>productCode()An identifier for the item purchased. final Optional<String>quantity()The quantity of the item purchased. final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_productCode()Returns the raw JSON value of productCode. final JsonField<String>_quantity()Returns the raw JSON value of quantity. final Map<String, JsonValue>_additionalProperties()final EnhancedData.CommonData.LineItem.BuildertoBuilder()final EnhancedData.CommonData.LineItemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedData.CommonData.LineItem.Builderbuilder()Returns a mutable builder for constructing an instance of LineItem. -
-
Method Detail
-
description
final Optional<String> description()
A human-readable description of the item.
-
productCode
final Optional<String> productCode()
An identifier for the item purchased.
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_productCode
final JsonField<String> _productCode()
Returns the raw JSON value of productCode.
Unlike productCode, this method doesn't throw if the JSON field has an unexpected type.
-
_quantity
final JsonField<String> _quantity()
Returns the raw JSON value of quantity.
Unlike quantity, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.CommonData.LineItem.Builder toBuilder()
-
validate
final EnhancedData.CommonData.LineItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedData.CommonData.LineItem.Builder builder()
Returns a mutable builder for constructing an instance of LineItem.
-
-
-
-