Class EnhancedData.CommonData.TaxData
-
- All Implemented Interfaces:
public final class EnhancedData.CommonData.TaxData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.CommonData.TaxData.BuilderA builder for TaxData.
public final classEnhancedData.CommonData.TaxData.TaxExemptIndicatorA flag indicating whether the transaction is tax exempt or not.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The amount of tax collected. final Optional<EnhancedData.CommonData.TaxData.TaxExemptIndicator>exempt()A flag indicating whether the transaction is tax exempt or not. final Optional<String>merchantTaxId()The tax ID of the merchant. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<EnhancedData.CommonData.TaxData.TaxExemptIndicator>_exempt()Returns the raw JSON value of exempt. final JsonField<String>_merchantTaxId()Returns the raw JSON value of merchantTaxId. final Map<String, JsonValue>_additionalProperties()final EnhancedData.CommonData.TaxData.BuildertoBuilder()final EnhancedData.CommonData.TaxDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedData.CommonData.TaxData.Builderbuilder()Returns a mutable builder for constructing an instance of TaxData. -
-
Method Detail
-
exempt
final Optional<EnhancedData.CommonData.TaxData.TaxExemptIndicator> exempt()
A flag indicating whether the transaction is tax exempt or not.
-
merchantTaxId
final Optional<String> merchantTaxId()
The tax ID of the merchant.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_exempt
final JsonField<EnhancedData.CommonData.TaxData.TaxExemptIndicator> _exempt()
Returns the raw JSON value of exempt.
Unlike exempt, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantTaxId
final JsonField<String> _merchantTaxId()
Returns the raw JSON value of merchantTaxId.
Unlike merchantTaxId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.CommonData.TaxData.Builder toBuilder()
-
validate
final EnhancedData.CommonData.TaxData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedData.CommonData.TaxData.Builder builder()
Returns a mutable builder for constructing an instance of TaxData.
-
-
-
-