Class EnhancedData.Fleet
-
- All Implemented Interfaces:
public final class EnhancedData.Fleet
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.Fleet.BuilderA builder for Fleet.
public final classEnhancedData.Fleet.AmountTotalspublic final classEnhancedData.Fleet.FuelDatapublic final classEnhancedData.Fleet.ServiceTypeThe type of fuel service.
-
Method Summary
Modifier and Type Method Description final EnhancedData.Fleet.AmountTotalsamountTotals()final EnhancedData.Fleet.FuelDatafuel()final Optional<String>driverNumber()The driver number entered into the terminal at the time of sale, with leading zeros stripped. final Optional<Long>odometer()The odometer reading entered into the terminal at the time of sale. final Optional<EnhancedData.Fleet.ServiceType>serviceType()The type of fuel service. final Optional<String>vehicleNumber()The vehicle number entered into the terminal at the time of sale, with leading zeros stripped. final JsonField<EnhancedData.Fleet.AmountTotals>_amountTotals()Returns the raw JSON value of amountTotals. final JsonField<EnhancedData.Fleet.FuelData>_fuel()Returns the raw JSON value of fuel. final JsonField<String>_driverNumber()Returns the raw JSON value of driverNumber. final JsonField<Long>_odometer()Returns the raw JSON value of odometer. final JsonField<EnhancedData.Fleet.ServiceType>_serviceType()Returns the raw JSON value of serviceType. final JsonField<String>_vehicleNumber()Returns the raw JSON value of vehicleNumber. final Map<String, JsonValue>_additionalProperties()final EnhancedData.Fleet.BuildertoBuilder()final EnhancedData.Fleetvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedData.Fleet.Builderbuilder()Returns a mutable builder for constructing an instance of Fleet. -
-
Method Detail
-
amountTotals
final EnhancedData.Fleet.AmountTotals amountTotals()
-
fuel
final EnhancedData.Fleet.FuelData fuel()
-
driverNumber
final Optional<String> driverNumber()
The driver number entered into the terminal at the time of sale, with leading zeros stripped.
-
odometer
final Optional<Long> odometer()
The odometer reading entered into the terminal at the time of sale.
-
serviceType
final Optional<EnhancedData.Fleet.ServiceType> serviceType()
The type of fuel service.
-
vehicleNumber
final Optional<String> vehicleNumber()
The vehicle number entered into the terminal at the time of sale, with leading zeros stripped.
-
_amountTotals
final JsonField<EnhancedData.Fleet.AmountTotals> _amountTotals()
Returns the raw JSON value of amountTotals.
Unlike amountTotals, this method doesn't throw if the JSON field has an unexpected type.
-
_fuel
final JsonField<EnhancedData.Fleet.FuelData> _fuel()
Returns the raw JSON value of fuel.
Unlike fuel, this method doesn't throw if the JSON field has an unexpected type.
-
_driverNumber
final JsonField<String> _driverNumber()
Returns the raw JSON value of driverNumber.
Unlike driverNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_odometer
final JsonField<Long> _odometer()
Returns the raw JSON value of odometer.
Unlike odometer, this method doesn't throw if the JSON field has an unexpected type.
-
_serviceType
final JsonField<EnhancedData.Fleet.ServiceType> _serviceType()
Returns the raw JSON value of serviceType.
Unlike serviceType, this method doesn't throw if the JSON field has an unexpected type.
-
_vehicleNumber
final JsonField<String> _vehicleNumber()
Returns the raw JSON value of vehicleNumber.
Unlike vehicleNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.Fleet.Builder toBuilder()
-
validate
final EnhancedData.Fleet validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedData.Fleet.Builder builder()
Returns a mutable builder for constructing an instance of Fleet.
The following fields are required:
.amountTotals() .fuel()
-
-
-
-