Class EnhancedData.Fleet.FuelData
-
- All Implemented Interfaces:
public final class EnhancedData.Fleet.FuelData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.Fleet.FuelData.BuilderA builder for FuelData.
public final classEnhancedData.Fleet.FuelData.FuelTypeThe type of fuel purchased.
public final classEnhancedData.Fleet.FuelData.FuelUnitOfMeasureUnit of measure for fuel disbursement.
-
Method Summary
Modifier and Type Method Description final Optional<String>quantity()The quantity of fuel purchased. final Optional<EnhancedData.Fleet.FuelData.FuelType>type()The type of fuel purchased. final Optional<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure>unitOfMeasure()Unit of measure for fuel disbursement. final Optional<Long>unitPrice()The price per unit of fuel. final JsonField<String>_quantity()Returns the raw JSON value of quantity. final JsonField<EnhancedData.Fleet.FuelData.FuelType>_type()Returns the raw JSON value of type. final JsonField<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure>_unitOfMeasure()Returns the raw JSON value of unitOfMeasure. final JsonField<Long>_unitPrice()Returns the raw JSON value of unitPrice. final Map<String, JsonValue>_additionalProperties()final EnhancedData.Fleet.FuelData.BuildertoBuilder()final EnhancedData.Fleet.FuelDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EnhancedData.Fleet.FuelData.Builderbuilder()Returns a mutable builder for constructing an instance of FuelData. -
-
Method Detail
-
type
final Optional<EnhancedData.Fleet.FuelData.FuelType> type()
The type of fuel purchased.
-
unitOfMeasure
final Optional<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> unitOfMeasure()
Unit of measure for fuel disbursement.
-
_quantity
final JsonField<String> _quantity()
Returns the raw JSON value of quantity.
Unlike quantity, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EnhancedData.Fleet.FuelData.FuelType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_unitOfMeasure
final JsonField<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> _unitOfMeasure()
Returns the raw JSON value of unitOfMeasure.
Unlike unitOfMeasure, this method doesn't throw if the JSON field has an unexpected type.
-
_unitPrice
final JsonField<Long> _unitPrice()
Returns the raw JSON value of unitPrice.
Unlike unitPrice, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.Fleet.FuelData.Builder toBuilder()
-
validate
final EnhancedData.Fleet.FuelData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EnhancedData.Fleet.FuelData.Builder builder()
Returns a mutable builder for constructing an instance of FuelData.
-
-
-
-