Class EntityCreateResponse
-
- All Implemented Interfaces:
public final class EntityCreateResponseResponse body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateResponse.BuilderA builder for EntityCreateResponse.
public final classEntityCreateResponse.EntityStatusEntity verification status
public final classEntityCreateResponse.StatusReasonsStatus Reasons for KYC/KYB enrollment states
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the entity final StringaccountHolderToken()Globally unique identifier for the account holder final OffsetDateTimecreated()Timestamp of when the entity was created final List<RequiredDocument>requiredDocuments()A list of documents required for the entity to be approved final EntityCreateResponse.EntityStatusstatus()Entity verification status final List<EntityCreateResponse.StatusReasons>statusReasons()Reason for the evaluation status final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountHolderToken()Returns the raw JSON value of accountHolderToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<List<RequiredDocument>>_requiredDocuments()Returns the raw JSON value of requiredDocuments. final JsonField<EntityCreateResponse.EntityStatus>_status()Returns the raw JSON value of status. final JsonField<List<EntityCreateResponse.StatusReasons>>_statusReasons()Returns the raw JSON value of statusReasons. final Map<String, JsonValue>_additionalProperties()final EntityCreateResponse.BuildertoBuilder()final EntityCreateResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EntityCreateResponse. -
-
Method Detail
-
accountHolderToken
final String accountHolderToken()
Globally unique identifier for the account holder
-
created
final OffsetDateTime created()
Timestamp of when the entity was created
-
requiredDocuments
final List<RequiredDocument> requiredDocuments()
A list of documents required for the entity to be approved
-
status
final EntityCreateResponse.EntityStatus status()
Entity verification status
-
statusReasons
final List<EntityCreateResponse.StatusReasons> statusReasons()
Reason for the evaluation status
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_requiredDocuments
final JsonField<List<RequiredDocument>> _requiredDocuments()
Returns the raw JSON value of requiredDocuments.
Unlike requiredDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EntityCreateResponse.EntityStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<EntityCreateResponse.StatusReasons>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateResponse.Builder toBuilder()
-
validate
final EntityCreateResponse validate()
-
builder
final static EntityCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of EntityCreateResponse.
The following fields are required:
.token() .accountHolderToken() .created() .requiredDocuments() .status() .statusReasons()
-
-
-
-