Class EntityCreateResponse.Builder
-
- All Implemented Interfaces:
public final class EntityCreateResponse.BuilderA builder for EntityCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
token
final EntityCreateResponse.Builder token(String token)
Globally unique identifier for the entity
-
token
final EntityCreateResponse.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolderToken
final EntityCreateResponse.Builder accountHolderToken(String accountHolderToken)
Globally unique identifier for the account holder
-
accountHolderToken
final EntityCreateResponse.Builder accountHolderToken(JsonField<String> accountHolderToken)
Sets Builder.accountHolderToken to an arbitrary JSON value.
You should usually call Builder.accountHolderToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final EntityCreateResponse.Builder created(OffsetDateTime created)
Timestamp of when the entity was created
-
created
final EntityCreateResponse.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requiredDocuments
final EntityCreateResponse.Builder requiredDocuments(List<RequiredDocument> requiredDocuments)
A list of documents required for the entity to be approved
-
requiredDocuments
final EntityCreateResponse.Builder requiredDocuments(JsonField<List<RequiredDocument>> requiredDocuments)
Sets Builder.requiredDocuments to an arbitrary JSON value.
You should usually call Builder.requiredDocuments with a well-typed
List<RequiredDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRequiredDocument
final EntityCreateResponse.Builder addRequiredDocument(RequiredDocument requiredDocument)
Adds a single RequiredDocument to requiredDocuments.
-
status
final EntityCreateResponse.Builder status(EntityCreateResponse.EntityStatus status)
Entity verification status
-
status
final EntityCreateResponse.Builder status(JsonField<EntityCreateResponse.EntityStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed EntityStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusReasons
final EntityCreateResponse.Builder statusReasons(List<EntityCreateResponse.StatusReasons> statusReasons)
Reason for the evaluation status
-
statusReasons
final EntityCreateResponse.Builder statusReasons(JsonField<List<EntityCreateResponse.StatusReasons>> statusReasons)
Sets Builder.statusReasons to an arbitrary JSON value.
You should usually call Builder.statusReasons with a well-typed
List<StatusReasons>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusReason
final EntityCreateResponse.Builder addStatusReason(EntityCreateResponse.StatusReasons statusReason)
Adds a single StatusReasons to statusReasons.
-
additionalProperties
final EntityCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateResponse build()
Returns an immutable instance of EntityCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountHolderToken() .created() .requiredDocuments() .status() .statusReasons()
-
-
-
-