Class EntityCreateResponse.EntityStatus
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class EntityCreateResponse.EntityStatus implements EnumEntity verification status
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumEntityCreateResponse.EntityStatus.KnownAn enum containing EntityStatus's known values.
public enumEntityCreateResponse.EntityStatus.ValueAn enum containing EntityStatus's known values, as well as an _UNKNOWN member.
An instance of EntityStatus can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static EntityCreateResponse.EntityStatusACCEPTEDpublic final static EntityCreateResponse.EntityStatusINACTIVEpublic final static EntityCreateResponse.EntityStatusPENDING_REVIEWpublic final static EntityCreateResponse.EntityStatusREJECTED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final EntityCreateResponse.EntityStatus.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final EntityCreateResponse.EntityStatus.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final EntityCreateResponse.EntityStatusvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateResponse.EntityStatusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final EntityCreateResponse.EntityStatus.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final EntityCreateResponse.EntityStatus.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final EntityCreateResponse.EntityStatus validate()
-
of
final static EntityCreateResponse.EntityStatus of(String value)
-
-
-
-