Package com.lithic.api.models
Class EventSubscriptionListPageResponse
-
- All Implemented Interfaces:
public final class EventSubscriptionListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionListPageResponse.BuilderA builder for EventSubscriptionListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<EventSubscription>data()final BooleanhasMore()final JsonField<List<EventSubscription>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionListPageResponse.BuildertoBuilder()final EventSubscriptionListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionListPageResponse. -
-
Method Detail
-
data
final List<EventSubscription> data()
-
_data
final JsonField<List<EventSubscription>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionListPageResponse.Builder toBuilder()
-
validate
final EventSubscriptionListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventSubscriptionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-