Class EventSubscriptionUpdateParams.Body
-
- All Implemented Interfaces:
public final class EventSubscriptionUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringurl()URL to which event webhooks will be sent. final Optional<String>description()Event subscription description. final Optional<Boolean>disabled()Whether the event subscription is active (false) or inactive (true). final Optional<List<EventSubscriptionUpdateParams.EventType>>eventTypes()Indicates types of events that will be sent to this subscription. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Boolean>_disabled()Returns the raw JSON value of disabled. final JsonField<List<EventSubscriptionUpdateParams.EventType>>_eventTypes()Returns the raw JSON value of eventTypes. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionUpdateParams.Body.BuildertoBuilder()final EventSubscriptionUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
Event subscription description.
-
disabled
final Optional<Boolean> disabled()
Whether the event subscription is active (false) or inactive (true).
-
eventTypes
final Optional<List<EventSubscriptionUpdateParams.EventType>> eventTypes()
Indicates types of events that will be sent to this subscription. If left blank, all types will be sent.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_disabled
final JsonField<Boolean> _disabled()
Returns the raw JSON value of disabled.
Unlike disabled, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTypes
final JsonField<List<EventSubscriptionUpdateParams.EventType>> _eventTypes()
Returns the raw JSON value of eventTypes.
Unlike eventTypes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionUpdateParams.Body.Builder toBuilder()
-
validate
final EventSubscriptionUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventSubscriptionUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.url()
-
-
-
-