Package com.lithic.api.models
Class ExtendedCredit
-
- All Implemented Interfaces:
public final class ExtendedCredit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtendedCredit.BuilderA builder for ExtendedCredit.
-
Method Summary
Modifier and Type Method Description final LongcreditExtended()final JsonField<Long>_creditExtended()Returns the raw JSON value of creditExtended. final Map<String, JsonValue>_additionalProperties()final ExtendedCredit.BuildertoBuilder()final ExtendedCreditvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtendedCredit.Builderbuilder()Returns a mutable builder for constructing an instance of ExtendedCredit. -
-
Method Detail
-
creditExtended
final Long creditExtended()
-
_creditExtended
final JsonField<Long> _creditExtended()
Returns the raw JSON value of creditExtended.
Unlike creditExtended, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtendedCredit.Builder toBuilder()
-
validate
final ExtendedCredit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExtendedCredit.Builder builder()
Returns a mutable builder for constructing an instance of ExtendedCredit.
The following fields are required:
.creditExtended()
-
-
-
-