Class ExternalBankAccountAddress
-
- All Implemented Interfaces:
public final class ExternalBankAccountAddress
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountAddress.BuilderA builder for ExternalBankAccountAddress.
-
Method Summary
Modifier and Type Method Description final Stringaddress1()final Stringcity()final Stringcountry()final StringpostalCode()final Stringstate()final Optional<String>address2()final JsonField<String>_address1()Returns the raw JSON value of address1. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_address2()Returns the raw JSON value of address2. final Map<String, JsonValue>_additionalProperties()final ExternalBankAccountAddress.BuildertoBuilder()final ExternalBankAccountAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountAddress.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountAddress. -
-
Method Detail
-
postalCode
final String postalCode()
-
_address1
final JsonField<String> _address1()
Returns the raw JSON value of address1.
Unlike address1, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_address2
final JsonField<String> _address2()
Returns the raw JSON value of address2.
Unlike address2, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountAddress.Builder toBuilder()
-
validate
final ExternalBankAccountAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalBankAccountAddress.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountAddress.
The following fields are required:
.address1() .city() .country() .postalCode() .state()
-
-
-
-