Package com.lithic.api.models
Class ExternalBankAccountCreateParams.Body
-
- All Implemented Interfaces:
public final class ExternalBankAccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExternalBankAccountCreateParams.Body.VisitorAn interface that defines how to map each variant of Body to a value of type T.
public final classExternalBankAccountCreateParams.Body.BankVerifiedCreateBankAccountApiRequestpublic final classExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequestpublic final classExternalBankAccountCreateParams.Body.UnverifiedCreateBankAccountApiRequest
-
Method Summary
-
-
Method Detail
-
bankVerifiedCreateBankAccountApiRequest
final Optional<ExternalBankAccountCreateParams.Body.BankVerifiedCreateBankAccountApiRequest> bankVerifiedCreateBankAccountApiRequest()
-
externallyVerified
final Optional<ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest> externallyVerified()
-
unverified
final Optional<ExternalBankAccountCreateParams.Body.UnverifiedCreateBankAccountApiRequest> unverified()
-
isBankVerifiedCreateBankAccountApiRequest
final Boolean isBankVerifiedCreateBankAccountApiRequest()
-
isExternallyVerified
final Boolean isExternallyVerified()
-
isUnverified
final Boolean isUnverified()
-
asBankVerifiedCreateBankAccountApiRequest
final ExternalBankAccountCreateParams.Body.BankVerifiedCreateBankAccountApiRequest asBankVerifiedCreateBankAccountApiRequest()
-
asExternallyVerified
final ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest asExternallyVerified()
-
asUnverified
final ExternalBankAccountCreateParams.Body.UnverifiedCreateBankAccountApiRequest asUnverified()
-
accept
final <T extends Any> T accept(ExternalBankAccountCreateParams.Body.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.lithic.api.core.JsonValue; import java.util.Optional; Optional<String> result = body.accept(new Body.Visitor<Optional<String>>() { @Override public Optional<String> visitBankVerifiedCreateBankAccountApiRequest(BankVerifiedCreateBankAccountApiRequest bankVerifiedCreateBankAccountApiRequest) { return Optional.of(bankVerifiedCreateBankAccountApiRequest.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final ExternalBankAccountCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofBankVerifiedCreateBankAccountApiRequest
final static ExternalBankAccountCreateParams.Body ofBankVerifiedCreateBankAccountApiRequest(ExternalBankAccountCreateParams.Body.BankVerifiedCreateBankAccountApiRequest bankVerifiedCreateBankAccountApiRequest)
-
ofExternallyVerified
final static ExternalBankAccountCreateParams.Body ofExternallyVerified(ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest externallyVerified)
-
ofUnverified
final static ExternalBankAccountCreateParams.Body ofUnverified(ExternalBankAccountCreateParams.Body.UnverifiedCreateBankAccountApiRequest unverified)
-
-
-
-