Class ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest
-
- All Implemented Interfaces:
public final class ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.BuilderA builder for ExternallyVerifiedCreateBankAccountApiRequest.
public final classExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.AccountTypeAccount Type
public final classExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.ExternallyVerifiedVerificationMethodVerification Method
-
Method Summary
-
-
Method Detail
-
accountNumber
final String accountNumber()
Account Number
-
country
final String country()
The country that the bank account is located in using ISO 3166-1. We will only accept USA bank accounts e.g., USA
-
currency
final String currency()
currency of the external account 3-character alphabetic ISO 4217 code
-
owner
final String owner()
Legal Name of the business or individual who owns the external account. This will appear in statements
-
routingNumber
final String routingNumber()
Routing Number
-
type
final ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.AccountType type()
Account Type
-
verificationMethod
final ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.ExternallyVerifiedVerificationMethod verificationMethod()
Verification Method
-
accountToken
final Optional<String> accountToken()
Indicates which Lithic account the external account is associated with. For external accounts that are associated with the program, account_token field returned will be null
-
address
final Optional<ExternalBankAccountAddress> address()
Address
-
companyId
final Optional<String> companyId()
Optional field that helps identify bank accounts in receipts
-
dob
final Optional<LocalDate> dob()
Date of Birth of the Individual that owns the external bank account
-
doingBusinessAs
final Optional<String> doingBusinessAs()
Doing Business As
-
userDefinedId
final Optional<String> userDefinedId()
User Defined ID
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_owner
final JsonField<String> _owner()
Returns the raw JSON value of owner.
Unlike owner, this method doesn't throw if the JSON field has an unexpected type.
-
_ownerType
final JsonField<OwnerType> _ownerType()
Returns the raw JSON value of ownerType.
Unlike ownerType, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.AccountType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationMethod
final JsonField<ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.ExternallyVerifiedVerificationMethod> _verificationMethod()
Returns the raw JSON value of verificationMethod.
Unlike verificationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<ExternalBankAccountAddress> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<LocalDate> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_doingBusinessAs
final JsonField<String> _doingBusinessAs()
Returns the raw JSON value of doingBusinessAs.
Unlike doingBusinessAs, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.Builder toBuilder()
-
validate
final ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalBankAccountCreateParams.Body.ExternallyVerifiedCreateBankAccountApiRequest.Builder builder()
Returns a mutable builder for constructing an instance of ExternallyVerifiedCreateBankAccountApiRequest.
The following fields are required:
.accountNumber() .country() .currency() .owner() .ownerType() .routingNumber() .type() .verificationMethod()
-
-
-
-