Class ExternalBankAccountListPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class ExternalBankAccountListPage implements Page<ExternalBankAccountListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountListPage.BuilderA builder for ExternalBankAccountListPage.
-
Method Summary
Modifier and Type Method Description final List<ExternalBankAccountListResponse>data()Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data. List<ExternalBankAccountListResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final ExternalBankAccountListParamsnextPageParams()ExternalBankAccountListPagenextPage()Returns the page after this one by making another request. final AutoPager<ExternalBankAccountListResponse>autoPager()final ExternalBankAccountListParamsparams()The parameters that were used to request this page. final ExternalBankAccountListPageResponseresponse()The response that this page was parsed from. final ExternalBankAccountListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalBankAccountListPage. -
-
Method Detail
-
data
final List<ExternalBankAccountListResponse> data()
Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to ExternalBankAccountListPageResponse, but gracefully handles missing data.
-
items
List<ExternalBankAccountListResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ExternalBankAccountListParams nextPageParams()
-
nextPage
ExternalBankAccountListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<ExternalBankAccountListResponse> autoPager()
-
params
final ExternalBankAccountListParams params()
The parameters that were used to request this page.
-
response
final ExternalBankAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExternalBankAccountListPage.Builder toBuilder()
-
builder
final static ExternalBankAccountListPage.Builder builder()
Returns a mutable builder for constructing an instance of ExternalBankAccountListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-