Package com.lithic.api.models
Class ExternalBankAccountListPage.Builder
-
- All Implemented Interfaces:
public final class ExternalBankAccountListPage.BuilderA builder for ExternalBankAccountListPage.
-
-
Method Summary
Modifier and Type Method Description final ExternalBankAccountListPage.Builderservice(ExternalBankAccountService service)final ExternalBankAccountListPage.Builderparams(ExternalBankAccountListParams params)The parameters that were used to request this page. final ExternalBankAccountListPage.Builderresponse(ExternalBankAccountListPageResponse response)The response that this page was parsed from. final ExternalBankAccountListPagebuild()Returns an immutable instance of ExternalBankAccountListPage. -
-
Method Detail
-
service
final ExternalBankAccountListPage.Builder service(ExternalBankAccountService service)
-
params
final ExternalBankAccountListPage.Builder params(ExternalBankAccountListParams params)
The parameters that were used to request this page.
-
response
final ExternalBankAccountListPage.Builder response(ExternalBankAccountListPageResponse response)
The response that this page was parsed from.
-
build
final ExternalBankAccountListPage build()
Returns an immutable instance of ExternalBankAccountListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-