Package com.lithic.api.models
Class ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest
-
- All Implemented Interfaces:
public final class ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.BuilderA builder for SetVerificationMethodRequest.
-
Method Summary
-
-
Method Detail
-
verificationMethod
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods verificationMethod()
The verification method to set for the external bank account
-
financialAccountToken
final Optional<String> financialAccountToken()
The financial account token of the operating account to fund the micro deposits. Required when verification_method is MICRO_DEPOSIT or PRENOTE.
-
_verificationMethod
final JsonField<ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods> _verificationMethod()
Returns the raw JSON value of verificationMethod.
Unlike verificationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder toBuilder()
-
validate
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest validate()
-
builder
final static ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder builder()
Returns a mutable builder for constructing an instance of SetVerificationMethodRequest.
The following fields are required:
.verificationMethod()
-
-
-
-