Class ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder
-
- All Implemented Interfaces:
public final class ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.BuilderA builder for SetVerificationMethodRequest.
-
-
Method Summary
-
-
Method Detail
-
verificationMethod
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder verificationMethod(ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods verificationMethod)
The verification method to set for the external bank account
-
verificationMethod
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder verificationMethod(JsonField<ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodAllowedVerificationMethods> verificationMethod)
Sets Builder.verificationMethod to an arbitrary JSON value.
You should usually call Builder.verificationMethod with a well-typed SetVerificationMethodAllowedVerificationMethods value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder financialAccountToken(String financialAccountToken)
The financial account token of the operating account to fund the micro deposits. Required when verification_method is MICRO_DEPOSIT or PRENOTE.
-
financialAccountToken
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalBankAccountSetVerificationMethodParams.SetVerificationMethodRequest build()
Returns an immutable instance of SetVerificationMethodRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.verificationMethod()
-
-
-
-