Class ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest
-
- All Implemented Interfaces:
public final class ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalBankAccountUpdateParams.UpdateBankAccountApiRequest.BuilderA builder for UpdateBankAccountApiRequest.
-
Method Summary
Modifier and Type Method Description final Optional<ExternalBankAccountAddress>address()Address final Optional<String>companyId()Optional field that helps identify bank accounts in receipts final Optional<LocalDate>dob()Date of Birth of the Individual that owns the external bank account final Optional<String>doingBusinessAs()Doing Business As final Optional<String>name()The nickname for this External Bank Account final Optional<String>owner()Legal Name of the business or individual who owns the external account. final Optional<OwnerType>ownerType()Owner Type final Optional<ExternalBankAccountUpdateParams.AccountTypeExternal>type()final Optional<String>userDefinedId()User Defined ID final JsonField<ExternalBankAccountAddress>_address()Returns the raw JSON value of address. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<LocalDate>_dob()Returns the raw JSON value of dob. final JsonField<String>_doingBusinessAs()Returns the raw JSON value of doingBusinessAs. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_owner()Returns the raw JSON value of owner. final JsonField<OwnerType>_ownerType()Returns the raw JSON value of ownerType. final JsonField<ExternalBankAccountUpdateParams.AccountTypeExternal>_type()Returns the raw JSON value of type. final JsonField<String>_userDefinedId()Returns the raw JSON value of userDefinedId. final Map<String, JsonValue>_additionalProperties()final ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest.BuildertoBuilder()final ExternalBankAccountUpdateParams.UpdateBankAccountApiRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateBankAccountApiRequest. -
-
Method Detail
-
address
final Optional<ExternalBankAccountAddress> address()
Address
-
companyId
final Optional<String> companyId()
Optional field that helps identify bank accounts in receipts
-
dob
final Optional<LocalDate> dob()
Date of Birth of the Individual that owns the external bank account
-
doingBusinessAs
final Optional<String> doingBusinessAs()
Doing Business As
-
owner
final Optional<String> owner()
Legal Name of the business or individual who owns the external account. This will appear in statements
-
type
final Optional<ExternalBankAccountUpdateParams.AccountTypeExternal> type()
-
userDefinedId
final Optional<String> userDefinedId()
User Defined ID
-
_address
final JsonField<ExternalBankAccountAddress> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<LocalDate> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_doingBusinessAs
final JsonField<String> _doingBusinessAs()
Returns the raw JSON value of doingBusinessAs.
Unlike doingBusinessAs, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_owner
final JsonField<String> _owner()
Returns the raw JSON value of owner.
Unlike owner, this method doesn't throw if the JSON field has an unexpected type.
-
_ownerType
final JsonField<OwnerType> _ownerType()
Returns the raw JSON value of ownerType.
Unlike ownerType, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ExternalBankAccountUpdateParams.AccountTypeExternal> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest.Builder toBuilder()
-
validate
final ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalBankAccountUpdateParams.UpdateBankAccountApiRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateBankAccountApiRequest.
-
-
-
-