Class ExternalPayment.ExternalPaymentEvent
-
- All Implemented Interfaces:
public final class ExternalPayment.ExternalPaymentEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPayment.ExternalPaymentEvent.BuilderA builder for ExternalPaymentEvent.
public final classExternalPayment.ExternalPaymentEvent.DetailedResultspublic final classExternalPayment.ExternalPaymentEvent.TransactionResultpublic final classExternalPayment.ExternalPaymentEvent.ExternalPaymentEventType
-
Method Summary
-
-
Method Detail
-
created
final OffsetDateTime created()
-
detailedResults
final List<ExternalPayment.ExternalPaymentEvent.DetailedResults> detailedResults()
-
effectiveDate
final LocalDate effectiveDate()
-
result
final ExternalPayment.ExternalPaymentEvent.TransactionResult result()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_detailedResults
final JsonField<List<ExternalPayment.ExternalPaymentEvent.DetailedResults>> _detailedResults()
Returns the raw JSON value of detailedResults.
Unlike detailedResults, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<ExternalPayment.ExternalPaymentEvent.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ExternalPayment.ExternalPaymentEvent.ExternalPaymentEventType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalPayment.ExternalPaymentEvent.Builder toBuilder()
-
validate
final ExternalPayment.ExternalPaymentEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalPayment.ExternalPaymentEvent.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentEvent.
The following fields are required:
.token() .amount() .created() .detailedResults() .effectiveDate() .memo() .result() .type()
-
-
-
-