Class ExternalPaymentCreateParams.CreateExternalPaymentRequest
-
- All Implemented Interfaces:
public final class ExternalPaymentCreateParams.CreateExternalPaymentRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentCreateParams.CreateExternalPaymentRequest.BuilderA builder for CreateExternalPaymentRequest.
-
Method Summary
-
-
Method Detail
-
category
final ExternalPaymentCreateParams.ExternalPaymentCategory category()
-
effectiveDate
final LocalDate effectiveDate()
-
financialAccountToken
final String financialAccountToken()
-
paymentType
final ExternalPaymentCreateParams.ExternalPaymentDirection paymentType()
-
token
final Optional<String> token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
progressTo
final Optional<ExternalPaymentCreateParams.ExternalPaymentProgressTo> progressTo()
-
userDefinedId
final Optional<String> userDefinedId()
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<ExternalPaymentCreateParams.ExternalPaymentCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentType
final JsonField<ExternalPaymentCreateParams.ExternalPaymentDirection> _paymentType()
Returns the raw JSON value of paymentType.
Unlike paymentType, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_progressTo
final JsonField<ExternalPaymentCreateParams.ExternalPaymentProgressTo> _progressTo()
Returns the raw JSON value of progressTo.
Unlike progressTo, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalPaymentCreateParams.CreateExternalPaymentRequest.Builder toBuilder()
-
validate
final ExternalPaymentCreateParams.CreateExternalPaymentRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalPaymentCreateParams.CreateExternalPaymentRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateExternalPaymentRequest.
The following fields are required:
.amount() .category() .effectiveDate() .financialAccountToken() .paymentType()
-
-
-
-