Package com.lithic.api.models
Class ExternalPaymentListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ExternalPaymentListPageAsync.BuilderA builder for ExternalPaymentListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ExternalPaymentListPageAsync.Builderservice(ExternalPaymentServiceAsync service)final ExternalPaymentListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ExternalPaymentListPageAsync.Builderparams(ExternalPaymentListParams params)The parameters that were used to request this page. final ExternalPaymentListPageAsync.Builderresponse(ExternalPaymentListPageResponse response)The response that this page was parsed from. final ExternalPaymentListPageAsyncbuild()Returns an immutable instance of ExternalPaymentListPageAsync. -
-
Method Detail
-
service
final ExternalPaymentListPageAsync.Builder service(ExternalPaymentServiceAsync service)
-
streamHandlerExecutor
final ExternalPaymentListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ExternalPaymentListPageAsync.Builder params(ExternalPaymentListParams params)
The parameters that were used to request this page.
-
response
final ExternalPaymentListPageAsync.Builder response(ExternalPaymentListPageResponse response)
The response that this page was parsed from.
-
build
final ExternalPaymentListPageAsync build()
Returns an immutable instance of ExternalPaymentListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-