Package com.lithic.api.models
Class ExternalPaymentListPageResponse
-
- All Implemented Interfaces:
public final class ExternalPaymentListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentListPageResponse.BuilderA builder for ExternalPaymentListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<ExternalPayment>data()final BooleanhasMore()final JsonField<List<ExternalPayment>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final ExternalPaymentListPageResponse.BuildertoBuilder()final ExternalPaymentListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalPaymentListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalPaymentListPageResponse. -
-
Method Detail
-
data
final List<ExternalPayment> data()
-
_data
final JsonField<List<ExternalPayment>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalPaymentListPageResponse.Builder toBuilder()
-
validate
final ExternalPaymentListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExternalPaymentListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-