Class ExternalPaymentListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalPaymentListParams implements Params
List external payments
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentListParams.BuilderA builder for ExternalPaymentListParams.
public final classExternalPaymentListParams.ExternalPaymentCategoryExternal Payment category to be returned.
public final classExternalPaymentListParams.TransactionResultExternal Payment result to be returned.
public final classExternalPaymentListParams.TransactionStatusBook transfer status to be returned.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>begin()Date string in RFC 3339 format. final Optional<String>businessAccountToken()final Optional<ExternalPaymentListParams.ExternalPaymentCategory>category()External Payment category to be returned. final Optional<OffsetDateTime>end()Date string in RFC 3339 format. final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<String>financialAccountToken()Globally unique identifier for the financial account or card that will send the funds. final Optional<Long>pageSize()Page size (for pagination). final Optional<ExternalPaymentListParams.TransactionResult>result()External Payment result to be returned. final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Optional<ExternalPaymentListParams.TransactionStatus>status()Book transfer status to be returned. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExternalPaymentListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalPaymentListParamsnone()final static ExternalPaymentListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalPaymentListParams. -
-
Method Detail
-
begin
final Optional<OffsetDateTime> begin()
Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.
-
businessAccountToken
final Optional<String> businessAccountToken()
-
category
final Optional<ExternalPaymentListParams.ExternalPaymentCategory> category()
External Payment category to be returned.
-
end
final Optional<OffsetDateTime> end()
Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
financialAccountToken
final Optional<String> financialAccountToken()
Globally unique identifier for the financial account or card that will send the funds. Accepted type dependent on the program's use case.
-
result
final Optional<ExternalPaymentListParams.TransactionResult> result()
External Payment result to be returned.
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
status
final Optional<ExternalPaymentListParams.TransactionStatus> status()
Book transfer status to be returned.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalPaymentListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExternalPaymentListParams none()
-
builder
final static ExternalPaymentListParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentListParams.
-
-
-
-