Package com.lithic.api.models
Class ExternalPaymentReverseParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalPaymentReverseParams implements Params
Reverse external payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentReverseParams.BuilderA builder for ExternalPaymentReverseParams.
public final classExternalPaymentReverseParams.ExternalPaymentActionRequest
-
Method Summary
Modifier and Type Method Description final Optional<String>externalPaymentToken()final LocalDateeffectiveDate()final Optional<String>memo()final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_memo()Returns the raw JSON value of memo. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExternalPaymentReverseParams.BuildertoBuilder()final ExternalPaymentReverseParams.ExternalPaymentActionRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalPaymentReverseParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalPaymentReverseParams. -
-
Method Detail
-
externalPaymentToken
final Optional<String> externalPaymentToken()
-
effectiveDate
final LocalDate effectiveDate()
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalPaymentReverseParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExternalPaymentReverseParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentReverseParams.
The following fields are required:
.effectiveDate()
-
-
-
-