Class ExternalPaymentSettleParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ExternalPaymentSettleParams implements Params
Settle external payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalPaymentSettleParams.BuilderA builder for ExternalPaymentSettleParams.
public final classExternalPaymentSettleParams.ExternalPaymentActionWithProgressToRequestpublic final classExternalPaymentSettleParams.ExternalPaymentProgressTo
-
Method Summary
-
-
Method Detail
-
externalPaymentToken
final Optional<String> externalPaymentToken()
-
effectiveDate
final LocalDate effectiveDate()
-
progressTo
final Optional<ExternalPaymentSettleParams.ExternalPaymentProgressTo> progressTo()
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_progressTo
final JsonField<ExternalPaymentSettleParams.ExternalPaymentProgressTo> _progressTo()
Returns the raw JSON value of progressTo.
Unlike progressTo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalPaymentSettleParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExternalPaymentSettleParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalPaymentSettleParams.
The following fields are required:
.effectiveDate()
-
-
-
-