Class ExternalPaymentUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class ExternalPaymentUpdatedWebhookEvent.BuilderA builder for ExternalPaymentUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final ExternalPaymentUpdatedWebhookEvent.Builder token(String token)
Unique identifier for the transaction
-
token
final ExternalPaymentUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final ExternalPaymentUpdatedWebhookEvent.Builder created(OffsetDateTime created)
ISO 8601 timestamp of when the transaction was created
-
created
final ExternalPaymentUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ExternalPaymentUpdatedWebhookEvent.Builder status(ExternalPayment.TransactionStatus status)
The status of the transaction
-
status
final ExternalPaymentUpdatedWebhookEvent.Builder status(JsonField<ExternalPayment.TransactionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed ExternalPayment.TransactionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final ExternalPaymentUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
ISO 8601 timestamp of when the transaction was last updated
-
updated
final ExternalPaymentUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final ExternalPaymentUpdatedWebhookEvent.Builder category(ExternalPayment.ExternalPaymentCategory category)
-
category
final ExternalPaymentUpdatedWebhookEvent.Builder category(JsonField<ExternalPayment.ExternalPaymentCategory> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed ExternalPayment.ExternalPaymentCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final ExternalPaymentUpdatedWebhookEvent.Builder currency(String currency)
-
currency
final ExternalPaymentUpdatedWebhookEvent.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final ExternalPaymentUpdatedWebhookEvent.Builder events(List<ExternalPayment.ExternalPaymentEvent> events)
-
events
final ExternalPaymentUpdatedWebhookEvent.Builder events(JsonField<List<ExternalPayment.ExternalPaymentEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<ExternalPayment.ExternalPaymentEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final ExternalPaymentUpdatedWebhookEvent.Builder addEvent(ExternalPayment.ExternalPaymentEvent event)
Adds a single ExternalPayment.ExternalPaymentEvent to events.
-
family
final ExternalPaymentUpdatedWebhookEvent.Builder family(ExternalPayment.Family family)
EXTERNAL_PAYMENT - External Payment Response
-
family
final ExternalPaymentUpdatedWebhookEvent.Builder family(JsonField<ExternalPayment.Family> family)
Sets Builder.family to an arbitrary JSON value.
You should usually call Builder.family with a well-typed ExternalPayment.Family value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final ExternalPaymentUpdatedWebhookEvent.Builder financialAccountToken(String financialAccountToken)
-
financialAccountToken
final ExternalPaymentUpdatedWebhookEvent.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentType
final ExternalPaymentUpdatedWebhookEvent.Builder paymentType(ExternalPayment.ExternalPaymentDirection paymentType)
-
paymentType
final ExternalPaymentUpdatedWebhookEvent.Builder paymentType(JsonField<ExternalPayment.ExternalPaymentDirection> paymentType)
Sets Builder.paymentType to an arbitrary JSON value.
You should usually call Builder.paymentType with a well-typed ExternalPayment.ExternalPaymentDirection value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final ExternalPaymentUpdatedWebhookEvent.Builder pendingAmount(Long pendingAmount)
-
pendingAmount
final ExternalPaymentUpdatedWebhookEvent.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final ExternalPaymentUpdatedWebhookEvent.Builder result(ExternalPayment.TransactionResult result)
-
result
final ExternalPaymentUpdatedWebhookEvent.Builder result(JsonField<ExternalPayment.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed ExternalPayment.TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final ExternalPaymentUpdatedWebhookEvent.Builder settledAmount(Long settledAmount)
-
settledAmount
final ExternalPaymentUpdatedWebhookEvent.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userDefinedId
final ExternalPaymentUpdatedWebhookEvent.Builder userDefinedId(String userDefinedId)
-
userDefinedId
final ExternalPaymentUpdatedWebhookEvent.Builder userDefinedId(Optional<String> userDefinedId)
Alias for calling Builder.userDefinedId with
userDefinedId.orElse(null).
-
userDefinedId
final ExternalPaymentUpdatedWebhookEvent.Builder userDefinedId(JsonField<String> userDefinedId)
Sets Builder.userDefinedId to an arbitrary JSON value.
You should usually call Builder.userDefinedId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final ExternalPaymentUpdatedWebhookEvent.Builder eventType(ExternalPaymentUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final ExternalPaymentUpdatedWebhookEvent.Builder eventType(JsonField<ExternalPaymentUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalPaymentUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalPaymentUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalPaymentUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalPaymentUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalPaymentUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalPaymentUpdatedWebhookEvent build()
Returns an immutable instance of ExternalPaymentUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .created() .status() .updated() .eventType()
-
-
-
-