Package com.lithic.api.models
Class FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse
-
- All Implemented Interfaces:
public final class FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.BuilderA builder for AutoCollectionConfigurationResponse.
-
Method Summary
Modifier and Type Method Description final BooleanautoCollectionEnabled()If auto collection is enabled for this account final JsonField<Boolean>_autoCollectionEnabled()Returns the raw JSON value of autoCollectionEnabled. final Map<String, JsonValue>_additionalProperties()final FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.BuildertoBuilder()final FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AutoCollectionConfigurationResponse. -
-
Method Detail
-
autoCollectionEnabled
final Boolean autoCollectionEnabled()
If auto collection is enabled for this account
-
_autoCollectionEnabled
final JsonField<Boolean> _autoCollectionEnabled()
Returns the raw JSON value of autoCollectionEnabled.
Unlike autoCollectionEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builder toBuilder()
-
validate
final FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccount.FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builder builder()
Returns a mutable builder for constructing an instance of AutoCollectionConfigurationResponse.
The following fields are required:
.autoCollectionEnabled()
-
-
-
-