Class FinancialAccountBalance.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountBalance.BuilderA builder for FinancialAccountBalance.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountBalance.Buildertoken(String token)Globally unique identifier for the financial account that holds this balance. final FinancialAccountBalance.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final FinancialAccountBalance.BuilderavailableAmount(Long availableAmount)Funds available for spend in the currency's smallest unit (e.g. final FinancialAccountBalance.BuilderavailableAmount(JsonField<Long> availableAmount)Sets Builder.availableAmount to an arbitrary JSON value. final FinancialAccountBalance.Buildercreated(OffsetDateTime created)Date and time for when the balance was first created. final FinancialAccountBalance.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final FinancialAccountBalance.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the local currency of the balance. final FinancialAccountBalance.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final FinancialAccountBalance.BuilderlastTransactionEventToken(String lastTransactionEventToken)Globally unique identifier for the last financial transaction event that impacted this balance. final FinancialAccountBalance.BuilderlastTransactionEventToken(JsonField<String> lastTransactionEventToken)Sets Builder.lastTransactionEventToken to an arbitrary JSON value. final FinancialAccountBalance.BuilderlastTransactionToken(String lastTransactionToken)Globally unique identifier for the last financial transaction that impacted this balance. final FinancialAccountBalance.BuilderlastTransactionToken(JsonField<String> lastTransactionToken)Sets Builder.lastTransactionToken to an arbitrary JSON value. final FinancialAccountBalance.BuilderpendingAmount(Long pendingAmount)Funds not available for spend due to card authorizations or pending ACH release. final FinancialAccountBalance.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final FinancialAccountBalance.BuildertotalAmount(Long totalAmount)The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD). final FinancialAccountBalance.BuildertotalAmount(JsonField<Long> totalAmount)Sets Builder.totalAmount to an arbitrary JSON value. final FinancialAccountBalance.Buildertype(FinancialAccountBalance.Type type)Type of financial account. final FinancialAccountBalance.Buildertype(JsonField<FinancialAccountBalance.Type> type)Sets Builder.type to an arbitrary JSON value. final FinancialAccountBalance.Builderupdated(OffsetDateTime updated)Date and time for when the balance was last updated. final FinancialAccountBalance.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final FinancialAccountBalance.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final FinancialAccountBalance.BuilderputAdditionalProperty(String key, JsonValue value)final FinancialAccountBalance.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final FinancialAccountBalance.BuilderremoveAdditionalProperty(String key)final FinancialAccountBalance.BuilderremoveAllAdditionalProperties(Set<String> keys)final FinancialAccountBalancebuild()Returns an immutable instance of FinancialAccountBalance. -
-
Method Detail
-
token
final FinancialAccountBalance.Builder token(String token)
Globally unique identifier for the financial account that holds this balance.
-
token
final FinancialAccountBalance.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
availableAmount
final FinancialAccountBalance.Builder availableAmount(Long availableAmount)
Funds available for spend in the currency's smallest unit (e.g., cents for USD)
-
availableAmount
final FinancialAccountBalance.Builder availableAmount(JsonField<Long> availableAmount)
Sets Builder.availableAmount to an arbitrary JSON value.
You should usually call Builder.availableAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final FinancialAccountBalance.Builder created(OffsetDateTime created)
Date and time for when the balance was first created.
-
created
final FinancialAccountBalance.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final FinancialAccountBalance.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the local currency of the balance.
-
currency
final FinancialAccountBalance.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionEventToken
final FinancialAccountBalance.Builder lastTransactionEventToken(String lastTransactionEventToken)
Globally unique identifier for the last financial transaction event that impacted this balance.
-
lastTransactionEventToken
final FinancialAccountBalance.Builder lastTransactionEventToken(JsonField<String> lastTransactionEventToken)
Sets Builder.lastTransactionEventToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionEventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTransactionToken
final FinancialAccountBalance.Builder lastTransactionToken(String lastTransactionToken)
Globally unique identifier for the last financial transaction that impacted this balance.
-
lastTransactionToken
final FinancialAccountBalance.Builder lastTransactionToken(JsonField<String> lastTransactionToken)
Sets Builder.lastTransactionToken to an arbitrary JSON value.
You should usually call Builder.lastTransactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final FinancialAccountBalance.Builder pendingAmount(Long pendingAmount)
Funds not available for spend due to card authorizations or pending ACH release. Shown in the currency's smallest unit (e.g., cents for USD).
-
pendingAmount
final FinancialAccountBalance.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalAmount
final FinancialAccountBalance.Builder totalAmount(Long totalAmount)
The sum of available and pending balance in the currency's smallest unit (e.g., cents for USD).
-
totalAmount
final FinancialAccountBalance.Builder totalAmount(JsonField<Long> totalAmount)
Sets Builder.totalAmount to an arbitrary JSON value.
You should usually call Builder.totalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final FinancialAccountBalance.Builder type(FinancialAccountBalance.Type type)
Type of financial account.
-
type
final FinancialAccountBalance.Builder type(JsonField<FinancialAccountBalance.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final FinancialAccountBalance.Builder updated(OffsetDateTime updated)
Date and time for when the balance was last updated.
-
updated
final FinancialAccountBalance.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FinancialAccountBalance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialAccountBalance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialAccountBalance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialAccountBalance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialAccountBalance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialAccountBalance build()
Returns an immutable instance of FinancialAccountBalance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .availableAmount() .created() .currency() .lastTransactionEventToken() .lastTransactionToken() .pendingAmount() .totalAmount() .type() .updated()
-
-
-
-