Package com.lithic.api.models
Class FinancialAccountBalanceListPage.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountBalanceListPage.BuilderA builder for FinancialAccountBalanceListPage.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountBalanceListPage.Builderservice(BalanceService service)final FinancialAccountBalanceListPage.Builderparams(FinancialAccountBalanceListParams params)The parameters that were used to request this page. final FinancialAccountBalanceListPage.Builderresponse(FinancialAccountBalanceListPageResponse response)The response that this page was parsed from. final FinancialAccountBalanceListPagebuild()Returns an immutable instance of FinancialAccountBalanceListPage. -
-
Method Detail
-
service
final FinancialAccountBalanceListPage.Builder service(BalanceService service)
-
params
final FinancialAccountBalanceListPage.Builder params(FinancialAccountBalanceListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountBalanceListPage.Builder response(FinancialAccountBalanceListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialAccountBalanceListPage build()
Returns an immutable instance of FinancialAccountBalanceListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-