Class FinancialAccountCreateParams.CreateFinancialAccountRequest
-
- All Implemented Interfaces:
public final class FinancialAccountCreateParams.CreateFinancialAccountRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountCreateParams.CreateFinancialAccountRequest.BuilderA builder for CreateFinancialAccountRequest.
-
Method Summary
-
-
Method Detail
-
type
final FinancialAccountCreateParams.Type type()
-
accountToken
final Optional<String> accountToken()
-
isForBenefitOf
final Optional<Boolean> isForBenefitOf()
-
_nickname
final JsonField<String> _nickname()
Returns the raw JSON value of nickname.
Unlike nickname, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<FinancialAccountCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_isForBenefitOf
final JsonField<Boolean> _isForBenefitOf()
Returns the raw JSON value of isForBenefitOf.
Unlike isForBenefitOf, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountCreateParams.CreateFinancialAccountRequest.Builder toBuilder()
-
validate
final FinancialAccountCreateParams.CreateFinancialAccountRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountCreateParams.CreateFinancialAccountRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateFinancialAccountRequest.
The following fields are required:
.nickname() .type()
-
-
-
-