Package com.lithic.api.models
Class FinancialAccountCreditConfig.AutoCollectionConfigurationResponse
-
- All Implemented Interfaces:
public final class FinancialAccountCreditConfig.AutoCollectionConfigurationResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountCreditConfig.AutoCollectionConfigurationResponse.BuilderA builder for AutoCollectionConfigurationResponse.
-
Method Summary
Modifier and Type Method Description final BooleanautoCollectionEnabled()If auto collection is enabled for this account final JsonField<Boolean>_autoCollectionEnabled()Returns the raw JSON value of autoCollectionEnabled. final Map<String, JsonValue>_additionalProperties()final FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.BuildertoBuilder()final FinancialAccountCreditConfig.AutoCollectionConfigurationResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AutoCollectionConfigurationResponse. -
-
Method Detail
-
autoCollectionEnabled
final Boolean autoCollectionEnabled()
If auto collection is enabled for this account
-
_autoCollectionEnabled
final JsonField<Boolean> _autoCollectionEnabled()
Returns the raw JSON value of autoCollectionEnabled.
Unlike autoCollectionEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builder toBuilder()
-
validate
final FinancialAccountCreditConfig.AutoCollectionConfigurationResponse validate()
-
builder
final static FinancialAccountCreditConfig.AutoCollectionConfigurationResponse.Builder builder()
Returns a mutable builder for constructing an instance of AutoCollectionConfigurationResponse.
The following fields are required:
.autoCollectionEnabled()
-
-
-
-