Class FinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest
-
- All Implemented Interfaces:
public final class FinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest.BuilderA builder for FinancialAccountCreditConfigRequest.
-
Method Summary
-
-
Method Detail
-
autoCollectionConfiguration
final Optional<FinancialAccountCreditConfigurationUpdateParams.AutoCollectionConfigurationRequest> autoCollectionConfiguration()
-
creditLimit
final Optional<Long> creditLimit()
-
creditProductToken
final Optional<String> creditProductToken()
Globally unique identifier for the credit product
-
externalBankAccountToken
final Optional<String> externalBankAccountToken()
-
_autoCollectionConfiguration
final JsonField<FinancialAccountCreditConfigurationUpdateParams.AutoCollectionConfigurationRequest> _autoCollectionConfiguration()
Returns the raw JSON value of autoCollectionConfiguration.
Unlike autoCollectionConfiguration, this method doesn't throw if the JSON field has an unexpected type.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_creditProductToken
final JsonField<String> _creditProductToken()
Returns the raw JSON value of creditProductToken.
Unlike creditProductToken, this method doesn't throw if the JSON field has an unexpected type.
-
_externalBankAccountToken
final JsonField<String> _externalBankAccountToken()
Returns the raw JSON value of externalBankAccountToken.
Unlike externalBankAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_tier
final JsonField<String> _tier()
Returns the raw JSON value of tier.
Unlike tier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest.Builder toBuilder()
-
validate
final FinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountCreditConfigurationUpdateParams.FinancialAccountCreditConfigRequest.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountCreditConfigRequest.
-
-
-
-