Class FinancialAccountInterestTierScheduleDeleteParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class FinancialAccountInterestTierScheduleDeleteParams
     implements Params
                        

    Delete an interest tier schedule entry.

    Returns:

    • 400 Bad Request: Invalid effective_date format OR attempting to delete the earliest tier schedule entry for a non-PENDING account

    • 404 Not Found: Tier schedule entry not found for the given effective_date OR ledger account not found

    Note: PENDING accounts can delete the earliest tier schedule entry (account hasn't opened yet). Active/non-PENDING accounts cannot delete the earliest entry to prevent orphaning the account.

    If the deleted tier schedule has a past effective_date and the account is ACTIVE, the loan tape rebuild configuration will be updated to trigger rebuilds from that date.