Package com.lithic.api.models
Class FinancialAccountInterestTierScheduleListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountInterestTierScheduleListPageAsync.BuilderA builder for FinancialAccountInterestTierScheduleListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountInterestTierScheduleListPageAsync.Builderservice(InterestTierScheduleServiceAsync service)final FinancialAccountInterestTierScheduleListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialAccountInterestTierScheduleListPageAsync.Builderparams(FinancialAccountInterestTierScheduleListParams params)The parameters that were used to request this page. final FinancialAccountInterestTierScheduleListPageAsync.Builderresponse(FinancialAccountInterestTierScheduleListPageResponse response)The response that this page was parsed from. final FinancialAccountInterestTierScheduleListPageAsyncbuild()Returns an immutable instance of FinancialAccountInterestTierScheduleListPageAsync. -
-
Method Detail
-
service
final FinancialAccountInterestTierScheduleListPageAsync.Builder service(InterestTierScheduleServiceAsync service)
-
streamHandlerExecutor
final FinancialAccountInterestTierScheduleListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialAccountInterestTierScheduleListPageAsync.Builder params(FinancialAccountInterestTierScheduleListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountInterestTierScheduleListPageAsync.Builder response(FinancialAccountInterestTierScheduleListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialAccountInterestTierScheduleListPageAsync build()
Returns an immutable instance of FinancialAccountInterestTierScheduleListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-