Package com.lithic.api.models
Class FinancialAccountInterestTierScheduleListPageResponse
-
- All Implemented Interfaces:
public final class FinancialAccountInterestTierScheduleListPageResponseTier Schedule of the given account. Only applicable for credit products with v2 configuration
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountInterestTierScheduleListPageResponse.BuilderA builder for FinancialAccountInterestTierScheduleListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<InterestTierSchedule>data()final BooleanhasMore()final JsonField<List<InterestTierSchedule>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final FinancialAccountInterestTierScheduleListPageResponse.BuildertoBuilder()final FinancialAccountInterestTierScheduleListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountInterestTierScheduleListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleListPageResponse. -
-
Method Detail
-
data
final List<InterestTierSchedule> data()
-
_data
final JsonField<List<InterestTierSchedule>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountInterestTierScheduleListPageResponse.Builder toBuilder()
-
validate
final FinancialAccountInterestTierScheduleListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountInterestTierScheduleListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-