Class FinancialAccountInterestTierScheduleListParams

  • All Implemented Interfaces:
    com.lithic.api.core.Params

    
    public final class FinancialAccountInterestTierScheduleListParams
     implements Params
                        

    List interest tier schedules for a financial account with optional date filtering.

    If no date parameters are provided, returns all tier schedules. If date parameters are provided, uses filtering to return matching schedules (max 100).

    • for_date: Returns exact match (takes precedence over other dates)

    • before_date: Returns schedules with effective_date <= before_date

    • after_date: Returns schedules with effective_date >= after_date

    • Both before_date and after_date: Returns schedules in range