Class FinancialAccountInterestTierScheduleUpdateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class FinancialAccountInterestTierScheduleUpdateParams implements Params
Update an existing interest tier schedule
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountInterestTierScheduleUpdateParams.BuilderA builder for FinancialAccountInterestTierScheduleUpdateParams.
public final classFinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequestEntry in the Tier Schedule of an account
-
Method Summary
Modifier and Type Method Description final StringfinancialAccountToken()final Optional<LocalDate>effectiveDate()final JsonValue_penaltyRates()Custom rates per category for penaltiesThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = financialAccountInterestTierScheduleUpdateParams.penaltyRates().convert(MyClass.class);final Optional<String>tierName()Name of a tier contained in the credit product. final JsonValue_tierRates()Custom rates per category. final JsonField<String>_tierName()Returns the raw JSON value of tierName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FinancialAccountInterestTierScheduleUpdateParams.BuildertoBuilder()final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountInterestTierScheduleUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleUpdateParams. -
-
Method Detail
-
financialAccountToken
final String financialAccountToken()
-
effectiveDate
final Optional<LocalDate> effectiveDate()
-
_penaltyRates
final JsonValue _penaltyRates()
Custom rates per category for penalties
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = financialAccountInterestTierScheduleUpdateParams.penaltyRates().convert(MyClass.class);
-
tierName
final Optional<String> tierName()
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
-
_tierRates
final JsonValue _tierRates()
Custom rates per category. Mutually exclusive with tier_name
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = financialAccountInterestTierScheduleUpdateParams.tierRates().convert(MyClass.class);
-
_tierName
final JsonField<String> _tierName()
Returns the raw JSON value of tierName.
Unlike tierName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FinancialAccountInterestTierScheduleUpdateParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FinancialAccountInterestTierScheduleUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleUpdateParams.
The following fields are required:
.financialAccountToken()
-
-
-
-