Class FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest
-
- All Implemented Interfaces:
public final class FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequestEntry in the Tier Schedule of an account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.BuilderA builder for UpdateTierScheduleEntryRequest.
-
Method Summary
Modifier and Type Method Description final JsonValue_penaltyRates()Custom rates per category for penaltiesThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = updateTierScheduleEntryRequest.penaltyRates().convert(MyClass.class);final Optional<String>tierName()Name of a tier contained in the credit product. final JsonValue_tierRates()Custom rates per category. final JsonField<String>_tierName()Returns the raw JSON value of tierName. final Map<String, JsonValue>_additionalProperties()final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.BuildertoBuilder()final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateTierScheduleEntryRequest. -
-
Method Detail
-
_penaltyRates
final JsonValue _penaltyRates()
Custom rates per category for penalties
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = updateTierScheduleEntryRequest.penaltyRates().convert(MyClass.class);
-
tierName
final Optional<String> tierName()
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
-
_tierRates
final JsonValue _tierRates()
Custom rates per category. Mutually exclusive with tier_name
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = updateTierScheduleEntryRequest.tierRates().convert(MyClass.class);
-
_tierName
final JsonField<String> _tierName()
Returns the raw JSON value of tierName.
Unlike tierName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder toBuilder()
-
validate
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateTierScheduleEntryRequest.
-
-
-
-