Package com.lithic.api.models
Class FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.BuilderA builder for UpdateTierScheduleEntryRequest.
-
-
Method Summary
-
-
Method Detail
-
penaltyRates
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder penaltyRates(JsonValue penaltyRates)
Custom rates per category for penalties
-
tierName
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder tierName(String tierName)
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
-
tierName
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder tierName(JsonField<String> tierName)
Sets Builder.tierName to an arbitrary JSON value.
You should usually call Builder.tierName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tierRates
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder tierRates(JsonValue tierRates)
Custom rates per category. Mutually exclusive with tier_name
-
additionalProperties
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialAccountInterestTierScheduleUpdateParams.UpdateTierScheduleEntryRequest build()
Returns an immutable instance of UpdateTierScheduleEntryRequest.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-