Package com.lithic.api.models
Class FinancialAccountListPage.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountListPage.BuilderA builder for FinancialAccountListPage.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountListPage.Builderservice(FinancialAccountService service)final FinancialAccountListPage.Builderparams(FinancialAccountListParams params)The parameters that were used to request this page. final FinancialAccountListPage.Builderresponse(FinancialAccountListPageResponse response)The response that this page was parsed from. final FinancialAccountListPagebuild()Returns an immutable instance of FinancialAccountListPage. -
-
Method Detail
-
service
final FinancialAccountListPage.Builder service(FinancialAccountService service)
-
params
final FinancialAccountListPage.Builder params(FinancialAccountListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountListPage.Builder response(FinancialAccountListPageResponse response)
The response that this page was parsed from.
-
build
final FinancialAccountListPage build()
Returns an immutable instance of FinancialAccountListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-