Package com.lithic.api.models
Class FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest
-
- All Implemented Interfaces:
public final class FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest.BuilderA builder for RegisterAccountNumberRequest.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final Map<String, JsonValue>_additionalProperties()final FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest.BuildertoBuilder()final FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest.Builderbuilder()Returns a mutable builder for constructing an instance of RegisterAccountNumberRequest. -
-
Method Detail
-
accountNumber
final String accountNumber()
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest.Builder toBuilder()
-
validate
final FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountRegisterAccountNumberParams.RegisterAccountNumberRequest.Builder builder()
Returns a mutable builder for constructing an instance of RegisterAccountNumberRequest.
The following fields are required:
.accountNumber()
-
-
-
-