Package com.lithic.api.models
Class FinancialAccountStatementLineItemListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountStatementLineItemListPageAsync.BuilderA builder for FinancialAccountStatementLineItemListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountStatementLineItemListPageAsync.Builderservice(LineItemServiceAsync service)final FinancialAccountStatementLineItemListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialAccountStatementLineItemListPageAsync.Builderparams(FinancialAccountStatementLineItemListParams params)The parameters that were used to request this page. final FinancialAccountStatementLineItemListPageAsync.Builderresponse(StatementLineItems response)The response that this page was parsed from. final FinancialAccountStatementLineItemListPageAsyncbuild()Returns an immutable instance of FinancialAccountStatementLineItemListPageAsync. -
-
Method Detail
-
service
final FinancialAccountStatementLineItemListPageAsync.Builder service(LineItemServiceAsync service)
-
streamHandlerExecutor
final FinancialAccountStatementLineItemListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialAccountStatementLineItemListPageAsync.Builder params(FinancialAccountStatementLineItemListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountStatementLineItemListPageAsync.Builder response(StatementLineItems response)
The response that this page was parsed from.
-
build
final FinancialAccountStatementLineItemListPageAsync build()
Returns an immutable instance of FinancialAccountStatementLineItemListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-