Package com.lithic.api.models
Class FinancialAccountStatementListPageAsync.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountStatementListPageAsync.BuilderA builder for FinancialAccountStatementListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final FinancialAccountStatementListPageAsync.Builderservice(StatementServiceAsync service)final FinancialAccountStatementListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final FinancialAccountStatementListPageAsync.Builderparams(FinancialAccountStatementListParams params)The parameters that were used to request this page. final FinancialAccountStatementListPageAsync.Builderresponse(Statements response)The response that this page was parsed from. final FinancialAccountStatementListPageAsyncbuild()Returns an immutable instance of FinancialAccountStatementListPageAsync. -
-
Method Detail
-
service
final FinancialAccountStatementListPageAsync.Builder service(StatementServiceAsync service)
-
streamHandlerExecutor
final FinancialAccountStatementListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final FinancialAccountStatementListPageAsync.Builder params(FinancialAccountStatementListParams params)
The parameters that were used to request this page.
-
response
final FinancialAccountStatementListPageAsync.Builder response(Statements response)
The response that this page was parsed from.
-
build
final FinancialAccountStatementListPageAsync build()
Returns an immutable instance of FinancialAccountStatementListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-