Class FinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest
-
- All Implemented Interfaces:
public final class FinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest.BuilderA builder for UpdateFinancialAccountStatusRequest.
-
Method Summary
-
-
Method Detail
-
status
final FinancialAccountUpdateStatusParams.FinancialAccountStatus status()
Status of the financial account
-
substatus
final Optional<FinancialAccountUpdateStatusParams.UpdateFinancialAccountSubstatus> substatus()
Substatus for the financial account
-
userDefinedStatus
final Optional<String> userDefinedStatus()
User-defined status for the financial account
-
_status
final JsonField<FinancialAccountUpdateStatusParams.FinancialAccountStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_substatus
final JsonField<FinancialAccountUpdateStatusParams.UpdateFinancialAccountSubstatus> _substatus()
Returns the raw JSON value of substatus.
Unlike substatus, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedStatus
final JsonField<String> _userDefinedStatus()
Returns the raw JSON value of userDefinedStatus.
Unlike userDefinedStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest.Builder toBuilder()
-
validate
final FinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialAccountUpdateStatusParams.UpdateFinancialAccountStatusRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateFinancialAccountStatusRequest.
The following fields are required:
.status() .substatus()
-
-
-
-