Class FinancialAccountUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class FinancialAccountUpdatedWebhookEvent.BuilderA builder for FinancialAccountUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final FinancialAccountUpdatedWebhookEvent.Builder token(String token)
Globally unique identifier for the account
-
token
final FinancialAccountUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountToken
final FinancialAccountUpdatedWebhookEvent.Builder accountToken(String accountToken)
-
accountToken
final FinancialAccountUpdatedWebhookEvent.Builder accountToken(Optional<String> accountToken)
Alias for calling Builder.accountToken with
accountToken.orElse(null).
-
accountToken
final FinancialAccountUpdatedWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final FinancialAccountUpdatedWebhookEvent.Builder created(OffsetDateTime created)
-
created
final FinancialAccountUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditConfiguration
final FinancialAccountUpdatedWebhookEvent.Builder creditConfiguration(FinancialAccount.FinancialAccountCreditConfig creditConfiguration)
-
creditConfiguration
final FinancialAccountUpdatedWebhookEvent.Builder creditConfiguration(Optional<FinancialAccount.FinancialAccountCreditConfig> creditConfiguration)
Alias for calling Builder.creditConfiguration with
creditConfiguration.orElse(null).
-
creditConfiguration
final FinancialAccountUpdatedWebhookEvent.Builder creditConfiguration(JsonField<FinancialAccount.FinancialAccountCreditConfig> creditConfiguration)
Sets Builder.creditConfiguration to an arbitrary JSON value.
You should usually call Builder.creditConfiguration with a well-typed FinancialAccount.FinancialAccountCreditConfig value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isForBenefitOf
final FinancialAccountUpdatedWebhookEvent.Builder isForBenefitOf(Boolean isForBenefitOf)
Whether financial account is for the benefit of another entity
-
isForBenefitOf
final FinancialAccountUpdatedWebhookEvent.Builder isForBenefitOf(JsonField<Boolean> isForBenefitOf)
Sets Builder.isForBenefitOf to an arbitrary JSON value.
You should usually call Builder.isForBenefitOf with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nickname
final FinancialAccountUpdatedWebhookEvent.Builder nickname(String nickname)
-
nickname
final FinancialAccountUpdatedWebhookEvent.Builder nickname(Optional<String> nickname)
Alias for calling Builder.nickname with
nickname.orElse(null).
-
nickname
final FinancialAccountUpdatedWebhookEvent.Builder nickname(JsonField<String> nickname)
Sets Builder.nickname to an arbitrary JSON value.
You should usually call Builder.nickname with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final FinancialAccountUpdatedWebhookEvent.Builder status(FinancialAccount.FinancialAccountStatus status)
Status of the financial account
-
status
final FinancialAccountUpdatedWebhookEvent.Builder status(JsonField<FinancialAccount.FinancialAccountStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed FinancialAccount.FinancialAccountStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
substatus
final FinancialAccountUpdatedWebhookEvent.Builder substatus(FinancialAccount.FinancialAccountSubstatus substatus)
Substatus for the financial account
-
substatus
final FinancialAccountUpdatedWebhookEvent.Builder substatus(Optional<FinancialAccount.FinancialAccountSubstatus> substatus)
Alias for calling Builder.substatus with
substatus.orElse(null).
-
substatus
final FinancialAccountUpdatedWebhookEvent.Builder substatus(JsonField<FinancialAccount.FinancialAccountSubstatus> substatus)
Sets Builder.substatus to an arbitrary JSON value.
You should usually call Builder.substatus with a well-typed FinancialAccount.FinancialAccountSubstatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final FinancialAccountUpdatedWebhookEvent.Builder type(FinancialAccount.Type type)
-
type
final FinancialAccountUpdatedWebhookEvent.Builder type(JsonField<FinancialAccount.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed FinancialAccount.Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final FinancialAccountUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
-
updated
final FinancialAccountUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userDefinedStatus
final FinancialAccountUpdatedWebhookEvent.Builder userDefinedStatus(String userDefinedStatus)
User-defined status for the financial account
-
userDefinedStatus
final FinancialAccountUpdatedWebhookEvent.Builder userDefinedStatus(Optional<String> userDefinedStatus)
Alias for calling Builder.userDefinedStatus with
userDefinedStatus.orElse(null).
-
userDefinedStatus
final FinancialAccountUpdatedWebhookEvent.Builder userDefinedStatus(JsonField<String> userDefinedStatus)
Sets Builder.userDefinedStatus to an arbitrary JSON value.
You should usually call Builder.userDefinedStatus with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final FinancialAccountUpdatedWebhookEvent.Builder accountNumber(String accountNumber)
-
accountNumber
final FinancialAccountUpdatedWebhookEvent.Builder accountNumber(Optional<String> accountNumber)
Alias for calling Builder.accountNumber with
accountNumber.orElse(null).
-
accountNumber
final FinancialAccountUpdatedWebhookEvent.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final FinancialAccountUpdatedWebhookEvent.Builder routingNumber(String routingNumber)
-
routingNumber
final FinancialAccountUpdatedWebhookEvent.Builder routingNumber(Optional<String> routingNumber)
Alias for calling Builder.routingNumber with
routingNumber.orElse(null).
-
routingNumber
final FinancialAccountUpdatedWebhookEvent.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final FinancialAccountUpdatedWebhookEvent.Builder eventType(FinancialAccountUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final FinancialAccountUpdatedWebhookEvent.Builder eventType(JsonField<FinancialAccountUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FinancialAccountUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FinancialAccountUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FinancialAccountUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FinancialAccountUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FinancialAccountUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FinancialAccountUpdatedWebhookEvent build()
Returns an immutable instance of FinancialAccountUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountToken() .created() .creditConfiguration() .isForBenefitOf() .nickname() .status() .substatus() .type() .updated() .userDefinedStatus() .eventType()
-
-
-
-