Package com.lithic.api.models
Class FinancialTransactionListPageResponse
-
- All Implemented Interfaces:
public final class FinancialTransactionListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialTransactionListPageResponse.BuilderA builder for FinancialTransactionListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<FinancialTransaction>data()final BooleanhasMore()More data exists. final JsonField<List<FinancialTransaction>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final FinancialTransactionListPageResponse.BuildertoBuilder()final FinancialTransactionListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialTransactionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialTransactionListPageResponse. -
-
Method Detail
-
data
final List<FinancialTransaction> data()
-
_data
final JsonField<List<FinancialTransaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FinancialTransactionListPageResponse.Builder toBuilder()
-
validate
final FinancialTransactionListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FinancialTransactionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of FinancialTransactionListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-