Class FundingEvent.Builder
-
- All Implemented Interfaces:
public final class FundingEvent.BuilderA builder for FundingEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final FundingEvent.Builder token(String token)
Unique token ID
-
token
final FundingEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionResourceType
final FundingEvent.Builder collectionResourceType(FundingEvent.CollectionResourceType collectionResourceType)
Collection resource type
-
collectionResourceType
final FundingEvent.Builder collectionResourceType(JsonField<FundingEvent.CollectionResourceType> collectionResourceType)
Sets Builder.collectionResourceType to an arbitrary JSON value.
You should usually call Builder.collectionResourceType with a well-typed CollectionResourceType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionTokens
final FundingEvent.Builder collectionTokens(List<String> collectionTokens)
IDs of collections, further information can be gathered from the appropriate collection API based on collection_resource_type
-
collectionTokens
final FundingEvent.Builder collectionTokens(JsonField<List<String>> collectionTokens)
Sets Builder.collectionTokens to an arbitrary JSON value.
You should usually call Builder.collectionTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCollectionToken
final FundingEvent.Builder addCollectionToken(String collectionToken)
Adds a single String to collectionTokens.
-
created
final FundingEvent.Builder created(OffsetDateTime created)
Time of the creation
-
created
final FundingEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
highWatermark
final FundingEvent.Builder highWatermark(OffsetDateTime highWatermark)
Time of the high watermark
-
highWatermark
final FundingEvent.Builder highWatermark(JsonField<OffsetDateTime> highWatermark)
Sets Builder.highWatermark to an arbitrary JSON value.
You should usually call Builder.highWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkSettlementSummary
final FundingEvent.Builder networkSettlementSummary(List<FundingEvent.FundingEventSettlement> networkSettlementSummary)
Network settlement summary breakdown by network settlement date
-
networkSettlementSummary
final FundingEvent.Builder networkSettlementSummary(JsonField<List<FundingEvent.FundingEventSettlement>> networkSettlementSummary)
Sets Builder.networkSettlementSummary to an arbitrary JSON value.
You should usually call Builder.networkSettlementSummary with a well-typed
List<FundingEventSettlement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addNetworkSettlementSummary
final FundingEvent.Builder addNetworkSettlementSummary(FundingEvent.FundingEventSettlement networkSettlementSummary)
Adds a single FundingEventSettlement to Builder.networkSettlementSummary.
-
previousHighWatermark
final FundingEvent.Builder previousHighWatermark(OffsetDateTime previousHighWatermark)
Time of the previous high watermark
-
previousHighWatermark
final FundingEvent.Builder previousHighWatermark(JsonField<OffsetDateTime> previousHighWatermark)
Sets Builder.previousHighWatermark to an arbitrary JSON value.
You should usually call Builder.previousHighWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final FundingEvent.Builder updated(OffsetDateTime updated)
Time of the update
-
updated
final FundingEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FundingEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FundingEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FundingEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FundingEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FundingEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FundingEvent build()
Returns an immutable instance of FundingEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .collectionResourceType() .collectionTokens() .created() .highWatermark() .networkSettlementSummary() .previousHighWatermark() .updated()
-
-
-
-