Class FundingEventCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class FundingEventCreatedWebhookEvent.BuilderA builder for FundingEventCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final FundingEventCreatedWebhookEvent.Builder token(String token)
Unique token ID
-
token
final FundingEventCreatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionResourceType
final FundingEventCreatedWebhookEvent.Builder collectionResourceType(FundingEvent.CollectionResourceType collectionResourceType)
Collection resource type
-
collectionResourceType
final FundingEventCreatedWebhookEvent.Builder collectionResourceType(JsonField<FundingEvent.CollectionResourceType> collectionResourceType)
Sets Builder.collectionResourceType to an arbitrary JSON value.
You should usually call Builder.collectionResourceType with a well-typed FundingEvent.CollectionResourceType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionTokens
final FundingEventCreatedWebhookEvent.Builder collectionTokens(List<String> collectionTokens)
IDs of collections, further information can be gathered from the appropriate collection API based on collection_resource_type
-
collectionTokens
final FundingEventCreatedWebhookEvent.Builder collectionTokens(JsonField<List<String>> collectionTokens)
Sets Builder.collectionTokens to an arbitrary JSON value.
You should usually call Builder.collectionTokens with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCollectionToken
final FundingEventCreatedWebhookEvent.Builder addCollectionToken(String collectionToken)
Adds a single String to collectionTokens.
-
created
final FundingEventCreatedWebhookEvent.Builder created(OffsetDateTime created)
Time of the creation
-
created
final FundingEventCreatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
highWatermark
final FundingEventCreatedWebhookEvent.Builder highWatermark(OffsetDateTime highWatermark)
Time of the high watermark
-
highWatermark
final FundingEventCreatedWebhookEvent.Builder highWatermark(JsonField<OffsetDateTime> highWatermark)
Sets Builder.highWatermark to an arbitrary JSON value.
You should usually call Builder.highWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkSettlementSummary
final FundingEventCreatedWebhookEvent.Builder networkSettlementSummary(List<FundingEvent.FundingEventSettlement> networkSettlementSummary)
Network settlement summary breakdown by network settlement date
-
networkSettlementSummary
final FundingEventCreatedWebhookEvent.Builder networkSettlementSummary(JsonField<List<FundingEvent.FundingEventSettlement>> networkSettlementSummary)
Sets Builder.networkSettlementSummary to an arbitrary JSON value.
You should usually call Builder.networkSettlementSummary with a well-typed
List<FundingEvent.FundingEventSettlement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addNetworkSettlementSummary
final FundingEventCreatedWebhookEvent.Builder addNetworkSettlementSummary(FundingEvent.FundingEventSettlement networkSettlementSummary)
Adds a single FundingEvent.FundingEventSettlement to Builder.networkSettlementSummary.
-
previousHighWatermark
final FundingEventCreatedWebhookEvent.Builder previousHighWatermark(OffsetDateTime previousHighWatermark)
Time of the previous high watermark
-
previousHighWatermark
final FundingEventCreatedWebhookEvent.Builder previousHighWatermark(JsonField<OffsetDateTime> previousHighWatermark)
Sets Builder.previousHighWatermark to an arbitrary JSON value.
You should usually call Builder.previousHighWatermark with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final FundingEventCreatedWebhookEvent.Builder updated(OffsetDateTime updated)
Time of the update
-
updated
final FundingEventCreatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final FundingEventCreatedWebhookEvent.Builder eventType(FundingEventCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final FundingEventCreatedWebhookEvent.Builder eventType(JsonField<FundingEventCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FundingEventCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FundingEventCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FundingEventCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FundingEventCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FundingEventCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FundingEventCreatedWebhookEvent build()
Returns an immutable instance of FundingEventCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .collectionResourceType() .collectionTokens() .created() .highWatermark() .networkSettlementSummary() .previousHighWatermark() .updated() .eventType()
-
-
-
-