Package com.lithic.api.models
Class FundingEventListPage.Builder
-
- All Implemented Interfaces:
public final class FundingEventListPage.BuilderA builder for FundingEventListPage.
-
-
Method Summary
Modifier and Type Method Description final FundingEventListPage.Builderservice(FundingEventService service)final FundingEventListPage.Builderparams(FundingEventListParams params)The parameters that were used to request this page. final FundingEventListPage.Builderresponse(FundingEventListPageResponse response)The response that this page was parsed from. final FundingEventListPagebuild()Returns an immutable instance of FundingEventListPage. -
-
Method Detail
-
service
final FundingEventListPage.Builder service(FundingEventService service)
-
params
final FundingEventListPage.Builder params(FundingEventListParams params)
The parameters that were used to request this page.
-
response
final FundingEventListPage.Builder response(FundingEventListPageResponse response)
The response that this page was parsed from.
-
build
final FundingEventListPage build()
Returns an immutable instance of FundingEventListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-