Class Hold
-
- All Implemented Interfaces:
public final class HoldA hold transaction representing reserved funds on a financial account. Holds move funds from available to pending balance in anticipation of future payments. They can be resolved via settlement (linked to payment), manual release, or expiration.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHold.BuilderA builder for Hold.
public final classHold.HoldStatusStatus of a hold transaction
public final classHold.FamilyHOLD - Hold Transaction
public final classHold.TransactionResult
-
Method Summary
Modifier and Type Method Description final Stringtoken()Unique identifier for the transaction final OffsetDateTimecreated()ISO 8601 timestamp of when the transaction was created final Hold.HoldStatusstatus()Status of a hold transaction final OffsetDateTimeupdated()ISO 8601 timestamp of when the transaction was last updated final Optional<String>currency()final Optional<List<HoldEvent>>events()final Optional<OffsetDateTime>expirationDatetime()When the hold will auto-expire if not resolved final Optional<Hold.Family>family()HOLD - Hold Transaction final Optional<String>financialAccountToken()final Optional<Long>pendingAmount()Current pending amount (0 when resolved) final Optional<Hold.TransactionResult>result()final Optional<String>userDefinedId()final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Hold.HoldStatus>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<List<HoldEvent>>_events()Returns the raw JSON value of events. final JsonField<OffsetDateTime>_expirationDatetime()Returns the raw JSON value of expirationDatetime. final JsonField<Hold.Family>_family()Returns the raw JSON value of family. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<Long>_pendingAmount()Returns the raw JSON value of pendingAmount. final JsonField<Hold.TransactionResult>_result()Returns the raw JSON value of result. final JsonField<String>_userDefinedId()Returns the raw JSON value of userDefinedId. final Map<String, JsonValue>_additionalProperties()final Hold.BuildertoBuilder()final Holdvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Hold.Builderbuilder()Returns a mutable builder for constructing an instance of Hold. -
-
Method Detail
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
status
final Hold.HoldStatus status()
Status of a hold transaction
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
expirationDatetime
final Optional<OffsetDateTime> expirationDatetime()
When the hold will auto-expire if not resolved
-
family
final Optional<Hold.Family> family()
HOLD - Hold Transaction
-
financialAccountToken
final Optional<String> financialAccountToken()
-
pendingAmount
final Optional<Long> pendingAmount()
Current pending amount (0 when resolved)
-
result
final Optional<Hold.TransactionResult> result()
-
userDefinedId
final Optional<String> userDefinedId()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Hold.HoldStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<HoldEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDatetime
final JsonField<OffsetDateTime> _expirationDatetime()
Returns the raw JSON value of expirationDatetime.
Unlike expirationDatetime, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<Hold.Family> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Hold.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Hold.Builder toBuilder()
-
validate
final Hold validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Hold.Builder builder()
Returns a mutable builder for constructing an instance of Hold.
The following fields are required:
.token() .created() .status() .updated()
-
-
-
-