Class Hold.Builder
-
- All Implemented Interfaces:
public final class Hold.BuilderA builder for Hold.
-
-
Method Summary
Modifier and Type Method Description final Hold.Buildertoken(String token)Unique identifier for the transaction final Hold.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final Hold.Buildercreated(OffsetDateTime created)ISO 8601 timestamp of when the transaction was created final Hold.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Hold.Builderstatus(Hold.HoldStatus status)Status of a hold transaction final Hold.Builderstatus(JsonField<Hold.HoldStatus> status)Sets Builder.status to an arbitrary JSON value. final Hold.Builderupdated(OffsetDateTime updated)ISO 8601 timestamp of when the transaction was last updated final Hold.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final Hold.Buildercurrency(String currency)final Hold.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final Hold.Builderevents(List<HoldEvent> events)final Hold.Builderevents(JsonField<List<HoldEvent>> events)Sets Builder.events to an arbitrary JSON value. final Hold.BuilderaddEvent(HoldEvent event)Adds a single HoldEvent to events. final Hold.BuilderexpirationDatetime(OffsetDateTime expirationDatetime)When the hold will auto-expire if not resolved final Hold.BuilderexpirationDatetime(Optional<OffsetDateTime> expirationDatetime)Alias for calling Builder.expirationDatetime with expirationDatetime.orElse(null).final Hold.BuilderexpirationDatetime(JsonField<OffsetDateTime> expirationDatetime)Sets Builder.expirationDatetime to an arbitrary JSON value. final Hold.Builderfamily(Hold.Family family)HOLD - Hold Transaction final Hold.Builderfamily(JsonField<Hold.Family> family)Sets Builder.family to an arbitrary JSON value. final Hold.BuilderfinancialAccountToken(String financialAccountToken)final Hold.BuilderfinancialAccountToken(JsonField<String> financialAccountToken)Sets Builder.financialAccountToken to an arbitrary JSON value. final Hold.BuilderpendingAmount(Long pendingAmount)Current pending amount (0 when resolved) final Hold.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final Hold.Builderresult(Hold.TransactionResult result)final Hold.Builderresult(JsonField<Hold.TransactionResult> result)Sets Builder.result to an arbitrary JSON value. final Hold.BuilderuserDefinedId(String userDefinedId)final Hold.BuilderuserDefinedId(Optional<String> userDefinedId)Alias for calling Builder.userDefinedId with userDefinedId.orElse(null).final Hold.BuilderuserDefinedId(JsonField<String> userDefinedId)Sets Builder.userDefinedId to an arbitrary JSON value. final Hold.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Hold.BuilderputAdditionalProperty(String key, JsonValue value)final Hold.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Hold.BuilderremoveAdditionalProperty(String key)final Hold.BuilderremoveAllAdditionalProperties(Set<String> keys)final Holdbuild()Returns an immutable instance of Hold. -
-
Method Detail
-
token
final Hold.Builder token(String token)
Unique identifier for the transaction
-
token
final Hold.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Hold.Builder created(OffsetDateTime created)
ISO 8601 timestamp of when the transaction was created
-
created
final Hold.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Hold.Builder status(Hold.HoldStatus status)
Status of a hold transaction
-
status
final Hold.Builder status(JsonField<Hold.HoldStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed HoldStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final Hold.Builder updated(OffsetDateTime updated)
ISO 8601 timestamp of when the transaction was last updated
-
updated
final Hold.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Hold.Builder currency(String currency)
-
currency
final Hold.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final Hold.Builder events(List<HoldEvent> events)
-
events
final Hold.Builder events(JsonField<List<HoldEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<HoldEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final Hold.Builder addEvent(HoldEvent event)
-
expirationDatetime
final Hold.Builder expirationDatetime(OffsetDateTime expirationDatetime)
When the hold will auto-expire if not resolved
-
expirationDatetime
final Hold.Builder expirationDatetime(Optional<OffsetDateTime> expirationDatetime)
Alias for calling Builder.expirationDatetime with
expirationDatetime.orElse(null).
-
expirationDatetime
final Hold.Builder expirationDatetime(JsonField<OffsetDateTime> expirationDatetime)
Sets Builder.expirationDatetime to an arbitrary JSON value.
You should usually call Builder.expirationDatetime with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
family
final Hold.Builder family(Hold.Family family)
HOLD - Hold Transaction
-
family
final Hold.Builder family(JsonField<Hold.Family> family)
Sets Builder.family to an arbitrary JSON value.
You should usually call Builder.family with a well-typed Family value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final Hold.Builder financialAccountToken(String financialAccountToken)
-
financialAccountToken
final Hold.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingAmount
final Hold.Builder pendingAmount(Long pendingAmount)
Current pending amount (0 when resolved)
-
pendingAmount
final Hold.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final Hold.Builder result(Hold.TransactionResult result)
-
result
final Hold.Builder result(JsonField<Hold.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userDefinedId
final Hold.Builder userDefinedId(String userDefinedId)
-
userDefinedId
final Hold.Builder userDefinedId(Optional<String> userDefinedId)
Alias for calling Builder.userDefinedId with
userDefinedId.orElse(null).
-
userDefinedId
final Hold.Builder userDefinedId(JsonField<String> userDefinedId)
Sets Builder.userDefinedId to an arbitrary JSON value.
You should usually call Builder.userDefinedId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Hold.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Hold.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Hold.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Hold.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Hold.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-