Class HoldCreateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class HoldCreateParams implements Params
Create a hold on a financial account. Holds reserve funds by moving them from available to pending balance. They can be resolved via settlement (linked to a payment or book transfer), voiding, or expiration.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldCreateParams.BuilderA builder for HoldCreateParams.
public final classHoldCreateParams.CreateHoldRequestRequest to create a new hold on a financial account
-
Method Summary
Modifier and Type Method Description final Optional<String>financialAccountToken()final Longamount()Amount to hold in cents final Optional<String>token()Customer-provided token for idempotency. final Optional<OffsetDateTime>expirationDatetime()When the hold should auto-expire final Optional<String>memo()Reason for the hold final Optional<String>userDefinedId()User-provided identifier for the hold final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_expirationDatetime()Returns the raw JSON value of expirationDatetime. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<String>_userDefinedId()Returns the raw JSON value of userDefinedId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final HoldCreateParams.BuildertoBuilder()final HoldCreateParams.CreateHoldRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of HoldCreateParams. -
-
Method Detail
-
financialAccountToken
final Optional<String> financialAccountToken()
-
token
final Optional<String> token()
Customer-provided token for idempotency. Becomes the hold token.
-
expirationDatetime
final Optional<OffsetDateTime> expirationDatetime()
When the hold should auto-expire
-
userDefinedId
final Optional<String> userDefinedId()
User-provided identifier for the hold
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDatetime
final JsonField<OffsetDateTime> _expirationDatetime()
Returns the raw JSON value of expirationDatetime.
Unlike expirationDatetime, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final HoldCreateParams.Builder toBuilder()
-
_body
final HoldCreateParams.CreateHoldRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static HoldCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of HoldCreateParams.
The following fields are required:
.amount()
-
-
-
-