Package com.lithic.api.models
Class HoldListPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class HoldListPage implements Page<Hold>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldListPage.BuilderA builder for HoldListPage.
-
Method Summary
Modifier and Type Method Description final List<Hold>data()Delegates to HoldListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to HoldListPageResponse, but gracefully handles missing data. List<Hold>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HoldListParamsnextPageParams()HoldListPagenextPage()Returns the page after this one by making another request. final AutoPager<Hold>autoPager()final HoldListParamsparams()The parameters that were used to request this page. final HoldListPageResponseresponse()The response that this page was parsed from. final HoldListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldListPage.Builderbuilder()Returns a mutable builder for constructing an instance of HoldListPage. -
-
Method Detail
-
data
final List<Hold> data()
Delegates to HoldListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to HoldListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HoldListParams nextPageParams()
-
nextPage
HoldListPage nextPage()
Returns the page after this one by making another request.
-
params
final HoldListParams params()
The parameters that were used to request this page.
-
response
final HoldListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HoldListPage.Builder toBuilder()
-
builder
final static HoldListPage.Builder builder()
Returns a mutable builder for constructing an instance of HoldListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-