Package com.lithic.api.models
Class HoldListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class HoldListPageAsync implements PageAsync<Hold>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldListPageAsync.BuilderA builder for HoldListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<Hold>data()Delegates to HoldListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to HoldListPageResponse, but gracefully handles missing data. List<Hold>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final HoldListParamsnextPageParams()CompletableFuture<HoldListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Hold>autoPager()final HoldListParamsparams()The parameters that were used to request this page. final HoldListPageResponseresponse()The response that this page was parsed from. final HoldListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of HoldListPageAsync. -
-
Method Detail
-
data
final List<Hold> data()
Delegates to HoldListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to HoldListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final HoldListParams nextPageParams()
-
nextPage
CompletableFuture<HoldListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Hold> autoPager()
-
params
final HoldListParams params()
The parameters that were used to request this page.
-
response
final HoldListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final HoldListPageAsync.Builder toBuilder()
-
builder
final static HoldListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of HoldListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-