Package com.lithic.api.models
Class HoldListPageResponse
-
- All Implemented Interfaces:
public final class HoldListPageResponsePaginated response containing hold transactions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldListPageResponse.BuilderA builder for HoldListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Hold>data()final BooleanhasMore()final JsonField<List<Hold>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final HoldListPageResponse.BuildertoBuilder()final HoldListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of HoldListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Hold>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HoldListPageResponse.Builder toBuilder()
-
validate
final HoldListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static HoldListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of HoldListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-