Class InternalTransaction.Builder
-
- All Implemented Interfaces:
public final class InternalTransaction.BuilderA builder for InternalTransaction.
-
-
Method Summary
-
-
Method Detail
-
token
final InternalTransaction.Builder token(String token)
-
token
final InternalTransaction.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final InternalTransaction.Builder category(InternalTransaction.Category category)
-
category
final InternalTransaction.Builder category(JsonField<InternalTransaction.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final InternalTransaction.Builder created(OffsetDateTime created)
-
created
final InternalTransaction.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InternalTransaction.Builder currency(String currency)
-
currency
final InternalTransaction.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
descriptor
final InternalTransaction.Builder descriptor(String descriptor)
-
descriptor
final InternalTransaction.Builder descriptor(JsonField<String> descriptor)
Sets Builder.descriptor to an arbitrary JSON value.
You should usually call Builder.descriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final InternalTransaction.Builder events(List<InternalTransaction.InternalAdjustmentEvent> events)
-
events
final InternalTransaction.Builder events(JsonField<List<InternalTransaction.InternalAdjustmentEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<InternalAdjustmentEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final InternalTransaction.Builder addEvent(InternalTransaction.InternalAdjustmentEvent event)
Adds a single InternalAdjustmentEvent to events.
-
pendingAmount
final InternalTransaction.Builder pendingAmount(Long pendingAmount)
-
pendingAmount
final InternalTransaction.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final InternalTransaction.Builder result(InternalTransaction.TransactionResult result)
-
result
final InternalTransaction.Builder result(JsonField<InternalTransaction.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final InternalTransaction.Builder settledAmount(Long settledAmount)
-
settledAmount
final InternalTransaction.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InternalTransaction.Builder status(InternalTransaction.TransactionStatus status)
-
status
final InternalTransaction.Builder status(JsonField<InternalTransaction.TransactionStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed TransactionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final InternalTransaction.Builder updated(OffsetDateTime updated)
-
updated
final InternalTransaction.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InternalTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InternalTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InternalTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InternalTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InternalTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InternalTransaction build()
Returns an immutable instance of InternalTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .category() .created() .currency() .descriptor() .events() .pendingAmount() .result() .settledAmount() .status() .updated()
-
-
-
-