Class InternalTransaction.InternalAdjustmentEvent.Builder
-
- All Implemented Interfaces:
public final class InternalTransaction.InternalAdjustmentEvent.BuilderA builder for InternalAdjustmentEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final InternalTransaction.InternalAdjustmentEvent.Builder token(String token)
-
token
final InternalTransaction.InternalAdjustmentEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InternalTransaction.InternalAdjustmentEvent.Builder amount(Long amount)
-
amount
final InternalTransaction.InternalAdjustmentEvent.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final InternalTransaction.InternalAdjustmentEvent.Builder created(OffsetDateTime created)
-
created
final InternalTransaction.InternalAdjustmentEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final InternalTransaction.InternalAdjustmentEvent.Builder result(InternalTransaction.InternalAdjustmentEvent.TransactionResult result)
-
result
final InternalTransaction.InternalAdjustmentEvent.Builder result(JsonField<InternalTransaction.InternalAdjustmentEvent.TransactionResult> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TransactionResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InternalTransaction.InternalAdjustmentEvent.Builder type(InternalTransaction.InternalAdjustmentEvent.Type type)
-
type
final InternalTransaction.InternalAdjustmentEvent.Builder type(JsonField<InternalTransaction.InternalAdjustmentEvent.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InternalTransaction.InternalAdjustmentEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InternalTransaction.InternalAdjustmentEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InternalTransaction.InternalAdjustmentEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InternalTransaction.InternalAdjustmentEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InternalTransaction.InternalAdjustmentEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InternalTransaction.InternalAdjustmentEvent build()
Returns an immutable instance of InternalAdjustmentEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .amount() .created() .result() .type()
-
-
-
-