Class KybBusinessEntity.Builder
-
- All Implemented Interfaces:
public final class KybBusinessEntity.BuilderA builder for KybBusinessEntity.
-
-
Method Summary
-
-
Method Detail
-
address
final KybBusinessEntity.Builder address(KybBusinessEntity.Address address)
Business''s physical address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable.
-
address
final KybBusinessEntity.Builder address(JsonField<KybBusinessEntity.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentId
final KybBusinessEntity.Builder governmentId(String governmentId)
Government-issued identification number. US Federal Employer Identification Numbers (EIN) are currently supported, entered as full nine-digits, with or without hyphens.
-
governmentId
final KybBusinessEntity.Builder governmentId(JsonField<String> governmentId)
Sets Builder.governmentId to an arbitrary JSON value.
You should usually call Builder.governmentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
legalBusinessName
final KybBusinessEntity.Builder legalBusinessName(String legalBusinessName)
Legal (formal) business name.
-
legalBusinessName
final KybBusinessEntity.Builder legalBusinessName(JsonField<String> legalBusinessName)
Sets Builder.legalBusinessName to an arbitrary JSON value.
You should usually call Builder.legalBusinessName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumbers
final KybBusinessEntity.Builder phoneNumbers(List<String> phoneNumbers)
One or more of the business's phone number(s), entered as a list in E.164 format.
-
phoneNumbers
final KybBusinessEntity.Builder phoneNumbers(JsonField<List<String>> phoneNumbers)
Sets Builder.phoneNumbers to an arbitrary JSON value.
You should usually call Builder.phoneNumbers with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPhoneNumber
final KybBusinessEntity.Builder addPhoneNumber(String phoneNumber)
Adds a single String to phoneNumbers.
-
dbaBusinessName
final KybBusinessEntity.Builder dbaBusinessName(String dbaBusinessName)
Any name that the business operates under that is not its legal business name (if applicable).
-
dbaBusinessName
final KybBusinessEntity.Builder dbaBusinessName(JsonField<String> dbaBusinessName)
Sets Builder.dbaBusinessName to an arbitrary JSON value.
You should usually call Builder.dbaBusinessName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
parentCompany
final KybBusinessEntity.Builder parentCompany(String parentCompany)
Parent company name (if applicable).
-
parentCompany
final KybBusinessEntity.Builder parentCompany(Optional<String> parentCompany)
Alias for calling Builder.parentCompany with
parentCompany.orElse(null).
-
parentCompany
final KybBusinessEntity.Builder parentCompany(JsonField<String> parentCompany)
Sets Builder.parentCompany to an arbitrary JSON value.
You should usually call Builder.parentCompany with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final KybBusinessEntity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final KybBusinessEntity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final KybBusinessEntity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final KybBusinessEntity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final KybBusinessEntity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final KybBusinessEntity build()
Returns an immutable instance of KybBusinessEntity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .governmentId() .legalBusinessName() .phoneNumbers()
-
-
-
-