Class Kyc.Individual

  • All Implemented Interfaces:

    
    public final class Kyc.Individual
    
                        

    Information on individual for whom the account is being opened and KYC is being run.

    • Constructor Detail

    • Method Detail

      • address

         final Address address()

        Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.

      • dob

         final String dob()

        Individual's date of birth, as an RFC 3339 date.

      • email

         final String email()

        Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.

      • firstName

         final String firstName()

        Individual's first name, as it appears on government-issued identity documents.

      • governmentId

         final String governmentId()

        Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens

      • lastName

         final String lastName()

        Individual's last name, as it appears on government-issued identity documents.

      • phoneNumber

         final String phoneNumber()

        Individual's phone number, entered in E.164 format.

      • _dob

         final JsonField<String> _dob()

        Returns the raw JSON value of dob.

        Unlike dob, this method doesn't throw if the JSON field has an unexpected type.

      • _email

         final JsonField<String> _email()

        Returns the raw JSON value of email.

        Unlike email, this method doesn't throw if the JSON field has an unexpected type.

      • validate

         final Kyc.Individual validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.

      • builder

         final static Kyc.Individual.Builder builder()

        Returns a mutable builder for constructing an instance of Individual.

        The following fields are required:

        .address()
        .dob()
        .email()
        .firstName()
        .governmentId()
        .lastName()
        .phoneNumber()