Class LoanTapeConfiguration
-
- All Implemented Interfaces:
public final class LoanTapeConfigurationConfiguration for loan tapes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLoanTapeConfiguration.BuilderA builder for LoanTapeConfiguration.
-
Method Summary
-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
-
financialAccountToken
final String financialAccountToken()
-
instanceToken
final String instanceToken()
-
updatedAt
final OffsetDateTime updatedAt()
-
creditProductToken
final Optional<String> creditProductToken()
-
loanTapeRebuildConfiguration
final Optional<LoanTapeRebuildConfiguration> loanTapeRebuildConfiguration()
Configuration for building loan tapes
-
tierScheduleChangedAt
final Optional<OffsetDateTime> tierScheduleChangedAt()
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_instanceToken
final JsonField<String> _instanceToken()
Returns the raw JSON value of instanceToken.
Unlike instanceToken, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creditProductToken
final JsonField<String> _creditProductToken()
Returns the raw JSON value of creditProductToken.
Unlike creditProductToken, this method doesn't throw if the JSON field has an unexpected type.
-
_loanTapeRebuildConfiguration
final JsonField<LoanTapeRebuildConfiguration> _loanTapeRebuildConfiguration()
Returns the raw JSON value of loanTapeRebuildConfiguration.
Unlike loanTapeRebuildConfiguration, this method doesn't throw if the JSON field has an unexpected type.
-
_tierScheduleChangedAt
final JsonField<OffsetDateTime> _tierScheduleChangedAt()
Returns the raw JSON value of tierScheduleChangedAt.
Unlike tierScheduleChangedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LoanTapeConfiguration.Builder toBuilder()
-
validate
final LoanTapeConfiguration validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LoanTapeConfiguration.Builder builder()
Returns a mutable builder for constructing an instance of LoanTapeConfiguration.
The following fields are required:
.createdAt() .financialAccountToken() .instanceToken() .updatedAt()
-
-
-
-