Class LoanTapeRebuildConfiguration
-
- All Implemented Interfaces:
public final class LoanTapeRebuildConfigurationConfiguration for building loan tapes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLoanTapeRebuildConfiguration.BuilderA builder for LoanTapeRebuildConfiguration.
-
Method Summary
Modifier and Type Method Description final BooleanrebuildNeeded()Whether the account's loan tapes need to be rebuilt or not final Optional<LocalDate>lastRebuild()The date for which the account's loan tapes were last rebuilt final Optional<LocalDate>rebuildFrom()Date from which to start rebuilding from if the account requires a rebuild final JsonField<Boolean>_rebuildNeeded()Returns the raw JSON value of rebuildNeeded. final JsonField<LocalDate>_lastRebuild()Returns the raw JSON value of lastRebuild. final JsonField<LocalDate>_rebuildFrom()Returns the raw JSON value of rebuildFrom. final Map<String, JsonValue>_additionalProperties()final LoanTapeRebuildConfiguration.BuildertoBuilder()final LoanTapeRebuildConfigurationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LoanTapeRebuildConfiguration.Builderbuilder()Returns a mutable builder for constructing an instance of LoanTapeRebuildConfiguration. -
-
Method Detail
-
rebuildNeeded
final Boolean rebuildNeeded()
Whether the account's loan tapes need to be rebuilt or not
-
lastRebuild
final Optional<LocalDate> lastRebuild()
The date for which the account's loan tapes were last rebuilt
-
rebuildFrom
final Optional<LocalDate> rebuildFrom()
Date from which to start rebuilding from if the account requires a rebuild
-
_rebuildNeeded
final JsonField<Boolean> _rebuildNeeded()
Returns the raw JSON value of rebuildNeeded.
Unlike rebuildNeeded, this method doesn't throw if the JSON field has an unexpected type.
-
_lastRebuild
final JsonField<LocalDate> _lastRebuild()
Returns the raw JSON value of lastRebuild.
Unlike lastRebuild, this method doesn't throw if the JSON field has an unexpected type.
-
_rebuildFrom
final JsonField<LocalDate> _rebuildFrom()
Returns the raw JSON value of rebuildFrom.
Unlike rebuildFrom, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LoanTapeRebuildConfiguration.Builder toBuilder()
-
validate
final LoanTapeRebuildConfiguration validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LoanTapeRebuildConfiguration.Builder builder()
Returns a mutable builder for constructing an instance of LoanTapeRebuildConfiguration.
The following fields are required:
.rebuildNeeded()
-
-
-
-