Class LoanTapeUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class LoanTapeUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLoanTapeUpdatedWebhookEvent.BuilderA builder for LoanTapeUpdatedWebhookEvent.
public final classLoanTapeUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final LoanTapetoLoanTape()final Stringtoken()Globally unique identifier for a loan tape final LoanTape.AccountStandingaccountStanding()final LongavailableCredit()Amount of credit available to spend in cents final LoanTape.Balancesbalances()final OffsetDateTimecreated()Timestamp of when the loan tape was created final LongcreditLimit()For prepay accounts, this is the minimum prepay balance that must be maintained. final StringcreditProductToken()Globally unique identifier for a credit product final LocalDatedate()Date of transactions that this loan tape covers final StatementTotalsdayTotals()final LongendingBalance()Balance at the end of the day final LongexcessCredits()Excess credits in the form of provisional credits, payments, or purchase refunds. final StringfinancialAccountToken()Globally unique identifier for a financial account final Optional<LoanTape.InterestDetails>interestDetails()final LoanTape.BalanceDetailsminimumPaymentBalance()final LoanTape.PaymentAllocationpaymentAllocation()final StatementTotalsperiodTotals()final LoanTape.BalanceDetailspreviousStatementBalance()final LongstartingBalance()Balance at the start of the day final OffsetDateTimeupdated()Timestamp of when the loan tape was updated final Longversion()Version number of the loan tape. final StatementTotalsytdTotals()final Optional<Long>dayOfPeriod()Day of the billing period that this loan tape covers, starting at 1 final Optional<String>tier()Interest tier to which this account belongs to final LoanTapeUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<LoanTape.AccountStanding>_accountStanding()Returns the raw JSON value of accountStanding. final JsonField<Long>_availableCredit()Returns the raw JSON value of availableCredit. final JsonField<LoanTape.Balances>_balances()Returns the raw JSON value of balances. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final JsonField<String>_creditProductToken()Returns the raw JSON value of creditProductToken. final JsonField<LocalDate>_date()Returns the raw JSON value of date. final JsonField<StatementTotals>_dayTotals()Returns the raw JSON value of dayTotals. final JsonField<Long>_endingBalance()Returns the raw JSON value of endingBalance. final JsonField<Long>_excessCredits()Returns the raw JSON value of excessCredits. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<LoanTape.InterestDetails>_interestDetails()Returns the raw JSON value of interestDetails. final JsonField<LoanTape.BalanceDetails>_minimumPaymentBalance()Returns the raw JSON value of minimumPaymentBalance. final JsonField<LoanTape.PaymentAllocation>_paymentAllocation()Returns the raw JSON value of paymentAllocation. final JsonField<StatementTotals>_periodTotals()Returns the raw JSON value of periodTotals. final JsonField<LoanTape.BalanceDetails>_previousStatementBalance()Returns the raw JSON value of previousStatementBalance. final JsonField<Long>_startingBalance()Returns the raw JSON value of startingBalance. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<Long>_version()Returns the raw JSON value of version. final JsonField<StatementTotals>_ytdTotals()Returns the raw JSON value of ytdTotals. final JsonField<Long>_dayOfPeriod()Returns the raw JSON value of dayOfPeriod. final JsonField<String>_tier()Returns the raw JSON value of tier. final JsonField<LoanTapeUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final LoanTapeUpdatedWebhookEvent.BuildertoBuilder()final LoanTapeUpdatedWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LoanTapeUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of LoanTapeUpdatedWebhookEvent. -
-
Method Detail
-
toLoanTape
final LoanTape toLoanTape()
-
accountStanding
final LoanTape.AccountStanding accountStanding()
-
availableCredit
final Long availableCredit()
Amount of credit available to spend in cents
-
balances
final LoanTape.Balances balances()
-
created
final OffsetDateTime created()
Timestamp of when the loan tape was created
-
creditLimit
final Long creditLimit()
For prepay accounts, this is the minimum prepay balance that must be maintained. For charge card accounts, this is the maximum credit balance extended by a lender
-
creditProductToken
final String creditProductToken()
Globally unique identifier for a credit product
-
dayTotals
final StatementTotals dayTotals()
-
endingBalance
final Long endingBalance()
Balance at the end of the day
-
excessCredits
final Long excessCredits()
Excess credits in the form of provisional credits, payments, or purchase refunds. If positive, the account is in net credit state with no outstanding balances. An overpayment could land an account in this state
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for a financial account
-
interestDetails
final Optional<LoanTape.InterestDetails> interestDetails()
-
minimumPaymentBalance
final LoanTape.BalanceDetails minimumPaymentBalance()
-
paymentAllocation
final LoanTape.PaymentAllocation paymentAllocation()
-
periodTotals
final StatementTotals periodTotals()
-
previousStatementBalance
final LoanTape.BalanceDetails previousStatementBalance()
-
startingBalance
final Long startingBalance()
Balance at the start of the day
-
updated
final OffsetDateTime updated()
Timestamp of when the loan tape was updated
-
ytdTotals
final StatementTotals ytdTotals()
-
dayOfPeriod
final Optional<Long> dayOfPeriod()
Day of the billing period that this loan tape covers, starting at 1
-
eventType
final LoanTapeUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStanding
final JsonField<LoanTape.AccountStanding> _accountStanding()
Returns the raw JSON value of accountStanding.
Unlike accountStanding, this method doesn't throw if the JSON field has an unexpected type.
-
_availableCredit
final JsonField<Long> _availableCredit()
Returns the raw JSON value of availableCredit.
Unlike availableCredit, this method doesn't throw if the JSON field has an unexpected type.
-
_balances
final JsonField<LoanTape.Balances> _balances()
Returns the raw JSON value of balances.
Unlike balances, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_creditProductToken
final JsonField<String> _creditProductToken()
Returns the raw JSON value of creditProductToken.
Unlike creditProductToken, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_dayTotals
final JsonField<StatementTotals> _dayTotals()
Returns the raw JSON value of dayTotals.
Unlike dayTotals, this method doesn't throw if the JSON field has an unexpected type.
-
_endingBalance
final JsonField<Long> _endingBalance()
Returns the raw JSON value of endingBalance.
Unlike endingBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_excessCredits
final JsonField<Long> _excessCredits()
Returns the raw JSON value of excessCredits.
Unlike excessCredits, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_interestDetails
final JsonField<LoanTape.InterestDetails> _interestDetails()
Returns the raw JSON value of interestDetails.
Unlike interestDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_minimumPaymentBalance
final JsonField<LoanTape.BalanceDetails> _minimumPaymentBalance()
Returns the raw JSON value of minimumPaymentBalance.
Unlike minimumPaymentBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentAllocation
final JsonField<LoanTape.PaymentAllocation> _paymentAllocation()
Returns the raw JSON value of paymentAllocation.
Unlike paymentAllocation, this method doesn't throw if the JSON field has an unexpected type.
-
_periodTotals
final JsonField<StatementTotals> _periodTotals()
Returns the raw JSON value of periodTotals.
Unlike periodTotals, this method doesn't throw if the JSON field has an unexpected type.
-
_previousStatementBalance
final JsonField<LoanTape.BalanceDetails> _previousStatementBalance()
Returns the raw JSON value of previousStatementBalance.
Unlike previousStatementBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_startingBalance
final JsonField<Long> _startingBalance()
Returns the raw JSON value of startingBalance.
Unlike startingBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_ytdTotals
final JsonField<StatementTotals> _ytdTotals()
Returns the raw JSON value of ytdTotals.
Unlike ytdTotals, this method doesn't throw if the JSON field has an unexpected type.
-
_dayOfPeriod
final JsonField<Long> _dayOfPeriod()
Returns the raw JSON value of dayOfPeriod.
Unlike dayOfPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_tier
final JsonField<String> _tier()
Returns the raw JSON value of tier.
Unlike tier, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<LoanTapeUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LoanTapeUpdatedWebhookEvent.Builder toBuilder()
-
validate
final LoanTapeUpdatedWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LoanTapeUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of LoanTapeUpdatedWebhookEvent.
The following fields are required:
.token() .accountStanding() .availableCredit() .balances() .created() .creditLimit() .creditProductToken() .date() .dayTotals() .endingBalance() .excessCredits() .financialAccountToken() .interestDetails() .minimumPaymentBalance() .paymentAllocation() .periodTotals() .previousStatementBalance() .startingBalance() .updated() .version() .ytdTotals() .eventType()
-
-
-
-