Class LoanTapeUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class LoanTapeUpdatedWebhookEvent.BuilderA builder for LoanTapeUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final LoanTapeUpdatedWebhookEvent.Builder token(String token)
Globally unique identifier for a loan tape
-
token
final LoanTapeUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStanding
final LoanTapeUpdatedWebhookEvent.Builder accountStanding(LoanTape.AccountStanding accountStanding)
-
accountStanding
final LoanTapeUpdatedWebhookEvent.Builder accountStanding(JsonField<LoanTape.AccountStanding> accountStanding)
Sets Builder.accountStanding to an arbitrary JSON value.
You should usually call Builder.accountStanding with a well-typed LoanTape.AccountStanding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
availableCredit
final LoanTapeUpdatedWebhookEvent.Builder availableCredit(Long availableCredit)
Amount of credit available to spend in cents
-
availableCredit
final LoanTapeUpdatedWebhookEvent.Builder availableCredit(JsonField<Long> availableCredit)
Sets Builder.availableCredit to an arbitrary JSON value.
You should usually call Builder.availableCredit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balances
final LoanTapeUpdatedWebhookEvent.Builder balances(LoanTape.Balances balances)
-
balances
final LoanTapeUpdatedWebhookEvent.Builder balances(JsonField<LoanTape.Balances> balances)
Sets Builder.balances to an arbitrary JSON value.
You should usually call Builder.balances with a well-typed LoanTape.Balances value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final LoanTapeUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Timestamp of when the loan tape was created
-
created
final LoanTapeUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditLimit
final LoanTapeUpdatedWebhookEvent.Builder creditLimit(Long creditLimit)
For prepay accounts, this is the minimum prepay balance that must be maintained. For charge card accounts, this is the maximum credit balance extended by a lender
-
creditLimit
final LoanTapeUpdatedWebhookEvent.Builder creditLimit(JsonField<Long> creditLimit)
Sets Builder.creditLimit to an arbitrary JSON value.
You should usually call Builder.creditLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditProductToken
final LoanTapeUpdatedWebhookEvent.Builder creditProductToken(String creditProductToken)
Globally unique identifier for a credit product
-
creditProductToken
final LoanTapeUpdatedWebhookEvent.Builder creditProductToken(JsonField<String> creditProductToken)
Sets Builder.creditProductToken to an arbitrary JSON value.
You should usually call Builder.creditProductToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
date
final LoanTapeUpdatedWebhookEvent.Builder date(LocalDate date)
Date of transactions that this loan tape covers
-
date
final LoanTapeUpdatedWebhookEvent.Builder date(JsonField<LocalDate> date)
Sets Builder.date to an arbitrary JSON value.
You should usually call Builder.date with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dayTotals
final LoanTapeUpdatedWebhookEvent.Builder dayTotals(StatementTotals dayTotals)
-
dayTotals
final LoanTapeUpdatedWebhookEvent.Builder dayTotals(JsonField<StatementTotals> dayTotals)
Sets Builder.dayTotals to an arbitrary JSON value.
You should usually call Builder.dayTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endingBalance
final LoanTapeUpdatedWebhookEvent.Builder endingBalance(Long endingBalance)
Balance at the end of the day
-
endingBalance
final LoanTapeUpdatedWebhookEvent.Builder endingBalance(JsonField<Long> endingBalance)
Sets Builder.endingBalance to an arbitrary JSON value.
You should usually call Builder.endingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
excessCredits
final LoanTapeUpdatedWebhookEvent.Builder excessCredits(Long excessCredits)
Excess credits in the form of provisional credits, payments, or purchase refunds. If positive, the account is in net credit state with no outstanding balances. An overpayment could land an account in this state
-
excessCredits
final LoanTapeUpdatedWebhookEvent.Builder excessCredits(JsonField<Long> excessCredits)
Sets Builder.excessCredits to an arbitrary JSON value.
You should usually call Builder.excessCredits with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final LoanTapeUpdatedWebhookEvent.Builder financialAccountToken(String financialAccountToken)
Globally unique identifier for a financial account
-
financialAccountToken
final LoanTapeUpdatedWebhookEvent.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestDetails
final LoanTapeUpdatedWebhookEvent.Builder interestDetails(LoanTape.InterestDetails interestDetails)
-
interestDetails
final LoanTapeUpdatedWebhookEvent.Builder interestDetails(Optional<LoanTape.InterestDetails> interestDetails)
Alias for calling Builder.interestDetails with
interestDetails.orElse(null).
-
interestDetails
final LoanTapeUpdatedWebhookEvent.Builder interestDetails(JsonField<LoanTape.InterestDetails> interestDetails)
Sets Builder.interestDetails to an arbitrary JSON value.
You should usually call Builder.interestDetails with a well-typed LoanTape.InterestDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minimumPaymentBalance
final LoanTapeUpdatedWebhookEvent.Builder minimumPaymentBalance(LoanTape.BalanceDetails minimumPaymentBalance)
-
minimumPaymentBalance
final LoanTapeUpdatedWebhookEvent.Builder minimumPaymentBalance(JsonField<LoanTape.BalanceDetails> minimumPaymentBalance)
Sets Builder.minimumPaymentBalance to an arbitrary JSON value.
You should usually call Builder.minimumPaymentBalance with a well-typed LoanTape.BalanceDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentAllocation
final LoanTapeUpdatedWebhookEvent.Builder paymentAllocation(LoanTape.PaymentAllocation paymentAllocation)
-
paymentAllocation
final LoanTapeUpdatedWebhookEvent.Builder paymentAllocation(JsonField<LoanTape.PaymentAllocation> paymentAllocation)
Sets Builder.paymentAllocation to an arbitrary JSON value.
You should usually call Builder.paymentAllocation with a well-typed LoanTape.PaymentAllocation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodTotals
final LoanTapeUpdatedWebhookEvent.Builder periodTotals(StatementTotals periodTotals)
-
periodTotals
final LoanTapeUpdatedWebhookEvent.Builder periodTotals(JsonField<StatementTotals> periodTotals)
Sets Builder.periodTotals to an arbitrary JSON value.
You should usually call Builder.periodTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousStatementBalance
final LoanTapeUpdatedWebhookEvent.Builder previousStatementBalance(LoanTape.BalanceDetails previousStatementBalance)
-
previousStatementBalance
final LoanTapeUpdatedWebhookEvent.Builder previousStatementBalance(JsonField<LoanTape.BalanceDetails> previousStatementBalance)
Sets Builder.previousStatementBalance to an arbitrary JSON value.
You should usually call Builder.previousStatementBalance with a well-typed LoanTape.BalanceDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startingBalance
final LoanTapeUpdatedWebhookEvent.Builder startingBalance(Long startingBalance)
Balance at the start of the day
-
startingBalance
final LoanTapeUpdatedWebhookEvent.Builder startingBalance(JsonField<Long> startingBalance)
Sets Builder.startingBalance to an arbitrary JSON value.
You should usually call Builder.startingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final LoanTapeUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
Timestamp of when the loan tape was updated
-
updated
final LoanTapeUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
version
final LoanTapeUpdatedWebhookEvent.Builder version(Long version)
Version number of the loan tape. This starts at 1
-
version
final LoanTapeUpdatedWebhookEvent.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ytdTotals
final LoanTapeUpdatedWebhookEvent.Builder ytdTotals(StatementTotals ytdTotals)
-
ytdTotals
final LoanTapeUpdatedWebhookEvent.Builder ytdTotals(JsonField<StatementTotals> ytdTotals)
Sets Builder.ytdTotals to an arbitrary JSON value.
You should usually call Builder.ytdTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dayOfPeriod
final LoanTapeUpdatedWebhookEvent.Builder dayOfPeriod(Long dayOfPeriod)
Day of the billing period that this loan tape covers, starting at 1
-
dayOfPeriod
final LoanTapeUpdatedWebhookEvent.Builder dayOfPeriod(Long dayOfPeriod)
Alias for Builder.dayOfPeriod.
This unboxed primitive overload exists for backwards compatibility.
-
dayOfPeriod
final LoanTapeUpdatedWebhookEvent.Builder dayOfPeriod(Optional<Long> dayOfPeriod)
Alias for calling Builder.dayOfPeriod with
dayOfPeriod.orElse(null).
-
dayOfPeriod
final LoanTapeUpdatedWebhookEvent.Builder dayOfPeriod(JsonField<Long> dayOfPeriod)
Sets Builder.dayOfPeriod to an arbitrary JSON value.
You should usually call Builder.dayOfPeriod with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tier
final LoanTapeUpdatedWebhookEvent.Builder tier(String tier)
Interest tier to which this account belongs to
-
tier
final LoanTapeUpdatedWebhookEvent.Builder tier(Optional<String> tier)
Alias for calling Builder.tier with
tier.orElse(null).
-
tier
final LoanTapeUpdatedWebhookEvent.Builder tier(JsonField<String> tier)
Sets Builder.tier to an arbitrary JSON value.
You should usually call Builder.tier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final LoanTapeUpdatedWebhookEvent.Builder eventType(LoanTapeUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final LoanTapeUpdatedWebhookEvent.Builder eventType(JsonField<LoanTapeUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LoanTapeUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LoanTapeUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LoanTapeUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LoanTapeUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LoanTapeUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LoanTapeUpdatedWebhookEvent build()
Returns an immutable instance of LoanTapeUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountStanding() .availableCredit() .balances() .created() .creditLimit() .creditProductToken() .date() .dayTotals() .endingBalance() .excessCredits() .financialAccountToken() .interestDetails() .minimumPaymentBalance() .paymentAllocation() .periodTotals() .previousStatementBalance() .startingBalance() .updated() .version() .ytdTotals() .eventType()
-
-
-
-