Class ManagementOperationCreateParams.CreateManagementOperationRequest
-
- All Implemented Interfaces:
public final class ManagementOperationCreateParams.CreateManagementOperationRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationCreateParams.CreateManagementOperationRequest.BuilderA builder for CreateManagementOperationRequest.
-
Method Summary
-
-
Method Detail
-
category
final ManagementOperationCreateParams.ManagementOperationCategory category()
-
direction
final ManagementOperationCreateParams.ManagementOperationDirection direction()
-
effectiveDate
final LocalDate effectiveDate()
-
eventType
final ManagementOperationCreateParams.ManagementOperationEventType eventType()
-
financialAccountToken
final String financialAccountToken()
-
token
final Optional<String> token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
onClosedAccount
final Optional<ManagementOperationCreateParams.OnClosedAccount> onClosedAccount()
What to do if the financial account is closed when posting an operation
-
userDefinedId
final Optional<String> userDefinedId()
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<ManagementOperationCreateParams.ManagementOperationCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<ManagementOperationCreateParams.ManagementOperationDirection> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ManagementOperationCreateParams.ManagementOperationEventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_onClosedAccount
final JsonField<ManagementOperationCreateParams.OnClosedAccount> _onClosedAccount()
Returns the raw JSON value of onClosedAccount.
Unlike onClosedAccount, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ManagementOperationCreateParams.CreateManagementOperationRequest.Builder toBuilder()
-
validate
final ManagementOperationCreateParams.CreateManagementOperationRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ManagementOperationCreateParams.CreateManagementOperationRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateManagementOperationRequest.
The following fields are required:
.amount() .category() .direction() .effectiveDate() .eventType() .financialAccountToken()
-
-
-
-