Package com.lithic.api.models
Class ManagementOperationListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ManagementOperationListPageAsync.BuilderA builder for ManagementOperationListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ManagementOperationListPageAsync.Builderservice(ManagementOperationServiceAsync service)final ManagementOperationListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ManagementOperationListPageAsync.Builderparams(ManagementOperationListParams params)The parameters that were used to request this page. final ManagementOperationListPageAsync.Builderresponse(ManagementOperationListPageResponse response)The response that this page was parsed from. final ManagementOperationListPageAsyncbuild()Returns an immutable instance of ManagementOperationListPageAsync. -
-
Method Detail
-
service
final ManagementOperationListPageAsync.Builder service(ManagementOperationServiceAsync service)
-
streamHandlerExecutor
final ManagementOperationListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ManagementOperationListPageAsync.Builder params(ManagementOperationListParams params)
The parameters that were used to request this page.
-
response
final ManagementOperationListPageAsync.Builder response(ManagementOperationListPageResponse response)
The response that this page was parsed from.
-
build
final ManagementOperationListPageAsync build()
Returns an immutable instance of ManagementOperationListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-