Package com.lithic.api.models
Class ManagementOperationListPageResponse
-
- All Implemented Interfaces:
public final class ManagementOperationListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationListPageResponse.BuilderA builder for ManagementOperationListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<ManagementOperationTransaction>data()final BooleanhasMore()final JsonField<List<ManagementOperationTransaction>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final ManagementOperationListPageResponse.BuildertoBuilder()final ManagementOperationListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ManagementOperationListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ManagementOperationListPageResponse. -
-
Method Detail
-
data
final List<ManagementOperationTransaction> data()
-
_data
final JsonField<List<ManagementOperationTransaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ManagementOperationListPageResponse.Builder toBuilder()
-
validate
final ManagementOperationListPageResponse validate()
-
builder
final static ManagementOperationListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-