Class ManagementOperationTransaction.ManagementOperationEvent
-
- All Implemented Interfaces:
public final class ManagementOperationTransaction.ManagementOperationEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classManagementOperationTransaction.ManagementOperationEvent.BuilderA builder for ManagementOperationEvent.
public final classManagementOperationTransaction.ManagementOperationEvent.DetailedResultspublic final classManagementOperationTransaction.ManagementOperationEvent.TransactionResultpublic final classManagementOperationTransaction.ManagementOperationEvent.ManagementOperationEventType
-
Method Summary
-
-
Method Detail
-
created
final OffsetDateTime created()
-
detailedResults
final List<ManagementOperationTransaction.ManagementOperationEvent.DetailedResults> detailedResults()
-
effectiveDate
final LocalDate effectiveDate()
-
type
final ManagementOperationTransaction.ManagementOperationEvent.ManagementOperationEventType type()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_detailedResults
final JsonField<List<ManagementOperationTransaction.ManagementOperationEvent.DetailedResults>> _detailedResults()
Returns the raw JSON value of detailedResults.
Unlike detailedResults, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<ManagementOperationTransaction.ManagementOperationEvent.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ManagementOperationTransaction.ManagementOperationEvent.ManagementOperationEventType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<String> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ManagementOperationTransaction.ManagementOperationEvent.Builder toBuilder()
-
validate
final ManagementOperationTransaction.ManagementOperationEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ManagementOperationTransaction.ManagementOperationEvent.Builder builder()
Returns a mutable builder for constructing an instance of ManagementOperationEvent.
The following fields are required:
.token() .amount() .created() .detailedResults() .effectiveDate() .memo() .result() .type()
-
-
-
-