Class MerchantLockParameters.Merchant
-
- All Implemented Interfaces:
public final class MerchantLockParameters.MerchantRepresents a specific merchant lock based on their ID or descriptor. Each merchant object allows transaction rules to work at a granular level and requires at least one of merchant_id or descriptor.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMerchantLockParameters.Merchant.BuilderA builder for Merchant.
-
Method Summary
Modifier and Type Method Description final Optional<String>comment()A comment or explanation about the merchant, used internally for rule management purposes. final Optional<String>descriptor()Short description of the merchant, often used to provide more human-readable context about the transaction merchant. final Optional<String>merchantId()Unique alphanumeric identifier for the payment card acceptor (merchant). final JsonField<String>_comment()Returns the raw JSON value of comment. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_merchantId()Returns the raw JSON value of merchantId. final Map<String, JsonValue>_additionalProperties()final MerchantLockParameters.Merchant.BuildertoBuilder()final MerchantLockParameters.Merchantvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static MerchantLockParameters.Merchant.Builderbuilder()Returns a mutable builder for constructing an instance of Merchant. -
-
Method Detail
-
comment
final Optional<String> comment()
A comment or explanation about the merchant, used internally for rule management purposes.
-
descriptor
final Optional<String> descriptor()
Short description of the merchant, often used to provide more human-readable context about the transaction merchant. This is typically the name or label shown on transaction summaries.
-
merchantId
final Optional<String> merchantId()
Unique alphanumeric identifier for the payment card acceptor (merchant). This attribute specifies the merchant entity that will be locked or referenced for authorization rules.
-
_comment
final JsonField<String> _comment()
Returns the raw JSON value of comment.
Unlike comment, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantId
final JsonField<String> _merchantId()
Returns the raw JSON value of merchantId.
Unlike merchantId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final MerchantLockParameters.Merchant.Builder toBuilder()
-
validate
final MerchantLockParameters.Merchant validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static MerchantLockParameters.Merchant.Builder builder()
Returns a mutable builder for constructing an instance of Merchant.
-
-
-
-