Class MonitoringCase.Builder
-
- All Implemented Interfaces:
public final class MonitoringCase.BuilderA builder for MonitoringCase.
-
-
Method Summary
Modifier and Type Method Description final MonitoringCase.Buildertoken(String token)Globally unique identifier for the case final MonitoringCase.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final MonitoringCase.Builderassignee(String assignee)Identifier of the user the case is currently assigned to final MonitoringCase.Builderassignee(Optional<String> assignee)Alias for calling Builder.assignee with assignee.orElse(null).final MonitoringCase.Builderassignee(JsonField<String> assignee)Sets Builder.assignee to an arbitrary JSON value. final MonitoringCase.BuildercollectionStopped(OffsetDateTime collectionStopped)Date and time at which transaction collection stopped for the case final MonitoringCase.BuildercollectionStopped(Optional<OffsetDateTime> collectionStopped)Alias for calling Builder.collectionStopped with collectionStopped.orElse(null).final MonitoringCase.BuildercollectionStopped(JsonField<OffsetDateTime> collectionStopped)Sets Builder.collectionStopped to an arbitrary JSON value. final MonitoringCase.Buildercreated(OffsetDateTime created)Date and time at which the case was created final MonitoringCase.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final MonitoringCase.Builderentity(CaseEntity entity)The entity a case is associated with final MonitoringCase.Builderentity(Optional<CaseEntity> entity)Alias for calling Builder.entity with entity.orElse(null).final MonitoringCase.Builderentity(JsonField<CaseEntity> entity)Sets Builder.entity to an arbitrary JSON value. final MonitoringCase.BuilderpendingTransactions(Boolean pendingTransactions)Whether the case still has transaction scopes pending resolution final MonitoringCase.BuilderpendingTransactions(JsonField<Boolean> pendingTransactions)Sets Builder.pendingTransactions to an arbitrary JSON value. final MonitoringCase.Builderpriority(CasePriority priority)Priority level of a case, controlling queue ordering and SLA urgency final MonitoringCase.Builderpriority(JsonField<CasePriority> priority)Sets Builder.priority to an arbitrary JSON value. final MonitoringCase.BuilderqueueToken(String queueToken)Token of the queue the case belongs to final MonitoringCase.BuilderqueueToken(JsonField<String> queueToken)Sets Builder.queueToken to an arbitrary JSON value. final MonitoringCase.Builderresolution(ResolutionOutcome resolution)Outcome recorded when a case is resolved: CONFIRMED_FRAUD- The reviewed activity was confirmed to be fraudulentSUSPICIOUS_ACTIVITY- The activity is suspicious but not confirmed fraudFALSE_POSITIVE- The activity was legitimate and the alert was a false positiveNO_ACTION_REQUIRED- No further action is requiredESCALATED_EXTERNAL- The case was escalated to an external party
final MonitoringCase.Builderresolution(Optional<ResolutionOutcome> resolution)Alias for calling Builder.resolution with resolution.orElse(null).final MonitoringCase.Builderresolution(JsonField<ResolutionOutcome> resolution)Sets Builder.resolution to an arbitrary JSON value. final MonitoringCase.BuilderresolutionNotes(String resolutionNotes)Free-form notes describing the resolution final MonitoringCase.BuilderresolutionNotes(Optional<String> resolutionNotes)Alias for calling Builder.resolutionNotes with resolutionNotes.orElse(null).final MonitoringCase.BuilderresolutionNotes(JsonField<String> resolutionNotes)Sets Builder.resolutionNotes to an arbitrary JSON value. final MonitoringCase.Builderresolved(OffsetDateTime resolved)Date and time at which the case was resolved final MonitoringCase.Builderresolved(Optional<OffsetDateTime> resolved)Alias for calling Builder.resolved with resolved.orElse(null).final MonitoringCase.Builderresolved(JsonField<OffsetDateTime> resolved)Sets Builder.resolved to an arbitrary JSON value. final MonitoringCase.BuilderruleToken(String ruleToken)Token of the transaction monitoring rule that triggered the case final MonitoringCase.BuilderruleToken(Optional<String> ruleToken)Alias for calling Builder.ruleToken with ruleToken.orElse(null).final MonitoringCase.BuilderruleToken(JsonField<String> ruleToken)Sets Builder.ruleToken to an arbitrary JSON value. final MonitoringCase.BuilderslaDeadline(OffsetDateTime slaDeadline)Deadline by which the case is expected to be resolved final MonitoringCase.BuilderslaDeadline(Optional<OffsetDateTime> slaDeadline)Alias for calling Builder.slaDeadline with slaDeadline.orElse(null).final MonitoringCase.BuilderslaDeadline(JsonField<OffsetDateTime> slaDeadline)Sets Builder.slaDeadline to an arbitrary JSON value. final MonitoringCase.Builderstatus(CaseStatus status)Status of a case as it progresses through the review workflow: OPEN- The case has been created and is still collecting matching transactionsASSIGNED- An analyst has been assigned and transaction collection has stoppedIN_REVIEW- The case is actively being investigatedESCALATED- The case has been reviewed and requires additional oversightRESOLVED- A determination has been made and a resolution recordedCLOSED- The case is finalized
final MonitoringCase.Builderstatus(JsonField<CaseStatus> status)Sets Builder.status to an arbitrary JSON value. final MonitoringCase.Buildertags(MonitoringCase.Tags tags)Arbitrary key-value metadata associated with the case final MonitoringCase.Buildertags(JsonField<MonitoringCase.Tags> tags)Sets Builder.tags to an arbitrary JSON value. final MonitoringCase.Buildertitle(String title)Short, human-readable summary of the case final MonitoringCase.Buildertitle(Optional<String> title)Alias for calling Builder.title with title.orElse(null).final MonitoringCase.Buildertitle(JsonField<String> title)Sets Builder.title to an arbitrary JSON value. final MonitoringCase.Builderupdated(OffsetDateTime updated)Date and time at which the case was last updated final MonitoringCase.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final MonitoringCase.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final MonitoringCase.BuilderputAdditionalProperty(String key, JsonValue value)final MonitoringCase.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final MonitoringCase.BuilderremoveAdditionalProperty(String key)final MonitoringCase.BuilderremoveAllAdditionalProperties(Set<String> keys)final MonitoringCasebuild()Returns an immutable instance of MonitoringCase. -
-
Method Detail
-
token
final MonitoringCase.Builder token(String token)
Globally unique identifier for the case
-
token
final MonitoringCase.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
assignee
final MonitoringCase.Builder assignee(String assignee)
Identifier of the user the case is currently assigned to
-
assignee
final MonitoringCase.Builder assignee(Optional<String> assignee)
Alias for calling Builder.assignee with
assignee.orElse(null).
-
assignee
final MonitoringCase.Builder assignee(JsonField<String> assignee)
Sets Builder.assignee to an arbitrary JSON value.
You should usually call Builder.assignee with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
collectionStopped
final MonitoringCase.Builder collectionStopped(OffsetDateTime collectionStopped)
Date and time at which transaction collection stopped for the case
-
collectionStopped
final MonitoringCase.Builder collectionStopped(Optional<OffsetDateTime> collectionStopped)
Alias for calling Builder.collectionStopped with
collectionStopped.orElse(null).
-
collectionStopped
final MonitoringCase.Builder collectionStopped(JsonField<OffsetDateTime> collectionStopped)
Sets Builder.collectionStopped to an arbitrary JSON value.
You should usually call Builder.collectionStopped with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final MonitoringCase.Builder created(OffsetDateTime created)
Date and time at which the case was created
-
created
final MonitoringCase.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entity
final MonitoringCase.Builder entity(CaseEntity entity)
The entity a case is associated with
-
entity
final MonitoringCase.Builder entity(Optional<CaseEntity> entity)
Alias for calling Builder.entity with
entity.orElse(null).
-
entity
final MonitoringCase.Builder entity(JsonField<CaseEntity> entity)
Sets Builder.entity to an arbitrary JSON value.
You should usually call Builder.entity with a well-typed CaseEntity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactions
final MonitoringCase.Builder pendingTransactions(Boolean pendingTransactions)
Whether the case still has transaction scopes pending resolution
-
pendingTransactions
final MonitoringCase.Builder pendingTransactions(JsonField<Boolean> pendingTransactions)
Sets Builder.pendingTransactions to an arbitrary JSON value.
You should usually call Builder.pendingTransactions with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priority
final MonitoringCase.Builder priority(CasePriority priority)
Priority level of a case, controlling queue ordering and SLA urgency
-
priority
final MonitoringCase.Builder priority(JsonField<CasePriority> priority)
Sets Builder.priority to an arbitrary JSON value.
You should usually call Builder.priority with a well-typed CasePriority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
queueToken
final MonitoringCase.Builder queueToken(String queueToken)
Token of the queue the case belongs to
-
queueToken
final MonitoringCase.Builder queueToken(JsonField<String> queueToken)
Sets Builder.queueToken to an arbitrary JSON value.
You should usually call Builder.queueToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolution
final MonitoringCase.Builder resolution(ResolutionOutcome resolution)
Outcome recorded when a case is resolved:
CONFIRMED_FRAUD- The reviewed activity was confirmed to be fraudulentSUSPICIOUS_ACTIVITY- The activity is suspicious but not confirmed fraudFALSE_POSITIVE- The activity was legitimate and the alert was a false positiveNO_ACTION_REQUIRED- No further action is requiredESCALATED_EXTERNAL- The case was escalated to an external party
-
resolution
final MonitoringCase.Builder resolution(Optional<ResolutionOutcome> resolution)
Alias for calling Builder.resolution with
resolution.orElse(null).
-
resolution
final MonitoringCase.Builder resolution(JsonField<ResolutionOutcome> resolution)
Sets Builder.resolution to an arbitrary JSON value.
You should usually call Builder.resolution with a well-typed ResolutionOutcome value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolutionNotes
final MonitoringCase.Builder resolutionNotes(String resolutionNotes)
Free-form notes describing the resolution
-
resolutionNotes
final MonitoringCase.Builder resolutionNotes(Optional<String> resolutionNotes)
Alias for calling Builder.resolutionNotes with
resolutionNotes.orElse(null).
-
resolutionNotes
final MonitoringCase.Builder resolutionNotes(JsonField<String> resolutionNotes)
Sets Builder.resolutionNotes to an arbitrary JSON value.
You should usually call Builder.resolutionNotes with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolved
final MonitoringCase.Builder resolved(OffsetDateTime resolved)
Date and time at which the case was resolved
-
resolved
final MonitoringCase.Builder resolved(Optional<OffsetDateTime> resolved)
Alias for calling Builder.resolved with
resolved.orElse(null).
-
resolved
final MonitoringCase.Builder resolved(JsonField<OffsetDateTime> resolved)
Sets Builder.resolved to an arbitrary JSON value.
You should usually call Builder.resolved with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ruleToken
final MonitoringCase.Builder ruleToken(String ruleToken)
Token of the transaction monitoring rule that triggered the case
-
ruleToken
final MonitoringCase.Builder ruleToken(Optional<String> ruleToken)
Alias for calling Builder.ruleToken with
ruleToken.orElse(null).
-
ruleToken
final MonitoringCase.Builder ruleToken(JsonField<String> ruleToken)
Sets Builder.ruleToken to an arbitrary JSON value.
You should usually call Builder.ruleToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
slaDeadline
final MonitoringCase.Builder slaDeadline(OffsetDateTime slaDeadline)
Deadline by which the case is expected to be resolved
-
slaDeadline
final MonitoringCase.Builder slaDeadline(Optional<OffsetDateTime> slaDeadline)
Alias for calling Builder.slaDeadline with
slaDeadline.orElse(null).
-
slaDeadline
final MonitoringCase.Builder slaDeadline(JsonField<OffsetDateTime> slaDeadline)
Sets Builder.slaDeadline to an arbitrary JSON value.
You should usually call Builder.slaDeadline with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final MonitoringCase.Builder status(CaseStatus status)
Status of a case as it progresses through the review workflow:
OPEN- The case has been created and is still collecting matching transactionsASSIGNED- An analyst has been assigned and transaction collection has stoppedIN_REVIEW- The case is actively being investigatedESCALATED- The case has been reviewed and requires additional oversightRESOLVED- A determination has been made and a resolution recordedCLOSED- The case is finalized
-
status
final MonitoringCase.Builder status(JsonField<CaseStatus> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed CaseStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final MonitoringCase.Builder tags(MonitoringCase.Tags tags)
Arbitrary key-value metadata associated with the case
-
tags
final MonitoringCase.Builder tags(JsonField<MonitoringCase.Tags> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed Tags value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
title
final MonitoringCase.Builder title(String title)
Short, human-readable summary of the case
-
title
final MonitoringCase.Builder title(Optional<String> title)
Alias for calling Builder.title with
title.orElse(null).
-
title
final MonitoringCase.Builder title(JsonField<String> title)
Sets Builder.title to an arbitrary JSON value.
You should usually call Builder.title with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final MonitoringCase.Builder updated(OffsetDateTime updated)
Date and time at which the case was last updated
-
updated
final MonitoringCase.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final MonitoringCase.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final MonitoringCase.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final MonitoringCase.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final MonitoringCase.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final MonitoringCase.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final MonitoringCase build()
Returns an immutable instance of MonitoringCase.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .assignee() .collectionStopped() .created() .entity() .pendingTransactions() .priority() .queueToken() .resolution() .resolutionNotes() .resolved() .ruleToken() .slaDeadline() .status() .tags() .title() .updated()
-
-
-