Class NetworkProgram
-
- All Implemented Interfaces:
public final class NetworkProgram
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNetworkProgram.BuilderA builder for NetworkProgram.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Lithic-generated unique identifier for the program final StringdefaultProductCode()Network product ID associated with this program. final Stringname()The name of the network program. final StringregisteredProgramIdentificationNumber()RPIN value assigned by the network. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_defaultProductCode()Returns the raw JSON value of defaultProductCode. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_registeredProgramIdentificationNumber()Returns the raw JSON value of registeredProgramIdentificationNumber. final Map<String, JsonValue>_additionalProperties()final NetworkProgram.BuildertoBuilder()final NetworkProgramvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NetworkProgram.Builderbuilder()Returns a mutable builder for constructing an instance of NetworkProgram. -
-
Method Detail
-
defaultProductCode
final String defaultProductCode()
Network product ID associated with this program.
-
registeredProgramIdentificationNumber
final String registeredProgramIdentificationNumber()
RPIN value assigned by the network.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_defaultProductCode
final JsonField<String> _defaultProductCode()
Returns the raw JSON value of defaultProductCode.
Unlike defaultProductCode, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_registeredProgramIdentificationNumber
final JsonField<String> _registeredProgramIdentificationNumber()
Returns the raw JSON value of registeredProgramIdentificationNumber.
Unlike registeredProgramIdentificationNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NetworkProgram.Builder toBuilder()
-
validate
final NetworkProgram validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NetworkProgram.Builder builder()
Returns a mutable builder for constructing an instance of NetworkProgram.
The following fields are required:
.token() .defaultProductCode() .name() .registeredProgramIdentificationNumber()
-
-
-
-