Class NetworkTotal.Amounts
-
- All Implemented Interfaces:
public final class NetworkTotal.Amounts
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNetworkTotal.Amounts.BuilderA builder for Amounts.
-
Method Summary
Modifier and Type Method Description final LonggrossSettlement()Total settlement amount excluding interchange, in currency's smallest unit. final LonginterchangeFees()Interchange amount, in currency's smallest unit. final LongnetSettlement()gross_settlementnet ofinterchange_feesandvisa_charges(if applicable), in currency's smallest unit.final Optional<Long>visaCharges()Charges specific to Visa/Interlink, in currency's smallest unit. final JsonField<Long>_grossSettlement()Returns the raw JSON value of grossSettlement. final JsonField<Long>_interchangeFees()Returns the raw JSON value of interchangeFees. final JsonField<Long>_netSettlement()Returns the raw JSON value of netSettlement. final JsonField<Long>_visaCharges()Returns the raw JSON value of visaCharges. final Map<String, JsonValue>_additionalProperties()final NetworkTotal.Amounts.BuildertoBuilder()final NetworkTotal.Amountsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NetworkTotal.Amounts.Builderbuilder()Returns a mutable builder for constructing an instance of Amounts. -
-
Method Detail
-
grossSettlement
final Long grossSettlement()
Total settlement amount excluding interchange, in currency's smallest unit.
-
interchangeFees
final Long interchangeFees()
Interchange amount, in currency's smallest unit.
-
netSettlement
final Long netSettlement()
gross_settlementnet ofinterchange_feesandvisa_charges(if applicable), in currency's smallest unit.
-
visaCharges
final Optional<Long> visaCharges()
Charges specific to Visa/Interlink, in currency's smallest unit.
-
_grossSettlement
final JsonField<Long> _grossSettlement()
Returns the raw JSON value of grossSettlement.
Unlike grossSettlement, this method doesn't throw if the JSON field has an unexpected type.
-
_interchangeFees
final JsonField<Long> _interchangeFees()
Returns the raw JSON value of interchangeFees.
Unlike interchangeFees, this method doesn't throw if the JSON field has an unexpected type.
-
_netSettlement
final JsonField<Long> _netSettlement()
Returns the raw JSON value of netSettlement.
Unlike netSettlement, this method doesn't throw if the JSON field has an unexpected type.
-
_visaCharges
final JsonField<Long> _visaCharges()
Returns the raw JSON value of visaCharges.
Unlike visaCharges, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NetworkTotal.Amounts.Builder toBuilder()
-
validate
final NetworkTotal.Amounts validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NetworkTotal.Amounts.Builder builder()
Returns a mutable builder for constructing an instance of Amounts.
The following fields are required:
.grossSettlement() .interchangeFees() .netSettlement()
-
-
-
-