Class NetworkTotal.Builder
-
- All Implemented Interfaces:
public final class NetworkTotal.BuilderA builder for NetworkTotal.
-
-
Method Summary
Modifier and Type Method Description final NetworkTotal.Buildertoken(String token)Globally unique identifier. final NetworkTotal.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final NetworkTotal.Builderamounts(NetworkTotal.Amounts amounts)final NetworkTotal.Builderamounts(JsonField<NetworkTotal.Amounts> amounts)Sets Builder.amounts to an arbitrary JSON value. final NetworkTotal.Buildercreated(OffsetDateTime created)RFC 3339 timestamp for when the record was created. final NetworkTotal.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final NetworkTotal.Buildercurrency(String currency)3-character alphabetic ISO 4217 code. final NetworkTotal.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final NetworkTotal.BuilderinstitutionId(String institutionId)The institution that activity occurred on. final NetworkTotal.BuilderinstitutionId(JsonField<String> institutionId)Sets Builder.institutionId to an arbitrary JSON value. final NetworkTotal.BuilderisComplete(Boolean isComplete)Indicates that all settlement records related to this Network Total are available in the details endpoint. final NetworkTotal.BuilderisComplete(JsonField<Boolean> isComplete)Sets Builder.isComplete to an arbitrary JSON value. final NetworkTotal.Buildernetwork(NetworkTotal.Network network)Card network where the transaction took place. final NetworkTotal.Buildernetwork(JsonField<NetworkTotal.Network> network)Sets Builder.network to an arbitrary JSON value. final NetworkTotal.BuilderreportDate(LocalDate reportDate)Date that the network total record applies to. final NetworkTotal.BuilderreportDate(JsonField<LocalDate> reportDate)Sets Builder.reportDate to an arbitrary JSON value. final NetworkTotal.BuildersettlementInstitutionId(String settlementInstitutionId)The institution responsible for settlement. final NetworkTotal.BuildersettlementInstitutionId(JsonField<String> settlementInstitutionId)Sets Builder.settlementInstitutionId to an arbitrary JSON value. final NetworkTotal.BuildersettlementService(String settlementService)Settlement service. final NetworkTotal.BuildersettlementService(JsonField<String> settlementService)Sets Builder.settlementService to an arbitrary JSON value. final NetworkTotal.Builderupdated(OffsetDateTime updated)RFC 3339 timestamp for when the record was last updated. final NetworkTotal.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final NetworkTotal.Buildercycle(Long cycle)The clearing cycle that the network total record applies to. final NetworkTotal.Buildercycle(JsonField<Long> cycle)Sets Builder.cycle to an arbitrary JSON value. final NetworkTotal.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final NetworkTotal.BuilderputAdditionalProperty(String key, JsonValue value)final NetworkTotal.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final NetworkTotal.BuilderremoveAdditionalProperty(String key)final NetworkTotal.BuilderremoveAllAdditionalProperties(Set<String> keys)final NetworkTotalbuild()Returns an immutable instance of NetworkTotal. -
-
Method Detail
-
token
final NetworkTotal.Builder token(String token)
Globally unique identifier.
-
token
final NetworkTotal.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amounts
final NetworkTotal.Builder amounts(NetworkTotal.Amounts amounts)
-
amounts
final NetworkTotal.Builder amounts(JsonField<NetworkTotal.Amounts> amounts)
Sets Builder.amounts to an arbitrary JSON value.
You should usually call Builder.amounts with a well-typed Amounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final NetworkTotal.Builder created(OffsetDateTime created)
RFC 3339 timestamp for when the record was created. UTC time zone.
-
created
final NetworkTotal.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final NetworkTotal.Builder currency(String currency)
3-character alphabetic ISO 4217 code.
-
currency
final NetworkTotal.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
institutionId
final NetworkTotal.Builder institutionId(String institutionId)
The institution that activity occurred on. For Mastercard: ICA (Interbank Card Association). For Maestro: institution ID. For Visa: lowest level SRE (Settlement Reporting Entity).
-
institutionId
final NetworkTotal.Builder institutionId(JsonField<String> institutionId)
Sets Builder.institutionId to an arbitrary JSON value.
You should usually call Builder.institutionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isComplete
final NetworkTotal.Builder isComplete(Boolean isComplete)
Indicates that all settlement records related to this Network Total are available in the details endpoint.
-
isComplete
final NetworkTotal.Builder isComplete(JsonField<Boolean> isComplete)
Sets Builder.isComplete to an arbitrary JSON value.
You should usually call Builder.isComplete with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final NetworkTotal.Builder network(NetworkTotal.Network network)
Card network where the transaction took place. AMEX, VISA, MASTERCARD, MAESTRO, or INTERLINK.
-
network
final NetworkTotal.Builder network(JsonField<NetworkTotal.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reportDate
final NetworkTotal.Builder reportDate(LocalDate reportDate)
Date that the network total record applies to. YYYY-MM-DD format.
-
reportDate
final NetworkTotal.Builder reportDate(JsonField<LocalDate> reportDate)
Sets Builder.reportDate to an arbitrary JSON value.
You should usually call Builder.reportDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlementInstitutionId
final NetworkTotal.Builder settlementInstitutionId(String settlementInstitutionId)
The institution responsible for settlement. For Mastercard: same as
institution_id. For Maestro: billing ICA. For Visa: Funds Transfer SRE (FTSRE).
-
settlementInstitutionId
final NetworkTotal.Builder settlementInstitutionId(JsonField<String> settlementInstitutionId)
Sets Builder.settlementInstitutionId to an arbitrary JSON value.
You should usually call Builder.settlementInstitutionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlementService
final NetworkTotal.Builder settlementService(String settlementService)
Settlement service.
-
settlementService
final NetworkTotal.Builder settlementService(JsonField<String> settlementService)
Sets Builder.settlementService to an arbitrary JSON value.
You should usually call Builder.settlementService with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final NetworkTotal.Builder updated(OffsetDateTime updated)
RFC 3339 timestamp for when the record was last updated. UTC time zone.
-
updated
final NetworkTotal.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cycle
final NetworkTotal.Builder cycle(Long cycle)
The clearing cycle that the network total record applies to. Mastercard only.
-
cycle
final NetworkTotal.Builder cycle(JsonField<Long> cycle)
Sets Builder.cycle to an arbitrary JSON value.
You should usually call Builder.cycle with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final NetworkTotal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final NetworkTotal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final NetworkTotal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final NetworkTotal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final NetworkTotal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final NetworkTotal build()
Returns an immutable instance of NetworkTotal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .amounts() .created() .currency() .institutionId() .isComplete() .network() .reportDate() .settlementInstitutionId() .settlementService() .updated()
-
-
-
-