Class NetworkTotalUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class NetworkTotalUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNetworkTotalUpdatedWebhookEvent.BuilderA builder for NetworkTotalUpdatedWebhookEvent.
public final classNetworkTotalUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final NetworkTotaltoNetworkTotal()final Stringtoken()Globally unique identifier. final NetworkTotal.Amountsamounts()final OffsetDateTimecreated()RFC 3339 timestamp for when the record was created. final Stringcurrency()3-character alphabetic ISO 4217 code. final StringinstitutionId()The institution that activity occurred on. final BooleanisComplete()Indicates that all settlement records related to this Network Total are available in the details endpoint. final NetworkTotal.Networknetwork()Card network where the transaction took place. final LocalDatereportDate()Date that the network total record applies to. final StringsettlementInstitutionId()The institution responsible for settlement. final StringsettlementService()Settlement service. final OffsetDateTimeupdated()RFC 3339 timestamp for when the record was last updated. final Optional<Long>cycle()The clearing cycle that the network total record applies to. final NetworkTotalUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<NetworkTotal.Amounts>_amounts()Returns the raw JSON value of amounts. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_institutionId()Returns the raw JSON value of institutionId. final JsonField<Boolean>_isComplete()Returns the raw JSON value of isComplete. final JsonField<NetworkTotal.Network>_network()Returns the raw JSON value of network. final JsonField<LocalDate>_reportDate()Returns the raw JSON value of reportDate. final JsonField<String>_settlementInstitutionId()Returns the raw JSON value of settlementInstitutionId. final JsonField<String>_settlementService()Returns the raw JSON value of settlementService. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<Long>_cycle()Returns the raw JSON value of cycle. final JsonField<NetworkTotalUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final NetworkTotalUpdatedWebhookEvent.BuildertoBuilder()final NetworkTotalUpdatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NetworkTotalUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of NetworkTotalUpdatedWebhookEvent. -
-
Method Detail
-
toNetworkTotal
final NetworkTotal toNetworkTotal()
-
amounts
final NetworkTotal.Amounts amounts()
-
created
final OffsetDateTime created()
RFC 3339 timestamp for when the record was created. UTC time zone.
-
institutionId
final String institutionId()
The institution that activity occurred on. For Mastercard: ICA (Interbank Card Association). For Maestro: institution ID. For Visa: lowest level SRE (Settlement Reporting Entity).
-
isComplete
final Boolean isComplete()
Indicates that all settlement records related to this Network Total are available in the details endpoint.
-
network
final NetworkTotal.Network network()
Card network where the transaction took place. AMEX, VISA, MASTERCARD, MAESTRO, or INTERLINK.
-
reportDate
final LocalDate reportDate()
Date that the network total record applies to. YYYY-MM-DD format.
-
settlementInstitutionId
final String settlementInstitutionId()
The institution responsible for settlement. For Mastercard: same as
institution_id. For Maestro: billing ICA. For Visa: Funds Transfer SRE (FTSRE).
-
settlementService
final String settlementService()
Settlement service.
-
updated
final OffsetDateTime updated()
RFC 3339 timestamp for when the record was last updated. UTC time zone.
-
cycle
final Optional<Long> cycle()
The clearing cycle that the network total record applies to. Mastercard only.
-
eventType
final NetworkTotalUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amounts
final JsonField<NetworkTotal.Amounts> _amounts()
Returns the raw JSON value of amounts.
Unlike amounts, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_institutionId
final JsonField<String> _institutionId()
Returns the raw JSON value of institutionId.
Unlike institutionId, this method doesn't throw if the JSON field has an unexpected type.
-
_isComplete
final JsonField<Boolean> _isComplete()
Returns the raw JSON value of isComplete.
Unlike isComplete, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<NetworkTotal.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_reportDate
final JsonField<LocalDate> _reportDate()
Returns the raw JSON value of reportDate.
Unlike reportDate, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementInstitutionId
final JsonField<String> _settlementInstitutionId()
Returns the raw JSON value of settlementInstitutionId.
Unlike settlementInstitutionId, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementService
final JsonField<String> _settlementService()
Returns the raw JSON value of settlementService.
Unlike settlementService, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_cycle
final JsonField<Long> _cycle()
Returns the raw JSON value of cycle.
Unlike cycle, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<NetworkTotalUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NetworkTotalUpdatedWebhookEvent.Builder toBuilder()
-
validate
final NetworkTotalUpdatedWebhookEvent validate()
-
builder
final static NetworkTotalUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of NetworkTotalUpdatedWebhookEvent.
The following fields are required:
.token() .amounts() .created() .currency() .institutionId() .isComplete() .network() .reportDate() .settlementInstitutionId() .settlementService() .updated() .eventType()
-
-
-
-