Class NonPciCard.FundingAccount
-
- All Implemented Interfaces:
public final class NonPciCard.FundingAccountFunding account for a card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNonPciCard.FundingAccount.BuilderA builder for FundingAccount.
public final classNonPciCard.FundingAccount.StateState of funding source. Funding source states: *
ENABLED- The funding account is available to use for card creation and transactions. *PENDING- The funding account is still being verified e.g. bank micro-deposits verification. *DELETED- The founding account has been deleted.public final classNonPciCard.FundingAccount.TypeTypes of funding source: *
DEPOSITORY_CHECKING- Bank checking account. *DEPOSITORY_SAVINGS- Bank savings account.
-
Method Summary
Modifier and Type Method Description final Stringtoken()A globally unique identifier for this FundingAccount. final OffsetDateTimecreated()An RFC 3339 string representing when this funding source was added to the Lithic account. final StringlastFour()The last 4 digits of the account (e.g. final NonPciCard.FundingAccount.Statestate()State of funding source. final NonPciCard.FundingAccount.Typetype()Types of funding source: * DEPOSITORY_CHECKING- Bank checking account.final Optional<String>accountName()Account name identifying the funding source. final Optional<String>nickname()The nickname given to the FundingAccountornullif it has no nickname.final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_lastFour()Returns the raw JSON value of lastFour. final JsonField<NonPciCard.FundingAccount.State>_state()Returns the raw JSON value of state. final JsonField<NonPciCard.FundingAccount.Type>_type()Returns the raw JSON value of type. final JsonField<String>_accountName()Returns the raw JSON value of accountName. final JsonField<String>_nickname()Returns the raw JSON value of nickname. final Map<String, JsonValue>_additionalProperties()final NonPciCard.FundingAccount.BuildertoBuilder()final NonPciCard.FundingAccountvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NonPciCard.FundingAccount.Builderbuilder()Returns a mutable builder for constructing an instance of FundingAccount. -
-
Method Detail
-
created
final OffsetDateTime created()
An RFC 3339 string representing when this funding source was added to the Lithic account. This may be
null. UTC time zone.
-
lastFour
final String lastFour()
The last 4 digits of the account (e.g. bank account, debit card) associated with this FundingAccount. This may be null.
-
state
final NonPciCard.FundingAccount.State state()
State of funding source. Funding source states: *
ENABLED- The funding account is available to use for card creation and transactions. *PENDING- The funding account is still being verified e.g. bank micro-deposits verification. *DELETED- The founding account has been deleted.
-
type
final NonPciCard.FundingAccount.Type type()
Types of funding source: *
DEPOSITORY_CHECKING- Bank checking account. *DEPOSITORY_SAVINGS- Bank savings account.
-
accountName
final Optional<String> accountName()
Account name identifying the funding source. This may be
null.
-
nickname
final Optional<String> nickname()
The nickname given to the
FundingAccountornullif it has no nickname.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_lastFour
final JsonField<String> _lastFour()
Returns the raw JSON value of lastFour.
Unlike lastFour, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<NonPciCard.FundingAccount.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<NonPciCard.FundingAccount.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_accountName
final JsonField<String> _accountName()
Returns the raw JSON value of accountName.
Unlike accountName, this method doesn't throw if the JSON field has an unexpected type.
-
_nickname
final JsonField<String> _nickname()
Returns the raw JSON value of nickname.
Unlike nickname, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final NonPciCard.FundingAccount.Builder toBuilder()
-
validate
final NonPciCard.FundingAccount validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static NonPciCard.FundingAccount.Builder builder()
Returns a mutable builder for constructing an instance of FundingAccount.
The following fields are required:
.token() .created() .lastFour() .state() .type()
-
-
-
-