Class NonPciCard.Substatus
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class NonPciCard.Substatus implements EnumCard state substatus values: *
LOST- The physical card is no longer in the cardholder's possession due to being lost or never received by the cardholder. *COMPROMISED- Card information has been exposed, potentially leading to unauthorized access. This may involve physical card theft, cloning, or online data breaches. *DAMAGED- The physical card is not functioning properly, such as having chip failures or a demagnetized magnetic stripe. *END_USER_REQUEST- The cardholder requested the closure of the card for reasons unrelated to fraud or damage, such as switching to a different product or closing the account. *ISSUER_REQUEST- The issuer closed the card for reasons unrelated to fraud or damage, such as account inactivity, product or policy changes, or technology upgrades. *NOT_ACTIVE- The card hasn’t had any transaction activity for a specified period, applicable to statuses likePAUSEDorCLOSED. *SUSPICIOUS_ACTIVITY- The card has one or more suspicious transactions or activities that require review. This can involve prompting the cardholder to confirm legitimate use or report confirmed fraud. *INTERNAL_REVIEW- The card is temporarily paused pending further internal review. *EXPIRED- The card has expired and has been closed without being reissued. *UNDELIVERABLE- The card cannot be delivered to the cardholder and has been returned. *OTHER- The reason for the status does not fall into any of the above categories. A comment can be provided to specify the reason.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumNonPciCard.Substatus.KnownAn enum containing Substatus's known values.
public enumNonPciCard.Substatus.ValueAn enum containing Substatus's known values, as well as an _UNKNOWN member.
An instance of Substatus can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static NonPciCard.SubstatusLOSTpublic final static NonPciCard.SubstatusCOMPROMISEDpublic final static NonPciCard.SubstatusDAMAGEDpublic final static NonPciCard.SubstatusEND_USER_REQUESTpublic final static NonPciCard.SubstatusISSUER_REQUESTpublic final static NonPciCard.SubstatusNOT_ACTIVEpublic final static NonPciCard.SubstatusSUSPICIOUS_ACTIVITYpublic final static NonPciCard.SubstatusINTERNAL_REVIEWpublic final static NonPciCard.SubstatusEXPIREDpublic final static NonPciCard.SubstatusUNDELIVERABLEpublic final static NonPciCard.SubstatusOTHER
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final NonPciCard.Substatus.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final NonPciCard.Substatus.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final NonPciCard.Substatusvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static NonPciCard.Substatusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final NonPciCard.Substatus.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final NonPciCard.Substatus.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final NonPciCard.Substatus validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static NonPciCard.Substatus of(String value)
-
-
-
-