Class ParsedWebhookEvent.KybPayload
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.KybPayloadKYB payload for an updated account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classParsedWebhookEvent.KybPayload.BuilderA builder for KybPayload.
public final classParsedWebhookEvent.KybPayload.UpdateRequestOriginal request to update the account holder.
public final classParsedWebhookEvent.KybPayload.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final Stringtoken()The token of the account_holder that was created. final ParsedWebhookEvent.KybPayload.UpdateRequestupdateRequest()Original request to update the account holder. final Optional<ParsedWebhookEvent.KybPayload.EventType>eventType()The type of event that occurred. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final Optional<String>naicsCode()6-digit North American Industry Classification System (NAICS) code for the business. final Optional<String>natureOfBusiness()Short description of the company's line of business (i.e., what does the company do?). final Optional<String>websiteUrl()Company website URL. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<ParsedWebhookEvent.KybPayload.UpdateRequest>_updateRequest()Returns the raw JSON value of updateRequest. final JsonField<ParsedWebhookEvent.KybPayload.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<String>_naicsCode()Returns the raw JSON value of naicsCode. final JsonField<String>_natureOfBusiness()Returns the raw JSON value of natureOfBusiness. final JsonField<String>_websiteUrl()Returns the raw JSON value of websiteUrl. final Map<String, JsonValue>_additionalProperties()final ParsedWebhookEvent.KybPayload.BuildertoBuilder()final ParsedWebhookEvent.KybPayloadvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ParsedWebhookEvent.KybPayload.Builderbuilder()Returns a mutable builder for constructing an instance of KybPayload. -
-
Method Detail
-
updateRequest
final ParsedWebhookEvent.KybPayload.UpdateRequest updateRequest()
Original request to update the account holder.
-
eventType
final Optional<ParsedWebhookEvent.KybPayload.EventType> eventType()
The type of event that occurred.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
naicsCode
final Optional<String> naicsCode()
6-digit North American Industry Classification System (NAICS) code for the business. Only present if naics_code was included in the update request.
-
natureOfBusiness
final Optional<String> natureOfBusiness()
Short description of the company's line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification
-
websiteUrl
final Optional<String> websiteUrl()
Company website URL.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_updateRequest
final JsonField<ParsedWebhookEvent.KybPayload.UpdateRequest> _updateRequest()
Returns the raw JSON value of updateRequest.
Unlike updateRequest, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ParsedWebhookEvent.KybPayload.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_naicsCode
final JsonField<String> _naicsCode()
Returns the raw JSON value of naicsCode.
Unlike naicsCode, this method doesn't throw if the JSON field has an unexpected type.
-
_natureOfBusiness
final JsonField<String> _natureOfBusiness()
Returns the raw JSON value of natureOfBusiness.
Unlike natureOfBusiness, this method doesn't throw if the JSON field has an unexpected type.
-
_websiteUrl
final JsonField<String> _websiteUrl()
Returns the raw JSON value of websiteUrl.
Unlike websiteUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ParsedWebhookEvent.KybPayload.Builder toBuilder()
-
validate
final ParsedWebhookEvent.KybPayload validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ParsedWebhookEvent.KybPayload.Builder builder()
Returns a mutable builder for constructing an instance of KybPayload.
The following fields are required:
.token() .updateRequest()
-
-
-
-