Class ParsedWebhookEvent.KybPayload.Builder
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.KybPayload.BuilderA builder for KybPayload.
-
-
Method Summary
-
-
Method Detail
-
token
final ParsedWebhookEvent.KybPayload.Builder token(String token)
The token of the account_holder that was created.
-
token
final ParsedWebhookEvent.KybPayload.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updateRequest
final ParsedWebhookEvent.KybPayload.Builder updateRequest(ParsedWebhookEvent.KybPayload.UpdateRequest updateRequest)
Original request to update the account holder.
-
updateRequest
final ParsedWebhookEvent.KybPayload.Builder updateRequest(JsonField<ParsedWebhookEvent.KybPayload.UpdateRequest> updateRequest)
Sets Builder.updateRequest to an arbitrary JSON value.
You should usually call Builder.updateRequest with a well-typed UpdateRequest value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final ParsedWebhookEvent.KybPayload.Builder eventType(ParsedWebhookEvent.KybPayload.EventType eventType)
The type of event that occurred.
-
eventType
final ParsedWebhookEvent.KybPayload.Builder eventType(JsonField<ParsedWebhookEvent.KybPayload.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalId
final ParsedWebhookEvent.KybPayload.Builder externalId(String externalId)
A user provided id that can be used to link an account holder with an external system
-
externalId
final ParsedWebhookEvent.KybPayload.Builder externalId(JsonField<String> externalId)
Sets Builder.externalId to an arbitrary JSON value.
You should usually call Builder.externalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naicsCode
final ParsedWebhookEvent.KybPayload.Builder naicsCode(String naicsCode)
6-digit North American Industry Classification System (NAICS) code for the business. Only present if naics_code was included in the update request.
-
naicsCode
final ParsedWebhookEvent.KybPayload.Builder naicsCode(JsonField<String> naicsCode)
Sets Builder.naicsCode to an arbitrary JSON value.
You should usually call Builder.naicsCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
natureOfBusiness
final ParsedWebhookEvent.KybPayload.Builder natureOfBusiness(String natureOfBusiness)
Short description of the company's line of business (i.e., what does the company do?). Values longer than 255 characters will be truncated before KYB verification
-
natureOfBusiness
final ParsedWebhookEvent.KybPayload.Builder natureOfBusiness(JsonField<String> natureOfBusiness)
Sets Builder.natureOfBusiness to an arbitrary JSON value.
You should usually call Builder.natureOfBusiness with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
websiteUrl
final ParsedWebhookEvent.KybPayload.Builder websiteUrl(String websiteUrl)
Company website URL.
-
websiteUrl
final ParsedWebhookEvent.KybPayload.Builder websiteUrl(JsonField<String> websiteUrl)
Sets Builder.websiteUrl to an arbitrary JSON value.
You should usually call Builder.websiteUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ParsedWebhookEvent.KybPayload.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ParsedWebhookEvent.KybPayload.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ParsedWebhookEvent.KybPayload.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ParsedWebhookEvent.KybPayload.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ParsedWebhookEvent.KybPayload.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ParsedWebhookEvent.KybPayload build()
Returns an immutable instance of KybPayload.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .updateRequest()
-
-
-
-