Class ParsedWebhookEvent.KybPayload.UpdateRequest.Builder
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.KybPayload.UpdateRequest.BuilderA builder for UpdateRequest.
-
-
Method Summary
-
-
Method Detail
-
beneficialOwnerIndividuals
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder beneficialOwnerIndividuals(List<ParsedWebhookEvent.KybPayload.UpdateRequest.Individual> beneficialOwnerIndividuals)
You must submit a list of all direct and indirect individuals with 25% or more ownership in the company. A maximum of 4 beneficial owners can be submitted. If no individual owns 25% of the company you do not need to send beneficial owner information. See FinCEN requirements (Section I) for more background on individuals that should be included.
-
beneficialOwnerIndividuals
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder beneficialOwnerIndividuals(JsonField<List<ParsedWebhookEvent.KybPayload.UpdateRequest.Individual>> beneficialOwnerIndividuals)
Sets Builder.beneficialOwnerIndividuals to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerIndividuals with a well-typed
List<Individual>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwnerIndividual
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder addBeneficialOwnerIndividual(ParsedWebhookEvent.KybPayload.UpdateRequest.Individual beneficialOwnerIndividual)
Adds a single Individual to beneficialOwnerIndividuals.
-
businessEntity
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder businessEntity(KybBusinessEntity businessEntity)
Information for business for which the account is being opened and KYB is being run.
-
businessEntity
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder businessEntity(JsonField<KybBusinessEntity> businessEntity)
Sets Builder.businessEntity to an arbitrary JSON value.
You should usually call Builder.businessEntity with a well-typed KybBusinessEntity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
controlPerson
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder controlPerson(ParsedWebhookEvent.KybPayload.UpdateRequest.Individual controlPerson)
An individual with significant responsibility for managing the legal entity (e.g., a Chief Executive Officer, Chief Financial Officer, Chief Operating Officer, Managing Member, General Partner, President, Vice President, or Treasurer). This can be an executive, or someone who will have program-wide access to the cards that Lithic will provide. In some cases, this individual could also be a beneficial owner listed above. See FinCEN requirements (Section II) for more background.
-
controlPerson
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder controlPerson(JsonField<ParsedWebhookEvent.KybPayload.UpdateRequest.Individual> controlPerson)
Sets Builder.controlPerson to an arbitrary JSON value.
You should usually call Builder.controlPerson with a well-typed Individual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ParsedWebhookEvent.KybPayload.UpdateRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ParsedWebhookEvent.KybPayload.UpdateRequest build()
Returns an immutable instance of UpdateRequest.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-