Class ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.BuilderA builder for Individual.
-
-
Method Summary
-
-
Method Detail
-
address
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder address(ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Address address)
Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
address
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder address(JsonField<ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dob
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder dob(String dob)
Individual's date of birth, as an RFC 3339 date.
-
dob
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder dob(JsonField<String> dob)
Sets Builder.dob to an arbitrary JSON value.
You should usually call Builder.dob with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder email(String email)
Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
-
email
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstName
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder firstName(String firstName)
Individual's first name, as it appears on government-issued identity documents.
-
firstName
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentId
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder governmentId(String governmentId)
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
-
governmentId
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder governmentId(JsonField<String> governmentId)
Sets Builder.governmentId to an arbitrary JSON value.
You should usually call Builder.governmentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder lastName(String lastName)
Individual's last name, as it appears on government-issued identity documents.
-
lastName
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder phoneNumber(String phoneNumber)
Individual's phone number, entered in E.164 format.
-
phoneNumber
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ParsedWebhookEvent.KycPayload.UpdateRequest.Individual build()
Returns an immutable instance of Individual.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-