Package com.lithic.api.models
Class Payment.MethodAttributes
-
- All Implemented Interfaces:
public final class Payment.MethodAttributesMethod-specific attributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePayment.MethodAttributes.VisitorAn interface that defines how to map each variant of MethodAttributes to a value of type T.
public final classPayment.MethodAttributes.AchMethodAttributespublic final classPayment.MethodAttributes.WireMethodAttributes
-
Method Summary
Modifier and Type Method Description final Optional<Payment.MethodAttributes.AchMethodAttributes>ach()final Optional<Payment.MethodAttributes.WireMethodAttributes>wire()final BooleanisAch()final BooleanisWire()final Payment.MethodAttributes.AchMethodAttributesasAch()final Payment.MethodAttributes.WireMethodAttributesasWire()final Optional<JsonValue>_json()final <T extends Any> Taccept(Payment.MethodAttributes.Visitor<T> visitor)final Payment.MethodAttributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.MethodAttributesofAch(Payment.MethodAttributes.AchMethodAttributes ach)final static Payment.MethodAttributesofWire(Payment.MethodAttributes.WireMethodAttributes wire)-
-
Method Detail
-
ach
final Optional<Payment.MethodAttributes.AchMethodAttributes> ach()
-
wire
final Optional<Payment.MethodAttributes.WireMethodAttributes> wire()
-
asAch
final Payment.MethodAttributes.AchMethodAttributes asAch()
-
asWire
final Payment.MethodAttributes.WireMethodAttributes asWire()
-
accept
final <T extends Any> T accept(Payment.MethodAttributes.Visitor<T> visitor)
-
validate
final Payment.MethodAttributes validate()
-
ofAch
final static Payment.MethodAttributes ofAch(Payment.MethodAttributes.AchMethodAttributes ach)
-
ofWire
final static Payment.MethodAttributes ofWire(Payment.MethodAttributes.WireMethodAttributes wire)
-
-
-
-