Class Payment.MethodAttributes.AchMethodAttributes
-
- All Implemented Interfaces:
public final class Payment.MethodAttributes.AchMethodAttributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.MethodAttributes.AchMethodAttributes.BuilderA builder for AchMethodAttributes.
public final classPayment.MethodAttributes.AchMethodAttributes.SecCodeSEC code for ACH transaction
-
Method Summary
Modifier and Type Method Description final Payment.MethodAttributes.AchMethodAttributes.SecCodesecCode()SEC code for ACH transaction final Optional<Long>achHoldPeriod()Number of days the ACH transaction is on hold final Optional<String>addenda()Addenda information final Optional<String>companyId()Company ID for the ACH transaction final Optional<String>overrideCompanyName()Value to override the configured company name with. final Optional<String>receiptRoutingNumber()Receipt routing number final Optional<Long>retries()Number of retries attempted final Optional<String>returnReasonCode()Return reason code if the transaction was returned final Optional<List<String>>traceNumbers()Trace numbers for the ACH transaction final JsonField<Payment.MethodAttributes.AchMethodAttributes.SecCode>_secCode()Returns the raw JSON value of secCode. final JsonField<Long>_achHoldPeriod()Returns the raw JSON value of achHoldPeriod. final JsonField<String>_addenda()Returns the raw JSON value of addenda. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_overrideCompanyName()Returns the raw JSON value of overrideCompanyName. final JsonField<String>_receiptRoutingNumber()Returns the raw JSON value of receiptRoutingNumber. final JsonField<Long>_retries()Returns the raw JSON value of retries. final JsonField<String>_returnReasonCode()Returns the raw JSON value of returnReasonCode. final JsonField<List<String>>_traceNumbers()Returns the raw JSON value of traceNumbers. final Map<String, JsonValue>_additionalProperties()final Payment.MethodAttributes.AchMethodAttributes.BuildertoBuilder()final Payment.MethodAttributes.AchMethodAttributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.MethodAttributes.AchMethodAttributes.Builderbuilder()Returns a mutable builder for constructing an instance of AchMethodAttributes. -
-
Method Detail
-
secCode
final Payment.MethodAttributes.AchMethodAttributes.SecCode secCode()
SEC code for ACH transaction
-
achHoldPeriod
final Optional<Long> achHoldPeriod()
Number of days the ACH transaction is on hold
-
overrideCompanyName
final Optional<String> overrideCompanyName()
Value to override the configured company name with. Can only be used if allowed to override
-
receiptRoutingNumber
final Optional<String> receiptRoutingNumber()
Receipt routing number
-
returnReasonCode
final Optional<String> returnReasonCode()
Return reason code if the transaction was returned
-
traceNumbers
final Optional<List<String>> traceNumbers()
Trace numbers for the ACH transaction
-
_secCode
final JsonField<Payment.MethodAttributes.AchMethodAttributes.SecCode> _secCode()
Returns the raw JSON value of secCode.
Unlike secCode, this method doesn't throw if the JSON field has an unexpected type.
-
_achHoldPeriod
final JsonField<Long> _achHoldPeriod()
Returns the raw JSON value of achHoldPeriod.
Unlike achHoldPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<String> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_overrideCompanyName
final JsonField<String> _overrideCompanyName()
Returns the raw JSON value of overrideCompanyName.
Unlike overrideCompanyName, this method doesn't throw if the JSON field has an unexpected type.
-
_receiptRoutingNumber
final JsonField<String> _receiptRoutingNumber()
Returns the raw JSON value of receiptRoutingNumber.
Unlike receiptRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_retries
final JsonField<Long> _retries()
Returns the raw JSON value of retries.
Unlike retries, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCode
final JsonField<String> _returnReasonCode()
Returns the raw JSON value of returnReasonCode.
Unlike returnReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumbers
final JsonField<List<String>> _traceNumbers()
Returns the raw JSON value of traceNumbers.
Unlike traceNumbers, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.MethodAttributes.AchMethodAttributes.Builder toBuilder()
-
validate
final Payment.MethodAttributes.AchMethodAttributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Payment.MethodAttributes.AchMethodAttributes.Builder builder()
Returns a mutable builder for constructing an instance of AchMethodAttributes.
The following fields are required:
.secCode()
-
-
-
-