Class Payment.MethodAttributes.WireMethodAttributes
-
- All Implemented Interfaces:
public final class Payment.MethodAttributes.WireMethodAttributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.MethodAttributes.WireMethodAttributes.BuilderA builder for WireMethodAttributes.
public final classPayment.MethodAttributes.WireMethodAttributes.WireNetworkType of wire transfer
-
Method Summary
-
-
Method Detail
-
wireMessageType
final Optional<String> wireMessageType()
Type of wire message
-
wireNetwork
final Payment.MethodAttributes.WireMethodAttributes.WireNetwork wireNetwork()
Type of wire transfer
-
creditor
final Optional<WirePartyDetails> creditor()
-
debtor
final Optional<WirePartyDetails> debtor()
-
messageId
final Optional<String> messageId()
Point to point reference identifier, as assigned by the instructing party, used for tracking the message through the Fedwire system
-
remittanceInformation
final Optional<String> remittanceInformation()
Payment details or invoice reference
-
_wireMessageType
final JsonField<String> _wireMessageType()
Returns the raw JSON value of wireMessageType.
Unlike wireMessageType, this method doesn't throw if the JSON field has an unexpected type.
-
_wireNetwork
final JsonField<Payment.MethodAttributes.WireMethodAttributes.WireNetwork> _wireNetwork()
Returns the raw JSON value of wireNetwork.
Unlike wireNetwork, this method doesn't throw if the JSON field has an unexpected type.
-
_creditor
final JsonField<WirePartyDetails> _creditor()
Returns the raw JSON value of creditor.
Unlike creditor, this method doesn't throw if the JSON field has an unexpected type.
-
_debtor
final JsonField<WirePartyDetails> _debtor()
Returns the raw JSON value of debtor.
Unlike debtor, this method doesn't throw if the JSON field has an unexpected type.
-
_messageId
final JsonField<String> _messageId()
Returns the raw JSON value of messageId.
Unlike messageId, this method doesn't throw if the JSON field has an unexpected type.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Returns the raw JSON value of remittanceInformation.
Unlike remittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.MethodAttributes.WireMethodAttributes.Builder toBuilder()
-
validate
final Payment.MethodAttributes.WireMethodAttributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Payment.MethodAttributes.WireMethodAttributes.Builder builder()
Returns a mutable builder for constructing an instance of WireMethodAttributes.
The following fields are required:
.wireMessageType() .wireNetwork()
-
-
-
-