Class Payment.PaymentEvent

  • All Implemented Interfaces:

    
    public final class Payment.PaymentEvent
    
                        

    Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related fields below are a preview. To learn more, contact your customer success manager.

    Payment Event

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public final class Payment.PaymentEvent.Builder

      A builder for PaymentEvent.

      public final class Payment.PaymentEvent.Result

      APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.

      public final class Payment.PaymentEvent.PaymentEventType

      Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.

      Event types:

      ACH events:

      • ACH_ORIGINATION_INITIATED - ACH origination received and pending approval/release from an ACH hold.

      • ACH_ORIGINATION_REVIEWED - ACH origination has completed the review process.

      • ACH_ORIGINATION_CANCELLED - ACH origination has been cancelled.

      • ACH_ORIGINATION_PROCESSED - ACH origination has been processed and sent to the Federal Reserve.

      • ACH_ORIGINATION_SETTLED - ACH origination has settled.

      • ACH_ORIGINATION_RELEASED - ACH origination released from pending to available balance.

      • ACH_ORIGINATION_REJECTED - ACH origination was rejected and not sent to the Federal Reserve.

      • ACH_RECEIPT_PROCESSED - ACH receipt pending release from an ACH holder.

      • ACH_RECEIPT_SETTLED - ACH receipt funds have settled.

      • ACH_RECEIPT_RELEASED - ACH receipt released from pending to available balance.

      • ACH_RECEIPT_RELEASED_EARLY - ACH receipt released early from pending to available balance.

      • ACH_RETURN_INITIATED - ACH initiated return for an ACH receipt.

      • ACH_RETURN_PROCESSED - ACH receipt returned by the Receiving Depository Financial Institution.

      • ACH_RETURN_SETTLED - ACH return settled by the Receiving Depository Financial Institution.

      • ACH_RETURN_REJECTED - ACH return was rejected by the Receiving Depository Financial Institution.

      Wire transfer events:

      • WIRE_TRANSFER_INBOUND_RECEIVED - Inbound wire transfer received from the Federal Reserve and pending release to available balance.

      • WIRE_TRANSFER_INBOUND_SETTLED - Inbound wire transfer funds released from pending to available balance.

      • WIRE_TRANSFER_INBOUND_BLOCKED - Inbound wire transfer blocked and funds frozen for regulatory review.

      Wire return events:

      • WIRE_RETURN_OUTBOUND_INITIATED - Outbound wire return initiated to return funds from an inbound wire transfer.

      • WIRE_RETURN_OUTBOUND_SENT - Outbound wire return sent to the Federal Reserve and pending acceptance.

      • WIRE_RETURN_OUTBOUND_SETTLED - Outbound wire return accepted by the Federal Reserve and funds returned to sender.

      • WIRE_RETURN_OUTBOUND_REJECTED - Outbound wire return rejected by the Federal Reserve.

      public final class Payment.PaymentEvent.DetailedResult
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Constructor Detail

    • Method Detail

      • token

         final String token()

        Globally unique identifier.

      • amount

         final Long amount()

        Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).

      • result

         final Payment.PaymentEvent.Result result()

        APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.

      • type

         final Payment.PaymentEvent.PaymentEventType type()

        Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.

        Event types:

        ACH events:

        • ACH_ORIGINATION_INITIATED - ACH origination received and pending approval/release from an ACH hold.

        • ACH_ORIGINATION_REVIEWED - ACH origination has completed the review process.

        • ACH_ORIGINATION_CANCELLED - ACH origination has been cancelled.

        • ACH_ORIGINATION_PROCESSED - ACH origination has been processed and sent to the Federal Reserve.

        • ACH_ORIGINATION_SETTLED - ACH origination has settled.

        • ACH_ORIGINATION_RELEASED - ACH origination released from pending to available balance.

        • ACH_ORIGINATION_REJECTED - ACH origination was rejected and not sent to the Federal Reserve.

        • ACH_RECEIPT_PROCESSED - ACH receipt pending release from an ACH holder.

        • ACH_RECEIPT_SETTLED - ACH receipt funds have settled.

        • ACH_RECEIPT_RELEASED - ACH receipt released from pending to available balance.

        • ACH_RECEIPT_RELEASED_EARLY - ACH receipt released early from pending to available balance.

        • ACH_RETURN_INITIATED - ACH initiated return for an ACH receipt.

        • ACH_RETURN_PROCESSED - ACH receipt returned by the Receiving Depository Financial Institution.

        • ACH_RETURN_SETTLED - ACH return settled by the Receiving Depository Financial Institution.

        • ACH_RETURN_REJECTED - ACH return was rejected by the Receiving Depository Financial Institution.

        Wire transfer events:

        • WIRE_TRANSFER_INBOUND_RECEIVED - Inbound wire transfer received from the Federal Reserve and pending release to available balance.

        • WIRE_TRANSFER_INBOUND_SETTLED - Inbound wire transfer funds released from pending to available balance.

        • WIRE_TRANSFER_INBOUND_BLOCKED - Inbound wire transfer blocked and funds frozen for regulatory review.

        Wire return events:

        • WIRE_RETURN_OUTBOUND_INITIATED - Outbound wire return initiated to return funds from an inbound wire transfer.

        • WIRE_RETURN_OUTBOUND_SENT - Outbound wire return sent to the Federal Reserve and pending acceptance.

        • WIRE_RETURN_OUTBOUND_SETTLED - Outbound wire return accepted by the Federal Reserve and funds returned to sender.

        • WIRE_RETURN_OUTBOUND_REJECTED - Outbound wire return rejected by the Federal Reserve.

      • externalId

         final Optional<String> externalId()

        Payment event external ID. For ACH transactions, this is the ACH trace number. For inbound wire transfers, this is the IMAD (Input Message Accountability Data).

      • _token

         final JsonField<String> _token()

        Returns the raw JSON value of token.

        Unlike token, this method doesn't throw if the JSON field has an unexpected type.

      • _amount

         final JsonField<Long> _amount()

        Returns the raw JSON value of amount.

        Unlike amount, this method doesn't throw if the JSON field has an unexpected type.

      • validate

         final Payment.PaymentEvent validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.