Package com.lithic.api.models
Class Payment.RelatedAccountTokens
-
- All Implemented Interfaces:
public final class Payment.RelatedAccountTokensAccount tokens related to a payment transaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.RelatedAccountTokens.BuilderA builder for RelatedAccountTokens.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()Globally unique identifier for the account final Optional<String>businessAccountToken()Globally unique identifier for the business account final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final Map<String, JsonValue>_additionalProperties()final Payment.RelatedAccountTokens.BuildertoBuilder()final Payment.RelatedAccountTokensvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.RelatedAccountTokens.Builderbuilder()Returns a mutable builder for constructing an instance of RelatedAccountTokens. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
Globally unique identifier for the account
-
businessAccountToken
final Optional<String> businessAccountToken()
Globally unique identifier for the business account
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.RelatedAccountTokens.Builder toBuilder()
-
validate
final Payment.RelatedAccountTokens validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Payment.RelatedAccountTokens.Builder builder()
Returns a mutable builder for constructing an instance of RelatedAccountTokens.
The following fields are required:
.accountToken() .businessAccountToken()
-
-
-
-