Class PaymentCreateParams.CreatePaymentRequest
-
- All Implemented Interfaces:
public final class PaymentCreateParams.CreatePaymentRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentCreateParams.CreatePaymentRequest.BuilderA builder for CreatePaymentRequest.
-
Method Summary
-
-
Method Detail
-
externalBankAccountToken
final String externalBankAccountToken()
-
financialAccountToken
final String financialAccountToken()
-
method
final PaymentCreateParams.Method method()
-
methodAttributes
final PaymentCreateParams.PaymentMethodRequestAttributes methodAttributes()
-
type
final PaymentCreateParams.Type type()
-
token
final Optional<String> token()
Customer-provided token that will serve as an idempotency token. This token will become the transaction token.
-
hold
final Optional<PaymentCreateParams.Hold> hold()
Optional hold to settle when this payment is initiated.
-
userDefinedId
final Optional<String> userDefinedId()
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_externalBankAccountToken
final JsonField<String> _externalBankAccountToken()
Returns the raw JSON value of externalBankAccountToken.
Unlike externalBankAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<PaymentCreateParams.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_methodAttributes
final JsonField<PaymentCreateParams.PaymentMethodRequestAttributes> _methodAttributes()
Returns the raw JSON value of methodAttributes.
Unlike methodAttributes, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PaymentCreateParams.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_hold
final JsonField<PaymentCreateParams.Hold> _hold()
Returns the raw JSON value of hold.
Unlike hold, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentCreateParams.CreatePaymentRequest.Builder toBuilder()
-
validate
final PaymentCreateParams.CreatePaymentRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentCreateParams.CreatePaymentRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreatePaymentRequest.
The following fields are required:
.amount() .externalBankAccountToken() .financialAccountToken() .method() .methodAttributes() .type()
-
-
-
-