Package com.lithic.api.models
Class PaymentCreateParams.Hold
-
- All Implemented Interfaces:
public final class PaymentCreateParams.HoldOptional hold to settle when this payment is initiated.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentCreateParams.Hold.BuilderA builder for Hold.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Token of the hold to settle when this payment is initiated. final JsonField<String>_token()Returns the raw JSON value of token. final Map<String, JsonValue>_additionalProperties()final PaymentCreateParams.Hold.BuildertoBuilder()final PaymentCreateParams.Holdvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentCreateParams.Hold.Builderbuilder()Returns a mutable builder for constructing an instance of Hold. -
-
Method Detail
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentCreateParams.Hold.Builder toBuilder()
-
validate
final PaymentCreateParams.Hold validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentCreateParams.Hold.Builder builder()
Returns a mutable builder for constructing an instance of Hold.
The following fields are required:
.token()
-
-
-
-