Class PaymentCreateParams.PaymentMethodRequestAttributes
-
- All Implemented Interfaces:
public final class PaymentCreateParams.PaymentMethodRequestAttributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentCreateParams.PaymentMethodRequestAttributes.BuilderA builder for PaymentMethodRequestAttributes.
public final classPaymentCreateParams.PaymentMethodRequestAttributes.SecCode
-
Method Summary
-
-
Method Detail
-
secCode
final PaymentCreateParams.PaymentMethodRequestAttributes.SecCode secCode()
-
achHoldPeriod
final Optional<Long> achHoldPeriod()
Number of days to hold the ACH payment
-
overrideCompanyName
final Optional<String> overrideCompanyName()
Value to override the configured company name with. Can only be used if allowed to override
-
_secCode
final JsonField<PaymentCreateParams.PaymentMethodRequestAttributes.SecCode> _secCode()
Returns the raw JSON value of secCode.
Unlike secCode, this method doesn't throw if the JSON field has an unexpected type.
-
_achHoldPeriod
final JsonField<Long> _achHoldPeriod()
Returns the raw JSON value of achHoldPeriod.
Unlike achHoldPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<String> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_overrideCompanyName
final JsonField<String> _overrideCompanyName()
Returns the raw JSON value of overrideCompanyName.
Unlike overrideCompanyName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder toBuilder()
-
validate
final PaymentCreateParams.PaymentMethodRequestAttributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentCreateParams.PaymentMethodRequestAttributes.Builder builder()
Returns a mutable builder for constructing an instance of PaymentMethodRequestAttributes.
The following fields are required:
.secCode()
-
-
-
-