Class PaymentCreateParams.PaymentMethodRequestAttributes.Builder
-
- All Implemented Interfaces:
public final class PaymentCreateParams.PaymentMethodRequestAttributes.BuilderA builder for PaymentMethodRequestAttributes.
-
-
Method Summary
-
-
Method Detail
-
secCode
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder secCode(PaymentCreateParams.PaymentMethodRequestAttributes.SecCode secCode)
-
secCode
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder secCode(JsonField<PaymentCreateParams.PaymentMethodRequestAttributes.SecCode> secCode)
Sets Builder.secCode to an arbitrary JSON value.
You should usually call Builder.secCode with a well-typed SecCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achHoldPeriod
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder achHoldPeriod(Long achHoldPeriod)
Number of days to hold the ACH payment
-
achHoldPeriod
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder achHoldPeriod(JsonField<Long> achHoldPeriod)
Sets Builder.achHoldPeriod to an arbitrary JSON value.
You should usually call Builder.achHoldPeriod with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addenda
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder addenda(String addenda)
-
addenda
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder addenda(Optional<String> addenda)
Alias for calling Builder.addenda with
addenda.orElse(null).
-
addenda
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder addenda(JsonField<String> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PaymentCreateParams.PaymentMethodRequestAttributes build()
Returns an immutable instance of PaymentMethodRequestAttributes.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.secCode()
-
-
-
-