Package com.lithic.api.models
Class PaymentListPageAsync.Builder
-
- All Implemented Interfaces:
public final class PaymentListPageAsync.BuilderA builder for PaymentListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final PaymentListPageAsync.Builderservice(PaymentServiceAsync service)final PaymentListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final PaymentListPageAsync.Builderparams(PaymentListParams params)The parameters that were used to request this page. final PaymentListPageAsync.Builderresponse(PaymentListPageResponse response)The response that this page was parsed from. final PaymentListPageAsyncbuild()Returns an immutable instance of PaymentListPageAsync. -
-
Method Detail
-
service
final PaymentListPageAsync.Builder service(PaymentServiceAsync service)
-
streamHandlerExecutor
final PaymentListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final PaymentListPageAsync.Builder params(PaymentListParams params)
The parameters that were used to request this page.
-
response
final PaymentListPageAsync.Builder response(PaymentListPageResponse response)
The response that this page was parsed from.
-
build
final PaymentListPageAsync build()
Returns an immutable instance of PaymentListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-