Package com.lithic.api.models
Class PaymentListPageResponse
-
- All Implemented Interfaces:
public final class PaymentListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentListPageResponse.BuilderA builder for PaymentListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Payment>data()final BooleanhasMore()More data exists. final JsonField<List<Payment>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final PaymentListPageResponse.BuildertoBuilder()final PaymentListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Payment>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentListPageResponse.Builder toBuilder()
-
validate
final PaymentListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of PaymentListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-