Class PaymentReturnParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class PaymentReturnParams implements Params
Return an ACH payment with a specified return reason code. Returns must be initiated within the time window specified by NACHA rules for each return code (typically 2 banking days for most codes, 60 calendar days for unauthorized debits). For a complete list of return codes and their meanings, see the ACH Return Reasons documentation.
Note:
This endpoint does not modify the state of the financial account associated with the payment. If you would like to change the account state, use the Update financial account status endpoint.
By default this endpoint is not enabled for your account. Please contact your implementations manager to enable this feature.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentReturnParams.BuilderA builder for PaymentReturnParams.
public final classPaymentReturnParams.PaymentReturnRequestRequest to return an ACH payment
-
Method Summary
Modifier and Type Method Description final Optional<String>paymentToken()final StringfinancialAccountToken()Globally unique identifier for the financial account final StringreturnReasonCode()ACH return reason code indicating the reason for returning the payment. final Optional<String>addenda()Optional additional information about the return. final Optional<LocalDate>dateOfDeath()Date of death in YYYY-MM-DD format. final Optional<String>memo()Optional memo for the return. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<String>_returnReasonCode()Returns the raw JSON value of returnReasonCode. final JsonField<String>_addenda()Returns the raw JSON value of addenda. final JsonField<LocalDate>_dateOfDeath()Returns the raw JSON value of dateOfDeath. final JsonField<String>_memo()Returns the raw JSON value of memo. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PaymentReturnParams.BuildertoBuilder()final PaymentReturnParams.PaymentReturnRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentReturnParams.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentReturnParams. -
-
Method Detail
-
paymentToken
final Optional<String> paymentToken()
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for the financial account
-
returnReasonCode
final String returnReasonCode()
ACH return reason code indicating the reason for returning the payment. Supported codes include R01-R53 and R80-R85. For a complete list of return codes and their meanings, see ACH Return Reasons
-
addenda
final Optional<String> addenda()
Optional additional information about the return. Limited to 44 characters
-
dateOfDeath
final Optional<LocalDate> dateOfDeath()
Date of death in YYYY-MM-DD format. Required when using return codes R14 (representative payee deceased) or R15 (beneficiary or account holder deceased)
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCode
final JsonField<String> _returnReasonCode()
Returns the raw JSON value of returnReasonCode.
Unlike returnReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<String> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfDeath
final JsonField<LocalDate> _dateOfDeath()
Returns the raw JSON value of dateOfDeath.
Unlike dateOfDeath, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PaymentReturnParams.Builder toBuilder()
-
_body
final PaymentReturnParams.PaymentReturnRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PaymentReturnParams.Builder builder()
Returns a mutable builder for constructing an instance of PaymentReturnParams.
The following fields are required:
.financialAccountToken() .returnReasonCode()
-
-
-
-