Class PaymentReturnParams.PaymentReturnRequest
-
- All Implemented Interfaces:
public final class PaymentReturnParams.PaymentReturnRequestRequest to return an ACH payment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentReturnParams.PaymentReturnRequest.BuilderA builder for PaymentReturnRequest.
-
Method Summary
Modifier and Type Method Description final StringfinancialAccountToken()Globally unique identifier for the financial account final StringreturnReasonCode()ACH return reason code indicating the reason for returning the payment. final Optional<String>addenda()Optional additional information about the return. final Optional<LocalDate>dateOfDeath()Date of death in YYYY-MM-DD format. final Optional<String>memo()Optional memo for the return. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<String>_returnReasonCode()Returns the raw JSON value of returnReasonCode. final JsonField<String>_addenda()Returns the raw JSON value of addenda. final JsonField<LocalDate>_dateOfDeath()Returns the raw JSON value of dateOfDeath. final JsonField<String>_memo()Returns the raw JSON value of memo. final Map<String, JsonValue>_additionalProperties()final PaymentReturnParams.PaymentReturnRequest.BuildertoBuilder()final PaymentReturnParams.PaymentReturnRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentReturnParams.PaymentReturnRequest.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentReturnRequest. -
-
Method Detail
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for the financial account
-
returnReasonCode
final String returnReasonCode()
ACH return reason code indicating the reason for returning the payment. Supported codes include R01-R53 and R80-R85. For a complete list of return codes and their meanings, see ACH Return Reasons
-
addenda
final Optional<String> addenda()
Optional additional information about the return. Limited to 44 characters
-
dateOfDeath
final Optional<LocalDate> dateOfDeath()
Date of death in YYYY-MM-DD format. Required when using return codes R14 (representative payee deceased) or R15 (beneficiary or account holder deceased)
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCode
final JsonField<String> _returnReasonCode()
Returns the raw JSON value of returnReasonCode.
Unlike returnReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<String> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfDeath
final JsonField<LocalDate> _dateOfDeath()
Returns the raw JSON value of dateOfDeath.
Unlike dateOfDeath, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentReturnParams.PaymentReturnRequest.Builder toBuilder()
-
validate
final PaymentReturnParams.PaymentReturnRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentReturnParams.PaymentReturnRequest.Builder builder()
Returns a mutable builder for constructing an instance of PaymentReturnRequest.
The following fields are required:
.financialAccountToken() .returnReasonCode()
-
-
-
-