Class PaymentSimulateActionParams.SimulateActionRequest
-
- All Implemented Interfaces:
public final class PaymentSimulateActionParams.SimulateActionRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentSimulateActionParams.SimulateActionRequest.BuilderA builder for SimulateActionRequest.
-
Method Summary
-
-
Method Detail
-
eventType
final PaymentSimulateActionParams.SupportedSimulationTypes eventType()
Event Type
-
dateOfDeath
final Optional<LocalDate> dateOfDeath()
Date of Death for ACH Return
-
declineReason
final Optional<PaymentSimulateActionParams.SupportedSimulationDeclineReasons> declineReason()
Decline reason
-
returnAddenda
final Optional<String> returnAddenda()
Return Addenda
-
returnReasonCode
final Optional<String> returnReasonCode()
Return Reason Code
-
_eventType
final JsonField<PaymentSimulateActionParams.SupportedSimulationTypes> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfDeath
final JsonField<LocalDate> _dateOfDeath()
Returns the raw JSON value of dateOfDeath.
Unlike dateOfDeath, this method doesn't throw if the JSON field has an unexpected type.
-
_declineReason
final JsonField<PaymentSimulateActionParams.SupportedSimulationDeclineReasons> _declineReason()
Returns the raw JSON value of declineReason.
Unlike declineReason, this method doesn't throw if the JSON field has an unexpected type.
-
_returnAddenda
final JsonField<String> _returnAddenda()
Returns the raw JSON value of returnAddenda.
Unlike returnAddenda, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCode
final JsonField<String> _returnReasonCode()
Returns the raw JSON value of returnReasonCode.
Unlike returnReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentSimulateActionParams.SimulateActionRequest.Builder toBuilder()
-
validate
final PaymentSimulateActionParams.SimulateActionRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentSimulateActionParams.SimulateActionRequest.Builder builder()
Returns a mutable builder for constructing an instance of SimulateActionRequest.
The following fields are required:
.eventType()
-
-
-
-