Class PaymentSimulateReceiptParams.SimulateReceiptRequest
-
- All Implemented Interfaces:
public final class PaymentSimulateReceiptParams.SimulateReceiptRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentSimulateReceiptParams.SimulateReceiptRequest.BuilderA builder for SimulateReceiptRequest.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Customer-generated payment token used to uniquely identify the simulated payment final Longamount()Amount final StringfinancialAccountToken()Financial Account Token final PaymentSimulateReceiptParams.ReceiptTypereceiptType()Receipt Type final Optional<String>memo()Memo final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<PaymentSimulateReceiptParams.ReceiptType>_receiptType()Returns the raw JSON value of receiptType. final JsonField<String>_memo()Returns the raw JSON value of memo. final Map<String, JsonValue>_additionalProperties()final PaymentSimulateReceiptParams.SimulateReceiptRequest.BuildertoBuilder()final PaymentSimulateReceiptParams.SimulateReceiptRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentSimulateReceiptParams.SimulateReceiptRequest.Builderbuilder()Returns a mutable builder for constructing an instance of SimulateReceiptRequest. -
-
Method Detail
-
token
final String token()
Customer-generated payment token used to uniquely identify the simulated payment
-
financialAccountToken
final String financialAccountToken()
Financial Account Token
-
receiptType
final PaymentSimulateReceiptParams.ReceiptType receiptType()
Receipt Type
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_receiptType
final JsonField<PaymentSimulateReceiptParams.ReceiptType> _receiptType()
Returns the raw JSON value of receiptType.
Unlike receiptType, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentSimulateReceiptParams.SimulateReceiptRequest.Builder toBuilder()
-
validate
final PaymentSimulateReceiptParams.SimulateReceiptRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentSimulateReceiptParams.SimulateReceiptRequest.Builder builder()
Returns a mutable builder for constructing an instance of SimulateReceiptRequest.
The following fields are required:
.token() .amount() .financialAccountToken() .receiptType()
-
-
-
-