Package com.lithic.api.models
Class PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest
-
- All Implemented Interfaces:
public final class PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentSimulateReleaseParams.SimulateOriginationReleaseRequest.BuilderA builder for SimulateOriginationReleaseRequest.
-
Method Summary
Modifier and Type Method Description final StringpaymentToken()Payment Token final JsonField<String>_paymentToken()Returns the raw JSON value of paymentToken. final Map<String, JsonValue>_additionalProperties()final PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest.BuildertoBuilder()final PaymentSimulateReleaseParams.SimulateOriginationReleaseRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest.Builderbuilder()Returns a mutable builder for constructing an instance of SimulateOriginationReleaseRequest. -
-
Method Detail
-
paymentToken
final String paymentToken()
Payment Token
-
_paymentToken
final JsonField<String> _paymentToken()
Returns the raw JSON value of paymentToken.
Unlike paymentToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PaymentSimulateReleaseParams.SimulateOriginationReleaseRequest.Builder builder()
Returns a mutable builder for constructing an instance of SimulateOriginationReleaseRequest.
The following fields are required:
.paymentToken()
-
-
-
-