Class PaymentTransactionUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class PaymentTransactionUpdatedWebhookEventPayment transaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentTransactionUpdatedWebhookEvent.BuilderA builder for PaymentTransactionUpdatedWebhookEvent.
public final classPaymentTransactionUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final PaymenttoPayment()final Stringtoken()Unique identifier for the transaction final Payment.TransactionCategorycategory()Transaction category final OffsetDateTimecreated()ISO 8601 timestamp of when the transaction was created final Stringdescriptor()Transaction descriptor final Payment.Directiondirection()Transfer direction final List<Payment.PaymentEvent>events()List of transaction events final Payment.Familyfamily()PAYMENT - Payment Transaction final StringfinancialAccountToken()Financial account token final Payment.Methodmethod()Transfer method final Payment.MethodAttributesmethodAttributes()Method-specific attributes final LongpendingAmount()Pending amount in cents final Optional<Payment.RelatedAccountTokens>relatedAccountTokens()Account tokens related to a payment transaction final Payment.TransactionResultresult()Transaction result final LongsettledAmount()Settled amount in cents final Payment.Sourcesource()Transaction source final Payment.TransactionStatusstatus()The status of the transaction final OffsetDateTimeupdated()ISO 8601 timestamp of when the transaction was last updated final Optional<String>currency()Currency of the transaction in ISO 4217 format final Optional<LocalDate>expectedReleaseDate()Expected release date for the transaction final Optional<String>externalBankAccountToken()External bank account token final Optional<Payment.TransferType>type()final Optional<String>userDefinedId()User-defined identifier final PaymentTransactionUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Payment.TransactionCategory>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<Payment.Direction>_direction()Returns the raw JSON value of direction. final JsonField<List<Payment.PaymentEvent>>_events()Returns the raw JSON value of events. final JsonField<Payment.Family>_family()Returns the raw JSON value of family. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<Payment.Method>_method()Returns the raw JSON value of method. final JsonField<Payment.MethodAttributes>_methodAttributes()Returns the raw JSON value of methodAttributes. final JsonField<Long>_pendingAmount()Returns the raw JSON value of pendingAmount. final JsonField<Payment.RelatedAccountTokens>_relatedAccountTokens()Returns the raw JSON value of relatedAccountTokens. final JsonField<Payment.TransactionResult>_result()Returns the raw JSON value of result. final JsonField<Long>_settledAmount()Returns the raw JSON value of settledAmount. final JsonField<Payment.Source>_source()Returns the raw JSON value of source. final JsonField<Payment.TransactionStatus>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<LocalDate>_expectedReleaseDate()Returns the raw JSON value of expectedReleaseDate. final JsonField<String>_externalBankAccountToken()Returns the raw JSON value of externalBankAccountToken. final JsonField<Payment.TransferType>_type()Returns the raw JSON value of type. final JsonField<String>_userDefinedId()Returns the raw JSON value of userDefinedId. final JsonField<PaymentTransactionUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final PaymentTransactionUpdatedWebhookEvent.BuildertoBuilder()final PaymentTransactionUpdatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentTransactionUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentTransactionUpdatedWebhookEvent. -
-
Method Detail
-
category
final Payment.TransactionCategory category()
Transaction category
-
created
final OffsetDateTime created()
ISO 8601 timestamp of when the transaction was created
-
descriptor
final String descriptor()
Transaction descriptor
-
direction
final Payment.Direction direction()
Transfer direction
-
events
final List<Payment.PaymentEvent> events()
List of transaction events
-
family
final Payment.Family family()
PAYMENT - Payment Transaction
-
financialAccountToken
final String financialAccountToken()
Financial account token
-
method
final Payment.Method method()
Transfer method
-
methodAttributes
final Payment.MethodAttributes methodAttributes()
Method-specific attributes
-
pendingAmount
final Long pendingAmount()
Pending amount in cents
-
relatedAccountTokens
final Optional<Payment.RelatedAccountTokens> relatedAccountTokens()
Account tokens related to a payment transaction
-
result
final Payment.TransactionResult result()
Transaction result
-
settledAmount
final Long settledAmount()
Settled amount in cents
-
source
final Payment.Source source()
Transaction source
-
status
final Payment.TransactionStatus status()
The status of the transaction
-
updated
final OffsetDateTime updated()
ISO 8601 timestamp of when the transaction was last updated
-
expectedReleaseDate
final Optional<LocalDate> expectedReleaseDate()
Expected release date for the transaction
-
externalBankAccountToken
final Optional<String> externalBankAccountToken()
External bank account token
-
type
final Optional<Payment.TransferType> type()
-
userDefinedId
final Optional<String> userDefinedId()
User-defined identifier
-
eventType
final PaymentTransactionUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Payment.TransactionCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<Payment.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<Payment.PaymentEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_family
final JsonField<Payment.Family> _family()
Returns the raw JSON value of family.
Unlike family, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<Payment.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_methodAttributes
final JsonField<Payment.MethodAttributes> _methodAttributes()
Returns the raw JSON value of methodAttributes.
Unlike methodAttributes, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_relatedAccountTokens
final JsonField<Payment.RelatedAccountTokens> _relatedAccountTokens()
Returns the raw JSON value of relatedAccountTokens.
Unlike relatedAccountTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Payment.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<Payment.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Payment.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_expectedReleaseDate
final JsonField<LocalDate> _expectedReleaseDate()
Returns the raw JSON value of expectedReleaseDate.
Unlike expectedReleaseDate, this method doesn't throw if the JSON field has an unexpected type.
-
_externalBankAccountToken
final JsonField<String> _externalBankAccountToken()
Returns the raw JSON value of externalBankAccountToken.
Unlike externalBankAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Payment.TransferType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<PaymentTransactionUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentTransactionUpdatedWebhookEvent.Builder toBuilder()
-
validate
final PaymentTransactionUpdatedWebhookEvent validate()
-
builder
final static PaymentTransactionUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of PaymentTransactionUpdatedWebhookEvent.
The following fields are required:
.token() .category() .created() .descriptor() .direction() .events() .family() .financialAccountToken() .method() .methodAttributes() .pendingAmount() .relatedAccountTokens() .result() .settledAmount() .source() .status() .updated() .eventType()
-
-
-
-