Package com.lithic.api.models
Class PrimeRateRetrieveResponse
-
- All Implemented Interfaces:
public final class PrimeRateRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPrimeRateRetrieveResponse.BuilderA builder for PrimeRateRetrieveResponse.
public final classPrimeRateRetrieveResponse.InterestRate
-
Method Summary
Modifier and Type Method Description final List<PrimeRateRetrieveResponse.InterestRate>data()List of prime rates final BooleanhasMore()Whether there are more prime rates final JsonField<List<PrimeRateRetrieveResponse.InterestRate>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final PrimeRateRetrieveResponse.BuildertoBuilder()final PrimeRateRetrieveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PrimeRateRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PrimeRateRetrieveResponse. -
-
Method Detail
-
data
final List<PrimeRateRetrieveResponse.InterestRate> data()
List of prime rates
-
_data
final JsonField<List<PrimeRateRetrieveResponse.InterestRate>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PrimeRateRetrieveResponse.Builder toBuilder()
-
validate
final PrimeRateRetrieveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PrimeRateRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of PrimeRateRetrieveResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-