Package com.lithic.api.models
Class PrimeRateRetrieveResponse.InterestRate
-
- All Implemented Interfaces:
public final class PrimeRateRetrieveResponse.InterestRate
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPrimeRateRetrieveResponse.InterestRate.BuilderA builder for InterestRate.
-
Method Summary
Modifier and Type Method Description final LocalDateeffectiveDate()Date the rate goes into effect final Stringrate()The rate in decimal format final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_rate()Returns the raw JSON value of rate. final Map<String, JsonValue>_additionalProperties()final PrimeRateRetrieveResponse.InterestRate.BuildertoBuilder()final PrimeRateRetrieveResponse.InterestRatevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PrimeRateRetrieveResponse.InterestRate.Builderbuilder()Returns a mutable builder for constructing an instance of InterestRate. -
-
Method Detail
-
effectiveDate
final LocalDate effectiveDate()
Date the rate goes into effect
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_rate
final JsonField<String> _rate()
Returns the raw JSON value of rate.
Unlike rate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PrimeRateRetrieveResponse.InterestRate.Builder toBuilder()
-
validate
final PrimeRateRetrieveResponse.InterestRate validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PrimeRateRetrieveResponse.InterestRate.Builder builder()
Returns a mutable builder for constructing an instance of InterestRate.
The following fields are required:
.effectiveDate() .rate()
-
-
-
-