Class ProvisionResponse
-
- All Implemented Interfaces:
public final class ProvisionResponseObject containing the fields required to add a card to Apple Pay. Applies only to Apple Pay wallet.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProvisionResponse.BuilderA builder for ProvisionResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>activationData()final Optional<String>encryptedData()final Optional<String>ephemeralPublicKey()final JsonField<String>_activationData()Returns the raw JSON value of activationData. final JsonField<String>_encryptedData()Returns the raw JSON value of encryptedData. final JsonField<String>_ephemeralPublicKey()Returns the raw JSON value of ephemeralPublicKey. final Map<String, JsonValue>_additionalProperties()final ProvisionResponse.BuildertoBuilder()final ProvisionResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProvisionResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProvisionResponse. -
-
Method Detail
-
activationData
final Optional<String> activationData()
-
encryptedData
final Optional<String> encryptedData()
-
ephemeralPublicKey
final Optional<String> ephemeralPublicKey()
-
_activationData
final JsonField<String> _activationData()
Returns the raw JSON value of activationData.
Unlike activationData, this method doesn't throw if the JSON field has an unexpected type.
-
_encryptedData
final JsonField<String> _encryptedData()
Returns the raw JSON value of encryptedData.
Unlike encryptedData, this method doesn't throw if the JSON field has an unexpected type.
-
_ephemeralPublicKey
final JsonField<String> _ephemeralPublicKey()
Returns the raw JSON value of ephemeralPublicKey.
Unlike ephemeralPublicKey, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProvisionResponse.Builder toBuilder()
-
validate
final ProvisionResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProvisionResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProvisionResponse.
-
-
-
-