Class ProvisionResponse.Builder
-
- All Implemented Interfaces:
public final class ProvisionResponse.BuilderA builder for ProvisionResponse.
-
-
Method Summary
-
-
Method Detail
-
activationData
final ProvisionResponse.Builder activationData(String activationData)
-
activationData
final ProvisionResponse.Builder activationData(JsonField<String> activationData)
Sets Builder.activationData to an arbitrary JSON value.
You should usually call Builder.activationData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
encryptedData
final ProvisionResponse.Builder encryptedData(String encryptedData)
-
encryptedData
final ProvisionResponse.Builder encryptedData(JsonField<String> encryptedData)
Sets Builder.encryptedData to an arbitrary JSON value.
You should usually call Builder.encryptedData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ephemeralPublicKey
final ProvisionResponse.Builder ephemeralPublicKey(String ephemeralPublicKey)
-
ephemeralPublicKey
final ProvisionResponse.Builder ephemeralPublicKey(JsonField<String> ephemeralPublicKey)
Sets Builder.ephemeralPublicKey to an arbitrary JSON value.
You should usually call Builder.ephemeralPublicKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProvisionResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProvisionResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProvisionResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProvisionResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProvisionResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProvisionResponse build()
Returns an immutable instance of ProvisionResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-