Class Queue
-
- All Implemented Interfaces:
public final class QueueA queue that groups transaction monitoring cases for review
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classQueue.BuilderA builder for Queue.
public final classQueue.CaseCountsNumber of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the queue final Queue.CaseCountscaseCounts()Number of cases in the queue, broken down by status. final OffsetDateTimecreated()Date and time at which the queue was created final Optional<String>description()Optional description of the queue final Stringname()Human-readable name of the queue final OffsetDateTimeupdated()Date and time at which the queue was last updated final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Queue.CaseCounts>_caseCounts()Returns the raw JSON value of caseCounts. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final Map<String, JsonValue>_additionalProperties()final Queue.BuildertoBuilder()final Queuevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Queue.Builderbuilder()Returns a mutable builder for constructing an instance of Queue. -
-
Method Detail
-
caseCounts
final Queue.CaseCounts caseCounts()
Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
-
created
final OffsetDateTime created()
Date and time at which the queue was created
-
description
final Optional<String> description()
Optional description of the queue
-
updated
final OffsetDateTime updated()
Date and time at which the queue was last updated
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_caseCounts
final JsonField<Queue.CaseCounts> _caseCounts()
Returns the raw JSON value of caseCounts.
Unlike caseCounts, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Queue.Builder toBuilder()
-
validate
final Queue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Queue.Builder builder()
Returns a mutable builder for constructing an instance of Queue.
The following fields are required:
.token() .caseCounts() .created() .description() .name() .updated()
-
-
-
-