Class Queue.Builder
-
- All Implemented Interfaces:
public final class Queue.BuilderA builder for Queue.
-
-
Method Summary
Modifier and Type Method Description final Queue.Buildertoken(String token)Globally unique identifier for the queue final Queue.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final Queue.BuildercaseCounts(Queue.CaseCounts caseCounts)Number of cases in the queue, broken down by status. final Queue.BuildercaseCounts(JsonField<Queue.CaseCounts> caseCounts)Sets Builder.caseCounts to an arbitrary JSON value. final Queue.Buildercreated(OffsetDateTime created)Date and time at which the queue was created final Queue.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Queue.Builderdescription(String description)Optional description of the queue final Queue.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final Queue.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final Queue.Buildername(String name)Human-readable name of the queue final Queue.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final Queue.Builderupdated(OffsetDateTime updated)Date and time at which the queue was last updated final Queue.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final Queue.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Queue.BuilderputAdditionalProperty(String key, JsonValue value)final Queue.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Queue.BuilderremoveAdditionalProperty(String key)final Queue.BuilderremoveAllAdditionalProperties(Set<String> keys)final Queuebuild()Returns an immutable instance of Queue. -
-
Method Detail
-
token
final Queue.Builder token(String token)
Globally unique identifier for the queue
-
token
final Queue.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
caseCounts
final Queue.Builder caseCounts(Queue.CaseCounts caseCounts)
Number of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
-
caseCounts
final Queue.Builder caseCounts(JsonField<Queue.CaseCounts> caseCounts)
Sets Builder.caseCounts to an arbitrary JSON value.
You should usually call Builder.caseCounts with a well-typed CaseCounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Queue.Builder created(OffsetDateTime created)
Date and time at which the queue was created
-
created
final Queue.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Queue.Builder description(String description)
Optional description of the queue
-
description
final Queue.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final Queue.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Queue.Builder name(String name)
Human-readable name of the queue
-
name
final Queue.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final Queue.Builder updated(OffsetDateTime updated)
Date and time at which the queue was last updated
-
updated
final Queue.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Queue.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Queue.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Queue.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Queue.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Queue.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-