Class Queue.CaseCounts
-
- All Implemented Interfaces:
public final class Queue.CaseCountsNumber of cases in the queue, broken down by status. A status is omitted when the queue has no cases in that status
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classQueue.CaseCounts.BuilderA builder for CaseCounts.
-
Method Summary
Modifier and Type Method Description final Optional<Long>assigned()Number of cases in the queue with status ASSIGNEDfinal Optional<Long>closed()Number of cases in the queue with status CLOSEDfinal Optional<Long>escalated()Number of cases in the queue with status ESCALATEDfinal Optional<Long>inReview()Number of cases in the queue with status IN_REVIEWfinal Optional<Long>open()Number of cases in the queue with status OPENfinal Optional<Long>resolved()Number of cases in the queue with status RESOLVEDfinal JsonField<Long>_assigned()Returns the raw JSON value of assigned. final JsonField<Long>_closed()Returns the raw JSON value of closed. final JsonField<Long>_escalated()Returns the raw JSON value of escalated. final JsonField<Long>_inReview()Returns the raw JSON value of inReview. final JsonField<Long>_open()Returns the raw JSON value of open. final JsonField<Long>_resolved()Returns the raw JSON value of resolved. final Map<String, JsonValue>_additionalProperties()final Queue.CaseCounts.BuildertoBuilder()final Queue.CaseCountsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Queue.CaseCounts.Builderbuilder()Returns a mutable builder for constructing an instance of CaseCounts. -
-
Method Detail
-
_assigned
final JsonField<Long> _assigned()
Returns the raw JSON value of assigned.
Unlike assigned, this method doesn't throw if the JSON field has an unexpected type.
-
_closed
final JsonField<Long> _closed()
Returns the raw JSON value of closed.
Unlike closed, this method doesn't throw if the JSON field has an unexpected type.
-
_escalated
final JsonField<Long> _escalated()
Returns the raw JSON value of escalated.
Unlike escalated, this method doesn't throw if the JSON field has an unexpected type.
-
_inReview
final JsonField<Long> _inReview()
Returns the raw JSON value of inReview.
Unlike inReview, this method doesn't throw if the JSON field has an unexpected type.
-
_open
final JsonField<Long> _open()
Returns the raw JSON value of open.
Unlike open, this method doesn't throw if the JSON field has an unexpected type.
-
_resolved
final JsonField<Long> _resolved()
Returns the raw JSON value of resolved.
Unlike resolved, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Queue.CaseCounts.Builder toBuilder()
-
validate
final Queue.CaseCounts validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Queue.CaseCounts.Builder builder()
Returns a mutable builder for constructing an instance of CaseCounts.
-
-
-
-