Class Queue.CaseCounts.Builder
-
- All Implemented Interfaces:
public final class Queue.CaseCounts.BuilderA builder for CaseCounts.
-
-
Method Summary
Modifier and Type Method Description final Queue.CaseCounts.Builderassigned(Long assigned)Number of cases in the queue with status ASSIGNEDfinal Queue.CaseCounts.Builderassigned(JsonField<Long> assigned)Sets Builder.assigned to an arbitrary JSON value. final Queue.CaseCounts.Builderclosed(Long closed)Number of cases in the queue with status CLOSEDfinal Queue.CaseCounts.Builderclosed(JsonField<Long> closed)Sets Builder.closed to an arbitrary JSON value. final Queue.CaseCounts.Builderescalated(Long escalated)Number of cases in the queue with status ESCALATEDfinal Queue.CaseCounts.Builderescalated(JsonField<Long> escalated)Sets Builder.escalated to an arbitrary JSON value. final Queue.CaseCounts.BuilderinReview(Long inReview)Number of cases in the queue with status IN_REVIEWfinal Queue.CaseCounts.BuilderinReview(JsonField<Long> inReview)Sets Builder.inReview to an arbitrary JSON value. final Queue.CaseCounts.Builderopen(Long open)Number of cases in the queue with status OPENfinal Queue.CaseCounts.Builderopen(JsonField<Long> open)Sets Builder.open to an arbitrary JSON value. final Queue.CaseCounts.Builderresolved(Long resolved)Number of cases in the queue with status RESOLVEDfinal Queue.CaseCounts.Builderresolved(JsonField<Long> resolved)Sets Builder.resolved to an arbitrary JSON value. final Queue.CaseCounts.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Queue.CaseCounts.BuilderputAdditionalProperty(String key, JsonValue value)final Queue.CaseCounts.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Queue.CaseCounts.BuilderremoveAdditionalProperty(String key)final Queue.CaseCounts.BuilderremoveAllAdditionalProperties(Set<String> keys)final Queue.CaseCountsbuild()Returns an immutable instance of CaseCounts. -
-
Method Detail
-
assigned
final Queue.CaseCounts.Builder assigned(Long assigned)
Number of cases in the queue with status
ASSIGNED
-
assigned
final Queue.CaseCounts.Builder assigned(JsonField<Long> assigned)
Sets Builder.assigned to an arbitrary JSON value.
You should usually call Builder.assigned with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
closed
final Queue.CaseCounts.Builder closed(Long closed)
Number of cases in the queue with status
CLOSED
-
closed
final Queue.CaseCounts.Builder closed(JsonField<Long> closed)
Sets Builder.closed to an arbitrary JSON value.
You should usually call Builder.closed with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
escalated
final Queue.CaseCounts.Builder escalated(Long escalated)
Number of cases in the queue with status
ESCALATED
-
escalated
final Queue.CaseCounts.Builder escalated(JsonField<Long> escalated)
Sets Builder.escalated to an arbitrary JSON value.
You should usually call Builder.escalated with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inReview
final Queue.CaseCounts.Builder inReview(Long inReview)
Number of cases in the queue with status
IN_REVIEW
-
inReview
final Queue.CaseCounts.Builder inReview(JsonField<Long> inReview)
Sets Builder.inReview to an arbitrary JSON value.
You should usually call Builder.inReview with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
open
final Queue.CaseCounts.Builder open(Long open)
Number of cases in the queue with status
OPEN
-
open
final Queue.CaseCounts.Builder open(JsonField<Long> open)
Sets Builder.open to an arbitrary JSON value.
You should usually call Builder.open with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolved
final Queue.CaseCounts.Builder resolved(Long resolved)
Number of cases in the queue with status
RESOLVED
-
resolved
final Queue.CaseCounts.Builder resolved(JsonField<Long> resolved)
Sets Builder.resolved to an arbitrary JSON value.
You should usually call Builder.resolved with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Queue.CaseCounts.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Queue.CaseCounts.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Queue.CaseCounts.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Queue.CaseCounts.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Queue.CaseCounts.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Queue.CaseCounts build()
Returns an immutable instance of CaseCounts.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-