Package com.lithic.api.models
Class ReportSettlementNetworkTotalListPageResponse
-
- All Implemented Interfaces:
public final class ReportSettlementNetworkTotalListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportSettlementNetworkTotalListPageResponse.BuilderA builder for ReportSettlementNetworkTotalListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<NetworkTotal>data()final BooleanhasMore()Indicates whether there are more network total records to be retrieved. final JsonField<List<NetworkTotal>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final ReportSettlementNetworkTotalListPageResponse.BuildertoBuilder()final ReportSettlementNetworkTotalListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportSettlementNetworkTotalListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ReportSettlementNetworkTotalListPageResponse. -
-
Method Detail
-
data
final List<NetworkTotal> data()
-
hasMore
final Boolean hasMore()
Indicates whether there are more network total records to be retrieved.
-
_data
final JsonField<List<NetworkTotal>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportSettlementNetworkTotalListPageResponse.Builder toBuilder()
-
validate
final ReportSettlementNetworkTotalListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReportSettlementNetworkTotalListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ReportSettlementNetworkTotalListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-