Class ReportSettlementNetworkTotalListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ReportSettlementNetworkTotalListParams implements Params
List network total records with optional filters. Not available in sandbox.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportSettlementNetworkTotalListParams.BuilderA builder for ReportSettlementNetworkTotalListParams.
public final classReportSettlementNetworkTotalListParams.NetworkNetwork to filter on.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>begin()Datetime in RFC 3339 format. final Optional<OffsetDateTime>end()Datetime in RFC 3339 format. final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<String>institutionId()Institution ID to filter on. final Optional<ReportSettlementNetworkTotalListParams.Network>network()Network to filter on. final Optional<Long>pageSize()Number of records per page. final Optional<LocalDate>reportDate()Singular report date to filter on (YYYY-MM-DD). final Optional<LocalDate>reportDateBegin()Earliest report date to filter on, inclusive (YYYY-MM-DD). final Optional<LocalDate>reportDateEnd()Latest report date to filter on, inclusive (YYYY-MM-DD). final Optional<String>settlementInstitutionId()Settlement institution ID to filter on. final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ReportSettlementNetworkTotalListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportSettlementNetworkTotalListParamsnone()final static ReportSettlementNetworkTotalListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ReportSettlementNetworkTotalListParams. -
-
Method Detail
-
begin
final Optional<OffsetDateTime> begin()
Datetime in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.
-
end
final Optional<OffsetDateTime> end()
Datetime in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
institutionId
final Optional<String> institutionId()
Institution ID to filter on.
-
network
final Optional<ReportSettlementNetworkTotalListParams.Network> network()
Network to filter on.
-
reportDate
final Optional<LocalDate> reportDate()
Singular report date to filter on (YYYY-MM-DD). Cannot be populated in conjunction with report_date_begin or report_date_end.
-
reportDateBegin
final Optional<LocalDate> reportDateBegin()
Earliest report date to filter on, inclusive (YYYY-MM-DD).
-
reportDateEnd
final Optional<LocalDate> reportDateEnd()
Latest report date to filter on, inclusive (YYYY-MM-DD).
-
settlementInstitutionId
final Optional<String> settlementInstitutionId()
Settlement institution ID to filter on.
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ReportSettlementNetworkTotalListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ReportSettlementNetworkTotalListParams none()
-
builder
final static ReportSettlementNetworkTotalListParams.Builder builder()
Returns a mutable builder for constructing an instance of ReportSettlementNetworkTotalListParams.
-
-
-
-