Class ReportStats
-
- All Implemented Interfaces:
public final class ReportStats
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.BuilderA builder for ReportStats.
public final classReportStats.ActionCountsA mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
public final classReportStats.Examplepublic final classReportStats.AuthRuleVersionStateThe evaluation mode of this version during the reported period.
-
Method Summary
Modifier and Type Method Description final ReportStats.ActionCountsactionCounts()A mapping of action types to the number of times that action was returned by this version during the relevant period. final List<ReportStats.Example>examples()Example events and their outcomes for this version. final ReportStats.AuthRuleVersionStatestate()The evaluation mode of this version during the reported period. final Longversion()The rule version number. final JsonField<ReportStats.ActionCounts>_actionCounts()Returns the raw JSON value of actionCounts. final JsonField<List<ReportStats.Example>>_examples()Returns the raw JSON value of examples. final JsonField<ReportStats.AuthRuleVersionState>_state()Returns the raw JSON value of state. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final ReportStats.BuildertoBuilder()final ReportStatsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Builderbuilder()Returns a mutable builder for constructing an instance of ReportStats. -
-
Method Detail
-
actionCounts
final ReportStats.ActionCounts actionCounts()
A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
examples
final List<ReportStats.Example> examples()
Example events and their outcomes for this version.
-
state
final ReportStats.AuthRuleVersionState state()
The evaluation mode of this version during the reported period.
-
_actionCounts
final JsonField<ReportStats.ActionCounts> _actionCounts()
Returns the raw JSON value of actionCounts.
Unlike actionCounts, this method doesn't throw if the JSON field has an unexpected type.
-
_examples
final JsonField<List<ReportStats.Example>> _examples()
Returns the raw JSON value of examples.
Unlike examples, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<ReportStats.AuthRuleVersionState> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Builder toBuilder()
-
validate
final ReportStats validate()
-
builder
final static ReportStats.Builder builder()
Returns a mutable builder for constructing an instance of ReportStats.
The following fields are required:
.actionCounts() .examples() .state() .version()
-
-
-
-