Class ReportStats.ActionCounts

  • All Implemented Interfaces:

    
    public final class ReportStats.ActionCounts
    
                        

    A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.