Class ReportStats.Builder
-
- All Implemented Interfaces:
public final class ReportStats.BuilderA builder for ReportStats.
-
-
Method Summary
-
-
Method Detail
-
actionCounts
final ReportStats.Builder actionCounts(ReportStats.ActionCounts actionCounts)
A mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
actionCounts
final ReportStats.Builder actionCounts(JsonField<ReportStats.ActionCounts> actionCounts)
Sets Builder.actionCounts to an arbitrary JSON value.
You should usually call Builder.actionCounts with a well-typed ActionCounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
examples
final ReportStats.Builder examples(List<ReportStats.Example> examples)
Example events and their outcomes for this version.
-
examples
final ReportStats.Builder examples(JsonField<List<ReportStats.Example>> examples)
Sets Builder.examples to an arbitrary JSON value.
You should usually call Builder.examples with a well-typed
List<Example>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExample
final ReportStats.Builder addExample(ReportStats.Example example)
-
state
final ReportStats.Builder state(ReportStats.AuthRuleVersionState state)
The evaluation mode of this version during the reported period.
-
state
final ReportStats.Builder state(JsonField<ReportStats.AuthRuleVersionState> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed AuthRuleVersionState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
version
final ReportStats.Builder version(Long version)
The rule version number.
-
version
final ReportStats.Builder version(JsonField<Long> version)
Sets Builder.version to an arbitrary JSON value.
You should usually call Builder.version with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ReportStats.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReportStats.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReportStats.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReportStats.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReportStats.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReportStats build()
Returns an immutable instance of ReportStats.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.actionCounts() .examples() .state() .version()
-
-
-
-