Class ReportStats.Example
-
- All Implemented Interfaces:
public final class ReportStats.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.BuilderA builder for Example.
public final classReportStats.Example.Action
-
Method Summary
Modifier and Type Method Description final List<ReportStats.Example.Action>actions()The actions taken by this version for this event. final StringeventToken()The event token. final OffsetDateTimetimestamp()The timestamp of the event. final Optional<String>transactionToken()The token of the transaction associated with the event final JsonField<List<ReportStats.Example.Action>>_actions()Returns the raw JSON value of actions. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final Map<String, JsonValue>_additionalProperties()final ReportStats.Example.BuildertoBuilder()final ReportStats.Examplevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Example.Builderbuilder()Returns a mutable builder for constructing an instance of Example. -
-
Method Detail
-
actions
final List<ReportStats.Example.Action> actions()
The actions taken by this version for this event.
-
eventToken
final String eventToken()
The event token.
-
timestamp
final OffsetDateTime timestamp()
The timestamp of the event.
-
transactionToken
final Optional<String> transactionToken()
The token of the transaction associated with the event
-
_actions
final JsonField<List<ReportStats.Example.Action>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Builder toBuilder()
-
validate
final ReportStats.Example validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReportStats.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
The following fields are required:
.actions() .eventToken() .timestamp()
-
-
-
-