Package com.lithic.api.models
Class ReportStats.Example.Action.ChallengeActionAuthorization
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.ChallengeActionAuthorization
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.Action.ChallengeActionAuthorization.BuilderA builder for ChallengeActionAuthorization.
public final classReportStats.Example.Action.ChallengeActionAuthorization.Type
-
Method Summary
Modifier and Type Method Description final ReportStats.Example.Action.ChallengeActionAuthorization.Typetype()final JsonField<ReportStats.Example.Action.ChallengeActionAuthorization.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ReportStats.Example.Action.ChallengeActionAuthorization.BuildertoBuilder()final ReportStats.Example.Action.ChallengeActionAuthorizationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Example.Action.ChallengeActionAuthorization.Builderbuilder()Returns a mutable builder for constructing an instance of ChallengeActionAuthorization. -
-
Method Detail
-
_type
final JsonField<ReportStats.Example.Action.ChallengeActionAuthorization.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder toBuilder()
-
validate
final ReportStats.Example.Action.ChallengeActionAuthorization validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReportStats.Example.Action.ChallengeActionAuthorization.Builder builder()
Returns a mutable builder for constructing an instance of ChallengeActionAuthorization.
The following fields are required:
.type()
-
-
-
-