Package com.lithic.api.models
Class ReportStats.Example.Action.ChallengeActionAuthorization.Builder
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.ChallengeActionAuthorization.BuilderA builder for ChallengeActionAuthorization.
-
-
Method Summary
-
-
Method Detail
-
type
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder type(ReportStats.Example.Action.ChallengeActionAuthorization.Type type)
-
type
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder type(JsonField<ReportStats.Example.Action.ChallengeActionAuthorization.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReportStats.Example.Action.ChallengeActionAuthorization.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReportStats.Example.Action.ChallengeActionAuthorization build()
Returns an immutable instance of ChallengeActionAuthorization.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-