Package com.lithic.api.models
Class ReportStats.Example.Action.DeclineActionAuthorization
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.DeclineActionAuthorization
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.Action.DeclineActionAuthorization.BuilderA builder for DeclineActionAuthorization.
public final classReportStats.Example.Action.DeclineActionAuthorization.DetailedResultThe detailed result code explaining the specific reason for the decline
public final classReportStats.Example.Action.DeclineActionAuthorization.Type
-
Method Summary
-
-
Method Detail
-
code
final ReportStats.Example.Action.DeclineActionAuthorization.DetailedResult code()
The detailed result code explaining the specific reason for the decline
-
_code
final JsonField<ReportStats.Example.Action.DeclineActionAuthorization.DetailedResult> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ReportStats.Example.Action.DeclineActionAuthorization.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Action.DeclineActionAuthorization.Builder toBuilder()
-
validate
final ReportStats.Example.Action.DeclineActionAuthorization validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReportStats.Example.Action.DeclineActionAuthorization.Builder builder()
Returns a mutable builder for constructing an instance of DeclineActionAuthorization.
The following fields are required:
.code() .type()
-
-
-
-