Package com.lithic.api.models
Class ReportStats.Example.Action.ResultAuthentication3dsAction.Builder
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.ResultAuthentication3dsAction.BuilderA builder for ResultAuthentication3dsAction.
-
-
Method Summary
-
-
Method Detail
-
type
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder type(ReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsAction type)
-
type
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder type(JsonField<ReportStats.Example.Action.ResultAuthentication3dsAction.Authentication3dsAction> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Authentication3dsAction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReportStats.Example.Action.ResultAuthentication3dsAction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReportStats.Example.Action.ResultAuthentication3dsAction build()
Returns an immutable instance of ResultAuthentication3dsAction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-