Class ReportStats.Example.Builder
-
- All Implemented Interfaces:
public final class ReportStats.Example.BuilderA builder for Example.
-
-
Method Summary
-
-
Method Detail
-
actions
final ReportStats.Example.Builder actions(List<ReportStats.Example.Action> actions)
The actions taken by this version for this event.
-
actions
final ReportStats.Example.Builder actions(JsonField<List<ReportStats.Example.Action>> actions)
Sets Builder.actions to an arbitrary JSON value.
You should usually call Builder.actions with a well-typed
List<Action>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action action)
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.DeclineActionAuthorization declineActionAuthorization)
Alias for calling addAction with
Action.ofDeclineActionAuthorization(declineActionAuthorization).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.ChallengeActionAuthorization challengeActionAuthorization)
Alias for calling addAction with
Action.ofChallengeActionAuthorization(challengeActionAuthorization).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.ResultAuthentication3dsAction resultAuthentication3ds)
Alias for calling addAction with
Action.ofResultAuthentication3ds(resultAuthentication3ds).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.DeclineActionTokenization declineActionTokenization)
Alias for calling addAction with
Action.ofDeclineActionTokenization(declineActionTokenization).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.RequireTfaAction requireTfa)
Alias for calling addAction with
Action.ofRequireTfa(requireTfa).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.ApproveActionAch approveActionAch)
Alias for calling addAction with
Action.ofApproveActionAch(approveActionAch).
-
addAction
final ReportStats.Example.Builder addAction(ReportStats.Example.Action.ReturnAction returnAction)
Alias for calling addAction with
Action.ofReturnAction(returnAction).
-
eventToken
final ReportStats.Example.Builder eventToken(String eventToken)
The event token.
-
eventToken
final ReportStats.Example.Builder eventToken(JsonField<String> eventToken)
Sets Builder.eventToken to an arbitrary JSON value.
You should usually call Builder.eventToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timestamp
final ReportStats.Example.Builder timestamp(OffsetDateTime timestamp)
The timestamp of the event.
-
timestamp
final ReportStats.Example.Builder timestamp(JsonField<OffsetDateTime> timestamp)
Sets Builder.timestamp to an arbitrary JSON value.
You should usually call Builder.timestamp with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionToken
final ReportStats.Example.Builder transactionToken(String transactionToken)
The token of the transaction associated with the event
-
transactionToken
final ReportStats.Example.Builder transactionToken(Optional<String> transactionToken)
Alias for calling Builder.transactionToken with
transactionToken.orElse(null).
-
transactionToken
final ReportStats.Example.Builder transactionToken(JsonField<String> transactionToken)
Sets Builder.transactionToken to an arbitrary JSON value.
You should usually call Builder.transactionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ReportStats.Example.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReportStats.Example.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReportStats.Example.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReportStats.Example.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReportStats.Example.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReportStats.Example build()
Returns an immutable instance of Example.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.actions() .eventToken() .timestamp()
-
-
-
-