Package com.lithic.api.models
Enum ResolutionOutcome.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ResolutionOutcome.Known extends Enum<ResolutionOutcome.Known>
An enum containing ResolutionOutcome's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ResolutionOutcome.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CONFIRMED_FRAUDSUSPICIOUS_ACTIVITYFALSE_POSITIVENO_ACTION_REQUIREDESCALATED_EXTERNAL
-
Method Summary
Modifier and Type Method Description final ResolutionOutcome.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ResolutionOutcome.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ResolutionOutcome.Known>getEntries()An enum containing ResolutionOutcome's known values. -
-
Method Detail
-
valueOf
final ResolutionOutcome.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ResolutionOutcome.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ResolutionOutcome.Known> getEntries()
An enum containing ResolutionOutcome's known values.
-
-
-
-