Package com.lithic.api.models
Class ResponderEndpointCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ResponderEndpointCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
type
final ResponderEndpointCreateParams.Body.Builder type(ResponderEndpointCreateParams.Type type)
The type of the endpoint.
-
type
final ResponderEndpointCreateParams.Body.Builder type(JsonField<ResponderEndpointCreateParams.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final ResponderEndpointCreateParams.Body.Builder url(String url)
The URL for the responder endpoint (must be http(s)).
-
url
final ResponderEndpointCreateParams.Body.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ResponderEndpointCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ResponderEndpointCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ResponderEndpointCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ResponderEndpointCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ResponderEndpointCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ResponderEndpointCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-