Package com.lithic.api.models
Class ResponderEndpointCreateResponse
-
- All Implemented Interfaces:
public final class ResponderEndpointCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponderEndpointCreateResponse.BuilderA builder for ResponderEndpointCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>enrolled()True if the endpoint was enrolled successfully. final JsonField<Boolean>_enrolled()Returns the raw JSON value of enrolled. final Map<String, JsonValue>_additionalProperties()final ResponderEndpointCreateResponse.BuildertoBuilder()final ResponderEndpointCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponderEndpointCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ResponderEndpointCreateResponse. -
-
Method Detail
-
_enrolled
final JsonField<Boolean> _enrolled()
Returns the raw JSON value of enrolled.
Unlike enrolled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponderEndpointCreateResponse.Builder toBuilder()
-
validate
final ResponderEndpointCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponderEndpointCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ResponderEndpointCreateResponse.
-
-
-
-