Package com.lithic.api.models
Class ResponderEndpointCreateResponse.Builder
-
- All Implemented Interfaces:
public final class ResponderEndpointCreateResponse.BuilderA builder for ResponderEndpointCreateResponse.
-
-
Method Summary
Modifier and Type Method Description final ResponderEndpointCreateResponse.Builderenrolled(Boolean enrolled)True if the endpoint was enrolled successfully. final ResponderEndpointCreateResponse.Builderenrolled(JsonField<Boolean> enrolled)Sets Builder.enrolled to an arbitrary JSON value. final ResponderEndpointCreateResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ResponderEndpointCreateResponse.BuilderputAdditionalProperty(String key, JsonValue value)final ResponderEndpointCreateResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ResponderEndpointCreateResponse.BuilderremoveAdditionalProperty(String key)final ResponderEndpointCreateResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final ResponderEndpointCreateResponsebuild()Returns an immutable instance of ResponderEndpointCreateResponse. -
-
Method Detail
-
enrolled
final ResponderEndpointCreateResponse.Builder enrolled(Boolean enrolled)
True if the endpoint was enrolled successfully.
-
enrolled
final ResponderEndpointCreateResponse.Builder enrolled(JsonField<Boolean> enrolled)
Sets Builder.enrolled to an arbitrary JSON value.
You should usually call Builder.enrolled with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ResponderEndpointCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ResponderEndpointCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ResponderEndpointCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ResponderEndpointCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ResponderEndpointCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ResponderEndpointCreateResponse build()
Returns an immutable instance of ResponderEndpointCreateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-