Package com.lithic.api.models
Class ResponderEndpointStatus
-
- All Implemented Interfaces:
public final class ResponderEndpointStatus
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponderEndpointStatus.BuilderA builder for ResponderEndpointStatus.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>enrolled()True if the instance has an endpoint enrolled. final Optional<String>url()The URL of the currently enrolled endpoint or null. final JsonField<Boolean>_enrolled()Returns the raw JSON value of enrolled. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final ResponderEndpointStatus.BuildertoBuilder()final ResponderEndpointStatusvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponderEndpointStatus.Builderbuilder()Returns a mutable builder for constructing an instance of ResponderEndpointStatus. -
-
Method Detail
-
_enrolled
final JsonField<Boolean> _enrolled()
Returns the raw JSON value of enrolled.
Unlike enrolled, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponderEndpointStatus.Builder toBuilder()
-
validate
final ResponderEndpointStatus validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponderEndpointStatus.Builder builder()
Returns a mutable builder for constructing an instance of ResponderEndpointStatus.
-
-
-
-