Class ResponderEndpointStatus.Builder
-
- All Implemented Interfaces:
public final class ResponderEndpointStatus.BuilderA builder for ResponderEndpointStatus.
-
-
Method Summary
-
-
Method Detail
-
enrolled
final ResponderEndpointStatus.Builder enrolled(Boolean enrolled)
True if the instance has an endpoint enrolled.
-
enrolled
final ResponderEndpointStatus.Builder enrolled(JsonField<Boolean> enrolled)
Sets Builder.enrolled to an arbitrary JSON value.
You should usually call Builder.enrolled with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final ResponderEndpointStatus.Builder url(String url)
The URL of the currently enrolled endpoint or null.
-
url
final ResponderEndpointStatus.Builder url(Optional<String> url)
Alias for calling Builder.url with
url.orElse(null).
-
url
final ResponderEndpointStatus.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ResponderEndpointStatus.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ResponderEndpointStatus.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ResponderEndpointStatus.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ResponderEndpointStatus.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ResponderEndpointStatus.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ResponderEndpointStatus build()
Returns an immutable instance of ResponderEndpointStatus.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-