Class RuleFeature

  • All Implemented Interfaces:

    
    public final class RuleFeature
    
                        

    A feature made available to the rule. The name field is the variable name used in the rule function signature. The type field determines which data the feature provides to the rule at evaluation time.

    • AUTHORIZATION: The authorization request being evaluated. Only available for AUTHORIZATION event stream rules.

    • AUTHENTICATION: The 3DS authentication request being evaluated. Only available for THREE_DS_AUTHENTICATION event stream rules.

    • TOKENIZATION: The tokenization request being evaluated. Only available for TOKENIZATION event stream rules.

    • ACH_RECEIPT: The ACH receipt being evaluated. Only available for ACH_CREDIT_RECEIPT and ACH_DEBIT_RECEIPT event stream rules.

    • CARD: The card associated with the event. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.

    • ACCOUNT_HOLDER: The account holder associated with the card. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.

    • IP_METADATA: IP address metadata for the request. Available for THREE_DS_AUTHENTICATION event stream rules.

    • SPEND_VELOCITY: Spend velocity data for the card or account. Requires scope, period, and optionally filters to configure the velocity calculation. Available for AUTHORIZATION event stream rules.