Class RuleFeature.AchPaymentHistoryFeature.Builder
-
- All Implemented Interfaces:
public final class RuleFeature.AchPaymentHistoryFeature.BuilderA builder for AchPaymentHistoryFeature.
-
-
Method Summary
-
-
Method Detail
-
scope
final RuleFeature.AchPaymentHistoryFeature.Builder scope(RuleFeature.AchPaymentHistoryFeature.Scope scope)
The entity scope to load ACH payment history for.
-
scope
final RuleFeature.AchPaymentHistoryFeature.Builder scope(JsonField<RuleFeature.AchPaymentHistoryFeature.Scope> scope)
Sets Builder.scope to an arbitrary JSON value.
You should usually call Builder.scope with a well-typed Scope value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final RuleFeature.AchPaymentHistoryFeature.Builder type(RuleFeature.AchPaymentHistoryFeature.Type type)
-
type
final RuleFeature.AchPaymentHistoryFeature.Builder type(JsonField<RuleFeature.AchPaymentHistoryFeature.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final RuleFeature.AchPaymentHistoryFeature.Builder name(String name)
The variable name for this feature in the rule function signature
-
name
final RuleFeature.AchPaymentHistoryFeature.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleFeature.AchPaymentHistoryFeature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleFeature.AchPaymentHistoryFeature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleFeature.AchPaymentHistoryFeature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleFeature.AchPaymentHistoryFeature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleFeature.AchPaymentHistoryFeature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleFeature.AchPaymentHistoryFeature build()
Returns an immutable instance of AchPaymentHistoryFeature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.scope() .type()
-
-
-
-