Package com.lithic.api.models
Class RuleFeature.AuthenticationFeature
-
- All Implemented Interfaces:
public final class RuleFeature.AuthenticationFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.AuthenticationFeature.BuilderA builder for AuthenticationFeature.
public final classRuleFeature.AuthenticationFeature.Type
-
Method Summary
Modifier and Type Method Description final RuleFeature.AuthenticationFeature.Typetype()final Optional<String>name()The variable name for this feature in the rule function signature final JsonField<RuleFeature.AuthenticationFeature.Type>_type()Returns the raw JSON value of type. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final RuleFeature.AuthenticationFeature.BuildertoBuilder()final RuleFeature.AuthenticationFeaturevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleFeature.AuthenticationFeature.Builderbuilder()Returns a mutable builder for constructing an instance of AuthenticationFeature. -
-
Method Detail
-
type
final RuleFeature.AuthenticationFeature.Type type()
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_type
final JsonField<RuleFeature.AuthenticationFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.AuthenticationFeature.Builder toBuilder()
-
validate
final RuleFeature.AuthenticationFeature validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleFeature.AuthenticationFeature.Builder builder()
Returns a mutable builder for constructing an instance of AuthenticationFeature.
The following fields are required:
.type()
-
-
-
-