Package com.lithic.api.models
Class RuleFeature.CardFeature.Builder
-
- All Implemented Interfaces:
public final class RuleFeature.CardFeature.BuilderA builder for CardFeature.
-
-
Method Summary
-
-
Method Detail
-
type
final RuleFeature.CardFeature.Builder type(RuleFeature.CardFeature.Type type)
-
type
final RuleFeature.CardFeature.Builder type(JsonField<RuleFeature.CardFeature.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final RuleFeature.CardFeature.Builder name(String name)
The variable name for this feature in the rule function signature
-
name
final RuleFeature.CardFeature.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleFeature.CardFeature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleFeature.CardFeature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleFeature.CardFeature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleFeature.CardFeature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleFeature.CardFeature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleFeature.CardFeature build()
Returns an immutable instance of CardFeature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-