Class RuleFeature.ConsecutiveDeclinesFeature
-
- All Implemented Interfaces:
public final class RuleFeature.ConsecutiveDeclinesFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.ConsecutiveDeclinesFeature.BuilderA builder for ConsecutiveDeclinesFeature.
public final classRuleFeature.ConsecutiveDeclinesFeature.ScopeThe entity scope to count consecutive declines for.
public final classRuleFeature.ConsecutiveDeclinesFeature.Type
-
Method Summary
Modifier and Type Method Description final RuleFeature.ConsecutiveDeclinesFeature.Scopescope()The entity scope to count consecutive declines for. final RuleFeature.ConsecutiveDeclinesFeature.Typetype()final Optional<String>name()The variable name for this feature in the rule function signature final JsonField<RuleFeature.ConsecutiveDeclinesFeature.Scope>_scope()Returns the raw JSON value of scope. final JsonField<RuleFeature.ConsecutiveDeclinesFeature.Type>_type()Returns the raw JSON value of type. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final RuleFeature.ConsecutiveDeclinesFeature.BuildertoBuilder()final RuleFeature.ConsecutiveDeclinesFeaturevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleFeature.ConsecutiveDeclinesFeature.Builderbuilder()Returns a mutable builder for constructing an instance of ConsecutiveDeclinesFeature. -
-
Method Detail
-
scope
final RuleFeature.ConsecutiveDeclinesFeature.Scope scope()
The entity scope to count consecutive declines for.
-
type
final RuleFeature.ConsecutiveDeclinesFeature.Type type()
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_scope
final JsonField<RuleFeature.ConsecutiveDeclinesFeature.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RuleFeature.ConsecutiveDeclinesFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.ConsecutiveDeclinesFeature.Builder toBuilder()
-
validate
final RuleFeature.ConsecutiveDeclinesFeature validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleFeature.ConsecutiveDeclinesFeature.Builder builder()
Returns a mutable builder for constructing an instance of ConsecutiveDeclinesFeature.
The following fields are required:
.scope() .type()
-
-
-
-