Class RuleFeature.ConsecutiveDeclinesFeature.Builder
-
- All Implemented Interfaces:
public final class RuleFeature.ConsecutiveDeclinesFeature.BuilderA builder for ConsecutiveDeclinesFeature.
-
-
Method Summary
-
-
Method Detail
-
scope
final RuleFeature.ConsecutiveDeclinesFeature.Builder scope(RuleFeature.ConsecutiveDeclinesFeature.Scope scope)
The entity scope to count consecutive declines for.
-
scope
final RuleFeature.ConsecutiveDeclinesFeature.Builder scope(JsonField<RuleFeature.ConsecutiveDeclinesFeature.Scope> scope)
Sets Builder.scope to an arbitrary JSON value.
You should usually call Builder.scope with a well-typed Scope value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final RuleFeature.ConsecutiveDeclinesFeature.Builder type(RuleFeature.ConsecutiveDeclinesFeature.Type type)
-
type
final RuleFeature.ConsecutiveDeclinesFeature.Builder type(JsonField<RuleFeature.ConsecutiveDeclinesFeature.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final RuleFeature.ConsecutiveDeclinesFeature.Builder name(String name)
The variable name for this feature in the rule function signature
-
name
final RuleFeature.ConsecutiveDeclinesFeature.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleFeature.ConsecutiveDeclinesFeature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleFeature.ConsecutiveDeclinesFeature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleFeature.ConsecutiveDeclinesFeature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleFeature.ConsecutiveDeclinesFeature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleFeature.ConsecutiveDeclinesFeature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleFeature.ConsecutiveDeclinesFeature build()
Returns an immutable instance of ConsecutiveDeclinesFeature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.scope() .type()
-
-
-
-