Class RuleFeature.PaymentVelocityFeature
-
- All Implemented Interfaces:
public final class RuleFeature.PaymentVelocityFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.PaymentVelocityFeature.BuilderA builder for PaymentVelocityFeature.
public final classRuleFeature.PaymentVelocityFeature.ScopeThe scope over which the ACH payment velocity is aggregated.
public final classRuleFeature.PaymentVelocityFeature.Typepublic final classRuleFeature.PaymentVelocityFeature.PaymentVelocityFiltersOptional filters applied when aggregating ACH payment velocity. Payments not matching the provided filters are excluded from the calculated velocity.
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriodperiod()Velocity over the current day since 00:00 / 12 AM in Eastern Time final RuleFeature.PaymentVelocityFeature.Scopescope()The scope over which the ACH payment velocity is aggregated. final RuleFeature.PaymentVelocityFeature.Typetype()final Optional<RuleFeature.PaymentVelocityFeature.PaymentVelocityFilters>filters()Optional filters applied when aggregating ACH payment velocity. final Optional<String>name()The variable name for this feature in the rule function signature final JsonField<VelocityLimitPeriod>_period()Returns the raw JSON value of period. final JsonField<RuleFeature.PaymentVelocityFeature.Scope>_scope()Returns the raw JSON value of scope. final JsonField<RuleFeature.PaymentVelocityFeature.Type>_type()Returns the raw JSON value of type. final JsonField<RuleFeature.PaymentVelocityFeature.PaymentVelocityFilters>_filters()Returns the raw JSON value of filters. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final RuleFeature.PaymentVelocityFeature.BuildertoBuilder()final RuleFeature.PaymentVelocityFeaturevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleFeature.PaymentVelocityFeature.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentVelocityFeature. -
-
Method Detail
-
period
final VelocityLimitPeriod period()
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
scope
final RuleFeature.PaymentVelocityFeature.Scope scope()
The scope over which the ACH payment velocity is aggregated.
-
type
final RuleFeature.PaymentVelocityFeature.Type type()
-
filters
final Optional<RuleFeature.PaymentVelocityFeature.PaymentVelocityFilters> filters()
Optional filters applied when aggregating ACH payment velocity. Payments not matching the provided filters are excluded from the calculated velocity.
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_period
final JsonField<VelocityLimitPeriod> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<RuleFeature.PaymentVelocityFeature.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RuleFeature.PaymentVelocityFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_filters
final JsonField<RuleFeature.PaymentVelocityFeature.PaymentVelocityFilters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.PaymentVelocityFeature.Builder toBuilder()
-
validate
final RuleFeature.PaymentVelocityFeature validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RuleFeature.PaymentVelocityFeature.Builder builder()
Returns a mutable builder for constructing an instance of PaymentVelocityFeature.
The following fields are required:
.period() .scope() .type()
-
-
-
-