Package com.lithic.api.models
Class RuleFeature.TokenizationFeature
-
- All Implemented Interfaces:
public final class RuleFeature.TokenizationFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.TokenizationFeature.BuilderA builder for TokenizationFeature.
public final classRuleFeature.TokenizationFeature.Type
-
Method Summary
Modifier and Type Method Description final RuleFeature.TokenizationFeature.Typetype()final Optional<String>name()The variable name for this feature in the rule function signature final JsonField<RuleFeature.TokenizationFeature.Type>_type()Returns the raw JSON value of type. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final RuleFeature.TokenizationFeature.BuildertoBuilder()final RuleFeature.TokenizationFeaturevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RuleFeature.TokenizationFeature.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationFeature. -
-
Method Detail
-
type
final RuleFeature.TokenizationFeature.Type type()
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_type
final JsonField<RuleFeature.TokenizationFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.TokenizationFeature.Builder toBuilder()
-
validate
final RuleFeature.TokenizationFeature validate()
-
builder
final static RuleFeature.TokenizationFeature.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationFeature.
The following fields are required:
.type()
-
-
-
-