Package com.lithic.api.models
Class RuleFeature.TokenizationFeature.Builder
-
- All Implemented Interfaces:
public final class RuleFeature.TokenizationFeature.BuilderA builder for TokenizationFeature.
-
-
Method Summary
-
-
Method Detail
-
type
final RuleFeature.TokenizationFeature.Builder type(JsonField<RuleFeature.TokenizationFeature.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final RuleFeature.TokenizationFeature.Builder name(String name)
The variable name for this feature in the rule function signature
-
name
final RuleFeature.TokenizationFeature.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleFeature.TokenizationFeature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleFeature.TokenizationFeature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleFeature.TokenizationFeature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleFeature.TokenizationFeature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleFeature.TokenizationFeature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleFeature.TokenizationFeature build()
Returns an immutable instance of TokenizationFeature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-