Class RuleFeature.TransactionHistorySignalsFeature.Builder
-
- All Implemented Interfaces:
public final class RuleFeature.TransactionHistorySignalsFeature.BuilderA builder for TransactionHistorySignalsFeature.
-
-
Method Summary
-
-
Method Detail
-
scope
final RuleFeature.TransactionHistorySignalsFeature.Builder scope(RuleFeature.TransactionHistorySignalsFeature.Scope scope)
The entity scope to load transaction history signals for.
-
scope
final RuleFeature.TransactionHistorySignalsFeature.Builder scope(JsonField<RuleFeature.TransactionHistorySignalsFeature.Scope> scope)
Sets Builder.scope to an arbitrary JSON value.
You should usually call Builder.scope with a well-typed Scope value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final RuleFeature.TransactionHistorySignalsFeature.Builder type(RuleFeature.TransactionHistorySignalsFeature.Type type)
-
type
final RuleFeature.TransactionHistorySignalsFeature.Builder type(JsonField<RuleFeature.TransactionHistorySignalsFeature.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final RuleFeature.TransactionHistorySignalsFeature.Builder name(String name)
The variable name for this feature in the rule function signature
-
name
final RuleFeature.TransactionHistorySignalsFeature.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RuleFeature.TransactionHistorySignalsFeature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RuleFeature.TransactionHistorySignalsFeature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RuleFeature.TransactionHistorySignalsFeature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RuleFeature.TransactionHistorySignalsFeature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RuleFeature.TransactionHistorySignalsFeature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RuleFeature.TransactionHistorySignalsFeature build()
Returns an immutable instance of TransactionHistorySignalsFeature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.scope() .type()
-
-
-
-