Package com.lithic.api.models
Enum RuleFeature.TransactionHistorySignalsFeature.Scope.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RuleFeature.TransactionHistorySignalsFeature.Scope.Known extends Enum<RuleFeature.TransactionHistorySignalsFeature.Scope.Known>
An enum containing Scope's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RuleFeature.TransactionHistorySignalsFeature.Scope.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARDACCOUNTBUSINESS_ACCOUNT
-
Method Summary
Modifier and Type Method Description final RuleFeature.TransactionHistorySignalsFeature.Scope.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RuleFeature.TransactionHistorySignalsFeature.Scope.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RuleFeature.TransactionHistorySignalsFeature.Scope.Known>getEntries()An enum containing Scope's known values. -
-
Method Detail
-
valueOf
final RuleFeature.TransactionHistorySignalsFeature.Scope.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RuleFeature.TransactionHistorySignalsFeature.Scope.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RuleFeature.TransactionHistorySignalsFeature.Scope.Known> getEntries()
An enum containing Scope's known values.
-
-
-
-