Package com.lithic.api.models
Interface RuleFeature.Visitor
-
- All Implemented Interfaces:
public interface RuleFeature.Visitor<T extends Object>An interface that defines how to map each variant of RuleFeature to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitAuthorization(RuleFeature.AuthorizationFeature authorization)abstract TvisitAuthentication(RuleFeature.AuthenticationFeature authentication)abstract TvisitTokenization(RuleFeature.TokenizationFeature tokenization)abstract TvisitAchReceipt(RuleFeature.AchReceiptFeature achReceipt)abstract TvisitCard(RuleFeature.CardFeature card)abstract TvisitAccountHolder(RuleFeature.AccountHolderFeature accountHolder)abstract TvisitIpMetadata(RuleFeature.IpMetadataFeature ipMetadata)abstract TvisitSpendVelocity(RuleFeature.SpendVelocityFeature spendVelocity)Tunknown(JsonValue json)Maps an unknown variant of RuleFeature to a value of type T. -
-
Method Detail
-
visitAuthorization
abstract T visitAuthorization(RuleFeature.AuthorizationFeature authorization)
-
visitAuthentication
abstract T visitAuthentication(RuleFeature.AuthenticationFeature authentication)
-
visitTokenization
abstract T visitTokenization(RuleFeature.TokenizationFeature tokenization)
-
visitAchReceipt
abstract T visitAchReceipt(RuleFeature.AchReceiptFeature achReceipt)
-
visitCard
abstract T visitCard(RuleFeature.CardFeature card)
-
visitAccountHolder
abstract T visitAccountHolder(RuleFeature.AccountHolderFeature accountHolder)
-
visitIpMetadata
abstract T visitIpMetadata(RuleFeature.IpMetadataFeature ipMetadata)
-
visitSpendVelocity
abstract T visitSpendVelocity(RuleFeature.SpendVelocityFeature spendVelocity)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of RuleFeature to a value of type T.
An instance of RuleFeature can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-