Class SettlementDetail
-
- All Implemented Interfaces:
public final class SettlementDetail
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettlementDetail.BuilderA builder for SettlementDetail.
public final classSettlementDetail.NetworkCard network where the transaction took place.
public final classSettlementDetail.OtherFeesDetailsThe total gross amount of other fees by type.
public final classSettlementDetail.TypeThe type of settlement record.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier denoting the Settlement Detail. final Optional<String>accountToken()Globally unique identifier denoting the account that the associated transaction occurred on. final Optional<String>cardProgramToken()Globally unique identifier denoting the card program that the associated transaction occurred on. final Optional<String>cardToken()Globally unique identifier denoting the card that the associated transaction occurred on. final OffsetDateTimecreated()Date and time when the transaction first occurred. final Stringcurrency()Three-character alphabetic ISO 4217 code. final LongdisputesGrossAmount()The total gross amount of disputes settlements. final List<String>eventTokens()Array of globally unique identifiers for the financial events that comprise this settlement. final Stringinstitution()The most granular ID the network settles with (e.g., ICA for Mastercard, FTSRE for Visa). final LonginterchangeFeeExtendedPrecision()The total amount of interchange in six-digit extended precision. final LonginterchangeGrossAmount()The total amount of interchange. final SettlementDetail.Networknetwork()Card network where the transaction took place. final SettlementDetail.OtherFeesDetailsotherFeesDetails()The total gross amount of other fees by type. final LongotherFeesGrossAmount()Total amount of gross other fees outside of interchange. final StringreportDate()Date of when the report was first generated. final StringsettlementDate()Date of when money movement is triggered for the transaction. final Optional<String>transactionToken()Globally unique identifier denoting the associated transaction. final LongtransactionsGrossAmount()The total amount of settlement impacting transactions (excluding interchange, fees, and disputes). final SettlementDetail.Typetype()The type of settlement record. final OffsetDateTimeupdated()Date and time when the transaction first occurred. final Optional<String>feeDescription()Network's description of a fee, only present on records with type FEE.final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_accountToken()Returns the raw JSON value of accountToken. final JsonField<String>_cardProgramToken()Returns the raw JSON value of cardProgramToken. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<Long>_disputesGrossAmount()Returns the raw JSON value of disputesGrossAmount. final JsonField<List<String>>_eventTokens()Returns the raw JSON value of eventTokens. final JsonField<String>_institution()Returns the raw JSON value of institution. final JsonField<Long>_interchangeFeeExtendedPrecision()Returns the raw JSON value of interchangeFeeExtendedPrecision. final JsonField<Long>_interchangeGrossAmount()Returns the raw JSON value of interchangeGrossAmount. final JsonField<SettlementDetail.Network>_network()Returns the raw JSON value of network. final JsonField<SettlementDetail.OtherFeesDetails>_otherFeesDetails()Returns the raw JSON value of otherFeesDetails. final JsonField<Long>_otherFeesGrossAmount()Returns the raw JSON value of otherFeesGrossAmount. final JsonField<String>_reportDate()Returns the raw JSON value of reportDate. final JsonField<String>_settlementDate()Returns the raw JSON value of settlementDate. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final JsonField<Long>_transactionsGrossAmount()Returns the raw JSON value of transactionsGrossAmount. final JsonField<SettlementDetail.Type>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<String>_feeDescription()Returns the raw JSON value of feeDescription. final Map<String, JsonValue>_additionalProperties()final SettlementDetail.BuildertoBuilder()final SettlementDetailvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SettlementDetail.Builderbuilder()Returns a mutable builder for constructing an instance of SettlementDetail. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
Globally unique identifier denoting the account that the associated transaction occurred on.
-
cardProgramToken
final Optional<String> cardProgramToken()
Globally unique identifier denoting the card program that the associated transaction occurred on.
-
cardToken
final Optional<String> cardToken()
Globally unique identifier denoting the card that the associated transaction occurred on.
-
created
final OffsetDateTime created()
Date and time when the transaction first occurred. UTC time zone.
-
disputesGrossAmount
final Long disputesGrossAmount()
The total gross amount of disputes settlements.
-
eventTokens
final List<String> eventTokens()
Array of globally unique identifiers for the financial events that comprise this settlement. Use these tokens to access detailed event-level information.
-
institution
final String institution()
The most granular ID the network settles with (e.g., ICA for Mastercard, FTSRE for Visa).
-
interchangeFeeExtendedPrecision
final Long interchangeFeeExtendedPrecision()
The total amount of interchange in six-digit extended precision.
-
interchangeGrossAmount
final Long interchangeGrossAmount()
The total amount of interchange.
-
network
final SettlementDetail.Network network()
Card network where the transaction took place.
-
otherFeesDetails
final SettlementDetail.OtherFeesDetails otherFeesDetails()
The total gross amount of other fees by type.
-
otherFeesGrossAmount
final Long otherFeesGrossAmount()
Total amount of gross other fees outside of interchange.
-
reportDate
final String reportDate()
Date of when the report was first generated.
-
settlementDate
final String settlementDate()
Date of when money movement is triggered for the transaction. One exception applies - for Mastercard dual message settlement, this is the settlement advisement date, which is distinct from the date of money movement.
-
transactionToken
final Optional<String> transactionToken()
Globally unique identifier denoting the associated transaction. For settlement records with type
CLEARING,FINANCIAL, orNON_FINANCIAL, this references a card transaction token. For settlement records with typeCHARGEBACK,REPRESENTMENT,PREARBITRATION,ARBITRATION, orCOLLABORATION, this references the dispute transaction token. May be null for certain settlement types.
-
transactionsGrossAmount
final Long transactionsGrossAmount()
The total amount of settlement impacting transactions (excluding interchange, fees, and disputes).
-
type
final SettlementDetail.Type type()
The type of settlement record.
-
updated
final OffsetDateTime updated()
Date and time when the transaction first occurred. UTC time zone.
-
feeDescription
final Optional<String> feeDescription()
Network's description of a fee, only present on records with type
FEE.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardProgramToken
final JsonField<String> _cardProgramToken()
Returns the raw JSON value of cardProgramToken.
Unlike cardProgramToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_disputesGrossAmount
final JsonField<Long> _disputesGrossAmount()
Returns the raw JSON value of disputesGrossAmount.
Unlike disputesGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_eventTokens
final JsonField<List<String>> _eventTokens()
Returns the raw JSON value of eventTokens.
Unlike eventTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_institution
final JsonField<String> _institution()
Returns the raw JSON value of institution.
Unlike institution, this method doesn't throw if the JSON field has an unexpected type.
-
_interchangeFeeExtendedPrecision
final JsonField<Long> _interchangeFeeExtendedPrecision()
Returns the raw JSON value of interchangeFeeExtendedPrecision.
Unlike interchangeFeeExtendedPrecision, this method doesn't throw if the JSON field has an unexpected type.
-
_interchangeGrossAmount
final JsonField<Long> _interchangeGrossAmount()
Returns the raw JSON value of interchangeGrossAmount.
Unlike interchangeGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<SettlementDetail.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_otherFeesDetails
final JsonField<SettlementDetail.OtherFeesDetails> _otherFeesDetails()
Returns the raw JSON value of otherFeesDetails.
Unlike otherFeesDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_otherFeesGrossAmount
final JsonField<Long> _otherFeesGrossAmount()
Returns the raw JSON value of otherFeesGrossAmount.
Unlike otherFeesGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_reportDate
final JsonField<String> _reportDate()
Returns the raw JSON value of reportDate.
Unlike reportDate, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementDate
final JsonField<String> _settlementDate()
Returns the raw JSON value of settlementDate.
Unlike settlementDate, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionsGrossAmount
final JsonField<Long> _transactionsGrossAmount()
Returns the raw JSON value of transactionsGrossAmount.
Unlike transactionsGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SettlementDetail.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_feeDescription
final JsonField<String> _feeDescription()
Returns the raw JSON value of feeDescription.
Unlike feeDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SettlementDetail.Builder toBuilder()
-
validate
final SettlementDetail validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SettlementDetail.Builder builder()
Returns a mutable builder for constructing an instance of SettlementDetail.
The following fields are required:
.token() .accountToken() .cardProgramToken() .cardToken() .created() .currency() .disputesGrossAmount() .eventTokens() .institution() .interchangeFeeExtendedPrecision() .interchangeGrossAmount() .network() .otherFeesDetails() .otherFeesGrossAmount() .reportDate() .settlementDate() .transactionToken() .transactionsGrossAmount() .type() .updated()
-
-
-
-