Class SettlementReportUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class SettlementReportUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettlementReportUpdatedWebhookEvent.BuilderA builder for SettlementReportUpdatedWebhookEvent.
public final classSettlementReportUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final SettlementReporttoSettlementReport()final OffsetDateTimecreated()Date and time when the transaction first occurred. final Stringcurrency()3-character alphabetic ISO 4217 code. final List<SettlementSummaryDetails>details()final LongdisputesGrossAmount()The total gross amount of disputes settlements. final LonginterchangeGrossAmount()The total amount of interchange. final BooleanisComplete()Indicates that all data expected on the given report date is available. final LongotherFeesGrossAmount()Total amount of gross other fees outside of interchange. final StringreportDate()Date of when the report was first generated. final LongsettledNetAmount()The total net amount of cash moved. final LongtransactionsGrossAmount()The total amount of settlement impacting transactions (excluding interchange, fees, and disputes). final OffsetDateTimeupdated()Date and time when the transaction first occurred. final SettlementReportUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<List<SettlementSummaryDetails>>_details()Returns the raw JSON value of details. final JsonField<Long>_disputesGrossAmount()Returns the raw JSON value of disputesGrossAmount. final JsonField<Long>_interchangeGrossAmount()Returns the raw JSON value of interchangeGrossAmount. final JsonField<Boolean>_isComplete()Returns the raw JSON value of isComplete. final JsonField<Long>_otherFeesGrossAmount()Returns the raw JSON value of otherFeesGrossAmount. final JsonField<String>_reportDate()Returns the raw JSON value of reportDate. final JsonField<Long>_settledNetAmount()Returns the raw JSON value of settledNetAmount. final JsonField<Long>_transactionsGrossAmount()Returns the raw JSON value of transactionsGrossAmount. final JsonField<OffsetDateTime>_updated()Returns the raw JSON value of updated. final JsonField<SettlementReportUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final SettlementReportUpdatedWebhookEvent.BuildertoBuilder()final SettlementReportUpdatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SettlementReportUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of SettlementReportUpdatedWebhookEvent. -
-
Method Detail
-
toSettlementReport
final SettlementReport toSettlementReport()
-
created
final OffsetDateTime created()
Date and time when the transaction first occurred. UTC time zone.
-
currency
@Deprecated(message = "deprecated") final String currency()
3-character alphabetic ISO 4217 code. (This field is deprecated and will be removed in a future version of the API.)
-
details
final List<SettlementSummaryDetails> details()
-
disputesGrossAmount
@Deprecated(message = "deprecated") final Long disputesGrossAmount()
The total gross amount of disputes settlements. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
interchangeGrossAmount
@Deprecated(message = "deprecated") final Long interchangeGrossAmount()
The total amount of interchange. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
isComplete
final Boolean isComplete()
Indicates that all data expected on the given report date is available.
-
otherFeesGrossAmount
@Deprecated(message = "deprecated") final Long otherFeesGrossAmount()
Total amount of gross other fees outside of interchange. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
reportDate
final String reportDate()
Date of when the report was first generated.
-
settledNetAmount
@Deprecated(message = "deprecated") final Long settledNetAmount()
The total net amount of cash moved. (net value of settled_gross_amount, interchange, fees). (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
transactionsGrossAmount
@Deprecated(message = "deprecated") final Long transactionsGrossAmount()
The total amount of settlement impacting transactions (excluding interchange, fees, and disputes). (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
updated
final OffsetDateTime updated()
Date and time when the transaction first occurred. UTC time zone.
-
eventType
final SettlementReportUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
@Deprecated(message = "deprecated") final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_details
final JsonField<List<SettlementSummaryDetails>> _details()
Returns the raw JSON value of details.
Unlike details, this method doesn't throw if the JSON field has an unexpected type.
-
_disputesGrossAmount
@Deprecated(message = "deprecated") final JsonField<Long> _disputesGrossAmount()
Returns the raw JSON value of disputesGrossAmount.
Unlike disputesGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_interchangeGrossAmount
@Deprecated(message = "deprecated") final JsonField<Long> _interchangeGrossAmount()
Returns the raw JSON value of interchangeGrossAmount.
Unlike interchangeGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_isComplete
final JsonField<Boolean> _isComplete()
Returns the raw JSON value of isComplete.
Unlike isComplete, this method doesn't throw if the JSON field has an unexpected type.
-
_otherFeesGrossAmount
@Deprecated(message = "deprecated") final JsonField<Long> _otherFeesGrossAmount()
Returns the raw JSON value of otherFeesGrossAmount.
Unlike otherFeesGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_reportDate
final JsonField<String> _reportDate()
Returns the raw JSON value of reportDate.
Unlike reportDate, this method doesn't throw if the JSON field has an unexpected type.
-
_settledNetAmount
@Deprecated(message = "deprecated") final JsonField<Long> _settledNetAmount()
Returns the raw JSON value of settledNetAmount.
Unlike settledNetAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionsGrossAmount
@Deprecated(message = "deprecated") final JsonField<Long> _transactionsGrossAmount()
Returns the raw JSON value of transactionsGrossAmount.
Unlike transactionsGrossAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<SettlementReportUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SettlementReportUpdatedWebhookEvent.Builder toBuilder()
-
validate
final SettlementReportUpdatedWebhookEvent validate()
-
builder
final static SettlementReportUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of SettlementReportUpdatedWebhookEvent.
The following fields are required:
.created() .currency() .details() .disputesGrossAmount() .interchangeGrossAmount() .isComplete() .otherFeesGrossAmount() .reportDate() .settledNetAmount() .transactionsGrossAmount() .updated() .eventType()
-
-
-
-