Class SettlementReportUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class SettlementReportUpdatedWebhookEvent.BuilderA builder for SettlementReportUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
created
final SettlementReportUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Date and time when the transaction first occurred. UTC time zone.
-
created
final SettlementReportUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder currency(String currency)
3-character alphabetic ISO 4217 code. (This field is deprecated and will be removed in a future version of the API.)
-
currency
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
details
final SettlementReportUpdatedWebhookEvent.Builder details(List<SettlementSummaryDetails> details)
-
details
final SettlementReportUpdatedWebhookEvent.Builder details(JsonField<List<SettlementSummaryDetails>> details)
Sets Builder.details to an arbitrary JSON value.
You should usually call Builder.details with a well-typed
List<SettlementSummaryDetails>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDetail
final SettlementReportUpdatedWebhookEvent.Builder addDetail(SettlementSummaryDetails detail)
Adds a single SettlementSummaryDetails to details.
-
disputesGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder disputesGrossAmount(Long disputesGrossAmount)
The total gross amount of disputes settlements. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
disputesGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder disputesGrossAmount(JsonField<Long> disputesGrossAmount)
Sets Builder.disputesGrossAmount to an arbitrary JSON value.
You should usually call Builder.disputesGrossAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interchangeGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder interchangeGrossAmount(Long interchangeGrossAmount)
The total amount of interchange. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
interchangeGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder interchangeGrossAmount(JsonField<Long> interchangeGrossAmount)
Sets Builder.interchangeGrossAmount to an arbitrary JSON value.
You should usually call Builder.interchangeGrossAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isComplete
final SettlementReportUpdatedWebhookEvent.Builder isComplete(Boolean isComplete)
Indicates that all data expected on the given report date is available.
-
isComplete
final SettlementReportUpdatedWebhookEvent.Builder isComplete(JsonField<Boolean> isComplete)
Sets Builder.isComplete to an arbitrary JSON value.
You should usually call Builder.isComplete with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
otherFeesGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder otherFeesGrossAmount(Long otherFeesGrossAmount)
Total amount of gross other fees outside of interchange. (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
otherFeesGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder otherFeesGrossAmount(JsonField<Long> otherFeesGrossAmount)
Sets Builder.otherFeesGrossAmount to an arbitrary JSON value.
You should usually call Builder.otherFeesGrossAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reportDate
final SettlementReportUpdatedWebhookEvent.Builder reportDate(String reportDate)
Date of when the report was first generated.
-
reportDate
final SettlementReportUpdatedWebhookEvent.Builder reportDate(JsonField<String> reportDate)
Sets Builder.reportDate to an arbitrary JSON value.
You should usually call Builder.reportDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledNetAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder settledNetAmount(Long settledNetAmount)
The total net amount of cash moved. (net value of settled_gross_amount, interchange, fees). (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
settledNetAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder settledNetAmount(JsonField<Long> settledNetAmount)
Sets Builder.settledNetAmount to an arbitrary JSON value.
You should usually call Builder.settledNetAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionsGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder transactionsGrossAmount(Long transactionsGrossAmount)
The total amount of settlement impacting transactions (excluding interchange, fees, and disputes). (This field is deprecated and will be removed in a future version of the API. To compute total amounts, Lithic recommends that customers sum the relevant settlement amounts found within
details.)
-
transactionsGrossAmount
@Deprecated(message = "deprecated") final SettlementReportUpdatedWebhookEvent.Builder transactionsGrossAmount(JsonField<Long> transactionsGrossAmount)
Sets Builder.transactionsGrossAmount to an arbitrary JSON value.
You should usually call Builder.transactionsGrossAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final SettlementReportUpdatedWebhookEvent.Builder updated(OffsetDateTime updated)
Date and time when the transaction first occurred. UTC time zone.
-
updated
final SettlementReportUpdatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final SettlementReportUpdatedWebhookEvent.Builder eventType(SettlementReportUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final SettlementReportUpdatedWebhookEvent.Builder eventType(JsonField<SettlementReportUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SettlementReportUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SettlementReportUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SettlementReportUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SettlementReportUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SettlementReportUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SettlementReportUpdatedWebhookEvent build()
Returns an immutable instance of SettlementReportUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.created() .currency() .details() .disputesGrossAmount() .interchangeGrossAmount() .isComplete() .otherFeesGrossAmount() .reportDate() .settledNetAmount() .transactionsGrossAmount() .updated() .eventType()
-
-
-
-