Class SignalsResponse.Builder
-
- All Implemented Interfaces:
public final class SignalsResponse.BuilderA builder for SignalsResponse.
-
-
Method Summary
Modifier and Type Method Description final SignalsResponse.BuilderapprovedTxnAmountM2(Double approvedTxnAmountM2)The Welford M2 accumulator for lifetime approved transaction amounts. final SignalsResponse.BuilderapprovedTxnAmountM2(Double approvedTxnAmountM2)Alias for Builder.approvedTxnAmountM2. final SignalsResponse.BuilderapprovedTxnAmountM2(Optional<Double> approvedTxnAmountM2)Alias for calling Builder.approvedTxnAmountM2 with approvedTxnAmountM2.orElse(null).final SignalsResponse.BuilderapprovedTxnAmountM2(JsonField<Double> approvedTxnAmountM2)Sets Builder.approvedTxnAmountM2 to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnAmountM2_30d(Double approvedTxnAmountM2_30d)The Welford M2 accumulator for approved transaction amounts over the last 30 days. final SignalsResponse.BuilderapprovedTxnAmountM2_30d(Double approvedTxnAmountM2_30d)Alias for Builder.approvedTxnAmountM2_30d. final SignalsResponse.BuilderapprovedTxnAmountM2_30d(Optional<Double> approvedTxnAmountM2_30d)Alias for calling Builder.approvedTxnAmountM2_30d with approvedTxnAmountM2_30d.orElse(null).final SignalsResponse.BuilderapprovedTxnAmountM2_30d(JsonField<Double> approvedTxnAmountM2_30d)Sets Builder.approvedTxnAmountM2_30d to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnAmountM2_7d(Double approvedTxnAmountM2_7d)The Welford M2 accumulator for approved transaction amounts over the last 7 days. final SignalsResponse.BuilderapprovedTxnAmountM2_7d(Double approvedTxnAmountM2_7d)Alias for Builder.approvedTxnAmountM2_7d. final SignalsResponse.BuilderapprovedTxnAmountM2_7d(Optional<Double> approvedTxnAmountM2_7d)Alias for calling Builder.approvedTxnAmountM2_7d with approvedTxnAmountM2_7d.orElse(null).final SignalsResponse.BuilderapprovedTxnAmountM2_7d(JsonField<Double> approvedTxnAmountM2_7d)Sets Builder.approvedTxnAmountM2_7d to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnAmountM2_90d(Double approvedTxnAmountM2_90d)The Welford M2 accumulator for approved transaction amounts over the last 90 days. final SignalsResponse.BuilderapprovedTxnAmountM2_90d(Double approvedTxnAmountM2_90d)Alias for Builder.approvedTxnAmountM2_90d. final SignalsResponse.BuilderapprovedTxnAmountM2_90d(Optional<Double> approvedTxnAmountM2_90d)Alias for calling Builder.approvedTxnAmountM2_90d with approvedTxnAmountM2_90d.orElse(null).final SignalsResponse.BuilderapprovedTxnAmountM2_90d(JsonField<Double> approvedTxnAmountM2_90d)Sets Builder.approvedTxnAmountM2_90d to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnCount(Long approvedTxnCount)The total number of approved transactions over the entity's lifetime. final SignalsResponse.BuilderapprovedTxnCount(Long approvedTxnCount)Alias for Builder.approvedTxnCount. final SignalsResponse.BuilderapprovedTxnCount(Optional<Long> approvedTxnCount)Alias for calling Builder.approvedTxnCount with approvedTxnCount.orElse(null).final SignalsResponse.BuilderapprovedTxnCount(JsonField<Long> approvedTxnCount)Sets Builder.approvedTxnCount to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnCount30d(Long approvedTxnCount30d)The number of approved transactions in the last 30 days. final SignalsResponse.BuilderapprovedTxnCount30d(Long approvedTxnCount30d)Alias for Builder.approvedTxnCount30d. final SignalsResponse.BuilderapprovedTxnCount30d(Optional<Long> approvedTxnCount30d)Alias for calling Builder.approvedTxnCount30d with approvedTxnCount30d.orElse(null).final SignalsResponse.BuilderapprovedTxnCount30d(JsonField<Long> approvedTxnCount30d)Sets Builder.approvedTxnCount30d to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnCount7d(Long approvedTxnCount7d)The number of approved transactions in the last 7 days. final SignalsResponse.BuilderapprovedTxnCount7d(Long approvedTxnCount7d)Alias for Builder.approvedTxnCount7d. final SignalsResponse.BuilderapprovedTxnCount7d(Optional<Long> approvedTxnCount7d)Alias for calling Builder.approvedTxnCount7d with approvedTxnCount7d.orElse(null).final SignalsResponse.BuilderapprovedTxnCount7d(JsonField<Long> approvedTxnCount7d)Sets Builder.approvedTxnCount7d to an arbitrary JSON value. final SignalsResponse.BuilderapprovedTxnCount90d(Long approvedTxnCount90d)The number of approved transactions in the last 90 days. final SignalsResponse.BuilderapprovedTxnCount90d(Long approvedTxnCount90d)Alias for Builder.approvedTxnCount90d. final SignalsResponse.BuilderapprovedTxnCount90d(Optional<Long> approvedTxnCount90d)Alias for calling Builder.approvedTxnCount90d with approvedTxnCount90d.orElse(null).final SignalsResponse.BuilderapprovedTxnCount90d(JsonField<Long> approvedTxnCount90d)Sets Builder.approvedTxnCount90d to an arbitrary JSON value. final SignalsResponse.BuilderavgTransactionAmount(Double avgTransactionAmount)The average approved transaction amount over the entity's lifetime, in cents. final SignalsResponse.BuilderavgTransactionAmount(Double avgTransactionAmount)Alias for Builder.avgTransactionAmount. final SignalsResponse.BuilderavgTransactionAmount(Optional<Double> avgTransactionAmount)Alias for calling Builder.avgTransactionAmount with avgTransactionAmount.orElse(null).final SignalsResponse.BuilderavgTransactionAmount(JsonField<Double> avgTransactionAmount)Sets Builder.avgTransactionAmount to an arbitrary JSON value. final SignalsResponse.BuilderavgTransactionAmount30d(Double avgTransactionAmount30d)The average approved transaction amount over the last 30 days, in cents. final SignalsResponse.BuilderavgTransactionAmount30d(Double avgTransactionAmount30d)Alias for Builder.avgTransactionAmount30d. final SignalsResponse.BuilderavgTransactionAmount30d(Optional<Double> avgTransactionAmount30d)Alias for calling Builder.avgTransactionAmount30d with avgTransactionAmount30d.orElse(null).final SignalsResponse.BuilderavgTransactionAmount30d(JsonField<Double> avgTransactionAmount30d)Sets Builder.avgTransactionAmount30d to an arbitrary JSON value. final SignalsResponse.BuilderavgTransactionAmount7d(Double avgTransactionAmount7d)The average approved transaction amount over the last 7 days, in cents. final SignalsResponse.BuilderavgTransactionAmount7d(Double avgTransactionAmount7d)Alias for Builder.avgTransactionAmount7d. final SignalsResponse.BuilderavgTransactionAmount7d(Optional<Double> avgTransactionAmount7d)Alias for calling Builder.avgTransactionAmount7d with avgTransactionAmount7d.orElse(null).final SignalsResponse.BuilderavgTransactionAmount7d(JsonField<Double> avgTransactionAmount7d)Sets Builder.avgTransactionAmount7d to an arbitrary JSON value. final SignalsResponse.BuilderavgTransactionAmount90d(Double avgTransactionAmount90d)The average approved transaction amount over the last 90 days, in cents. final SignalsResponse.BuilderavgTransactionAmount90d(Double avgTransactionAmount90d)Alias for Builder.avgTransactionAmount90d. final SignalsResponse.BuilderavgTransactionAmount90d(Optional<Double> avgTransactionAmount90d)Alias for calling Builder.avgTransactionAmount90d with avgTransactionAmount90d.orElse(null).final SignalsResponse.BuilderavgTransactionAmount90d(JsonField<Double> avgTransactionAmount90d)Sets Builder.avgTransactionAmount90d to an arbitrary JSON value. final SignalsResponse.BuilderdistinctCountryCount(Long distinctCountryCount)The number of distinct merchant countries seen in the entity's transaction history. final SignalsResponse.BuilderdistinctCountryCount(Long distinctCountryCount)Alias for Builder.distinctCountryCount. final SignalsResponse.BuilderdistinctCountryCount(Optional<Long> distinctCountryCount)Alias for calling Builder.distinctCountryCount with distinctCountryCount.orElse(null).final SignalsResponse.BuilderdistinctCountryCount(JsonField<Long> distinctCountryCount)Sets Builder.distinctCountryCount to an arbitrary JSON value. final SignalsResponse.BuilderdistinctMccCount(Long distinctMccCount)The number of distinct MCCs seen in the entity's transaction history. final SignalsResponse.BuilderdistinctMccCount(Long distinctMccCount)Alias for Builder.distinctMccCount. final SignalsResponse.BuilderdistinctMccCount(Optional<Long> distinctMccCount)Alias for calling Builder.distinctMccCount with distinctMccCount.orElse(null).final SignalsResponse.BuilderdistinctMccCount(JsonField<Long> distinctMccCount)Sets Builder.distinctMccCount to an arbitrary JSON value. final SignalsResponse.BuilderfirstTxnAt(OffsetDateTime firstTxnAt)The timestamp of the first approved transaction for the entity, in ISO 8601 format. final SignalsResponse.BuilderfirstTxnAt(Optional<OffsetDateTime> firstTxnAt)Alias for calling Builder.firstTxnAt with firstTxnAt.orElse(null).final SignalsResponse.BuilderfirstTxnAt(JsonField<OffsetDateTime> firstTxnAt)Sets Builder.firstTxnAt to an arbitrary JSON value. final SignalsResponse.BuilderisFirstTransaction(Boolean isFirstTransaction)Whether the entity has no prior transaction history. final SignalsResponse.BuilderisFirstTransaction(Boolean isFirstTransaction)Alias for Builder.isFirstTransaction. final SignalsResponse.BuilderisFirstTransaction(Optional<Boolean> isFirstTransaction)Alias for calling Builder.isFirstTransaction with isFirstTransaction.orElse(null).final SignalsResponse.BuilderisFirstTransaction(JsonField<Boolean> isFirstTransaction)Sets Builder.isFirstTransaction to an arbitrary JSON value. final SignalsResponse.BuilderlastCpCountry(String lastCpCountry)The merchant country of the last card-present transaction. final SignalsResponse.BuilderlastCpCountry(Optional<String> lastCpCountry)Alias for calling Builder.lastCpCountry with lastCpCountry.orElse(null).final SignalsResponse.BuilderlastCpCountry(JsonField<String> lastCpCountry)Sets Builder.lastCpCountry to an arbitrary JSON value. final SignalsResponse.BuilderlastCpPostalCode(String lastCpPostalCode)The merchant postal code of the last card-present transaction. final SignalsResponse.BuilderlastCpPostalCode(Optional<String> lastCpPostalCode)Alias for calling Builder.lastCpPostalCode with lastCpPostalCode.orElse(null).final SignalsResponse.BuilderlastCpPostalCode(JsonField<String> lastCpPostalCode)Sets Builder.lastCpPostalCode to an arbitrary JSON value. final SignalsResponse.BuilderlastCpTimestamp(OffsetDateTime lastCpTimestamp)The timestamp of the last card-present transaction, in ISO 8601 format. final SignalsResponse.BuilderlastCpTimestamp(Optional<OffsetDateTime> lastCpTimestamp)Alias for calling Builder.lastCpTimestamp with lastCpTimestamp.orElse(null).final SignalsResponse.BuilderlastCpTimestamp(JsonField<OffsetDateTime> lastCpTimestamp)Sets Builder.lastCpTimestamp to an arbitrary JSON value. final SignalsResponse.BuilderlastTxnApprovedAt(OffsetDateTime lastTxnApprovedAt)The timestamp of the most recent approved transaction for the entity, in ISO 8601 format. final SignalsResponse.BuilderlastTxnApprovedAt(Optional<OffsetDateTime> lastTxnApprovedAt)Alias for calling Builder.lastTxnApprovedAt with lastTxnApprovedAt.orElse(null).final SignalsResponse.BuilderlastTxnApprovedAt(JsonField<OffsetDateTime> lastTxnApprovedAt)Sets Builder.lastTxnApprovedAt to an arbitrary JSON value. final SignalsResponse.BuilderseenCountries(List<String> seenCountries)The set of merchant countries seen in the entity's transaction history. final SignalsResponse.BuilderseenCountries(Optional<List<String>> seenCountries)Alias for calling Builder.seenCountries with seenCountries.orElse(null).final SignalsResponse.BuilderseenCountries(JsonField<List<String>> seenCountries)Sets Builder.seenCountries to an arbitrary JSON value. final SignalsResponse.BuilderaddSeenCountry(String seenCountry)Adds a single String to seenCountries. final SignalsResponse.BuilderseenMccs(List<String> seenMccs)The set of MCCs seen in the entity's transaction history. final SignalsResponse.BuilderseenMccs(Optional<List<String>> seenMccs)Alias for calling Builder.seenMccs with seenMccs.orElse(null).final SignalsResponse.BuilderseenMccs(JsonField<List<String>> seenMccs)Sets Builder.seenMccs to an arbitrary JSON value. final SignalsResponse.BuilderaddSeenMcc(String seenMcc)Adds a single String to seenMccs. final SignalsResponse.BuilderseenMerchants(List<String> seenMerchants)The set of card acceptor IDs seen in the card's approved transaction history, capped at the 1000 most recently seen. final SignalsResponse.BuilderseenMerchants(Optional<List<String>> seenMerchants)Alias for calling Builder.seenMerchants with seenMerchants.orElse(null).final SignalsResponse.BuilderseenMerchants(JsonField<List<String>> seenMerchants)Sets Builder.seenMerchants to an arbitrary JSON value. final SignalsResponse.BuilderaddSeenMerchant(String seenMerchant)Adds a single String to seenMerchants. final SignalsResponse.BuilderstdevTransactionAmount(Double stdevTransactionAmount)The standard deviation of approved transaction amounts over the entity's lifetime, in cents. final SignalsResponse.BuilderstdevTransactionAmount(Double stdevTransactionAmount)Alias for Builder.stdevTransactionAmount. final SignalsResponse.BuilderstdevTransactionAmount(Optional<Double> stdevTransactionAmount)Alias for calling Builder.stdevTransactionAmount with stdevTransactionAmount.orElse(null).final SignalsResponse.BuilderstdevTransactionAmount(JsonField<Double> stdevTransactionAmount)Sets Builder.stdevTransactionAmount to an arbitrary JSON value. final SignalsResponse.BuilderstdevTransactionAmount30d(Double stdevTransactionAmount30d)The standard deviation of approved transaction amounts over the last 30 days, in cents. final SignalsResponse.BuilderstdevTransactionAmount30d(Double stdevTransactionAmount30d)Alias for Builder.stdevTransactionAmount30d. final SignalsResponse.BuilderstdevTransactionAmount30d(Optional<Double> stdevTransactionAmount30d)Alias for calling Builder.stdevTransactionAmount30d with stdevTransactionAmount30d.orElse(null).final SignalsResponse.BuilderstdevTransactionAmount30d(JsonField<Double> stdevTransactionAmount30d)Sets Builder.stdevTransactionAmount30d to an arbitrary JSON value. final SignalsResponse.BuilderstdevTransactionAmount7d(Double stdevTransactionAmount7d)The standard deviation of approved transaction amounts over the last 7 days, in cents. final SignalsResponse.BuilderstdevTransactionAmount7d(Double stdevTransactionAmount7d)Alias for Builder.stdevTransactionAmount7d. final SignalsResponse.BuilderstdevTransactionAmount7d(Optional<Double> stdevTransactionAmount7d)Alias for calling Builder.stdevTransactionAmount7d with stdevTransactionAmount7d.orElse(null).final SignalsResponse.BuilderstdevTransactionAmount7d(JsonField<Double> stdevTransactionAmount7d)Sets Builder.stdevTransactionAmount7d to an arbitrary JSON value. final SignalsResponse.BuilderstdevTransactionAmount90d(Double stdevTransactionAmount90d)The standard deviation of approved transaction amounts over the last 90 days, in cents. final SignalsResponse.BuilderstdevTransactionAmount90d(Double stdevTransactionAmount90d)Alias for Builder.stdevTransactionAmount90d. final SignalsResponse.BuilderstdevTransactionAmount90d(Optional<Double> stdevTransactionAmount90d)Alias for calling Builder.stdevTransactionAmount90d with stdevTransactionAmount90d.orElse(null).final SignalsResponse.BuilderstdevTransactionAmount90d(JsonField<Double> stdevTransactionAmount90d)Sets Builder.stdevTransactionAmount90d to an arbitrary JSON value. final SignalsResponse.BuilderthreeDSSuccessCount(Long threeDSSuccessCount)The number of successful 3DS authentications for the card. final SignalsResponse.BuilderthreeDSSuccessCount(Long threeDSSuccessCount)Alias for Builder.threeDSSuccessCount. final SignalsResponse.BuilderthreeDSSuccessCount(Optional<Long> threeDSSuccessCount)Alias for calling Builder.threeDSSuccessCount with threeDSSuccessCount.orElse(null).final SignalsResponse.BuilderthreeDSSuccessCount(JsonField<Long> threeDSSuccessCount)Sets Builder.threeDSSuccessCount to an arbitrary JSON value. final SignalsResponse.BuilderthreeDSSuccessRate(Double threeDSSuccessRate)The 3DS authentication success rate for the card, as a percentage from 0.0 to 100.0. final SignalsResponse.BuilderthreeDSSuccessRate(Double threeDSSuccessRate)Alias for Builder.threeDSSuccessRate. final SignalsResponse.BuilderthreeDSSuccessRate(Optional<Double> threeDSSuccessRate)Alias for calling Builder.threeDSSuccessRate with threeDSSuccessRate.orElse(null).final SignalsResponse.BuilderthreeDSSuccessRate(JsonField<Double> threeDSSuccessRate)Sets Builder.threeDSSuccessRate to an arbitrary JSON value. final SignalsResponse.BuilderthreeDSTotalCount(Long threeDSTotalCount)The total number of 3DS authentication attempts for the card. final SignalsResponse.BuilderthreeDSTotalCount(Long threeDSTotalCount)Alias for Builder.threeDSTotalCount. final SignalsResponse.BuilderthreeDSTotalCount(Optional<Long> threeDSTotalCount)Alias for calling Builder.threeDSTotalCount with threeDSTotalCount.orElse(null).final SignalsResponse.BuilderthreeDSTotalCount(JsonField<Long> threeDSTotalCount)Sets Builder.threeDSTotalCount to an arbitrary JSON value. final SignalsResponse.BuildertimeSinceLastTransactionDays(Double timeSinceLastTransactionDays)The number of days since the last approved transaction on the entity. final SignalsResponse.BuildertimeSinceLastTransactionDays(Double timeSinceLastTransactionDays)Alias for Builder.timeSinceLastTransactionDays. final SignalsResponse.BuildertimeSinceLastTransactionDays(Optional<Double> timeSinceLastTransactionDays)Alias for calling Builder.timeSinceLastTransactionDays with timeSinceLastTransactionDays.orElse(null).final SignalsResponse.BuildertimeSinceLastTransactionDays(JsonField<Double> timeSinceLastTransactionDays)Sets Builder.timeSinceLastTransactionDays to an arbitrary JSON value. final SignalsResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final SignalsResponse.BuilderputAdditionalProperty(String key, JsonValue value)final SignalsResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final SignalsResponse.BuilderremoveAdditionalProperty(String key)final SignalsResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final SignalsResponsebuild()Returns an immutable instance of SignalsResponse. -
-
Method Detail
-
approvedTxnAmountM2
final SignalsResponse.Builder approvedTxnAmountM2(Double approvedTxnAmountM2)
The Welford M2 accumulator for lifetime approved transaction amounts. Used together with
avg_transaction_amountandapproved_txn_countto compute the z-score of a new transaction amount (variance = M2 / (count - 1)).
-
approvedTxnAmountM2
final SignalsResponse.Builder approvedTxnAmountM2(Double approvedTxnAmountM2)
Alias for Builder.approvedTxnAmountM2.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnAmountM2
final SignalsResponse.Builder approvedTxnAmountM2(Optional<Double> approvedTxnAmountM2)
Alias for calling Builder.approvedTxnAmountM2 with
approvedTxnAmountM2.orElse(null).
-
approvedTxnAmountM2
final SignalsResponse.Builder approvedTxnAmountM2(JsonField<Double> approvedTxnAmountM2)
Sets Builder.approvedTxnAmountM2 to an arbitrary JSON value.
You should usually call Builder.approvedTxnAmountM2 with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnAmountM2_30d
final SignalsResponse.Builder approvedTxnAmountM2_30d(Double approvedTxnAmountM2_30d)
The Welford M2 accumulator for approved transaction amounts over the last 30 days.
-
approvedTxnAmountM2_30d
final SignalsResponse.Builder approvedTxnAmountM2_30d(Double approvedTxnAmountM2_30d)
Alias for Builder.approvedTxnAmountM2_30d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnAmountM2_30d
final SignalsResponse.Builder approvedTxnAmountM2_30d(Optional<Double> approvedTxnAmountM2_30d)
Alias for calling Builder.approvedTxnAmountM2_30d with
approvedTxnAmountM2_30d.orElse(null).
-
approvedTxnAmountM2_30d
final SignalsResponse.Builder approvedTxnAmountM2_30d(JsonField<Double> approvedTxnAmountM2_30d)
Sets Builder.approvedTxnAmountM2_30d to an arbitrary JSON value.
You should usually call Builder.approvedTxnAmountM2_30d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnAmountM2_7d
final SignalsResponse.Builder approvedTxnAmountM2_7d(Double approvedTxnAmountM2_7d)
The Welford M2 accumulator for approved transaction amounts over the last 7 days.
-
approvedTxnAmountM2_7d
final SignalsResponse.Builder approvedTxnAmountM2_7d(Double approvedTxnAmountM2_7d)
Alias for Builder.approvedTxnAmountM2_7d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnAmountM2_7d
final SignalsResponse.Builder approvedTxnAmountM2_7d(Optional<Double> approvedTxnAmountM2_7d)
Alias for calling Builder.approvedTxnAmountM2_7d with
approvedTxnAmountM2_7d.orElse(null).
-
approvedTxnAmountM2_7d
final SignalsResponse.Builder approvedTxnAmountM2_7d(JsonField<Double> approvedTxnAmountM2_7d)
Sets Builder.approvedTxnAmountM2_7d to an arbitrary JSON value.
You should usually call Builder.approvedTxnAmountM2_7d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnAmountM2_90d
final SignalsResponse.Builder approvedTxnAmountM2_90d(Double approvedTxnAmountM2_90d)
The Welford M2 accumulator for approved transaction amounts over the last 90 days.
-
approvedTxnAmountM2_90d
final SignalsResponse.Builder approvedTxnAmountM2_90d(Double approvedTxnAmountM2_90d)
Alias for Builder.approvedTxnAmountM2_90d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnAmountM2_90d
final SignalsResponse.Builder approvedTxnAmountM2_90d(Optional<Double> approvedTxnAmountM2_90d)
Alias for calling Builder.approvedTxnAmountM2_90d with
approvedTxnAmountM2_90d.orElse(null).
-
approvedTxnAmountM2_90d
final SignalsResponse.Builder approvedTxnAmountM2_90d(JsonField<Double> approvedTxnAmountM2_90d)
Sets Builder.approvedTxnAmountM2_90d to an arbitrary JSON value.
You should usually call Builder.approvedTxnAmountM2_90d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnCount
final SignalsResponse.Builder approvedTxnCount(Long approvedTxnCount)
The total number of approved transactions over the entity's lifetime.
-
approvedTxnCount
final SignalsResponse.Builder approvedTxnCount(Long approvedTxnCount)
Alias for Builder.approvedTxnCount.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnCount
final SignalsResponse.Builder approvedTxnCount(Optional<Long> approvedTxnCount)
Alias for calling Builder.approvedTxnCount with
approvedTxnCount.orElse(null).
-
approvedTxnCount
final SignalsResponse.Builder approvedTxnCount(JsonField<Long> approvedTxnCount)
Sets Builder.approvedTxnCount to an arbitrary JSON value.
You should usually call Builder.approvedTxnCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnCount30d
final SignalsResponse.Builder approvedTxnCount30d(Long approvedTxnCount30d)
The number of approved transactions in the last 30 days.
-
approvedTxnCount30d
final SignalsResponse.Builder approvedTxnCount30d(Long approvedTxnCount30d)
Alias for Builder.approvedTxnCount30d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnCount30d
final SignalsResponse.Builder approvedTxnCount30d(Optional<Long> approvedTxnCount30d)
Alias for calling Builder.approvedTxnCount30d with
approvedTxnCount30d.orElse(null).
-
approvedTxnCount30d
final SignalsResponse.Builder approvedTxnCount30d(JsonField<Long> approvedTxnCount30d)
Sets Builder.approvedTxnCount30d to an arbitrary JSON value.
You should usually call Builder.approvedTxnCount30d with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnCount7d
final SignalsResponse.Builder approvedTxnCount7d(Long approvedTxnCount7d)
The number of approved transactions in the last 7 days.
-
approvedTxnCount7d
final SignalsResponse.Builder approvedTxnCount7d(Long approvedTxnCount7d)
Alias for Builder.approvedTxnCount7d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnCount7d
final SignalsResponse.Builder approvedTxnCount7d(Optional<Long> approvedTxnCount7d)
Alias for calling Builder.approvedTxnCount7d with
approvedTxnCount7d.orElse(null).
-
approvedTxnCount7d
final SignalsResponse.Builder approvedTxnCount7d(JsonField<Long> approvedTxnCount7d)
Sets Builder.approvedTxnCount7d to an arbitrary JSON value.
You should usually call Builder.approvedTxnCount7d with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedTxnCount90d
final SignalsResponse.Builder approvedTxnCount90d(Long approvedTxnCount90d)
The number of approved transactions in the last 90 days.
-
approvedTxnCount90d
final SignalsResponse.Builder approvedTxnCount90d(Long approvedTxnCount90d)
Alias for Builder.approvedTxnCount90d.
This unboxed primitive overload exists for backwards compatibility.
-
approvedTxnCount90d
final SignalsResponse.Builder approvedTxnCount90d(Optional<Long> approvedTxnCount90d)
Alias for calling Builder.approvedTxnCount90d with
approvedTxnCount90d.orElse(null).
-
approvedTxnCount90d
final SignalsResponse.Builder approvedTxnCount90d(JsonField<Long> approvedTxnCount90d)
Sets Builder.approvedTxnCount90d to an arbitrary JSON value.
You should usually call Builder.approvedTxnCount90d with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avgTransactionAmount
final SignalsResponse.Builder avgTransactionAmount(Double avgTransactionAmount)
The average approved transaction amount over the entity's lifetime, in cents. Null if fewer than 5 approved transactions have been recorded.
-
avgTransactionAmount
final SignalsResponse.Builder avgTransactionAmount(Double avgTransactionAmount)
Alias for Builder.avgTransactionAmount.
This unboxed primitive overload exists for backwards compatibility.
-
avgTransactionAmount
final SignalsResponse.Builder avgTransactionAmount(Optional<Double> avgTransactionAmount)
Alias for calling Builder.avgTransactionAmount with
avgTransactionAmount.orElse(null).
-
avgTransactionAmount
final SignalsResponse.Builder avgTransactionAmount(JsonField<Double> avgTransactionAmount)
Sets Builder.avgTransactionAmount to an arbitrary JSON value.
You should usually call Builder.avgTransactionAmount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avgTransactionAmount30d
final SignalsResponse.Builder avgTransactionAmount30d(Double avgTransactionAmount30d)
The average approved transaction amount over the last 30 days, in cents. Null if fewer than 5 approved transactions in window.
-
avgTransactionAmount30d
final SignalsResponse.Builder avgTransactionAmount30d(Double avgTransactionAmount30d)
Alias for Builder.avgTransactionAmount30d.
This unboxed primitive overload exists for backwards compatibility.
-
avgTransactionAmount30d
final SignalsResponse.Builder avgTransactionAmount30d(Optional<Double> avgTransactionAmount30d)
Alias for calling Builder.avgTransactionAmount30d with
avgTransactionAmount30d.orElse(null).
-
avgTransactionAmount30d
final SignalsResponse.Builder avgTransactionAmount30d(JsonField<Double> avgTransactionAmount30d)
Sets Builder.avgTransactionAmount30d to an arbitrary JSON value.
You should usually call Builder.avgTransactionAmount30d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avgTransactionAmount7d
final SignalsResponse.Builder avgTransactionAmount7d(Double avgTransactionAmount7d)
The average approved transaction amount over the last 7 days, in cents. Null if fewer than 5 approved transactions in window.
-
avgTransactionAmount7d
final SignalsResponse.Builder avgTransactionAmount7d(Double avgTransactionAmount7d)
Alias for Builder.avgTransactionAmount7d.
This unboxed primitive overload exists for backwards compatibility.
-
avgTransactionAmount7d
final SignalsResponse.Builder avgTransactionAmount7d(Optional<Double> avgTransactionAmount7d)
Alias for calling Builder.avgTransactionAmount7d with
avgTransactionAmount7d.orElse(null).
-
avgTransactionAmount7d
final SignalsResponse.Builder avgTransactionAmount7d(JsonField<Double> avgTransactionAmount7d)
Sets Builder.avgTransactionAmount7d to an arbitrary JSON value.
You should usually call Builder.avgTransactionAmount7d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
avgTransactionAmount90d
final SignalsResponse.Builder avgTransactionAmount90d(Double avgTransactionAmount90d)
The average approved transaction amount over the last 90 days, in cents. Null if fewer than 5 approved transactions in window.
-
avgTransactionAmount90d
final SignalsResponse.Builder avgTransactionAmount90d(Double avgTransactionAmount90d)
Alias for Builder.avgTransactionAmount90d.
This unboxed primitive overload exists for backwards compatibility.
-
avgTransactionAmount90d
final SignalsResponse.Builder avgTransactionAmount90d(Optional<Double> avgTransactionAmount90d)
Alias for calling Builder.avgTransactionAmount90d with
avgTransactionAmount90d.orElse(null).
-
avgTransactionAmount90d
final SignalsResponse.Builder avgTransactionAmount90d(JsonField<Double> avgTransactionAmount90d)
Sets Builder.avgTransactionAmount90d to an arbitrary JSON value.
You should usually call Builder.avgTransactionAmount90d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
distinctCountryCount
final SignalsResponse.Builder distinctCountryCount(Long distinctCountryCount)
The number of distinct merchant countries seen in the entity's transaction history.
-
distinctCountryCount
final SignalsResponse.Builder distinctCountryCount(Long distinctCountryCount)
Alias for Builder.distinctCountryCount.
This unboxed primitive overload exists for backwards compatibility.
-
distinctCountryCount
final SignalsResponse.Builder distinctCountryCount(Optional<Long> distinctCountryCount)
Alias for calling Builder.distinctCountryCount with
distinctCountryCount.orElse(null).
-
distinctCountryCount
final SignalsResponse.Builder distinctCountryCount(JsonField<Long> distinctCountryCount)
Sets Builder.distinctCountryCount to an arbitrary JSON value.
You should usually call Builder.distinctCountryCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
distinctMccCount
final SignalsResponse.Builder distinctMccCount(Long distinctMccCount)
The number of distinct MCCs seen in the entity's transaction history.
-
distinctMccCount
final SignalsResponse.Builder distinctMccCount(Long distinctMccCount)
Alias for Builder.distinctMccCount.
This unboxed primitive overload exists for backwards compatibility.
-
distinctMccCount
final SignalsResponse.Builder distinctMccCount(Optional<Long> distinctMccCount)
Alias for calling Builder.distinctMccCount with
distinctMccCount.orElse(null).
-
distinctMccCount
final SignalsResponse.Builder distinctMccCount(JsonField<Long> distinctMccCount)
Sets Builder.distinctMccCount to an arbitrary JSON value.
You should usually call Builder.distinctMccCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
firstTxnAt
final SignalsResponse.Builder firstTxnAt(OffsetDateTime firstTxnAt)
The timestamp of the first approved transaction for the entity, in ISO 8601 format.
-
firstTxnAt
final SignalsResponse.Builder firstTxnAt(Optional<OffsetDateTime> firstTxnAt)
Alias for calling Builder.firstTxnAt with
firstTxnAt.orElse(null).
-
firstTxnAt
final SignalsResponse.Builder firstTxnAt(JsonField<OffsetDateTime> firstTxnAt)
Sets Builder.firstTxnAt to an arbitrary JSON value.
You should usually call Builder.firstTxnAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isFirstTransaction
final SignalsResponse.Builder isFirstTransaction(Boolean isFirstTransaction)
Whether the entity has no prior transaction history. Returns true if no history is found. Null if transaction history exists but a first transaction timestamp is unavailable.
-
isFirstTransaction
final SignalsResponse.Builder isFirstTransaction(Boolean isFirstTransaction)
Alias for Builder.isFirstTransaction.
This unboxed primitive overload exists for backwards compatibility.
-
isFirstTransaction
final SignalsResponse.Builder isFirstTransaction(Optional<Boolean> isFirstTransaction)
Alias for calling Builder.isFirstTransaction with
isFirstTransaction.orElse(null).
-
isFirstTransaction
final SignalsResponse.Builder isFirstTransaction(JsonField<Boolean> isFirstTransaction)
Sets Builder.isFirstTransaction to an arbitrary JSON value.
You should usually call Builder.isFirstTransaction with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastCpCountry
final SignalsResponse.Builder lastCpCountry(String lastCpCountry)
The merchant country of the last card-present transaction.
-
lastCpCountry
final SignalsResponse.Builder lastCpCountry(Optional<String> lastCpCountry)
Alias for calling Builder.lastCpCountry with
lastCpCountry.orElse(null).
-
lastCpCountry
final SignalsResponse.Builder lastCpCountry(JsonField<String> lastCpCountry)
Sets Builder.lastCpCountry to an arbitrary JSON value.
You should usually call Builder.lastCpCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastCpPostalCode
final SignalsResponse.Builder lastCpPostalCode(String lastCpPostalCode)
The merchant postal code of the last card-present transaction.
-
lastCpPostalCode
final SignalsResponse.Builder lastCpPostalCode(Optional<String> lastCpPostalCode)
Alias for calling Builder.lastCpPostalCode with
lastCpPostalCode.orElse(null).
-
lastCpPostalCode
final SignalsResponse.Builder lastCpPostalCode(JsonField<String> lastCpPostalCode)
Sets Builder.lastCpPostalCode to an arbitrary JSON value.
You should usually call Builder.lastCpPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastCpTimestamp
final SignalsResponse.Builder lastCpTimestamp(OffsetDateTime lastCpTimestamp)
The timestamp of the last card-present transaction, in ISO 8601 format.
-
lastCpTimestamp
final SignalsResponse.Builder lastCpTimestamp(Optional<OffsetDateTime> lastCpTimestamp)
Alias for calling Builder.lastCpTimestamp with
lastCpTimestamp.orElse(null).
-
lastCpTimestamp
final SignalsResponse.Builder lastCpTimestamp(JsonField<OffsetDateTime> lastCpTimestamp)
Sets Builder.lastCpTimestamp to an arbitrary JSON value.
You should usually call Builder.lastCpTimestamp with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastTxnApprovedAt
final SignalsResponse.Builder lastTxnApprovedAt(OffsetDateTime lastTxnApprovedAt)
The timestamp of the most recent approved transaction for the entity, in ISO 8601 format.
-
lastTxnApprovedAt
final SignalsResponse.Builder lastTxnApprovedAt(Optional<OffsetDateTime> lastTxnApprovedAt)
Alias for calling Builder.lastTxnApprovedAt with
lastTxnApprovedAt.orElse(null).
-
lastTxnApprovedAt
final SignalsResponse.Builder lastTxnApprovedAt(JsonField<OffsetDateTime> lastTxnApprovedAt)
Sets Builder.lastTxnApprovedAt to an arbitrary JSON value.
You should usually call Builder.lastTxnApprovedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
seenCountries
final SignalsResponse.Builder seenCountries(List<String> seenCountries)
The set of merchant countries seen in the entity's transaction history. Clients can use this to determine whether a new transaction's country is novel (i.e. compute
is_new_country).
-
seenCountries
final SignalsResponse.Builder seenCountries(Optional<List<String>> seenCountries)
Alias for calling Builder.seenCountries with
seenCountries.orElse(null).
-
seenCountries
final SignalsResponse.Builder seenCountries(JsonField<List<String>> seenCountries)
Sets Builder.seenCountries to an arbitrary JSON value.
You should usually call Builder.seenCountries with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSeenCountry
final SignalsResponse.Builder addSeenCountry(String seenCountry)
Adds a single String to seenCountries.
-
seenMccs
final SignalsResponse.Builder seenMccs(List<String> seenMccs)
The set of MCCs seen in the entity's transaction history. Clients can use this to determine whether a new transaction's MCC is novel (i.e. compute
is_new_mcc).
-
seenMccs
final SignalsResponse.Builder seenMccs(Optional<List<String>> seenMccs)
Alias for calling Builder.seenMccs with
seenMccs.orElse(null).
-
seenMccs
final SignalsResponse.Builder seenMccs(JsonField<List<String>> seenMccs)
Sets Builder.seenMccs to an arbitrary JSON value.
You should usually call Builder.seenMccs with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSeenMcc
final SignalsResponse.Builder addSeenMcc(String seenMcc)
-
seenMerchants
final SignalsResponse.Builder seenMerchants(List<String> seenMerchants)
The set of card acceptor IDs seen in the card's approved transaction history, capped at the 1000 most recently seen. Null for account responses. Clients can use this to determine whether a new transaction's merchant is novel (i.e. compute
is_new_merchant).
-
seenMerchants
final SignalsResponse.Builder seenMerchants(Optional<List<String>> seenMerchants)
Alias for calling Builder.seenMerchants with
seenMerchants.orElse(null).
-
seenMerchants
final SignalsResponse.Builder seenMerchants(JsonField<List<String>> seenMerchants)
Sets Builder.seenMerchants to an arbitrary JSON value.
You should usually call Builder.seenMerchants with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSeenMerchant
final SignalsResponse.Builder addSeenMerchant(String seenMerchant)
Adds a single String to seenMerchants.
-
stdevTransactionAmount
final SignalsResponse.Builder stdevTransactionAmount(Double stdevTransactionAmount)
The standard deviation of approved transaction amounts over the entity's lifetime, in cents. Null if fewer than 30 approved transactions have been recorded.
-
stdevTransactionAmount
final SignalsResponse.Builder stdevTransactionAmount(Double stdevTransactionAmount)
Alias for Builder.stdevTransactionAmount.
This unboxed primitive overload exists for backwards compatibility.
-
stdevTransactionAmount
final SignalsResponse.Builder stdevTransactionAmount(Optional<Double> stdevTransactionAmount)
Alias for calling Builder.stdevTransactionAmount with
stdevTransactionAmount.orElse(null).
-
stdevTransactionAmount
final SignalsResponse.Builder stdevTransactionAmount(JsonField<Double> stdevTransactionAmount)
Sets Builder.stdevTransactionAmount to an arbitrary JSON value.
You should usually call Builder.stdevTransactionAmount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stdevTransactionAmount30d
final SignalsResponse.Builder stdevTransactionAmount30d(Double stdevTransactionAmount30d)
The standard deviation of approved transaction amounts over the last 30 days, in cents. Null if fewer than 30 approved transactions in window.
-
stdevTransactionAmount30d
final SignalsResponse.Builder stdevTransactionAmount30d(Double stdevTransactionAmount30d)
Alias for Builder.stdevTransactionAmount30d.
This unboxed primitive overload exists for backwards compatibility.
-
stdevTransactionAmount30d
final SignalsResponse.Builder stdevTransactionAmount30d(Optional<Double> stdevTransactionAmount30d)
Alias for calling Builder.stdevTransactionAmount30d with
stdevTransactionAmount30d.orElse(null).
-
stdevTransactionAmount30d
final SignalsResponse.Builder stdevTransactionAmount30d(JsonField<Double> stdevTransactionAmount30d)
Sets Builder.stdevTransactionAmount30d to an arbitrary JSON value.
You should usually call Builder.stdevTransactionAmount30d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stdevTransactionAmount7d
final SignalsResponse.Builder stdevTransactionAmount7d(Double stdevTransactionAmount7d)
The standard deviation of approved transaction amounts over the last 7 days, in cents. Null if fewer than 30 approved transactions in window.
-
stdevTransactionAmount7d
final SignalsResponse.Builder stdevTransactionAmount7d(Double stdevTransactionAmount7d)
Alias for Builder.stdevTransactionAmount7d.
This unboxed primitive overload exists for backwards compatibility.
-
stdevTransactionAmount7d
final SignalsResponse.Builder stdevTransactionAmount7d(Optional<Double> stdevTransactionAmount7d)
Alias for calling Builder.stdevTransactionAmount7d with
stdevTransactionAmount7d.orElse(null).
-
stdevTransactionAmount7d
final SignalsResponse.Builder stdevTransactionAmount7d(JsonField<Double> stdevTransactionAmount7d)
Sets Builder.stdevTransactionAmount7d to an arbitrary JSON value.
You should usually call Builder.stdevTransactionAmount7d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stdevTransactionAmount90d
final SignalsResponse.Builder stdevTransactionAmount90d(Double stdevTransactionAmount90d)
The standard deviation of approved transaction amounts over the last 90 days, in cents. Null if fewer than 30 approved transactions in window.
-
stdevTransactionAmount90d
final SignalsResponse.Builder stdevTransactionAmount90d(Double stdevTransactionAmount90d)
Alias for Builder.stdevTransactionAmount90d.
This unboxed primitive overload exists for backwards compatibility.
-
stdevTransactionAmount90d
final SignalsResponse.Builder stdevTransactionAmount90d(Optional<Double> stdevTransactionAmount90d)
Alias for calling Builder.stdevTransactionAmount90d with
stdevTransactionAmount90d.orElse(null).
-
stdevTransactionAmount90d
final SignalsResponse.Builder stdevTransactionAmount90d(JsonField<Double> stdevTransactionAmount90d)
Sets Builder.stdevTransactionAmount90d to an arbitrary JSON value.
You should usually call Builder.stdevTransactionAmount90d with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSSuccessCount
final SignalsResponse.Builder threeDSSuccessCount(Long threeDSSuccessCount)
The number of successful 3DS authentications for the card. Null for account responses.
-
threeDSSuccessCount
final SignalsResponse.Builder threeDSSuccessCount(Long threeDSSuccessCount)
Alias for Builder.threeDSSuccessCount.
This unboxed primitive overload exists for backwards compatibility.
-
threeDSSuccessCount
final SignalsResponse.Builder threeDSSuccessCount(Optional<Long> threeDSSuccessCount)
Alias for calling Builder.threeDSSuccessCount with
threeDSSuccessCount.orElse(null).
-
threeDSSuccessCount
final SignalsResponse.Builder threeDSSuccessCount(JsonField<Long> threeDSSuccessCount)
Sets Builder.threeDSSuccessCount to an arbitrary JSON value.
You should usually call Builder.threeDSSuccessCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSSuccessRate
final SignalsResponse.Builder threeDSSuccessRate(Double threeDSSuccessRate)
The 3DS authentication success rate for the card, as a percentage from 0.0 to 100.0. Null for account responses.
-
threeDSSuccessRate
final SignalsResponse.Builder threeDSSuccessRate(Double threeDSSuccessRate)
Alias for Builder.threeDSSuccessRate.
This unboxed primitive overload exists for backwards compatibility.
-
threeDSSuccessRate
final SignalsResponse.Builder threeDSSuccessRate(Optional<Double> threeDSSuccessRate)
Alias for calling Builder.threeDSSuccessRate with
threeDSSuccessRate.orElse(null).
-
threeDSSuccessRate
final SignalsResponse.Builder threeDSSuccessRate(JsonField<Double> threeDSSuccessRate)
Sets Builder.threeDSSuccessRate to an arbitrary JSON value.
You should usually call Builder.threeDSSuccessRate with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSTotalCount
final SignalsResponse.Builder threeDSTotalCount(Long threeDSTotalCount)
The total number of 3DS authentication attempts for the card. Null for account responses.
-
threeDSTotalCount
final SignalsResponse.Builder threeDSTotalCount(Long threeDSTotalCount)
Alias for Builder.threeDSTotalCount.
This unboxed primitive overload exists for backwards compatibility.
-
threeDSTotalCount
final SignalsResponse.Builder threeDSTotalCount(Optional<Long> threeDSTotalCount)
Alias for calling Builder.threeDSTotalCount with
threeDSTotalCount.orElse(null).
-
threeDSTotalCount
final SignalsResponse.Builder threeDSTotalCount(JsonField<Long> threeDSTotalCount)
Sets Builder.threeDSTotalCount to an arbitrary JSON value.
You should usually call Builder.threeDSTotalCount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timeSinceLastTransactionDays
final SignalsResponse.Builder timeSinceLastTransactionDays(Double timeSinceLastTransactionDays)
The number of days since the last approved transaction on the entity.
-
timeSinceLastTransactionDays
final SignalsResponse.Builder timeSinceLastTransactionDays(Double timeSinceLastTransactionDays)
Alias for Builder.timeSinceLastTransactionDays.
This unboxed primitive overload exists for backwards compatibility.
-
timeSinceLastTransactionDays
final SignalsResponse.Builder timeSinceLastTransactionDays(Optional<Double> timeSinceLastTransactionDays)
Alias for calling Builder.timeSinceLastTransactionDays with
timeSinceLastTransactionDays.orElse(null).
-
timeSinceLastTransactionDays
final SignalsResponse.Builder timeSinceLastTransactionDays(JsonField<Double> timeSinceLastTransactionDays)
Sets Builder.timeSinceLastTransactionDays to an arbitrary JSON value.
You should usually call Builder.timeSinceLastTransactionDays with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SignalsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SignalsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SignalsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SignalsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SignalsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SignalsResponse build()
Returns an immutable instance of SignalsResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.approvedTxnAmountM2() .approvedTxnAmountM2_30d() .approvedTxnAmountM2_7d() .approvedTxnAmountM2_90d() .approvedTxnCount() .approvedTxnCount30d() .approvedTxnCount7d() .approvedTxnCount90d() .avgTransactionAmount() .avgTransactionAmount30d() .avgTransactionAmount7d() .avgTransactionAmount90d() .distinctCountryCount() .distinctMccCount() .firstTxnAt() .isFirstTransaction() .lastCpCountry() .lastCpPostalCode() .lastCpTimestamp() .lastTxnApprovedAt() .seenCountries() .seenMccs() .seenMerchants() .stdevTransactionAmount() .stdevTransactionAmount30d() .stdevTransactionAmount7d() .stdevTransactionAmount90d() .threeDSSuccessCount() .threeDSSuccessRate() .threeDSTotalCount() .timeSinceLastTransactionDays()
-
-
-
-