Class Statement.AccountStanding
-
- All Implemented Interfaces:
public final class Statement.AccountStanding
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.AccountStanding.BuilderA builder for AccountStanding.
public final classStatement.AccountStanding.FinancialAccountStateInformation about the financial account state
public final classStatement.AccountStanding.PeriodState
-
Method Summary
-
-
Method Detail
-
consecutiveFullPaymentsMade
final Long consecutiveFullPaymentsMade()
Number of consecutive full payments made
-
consecutiveMinimumPaymentsMade
final Long consecutiveMinimumPaymentsMade()
Number of consecutive minimum payments made
-
consecutiveMinimumPaymentsMissed
final Long consecutiveMinimumPaymentsMissed()
Number of consecutive minimum payments missed
-
daysPastDue
final Long daysPastDue()
Number of days past due
-
financialAccountState
final Statement.AccountStanding.FinancialAccountState financialAccountState()
Information about the financial account state
-
periodNumber
final Long periodNumber()
Current overall period number
-
periodState
final Statement.AccountStanding.PeriodState periodState()
-
_consecutiveFullPaymentsMade
final JsonField<Long> _consecutiveFullPaymentsMade()
Returns the raw JSON value of consecutiveFullPaymentsMade.
Unlike consecutiveFullPaymentsMade, this method doesn't throw if the JSON field has an unexpected type.
-
_consecutiveMinimumPaymentsMade
final JsonField<Long> _consecutiveMinimumPaymentsMade()
Returns the raw JSON value of consecutiveMinimumPaymentsMade.
Unlike consecutiveMinimumPaymentsMade, this method doesn't throw if the JSON field has an unexpected type.
-
_consecutiveMinimumPaymentsMissed
final JsonField<Long> _consecutiveMinimumPaymentsMissed()
Returns the raw JSON value of consecutiveMinimumPaymentsMissed.
Unlike consecutiveMinimumPaymentsMissed, this method doesn't throw if the JSON field has an unexpected type.
-
_daysPastDue
final JsonField<Long> _daysPastDue()
Returns the raw JSON value of daysPastDue.
Unlike daysPastDue, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountState
final JsonField<Statement.AccountStanding.FinancialAccountState> _financialAccountState()
Returns the raw JSON value of financialAccountState.
Unlike financialAccountState, this method doesn't throw if the JSON field has an unexpected type.
-
_hasGrace
final JsonField<Boolean> _hasGrace()
Returns the raw JSON value of hasGrace.
Unlike hasGrace, this method doesn't throw if the JSON field has an unexpected type.
-
_periodNumber
final JsonField<Long> _periodNumber()
Returns the raw JSON value of periodNumber.
Unlike periodNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_periodState
final JsonField<Statement.AccountStanding.PeriodState> _periodState()
Returns the raw JSON value of periodState.
Unlike periodState, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.AccountStanding.Builder toBuilder()
-
validate
final Statement.AccountStanding validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statement.AccountStanding.Builder builder()
Returns a mutable builder for constructing an instance of AccountStanding.
The following fields are required:
.consecutiveFullPaymentsMade() .consecutiveMinimumPaymentsMade() .consecutiveMinimumPaymentsMissed() .daysPastDue() .financialAccountState() .hasGrace() .periodNumber() .periodState()
-
-
-
-