Class Statement.AccountStanding.Builder
-
- All Implemented Interfaces:
public final class Statement.AccountStanding.BuilderA builder for AccountStanding.
-
-
Method Summary
-
-
Method Detail
-
consecutiveFullPaymentsMade
final Statement.AccountStanding.Builder consecutiveFullPaymentsMade(Long consecutiveFullPaymentsMade)
Number of consecutive full payments made
-
consecutiveFullPaymentsMade
final Statement.AccountStanding.Builder consecutiveFullPaymentsMade(JsonField<Long> consecutiveFullPaymentsMade)
Sets Builder.consecutiveFullPaymentsMade to an arbitrary JSON value.
You should usually call Builder.consecutiveFullPaymentsMade with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
consecutiveMinimumPaymentsMade
final Statement.AccountStanding.Builder consecutiveMinimumPaymentsMade(Long consecutiveMinimumPaymentsMade)
Number of consecutive minimum payments made
-
consecutiveMinimumPaymentsMade
final Statement.AccountStanding.Builder consecutiveMinimumPaymentsMade(JsonField<Long> consecutiveMinimumPaymentsMade)
Sets Builder.consecutiveMinimumPaymentsMade to an arbitrary JSON value.
You should usually call Builder.consecutiveMinimumPaymentsMade with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
consecutiveMinimumPaymentsMissed
final Statement.AccountStanding.Builder consecutiveMinimumPaymentsMissed(Long consecutiveMinimumPaymentsMissed)
Number of consecutive minimum payments missed
-
consecutiveMinimumPaymentsMissed
final Statement.AccountStanding.Builder consecutiveMinimumPaymentsMissed(JsonField<Long> consecutiveMinimumPaymentsMissed)
Sets Builder.consecutiveMinimumPaymentsMissed to an arbitrary JSON value.
You should usually call Builder.consecutiveMinimumPaymentsMissed with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
daysPastDue
final Statement.AccountStanding.Builder daysPastDue(Long daysPastDue)
Number of days past due
-
daysPastDue
final Statement.AccountStanding.Builder daysPastDue(JsonField<Long> daysPastDue)
Sets Builder.daysPastDue to an arbitrary JSON value.
You should usually call Builder.daysPastDue with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountState
final Statement.AccountStanding.Builder financialAccountState(Statement.AccountStanding.FinancialAccountState financialAccountState)
Information about the financial account state
-
financialAccountState
final Statement.AccountStanding.Builder financialAccountState(JsonField<Statement.AccountStanding.FinancialAccountState> financialAccountState)
Sets Builder.financialAccountState to an arbitrary JSON value.
You should usually call Builder.financialAccountState with a well-typed FinancialAccountState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hasGrace
final Statement.AccountStanding.Builder hasGrace(Boolean hasGrace)
Whether the account currently has grace or not
-
hasGrace
final Statement.AccountStanding.Builder hasGrace(JsonField<Boolean> hasGrace)
Sets Builder.hasGrace to an arbitrary JSON value.
You should usually call Builder.hasGrace with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodNumber
final Statement.AccountStanding.Builder periodNumber(Long periodNumber)
Current overall period number
-
periodNumber
final Statement.AccountStanding.Builder periodNumber(JsonField<Long> periodNumber)
Sets Builder.periodNumber to an arbitrary JSON value.
You should usually call Builder.periodNumber with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodState
final Statement.AccountStanding.Builder periodState(Statement.AccountStanding.PeriodState periodState)
-
periodState
final Statement.AccountStanding.Builder periodState(JsonField<Statement.AccountStanding.PeriodState> periodState)
Sets Builder.periodState to an arbitrary JSON value.
You should usually call Builder.periodState with a well-typed PeriodState value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Statement.AccountStanding.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Statement.AccountStanding.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Statement.AccountStanding.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Statement.AccountStanding.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Statement.AccountStanding.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Statement.AccountStanding build()
Returns an immutable instance of AccountStanding.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.consecutiveFullPaymentsMade() .consecutiveMinimumPaymentsMade() .consecutiveMinimumPaymentsMissed() .daysPastDue() .financialAccountState() .hasGrace() .periodNumber() .periodState()
-
-
-
-