Class Statement.AccountStanding.FinancialAccountState
-
- All Implemented Interfaces:
public final class Statement.AccountStanding.FinancialAccountStateInformation about the financial account state
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.AccountStanding.FinancialAccountState.BuilderA builder for FinancialAccountState.
public final classStatement.AccountStanding.FinancialAccountState.FinancialAccountStatusStatus of the financial account
public final classStatement.AccountStanding.FinancialAccountState.FinancialAccountSubstatusSubstatus for the financial account
-
Method Summary
-
-
Method Detail
-
status
final Statement.AccountStanding.FinancialAccountState.FinancialAccountStatus status()
Status of the financial account
-
substatus
final Optional<Statement.AccountStanding.FinancialAccountState.FinancialAccountSubstatus> substatus()
Substatus for the financial account
-
_status
final JsonField<Statement.AccountStanding.FinancialAccountState.FinancialAccountStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_substatus
final JsonField<Statement.AccountStanding.FinancialAccountState.FinancialAccountSubstatus> _substatus()
Returns the raw JSON value of substatus.
Unlike substatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.AccountStanding.FinancialAccountState.Builder toBuilder()
-
validate
final Statement.AccountStanding.FinancialAccountState validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statement.AccountStanding.FinancialAccountState.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountState.
The following fields are required:
.status()
-
-
-
-