Class Statement.AmountDue
-
- All Implemented Interfaces:
public final class Statement.AmountDue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.AmountDue.BuilderA builder for AmountDue.
-
Method Summary
Modifier and Type Method Description final Longamount()Payment due at the end of the billing period in cents. final LongpastDue()Amount past due for statement in cents final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Long>_pastDue()Returns the raw JSON value of pastDue. final Map<String, JsonValue>_additionalProperties()final Statement.AmountDue.BuildertoBuilder()final Statement.AmountDuevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statement.AmountDue.Builderbuilder()Returns a mutable builder for constructing an instance of AmountDue. -
-
Method Detail
-
amount
final Long amount()
Payment due at the end of the billing period in cents. Negative amount indicates something is owed. If the amount owed is positive there was a net credit. If auto-collections are enabled this is the amount that will be requested on the payment due date
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_pastDue
final JsonField<Long> _pastDue()
Returns the raw JSON value of pastDue.
Unlike pastDue, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.AmountDue.Builder toBuilder()
-
validate
final Statement.AmountDue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statement.AmountDue.Builder builder()
Returns a mutable builder for constructing an instance of AmountDue.
The following fields are required:
.amount() .pastDue()
-
-
-
-