Class Statement.InterestDetails
-
- All Implemented Interfaces:
public final class Statement.InterestDetails
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.InterestDetails.BuilderA builder for InterestDetails.
public final classStatement.InterestDetails.InterestCalculationMethod
-
Method Summary
-
-
Method Detail
-
actualInterestCharged
final Optional<Long> actualInterestCharged()
-
dailyBalanceAmounts
final CategoryDetails dailyBalanceAmounts()
-
effectiveApr
final CategoryDetails effectiveApr()
-
interestCalculationMethod
final Statement.InterestDetails.InterestCalculationMethod interestCalculationMethod()
-
interestForPeriod
final CategoryDetails interestForPeriod()
-
minimumInterestCharged
final Optional<Long> minimumInterestCharged()
-
_actualInterestCharged
final JsonField<Long> _actualInterestCharged()
Returns the raw JSON value of actualInterestCharged.
Unlike actualInterestCharged, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyBalanceAmounts
final JsonField<CategoryDetails> _dailyBalanceAmounts()
Returns the raw JSON value of dailyBalanceAmounts.
Unlike dailyBalanceAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveApr
final JsonField<CategoryDetails> _effectiveApr()
Returns the raw JSON value of effectiveApr.
Unlike effectiveApr, this method doesn't throw if the JSON field has an unexpected type.
-
_interestCalculationMethod
final JsonField<Statement.InterestDetails.InterestCalculationMethod> _interestCalculationMethod()
Returns the raw JSON value of interestCalculationMethod.
Unlike interestCalculationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_interestForPeriod
final JsonField<CategoryDetails> _interestForPeriod()
Returns the raw JSON value of interestForPeriod.
Unlike interestForPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_primeRate
final JsonField<String> _primeRate()
Returns the raw JSON value of primeRate.
Unlike primeRate, this method doesn't throw if the JSON field has an unexpected type.
-
_minimumInterestCharged
final JsonField<Long> _minimumInterestCharged()
Returns the raw JSON value of minimumInterestCharged.
Unlike minimumInterestCharged, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.InterestDetails.Builder toBuilder()
-
validate
final Statement.InterestDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statement.InterestDetails.Builder builder()
Returns a mutable builder for constructing an instance of InterestDetails.
The following fields are required:
.actualInterestCharged() .dailyBalanceAmounts() .effectiveApr() .interestCalculationMethod() .interestForPeriod() .primeRate()
-
-
-
-