Class Statement.InterestDetails.Builder
-
- All Implemented Interfaces:
public final class Statement.InterestDetails.BuilderA builder for InterestDetails.
-
-
Method Summary
-
-
Method Detail
-
actualInterestCharged
final Statement.InterestDetails.Builder actualInterestCharged(Long actualInterestCharged)
-
actualInterestCharged
final Statement.InterestDetails.Builder actualInterestCharged(Long actualInterestCharged)
Alias for Builder.actualInterestCharged.
This unboxed primitive overload exists for backwards compatibility.
-
actualInterestCharged
final Statement.InterestDetails.Builder actualInterestCharged(Optional<Long> actualInterestCharged)
Alias for calling Builder.actualInterestCharged with
actualInterestCharged.orElse(null).
-
actualInterestCharged
final Statement.InterestDetails.Builder actualInterestCharged(JsonField<Long> actualInterestCharged)
Sets Builder.actualInterestCharged to an arbitrary JSON value.
You should usually call Builder.actualInterestCharged with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dailyBalanceAmounts
final Statement.InterestDetails.Builder dailyBalanceAmounts(CategoryDetails dailyBalanceAmounts)
-
dailyBalanceAmounts
final Statement.InterestDetails.Builder dailyBalanceAmounts(JsonField<CategoryDetails> dailyBalanceAmounts)
Sets Builder.dailyBalanceAmounts to an arbitrary JSON value.
You should usually call Builder.dailyBalanceAmounts with a well-typed CategoryDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveApr
final Statement.InterestDetails.Builder effectiveApr(CategoryDetails effectiveApr)
-
effectiveApr
final Statement.InterestDetails.Builder effectiveApr(JsonField<CategoryDetails> effectiveApr)
Sets Builder.effectiveApr to an arbitrary JSON value.
You should usually call Builder.effectiveApr with a well-typed CategoryDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestCalculationMethod
final Statement.InterestDetails.Builder interestCalculationMethod(Statement.InterestDetails.InterestCalculationMethod interestCalculationMethod)
-
interestCalculationMethod
final Statement.InterestDetails.Builder interestCalculationMethod(JsonField<Statement.InterestDetails.InterestCalculationMethod> interestCalculationMethod)
Sets Builder.interestCalculationMethod to an arbitrary JSON value.
You should usually call Builder.interestCalculationMethod with a well-typed InterestCalculationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestForPeriod
final Statement.InterestDetails.Builder interestForPeriod(CategoryDetails interestForPeriod)
-
interestForPeriod
final Statement.InterestDetails.Builder interestForPeriod(JsonField<CategoryDetails> interestForPeriod)
Sets Builder.interestForPeriod to an arbitrary JSON value.
You should usually call Builder.interestForPeriod with a well-typed CategoryDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primeRate
final Statement.InterestDetails.Builder primeRate(String primeRate)
-
primeRate
final Statement.InterestDetails.Builder primeRate(Optional<String> primeRate)
Alias for calling Builder.primeRate with
primeRate.orElse(null).
-
primeRate
final Statement.InterestDetails.Builder primeRate(JsonField<String> primeRate)
Sets Builder.primeRate to an arbitrary JSON value.
You should usually call Builder.primeRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minimumInterestCharged
final Statement.InterestDetails.Builder minimumInterestCharged(Long minimumInterestCharged)
-
minimumInterestCharged
final Statement.InterestDetails.Builder minimumInterestCharged(Long minimumInterestCharged)
Alias for Builder.minimumInterestCharged.
This unboxed primitive overload exists for backwards compatibility.
-
minimumInterestCharged
final Statement.InterestDetails.Builder minimumInterestCharged(Optional<Long> minimumInterestCharged)
Alias for calling Builder.minimumInterestCharged with
minimumInterestCharged.orElse(null).
-
minimumInterestCharged
final Statement.InterestDetails.Builder minimumInterestCharged(JsonField<Long> minimumInterestCharged)
Sets Builder.minimumInterestCharged to an arbitrary JSON value.
You should usually call Builder.minimumInterestCharged with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Statement.InterestDetails.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Statement.InterestDetails.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Statement.InterestDetails.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Statement.InterestDetails.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Statement.InterestDetails.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Statement.InterestDetails build()
Returns an immutable instance of InterestDetails.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.actualInterestCharged() .dailyBalanceAmounts() .effectiveApr() .interestCalculationMethod() .interestForPeriod() .primeRate()
-
-
-
-