Class Statement.PayoffDetails
-
- All Implemented Interfaces:
public final class Statement.PayoffDetailsDetails on number and size of payments to pay off balance
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatement.PayoffDetails.BuilderA builder for PayoffDetails.
-
Method Summary
Modifier and Type Method Description final StringminimumPaymentMonths()The number of months it would take to pay off the balance in full by only paying the minimum payment. final StringminimumPaymentTotal()The sum of all interest and principal paid, in cents, when only paying minimum monthly payment. final Optional<Long>payoffPeriodLengthMonths()Number of months to full pay off final Optional<Long>payoffPeriodMonthlyPaymentAmount()The amount needed to be paid, in cents, each month in order to pay off current balance in the payoff period final Optional<Long>payoffPeriodPaymentTotal()The sum of all interest and principal paid, in cents, when paying off in the payoff period final JsonField<String>_minimumPaymentMonths()Returns the raw JSON value of minimumPaymentMonths. final JsonField<String>_minimumPaymentTotal()Returns the raw JSON value of minimumPaymentTotal. final JsonField<Long>_payoffPeriodLengthMonths()Returns the raw JSON value of payoffPeriodLengthMonths. final JsonField<Long>_payoffPeriodMonthlyPaymentAmount()Returns the raw JSON value of payoffPeriodMonthlyPaymentAmount. final JsonField<Long>_payoffPeriodPaymentTotal()Returns the raw JSON value of payoffPeriodPaymentTotal. final Map<String, JsonValue>_additionalProperties()final Statement.PayoffDetails.BuildertoBuilder()final Statement.PayoffDetailsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statement.PayoffDetails.Builderbuilder()Returns a mutable builder for constructing an instance of PayoffDetails. -
-
Method Detail
-
minimumPaymentMonths
final String minimumPaymentMonths()
The number of months it would take to pay off the balance in full by only paying the minimum payment. "NA" will signal negative or zero amortization
-
minimumPaymentTotal
final String minimumPaymentTotal()
The sum of all interest and principal paid, in cents, when only paying minimum monthly payment. "NA" will signal negative or zero amortization
-
payoffPeriodLengthMonths
final Optional<Long> payoffPeriodLengthMonths()
Number of months to full pay off
-
payoffPeriodMonthlyPaymentAmount
final Optional<Long> payoffPeriodMonthlyPaymentAmount()
The amount needed to be paid, in cents, each month in order to pay off current balance in the payoff period
-
payoffPeriodPaymentTotal
final Optional<Long> payoffPeriodPaymentTotal()
The sum of all interest and principal paid, in cents, when paying off in the payoff period
-
_minimumPaymentMonths
final JsonField<String> _minimumPaymentMonths()
Returns the raw JSON value of minimumPaymentMonths.
Unlike minimumPaymentMonths, this method doesn't throw if the JSON field has an unexpected type.
-
_minimumPaymentTotal
final JsonField<String> _minimumPaymentTotal()
Returns the raw JSON value of minimumPaymentTotal.
Unlike minimumPaymentTotal, this method doesn't throw if the JSON field has an unexpected type.
-
_payoffPeriodLengthMonths
final JsonField<Long> _payoffPeriodLengthMonths()
Returns the raw JSON value of payoffPeriodLengthMonths.
Unlike payoffPeriodLengthMonths, this method doesn't throw if the JSON field has an unexpected type.
-
_payoffPeriodMonthlyPaymentAmount
final JsonField<Long> _payoffPeriodMonthlyPaymentAmount()
Returns the raw JSON value of payoffPeriodMonthlyPaymentAmount.
Unlike payoffPeriodMonthlyPaymentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_payoffPeriodPaymentTotal
final JsonField<Long> _payoffPeriodPaymentTotal()
Returns the raw JSON value of payoffPeriodPaymentTotal.
Unlike payoffPeriodPaymentTotal, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statement.PayoffDetails.Builder toBuilder()
-
validate
final Statement.PayoffDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statement.PayoffDetails.Builder builder()
Returns a mutable builder for constructing an instance of PayoffDetails.
The following fields are required:
.minimumPaymentMonths() .minimumPaymentTotal() .payoffPeriodLengthMonths() .payoffPeriodMonthlyPaymentAmount() .payoffPeriodPaymentTotal()
-
-
-
-