Package com.lithic.api.models
Class StatementLineItems
-
- All Implemented Interfaces:
public final class StatementLineItems
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatementLineItems.BuilderA builder for StatementLineItems.
public final classStatementLineItems.StatementLineItemResponse
-
Method Summary
Modifier and Type Method Description final List<StatementLineItems.StatementLineItemResponse>data()final BooleanhasMore()final JsonField<List<StatementLineItems.StatementLineItemResponse>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final StatementLineItems.BuildertoBuilder()final StatementLineItemsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StatementLineItems.Builderbuilder()Returns a mutable builder for constructing an instance of StatementLineItems. -
-
Method Detail
-
data
final List<StatementLineItems.StatementLineItemResponse> data()
-
_data
final JsonField<List<StatementLineItems.StatementLineItemResponse>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StatementLineItems.Builder toBuilder()
-
validate
final StatementLineItems validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StatementLineItems.Builder builder()
Returns a mutable builder for constructing an instance of StatementLineItems.
The following fields are required:
.data() .hasMore()
-
-
-
-