Class StatementLineItems.StatementLineItemResponse
-
- All Implemented Interfaces:
public final class StatementLineItems.StatementLineItemResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatementLineItems.StatementLineItemResponse.BuilderA builder for StatementLineItemResponse.
public final classStatementLineItems.StatementLineItemResponse.TransactionCategoryNote: Inbound wire transfers are coming soon (availability varies by partner bank). The WIRE category is a preview. To learn more, contact your customer success manager.
public final classStatementLineItems.StatementLineItemResponse.FinancialEventType
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for a Statement Line Item final Longamount()Transaction amount in cents final StatementLineItems.StatementLineItemResponse.TransactionCategorycategory()Note: Inbound wire transfers are coming soon (availability varies by partner bank). final OffsetDateTimecreated()Timestamp of when the line item was generated final Stringcurrency()3-character alphabetic ISO 4217 code for the settling currency of the transaction final LocalDateeffectiveDate()Date that the transaction effected the account balance final StatementLineItems.StatementLineItemResponse.FinancialEventTypeeventType()final StringfinancialAccountToken()Globally unique identifier for a financial account final StringfinancialTransactionEventToken()Globally unique identifier for a financial transaction event final StringfinancialTransactionToken()Globally unique identifier for a financial transaction final Optional<String>cardToken()Globally unique identifier for a card final Optional<String>descriptor()final Optional<String>eventSubtype()Subtype of the event that generated the line items final Optional<LocalDate>loanTapeDate()Date of the loan tape that generated this line item final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<StatementLineItems.StatementLineItemResponse.TransactionCategory>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<StatementLineItems.StatementLineItemResponse.FinancialEventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final JsonField<String>_financialTransactionEventToken()Returns the raw JSON value of financialTransactionEventToken. final JsonField<String>_financialTransactionToken()Returns the raw JSON value of financialTransactionToken. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_eventSubtype()Returns the raw JSON value of eventSubtype. final JsonField<LocalDate>_loanTapeDate()Returns the raw JSON value of loanTapeDate. final Map<String, JsonValue>_additionalProperties()final StatementLineItems.StatementLineItemResponse.BuildertoBuilder()final StatementLineItems.StatementLineItemResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StatementLineItems.StatementLineItemResponse.Builderbuilder()Returns a mutable builder for constructing an instance of StatementLineItemResponse. -
-
Method Detail
-
category
final StatementLineItems.StatementLineItemResponse.TransactionCategory category()
Note: Inbound wire transfers are coming soon (availability varies by partner bank). The WIRE category is a preview. To learn more, contact your customer success manager.
-
created
final OffsetDateTime created()
Timestamp of when the line item was generated
-
currency
final String currency()
3-character alphabetic ISO 4217 code for the settling currency of the transaction
-
effectiveDate
final LocalDate effectiveDate()
Date that the transaction effected the account balance
-
eventType
final StatementLineItems.StatementLineItemResponse.FinancialEventType eventType()
-
financialAccountToken
final String financialAccountToken()
Globally unique identifier for a financial account
-
financialTransactionEventToken
final String financialTransactionEventToken()
Globally unique identifier for a financial transaction event
-
financialTransactionToken
final String financialTransactionToken()
Globally unique identifier for a financial transaction
-
descriptor
final Optional<String> descriptor()
-
eventSubtype
final Optional<String> eventSubtype()
Subtype of the event that generated the line items
-
loanTapeDate
final Optional<LocalDate> loanTapeDate()
Date of the loan tape that generated this line item
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<StatementLineItems.StatementLineItemResponse.TransactionCategory> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<StatementLineItems.StatementLineItemResponse.FinancialEventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_financialTransactionEventToken
final JsonField<String> _financialTransactionEventToken()
Returns the raw JSON value of financialTransactionEventToken.
Unlike financialTransactionEventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_financialTransactionToken
final JsonField<String> _financialTransactionToken()
Returns the raw JSON value of financialTransactionToken.
Unlike financialTransactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_eventSubtype
final JsonField<String> _eventSubtype()
Returns the raw JSON value of eventSubtype.
Unlike eventSubtype, this method doesn't throw if the JSON field has an unexpected type.
-
_loanTapeDate
final JsonField<LocalDate> _loanTapeDate()
Returns the raw JSON value of loanTapeDate.
Unlike loanTapeDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StatementLineItems.StatementLineItemResponse.Builder toBuilder()
-
validate
final StatementLineItems.StatementLineItemResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StatementLineItems.StatementLineItemResponse.Builder builder()
Returns a mutable builder for constructing an instance of StatementLineItemResponse.
The following fields are required:
.token() .amount() .category() .created() .currency() .effectiveDate() .eventType() .financialAccountToken() .financialTransactionEventToken() .financialTransactionToken()
-
-
-
-