Class StatementTotals.Builder
-
- All Implemented Interfaces:
public final class StatementTotals.BuilderA builder for StatementTotals.
-
-
Method Summary
Modifier and Type Method Description final StatementTotals.BuilderbalanceTransfers(Long balanceTransfers)Opening balance transferred from previous account in cents final StatementTotals.BuilderbalanceTransfers(JsonField<Long> balanceTransfers)Sets Builder.balanceTransfers to an arbitrary JSON value. final StatementTotals.BuildercashAdvances(Long cashAdvances)ATM and cashback transactions in cents final StatementTotals.BuildercashAdvances(JsonField<Long> cashAdvances)Sets Builder.cashAdvances to an arbitrary JSON value. final StatementTotals.Buildercredits(Long credits)Volume of credit management operation transactions less any balance transfers in cents final StatementTotals.Buildercredits(JsonField<Long> credits)Sets Builder.credits to an arbitrary JSON value. final StatementTotals.Builderdebits(Long debits)Volume of debit management operation transactions less any interest in cents final StatementTotals.Builderdebits(JsonField<Long> debits)Sets Builder.debits to an arbitrary JSON value. final StatementTotals.Builderfees(Long fees)Volume of debit management operation transactions less any interest in cents final StatementTotals.Builderfees(JsonField<Long> fees)Sets Builder.fees to an arbitrary JSON value. final StatementTotals.Builderinterest(Long interest)Interest accrued in cents final StatementTotals.Builderinterest(JsonField<Long> interest)Sets Builder.interest to an arbitrary JSON value. final StatementTotals.Builderpayments(Long payments)Any funds transfers which affective the balance in cents final StatementTotals.Builderpayments(JsonField<Long> payments)Sets Builder.payments to an arbitrary JSON value. final StatementTotals.Builderpurchases(Long purchases)Net card transaction volume less any cash advances in cents final StatementTotals.Builderpurchases(JsonField<Long> purchases)Sets Builder.purchases to an arbitrary JSON value. final StatementTotals.BuildercreditDetails(JsonValue creditDetails)Breakdown of credits final StatementTotals.BuilderdebitDetails(JsonValue debitDetails)Breakdown of debits final StatementTotals.BuilderpaymentDetails(JsonValue paymentDetails)Breakdown of payments final StatementTotals.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final StatementTotals.BuilderputAdditionalProperty(String key, JsonValue value)final StatementTotals.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final StatementTotals.BuilderremoveAdditionalProperty(String key)final StatementTotals.BuilderremoveAllAdditionalProperties(Set<String> keys)final StatementTotalsbuild()Returns an immutable instance of StatementTotals. -
-
Method Detail
-
balanceTransfers
final StatementTotals.Builder balanceTransfers(Long balanceTransfers)
Opening balance transferred from previous account in cents
-
balanceTransfers
final StatementTotals.Builder balanceTransfers(JsonField<Long> balanceTransfers)
Sets Builder.balanceTransfers to an arbitrary JSON value.
You should usually call Builder.balanceTransfers with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashAdvances
final StatementTotals.Builder cashAdvances(Long cashAdvances)
ATM and cashback transactions in cents
-
cashAdvances
final StatementTotals.Builder cashAdvances(JsonField<Long> cashAdvances)
Sets Builder.cashAdvances to an arbitrary JSON value.
You should usually call Builder.cashAdvances with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
credits
final StatementTotals.Builder credits(Long credits)
Volume of credit management operation transactions less any balance transfers in cents
-
credits
final StatementTotals.Builder credits(JsonField<Long> credits)
Sets Builder.credits to an arbitrary JSON value.
You should usually call Builder.credits with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debits
final StatementTotals.Builder debits(Long debits)
Volume of debit management operation transactions less any interest in cents
-
debits
final StatementTotals.Builder debits(JsonField<Long> debits)
Sets Builder.debits to an arbitrary JSON value.
You should usually call Builder.debits with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fees
final StatementTotals.Builder fees(Long fees)
Volume of debit management operation transactions less any interest in cents
-
fees
final StatementTotals.Builder fees(JsonField<Long> fees)
Sets Builder.fees to an arbitrary JSON value.
You should usually call Builder.fees with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interest
final StatementTotals.Builder interest(Long interest)
Interest accrued in cents
-
interest
final StatementTotals.Builder interest(JsonField<Long> interest)
Sets Builder.interest to an arbitrary JSON value.
You should usually call Builder.interest with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payments
final StatementTotals.Builder payments(Long payments)
Any funds transfers which affective the balance in cents
-
payments
final StatementTotals.Builder payments(JsonField<Long> payments)
Sets Builder.payments to an arbitrary JSON value.
You should usually call Builder.payments with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchases
final StatementTotals.Builder purchases(Long purchases)
Net card transaction volume less any cash advances in cents
-
purchases
final StatementTotals.Builder purchases(JsonField<Long> purchases)
Sets Builder.purchases to an arbitrary JSON value.
You should usually call Builder.purchases with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditDetails
final StatementTotals.Builder creditDetails(JsonValue creditDetails)
Breakdown of credits
-
debitDetails
final StatementTotals.Builder debitDetails(JsonValue debitDetails)
Breakdown of debits
-
paymentDetails
final StatementTotals.Builder paymentDetails(JsonValue paymentDetails)
Breakdown of payments
-
additionalProperties
final StatementTotals.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StatementTotals.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StatementTotals.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StatementTotals.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StatementTotals.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StatementTotals build()
Returns an immutable instance of StatementTotals.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.balanceTransfers() .cashAdvances() .credits() .debits() .fees() .interest() .payments() .purchases()
-
-
-
-