Package com.lithic.api.models
Class Statements
-
- All Implemented Interfaces:
public final class Statements
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatements.BuilderA builder for Statements.
-
Method Summary
Modifier and Type Method Description final List<Statement>data()final BooleanhasMore()final JsonField<List<Statement>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final Statements.BuildertoBuilder()final Statementsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Statements.Builderbuilder()Returns a mutable builder for constructing an instance of Statements. -
-
Method Detail
-
_data
final JsonField<List<Statement>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Statements.Builder toBuilder()
-
validate
final Statements validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Statements.Builder builder()
Returns a mutable builder for constructing an instance of Statements.
The following fields are required:
.data() .hasMore()
-
-
-
-