Class StatementsCreatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class StatementsCreatedWebhookEvent.BuilderA builder for StatementsCreatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final StatementsCreatedWebhookEvent.Builder token(String token)
Globally unique identifier for a statement
-
token
final StatementsCreatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStanding
final StatementsCreatedWebhookEvent.Builder accountStanding(Statement.AccountStanding accountStanding)
-
accountStanding
final StatementsCreatedWebhookEvent.Builder accountStanding(JsonField<Statement.AccountStanding> accountStanding)
Sets Builder.accountStanding to an arbitrary JSON value.
You should usually call Builder.accountStanding with a well-typed Statement.AccountStanding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amountDue
final StatementsCreatedWebhookEvent.Builder amountDue(Statement.AmountDue amountDue)
-
amountDue
final StatementsCreatedWebhookEvent.Builder amountDue(JsonField<Statement.AmountDue> amountDue)
Sets Builder.amountDue to an arbitrary JSON value.
You should usually call Builder.amountDue with a well-typed Statement.AmountDue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
availableCredit
final StatementsCreatedWebhookEvent.Builder availableCredit(Long availableCredit)
Amount of credit available to spend in cents
-
availableCredit
final StatementsCreatedWebhookEvent.Builder availableCredit(JsonField<Long> availableCredit)
Sets Builder.availableCredit to an arbitrary JSON value.
You should usually call Builder.availableCredit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final StatementsCreatedWebhookEvent.Builder created(OffsetDateTime created)
Timestamp of when the statement was created
-
created
final StatementsCreatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditLimit
final StatementsCreatedWebhookEvent.Builder creditLimit(Long creditLimit)
This is the maximum credit balance extended by the lender in cents
-
creditLimit
final StatementsCreatedWebhookEvent.Builder creditLimit(JsonField<Long> creditLimit)
Sets Builder.creditLimit to an arbitrary JSON value.
You should usually call Builder.creditLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditProductToken
final StatementsCreatedWebhookEvent.Builder creditProductToken(String creditProductToken)
Globally unique identifier for a credit product
-
creditProductToken
final StatementsCreatedWebhookEvent.Builder creditProductToken(Optional<String> creditProductToken)
Alias for calling Builder.creditProductToken with
creditProductToken.orElse(null).
-
creditProductToken
final StatementsCreatedWebhookEvent.Builder creditProductToken(JsonField<String> creditProductToken)
Sets Builder.creditProductToken to an arbitrary JSON value.
You should usually call Builder.creditProductToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
daysInBillingCycle
final StatementsCreatedWebhookEvent.Builder daysInBillingCycle(Long daysInBillingCycle)
Number of days in the billing cycle
-
daysInBillingCycle
final StatementsCreatedWebhookEvent.Builder daysInBillingCycle(JsonField<Long> daysInBillingCycle)
Sets Builder.daysInBillingCycle to an arbitrary JSON value.
You should usually call Builder.daysInBillingCycle with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endingBalance
final StatementsCreatedWebhookEvent.Builder endingBalance(Long endingBalance)
Balance at the end of the billing period. For charge cards, this should be the same at the statement amount due in cents
-
endingBalance
final StatementsCreatedWebhookEvent.Builder endingBalance(JsonField<Long> endingBalance)
Sets Builder.endingBalance to an arbitrary JSON value.
You should usually call Builder.endingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialAccountToken
final StatementsCreatedWebhookEvent.Builder financialAccountToken(String financialAccountToken)
Globally unique identifier for a financial account
-
financialAccountToken
final StatementsCreatedWebhookEvent.Builder financialAccountToken(JsonField<String> financialAccountToken)
Sets Builder.financialAccountToken to an arbitrary JSON value.
You should usually call Builder.financialAccountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentDueDate
final StatementsCreatedWebhookEvent.Builder paymentDueDate(LocalDate paymentDueDate)
Date when the payment is due
-
paymentDueDate
final StatementsCreatedWebhookEvent.Builder paymentDueDate(Optional<LocalDate> paymentDueDate)
Alias for calling Builder.paymentDueDate with
paymentDueDate.orElse(null).
-
paymentDueDate
final StatementsCreatedWebhookEvent.Builder paymentDueDate(JsonField<LocalDate> paymentDueDate)
Sets Builder.paymentDueDate to an arbitrary JSON value.
You should usually call Builder.paymentDueDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodTotals
final StatementsCreatedWebhookEvent.Builder periodTotals(StatementTotals periodTotals)
-
periodTotals
final StatementsCreatedWebhookEvent.Builder periodTotals(JsonField<StatementTotals> periodTotals)
Sets Builder.periodTotals to an arbitrary JSON value.
You should usually call Builder.periodTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startingBalance
final StatementsCreatedWebhookEvent.Builder startingBalance(Long startingBalance)
Balance at the start of the billing period
-
startingBalance
final StatementsCreatedWebhookEvent.Builder startingBalance(JsonField<Long> startingBalance)
Sets Builder.startingBalance to an arbitrary JSON value.
You should usually call Builder.startingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementEndDate
final StatementsCreatedWebhookEvent.Builder statementEndDate(LocalDate statementEndDate)
Date when the billing period ended
-
statementEndDate
final StatementsCreatedWebhookEvent.Builder statementEndDate(JsonField<LocalDate> statementEndDate)
Sets Builder.statementEndDate to an arbitrary JSON value.
You should usually call Builder.statementEndDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementStartDate
final StatementsCreatedWebhookEvent.Builder statementStartDate(LocalDate statementStartDate)
Date when the billing period began
-
statementStartDate
final StatementsCreatedWebhookEvent.Builder statementStartDate(JsonField<LocalDate> statementStartDate)
Sets Builder.statementStartDate to an arbitrary JSON value.
You should usually call Builder.statementStartDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementType
final StatementsCreatedWebhookEvent.Builder statementType(Statement.StatementType statementType)
-
statementType
final StatementsCreatedWebhookEvent.Builder statementType(JsonField<Statement.StatementType> statementType)
Sets Builder.statementType to an arbitrary JSON value.
You should usually call Builder.statementType with a well-typed Statement.StatementType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updated
final StatementsCreatedWebhookEvent.Builder updated(OffsetDateTime updated)
Timestamp of when the statement was updated
-
updated
final StatementsCreatedWebhookEvent.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ytdTotals
final StatementsCreatedWebhookEvent.Builder ytdTotals(StatementTotals ytdTotals)
-
ytdTotals
final StatementsCreatedWebhookEvent.Builder ytdTotals(JsonField<StatementTotals> ytdTotals)
Sets Builder.ytdTotals to an arbitrary JSON value.
You should usually call Builder.ytdTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestDetails
final StatementsCreatedWebhookEvent.Builder interestDetails(Statement.InterestDetails interestDetails)
-
interestDetails
final StatementsCreatedWebhookEvent.Builder interestDetails(Optional<Statement.InterestDetails> interestDetails)
Alias for calling Builder.interestDetails with
interestDetails.orElse(null).
-
interestDetails
final StatementsCreatedWebhookEvent.Builder interestDetails(JsonField<Statement.InterestDetails> interestDetails)
Sets Builder.interestDetails to an arbitrary JSON value.
You should usually call Builder.interestDetails with a well-typed Statement.InterestDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextPaymentDueDate
final StatementsCreatedWebhookEvent.Builder nextPaymentDueDate(LocalDate nextPaymentDueDate)
Date when the next payment is due
-
nextPaymentDueDate
final StatementsCreatedWebhookEvent.Builder nextPaymentDueDate(JsonField<LocalDate> nextPaymentDueDate)
Sets Builder.nextPaymentDueDate to an arbitrary JSON value.
You should usually call Builder.nextPaymentDueDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nextStatementEndDate
final StatementsCreatedWebhookEvent.Builder nextStatementEndDate(LocalDate nextStatementEndDate)
Date when the next billing period will end
-
nextStatementEndDate
final StatementsCreatedWebhookEvent.Builder nextStatementEndDate(JsonField<LocalDate> nextStatementEndDate)
Sets Builder.nextStatementEndDate to an arbitrary JSON value.
You should usually call Builder.nextStatementEndDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payoffDetails
final StatementsCreatedWebhookEvent.Builder payoffDetails(Statement.PayoffDetails payoffDetails)
Details on number and size of payments to pay off balance
-
payoffDetails
final StatementsCreatedWebhookEvent.Builder payoffDetails(Optional<Statement.PayoffDetails> payoffDetails)
Alias for calling Builder.payoffDetails with
payoffDetails.orElse(null).
-
payoffDetails
final StatementsCreatedWebhookEvent.Builder payoffDetails(JsonField<Statement.PayoffDetails> payoffDetails)
Sets Builder.payoffDetails to an arbitrary JSON value.
You should usually call Builder.payoffDetails with a well-typed Statement.PayoffDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementTotals
final StatementsCreatedWebhookEvent.Builder statementTotals(StatementTotals statementTotals)
-
statementTotals
final StatementsCreatedWebhookEvent.Builder statementTotals(JsonField<StatementTotals> statementTotals)
Sets Builder.statementTotals to an arbitrary JSON value.
You should usually call Builder.statementTotals with a well-typed StatementTotals value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final StatementsCreatedWebhookEvent.Builder eventType(StatementsCreatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final StatementsCreatedWebhookEvent.Builder eventType(JsonField<StatementsCreatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final StatementsCreatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final StatementsCreatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final StatementsCreatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final StatementsCreatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final StatementsCreatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final StatementsCreatedWebhookEvent build()
Returns an immutable instance of StatementsCreatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountStanding() .amountDue() .availableCredit() .created() .creditLimit() .creditProductToken() .daysInBillingCycle() .endingBalance() .financialAccountToken() .paymentDueDate() .periodTotals() .startingBalance() .statementEndDate() .statementStartDate() .statementType() .updated() .ytdTotals() .eventType()
-
-
-
-