Class ThreeDSAuthentication
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationRepresents a 3DS authentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthentication.BuilderA builder for ThreeDSAuthentication.
public final classThreeDSAuthentication.AccountTypeType of account/card that is being used for the transaction. Maps to EMV 3DS field
acctType.public final classThreeDSAuthentication.AuthenticationResultIndicates the outcome of the 3DS authentication process.
public final classThreeDSAuthentication.CardExpiryCheckIndicates whether the expiration date provided by the cardholder during checkout matches Lithic's record of the card's expiration date.
public final classThreeDSAuthentication.CardholderObject containing data about the cardholder provided during the transaction.
public final classThreeDSAuthentication.ChannelChannel in which the authentication occurs. Maps to EMV 3DS field
deviceChannel.public final classThreeDSAuthentication.MerchantObject containing data about the merchant involved in the e-commerce transaction.
public final classThreeDSAuthentication.MessageCategoryEither PAYMENT_AUTHENTICATION or NON_PAYMENT_AUTHENTICATION. For NON_PAYMENT_AUTHENTICATION, additional_data and transaction fields are not populated.
public final classThreeDSAuthentication.ThreeDSRequestorChallengeIndicatorIndicates whether a challenge is requested for this transaction
NO_PREFERENCE- No PreferenceNO_CHALLENGE_REQUESTED- No Challenge RequestedCHALLENGE_PREFERENCE- Challenge requested (3DS Requestor preference)CHALLENGE_MANDATE- Challenge requested (Mandate)NO_CHALLENGE_RISK_ALREADY_ASSESSED- No Challenge requested (Transactional risk analysis is already performed)DATA_SHARE_ONLY- No Challenge requested (Data Share Only)OTHER- Other indicators not captured by above. These are rarely used
public final classThreeDSAuthentication.AdditionalDataObject containing additional data about the 3DS request that is beyond the EMV 3DS standard spec (e.g., specific fields that only certain card networks send but are not required across all 3DS requests).
public final classThreeDSAuthentication.AppObject containing data about the app used in the e-commerce transaction. Present if the channel is 'APP_BASED'.
public final classThreeDSAuthentication.AuthenticationRequestTypeType of authentication request - i.e., the type of transaction or interaction is causing the merchant to request an authentication. Maps to EMV 3DS field
threeDSRequestorAuthenticationInd.public final classThreeDSAuthentication.BrowserObject containing data about the browser used in the e-commerce transaction. Present if the channel is 'BROWSER'.
public final classThreeDSAuthentication.ChallengeMetadataMetadata about the challenge method and delivery. Only present when a challenge is triggered.
public final classThreeDSAuthentication.ChallengeOrchestratedByEntity that orchestrates the challenge. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
public final classThreeDSAuthentication.DecisionMadeByEntity that made the authentication decision. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
public final classThreeDSAuthentication.ThreeRiRequestTypeType of 3DS Requestor Initiated (3RI) request — i.e., a 3DS authentication that takes place at the initiation of the merchant rather than the cardholder. The most common example of this is where a merchant is authenticating before billing for a recurring transaction such as a pay TV subscription or a utility bill. Maps to EMV 3DS field
threeRIInd.public final classThreeDSAuthentication.TransactionObject containing data about the e-commerce transaction for which the merchant is requesting authentication.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the 3DS authentication. final Optional<ThreeDSAuthentication.AccountType>accountType()Type of account/card that is being used for the transaction. final ThreeDSAuthentication.AuthenticationResultauthenticationResult()Indicates the outcome of the 3DS authentication process. final ThreeDSAuthentication.CardExpiryCheckcardExpiryCheck()Indicates whether the expiration date provided by the cardholder during checkout matches Lithic's record of the card's expiration date. final StringcardToken()Globally unique identifier for the card on which the 3DS authentication has occurred. final ThreeDSAuthentication.Cardholdercardholder()Object containing data about the cardholder provided during the transaction. final ThreeDSAuthentication.Channelchannel()Channel in which the authentication occurs. final OffsetDateTimecreated()Date and time when the authentication was created in Lithic's system. final ThreeDSAuthentication.Merchantmerchant()Object containing data about the merchant involved in the e-commerce transaction. final ThreeDSAuthentication.MessageCategorymessageCategory()Either PAYMENT_AUTHENTICATION or NON_PAYMENT_AUTHENTICATION. final ThreeDSAuthentication.ThreeDSRequestorChallengeIndicatorthreeDSRequestorChallengeIndicator()Indicates whether a challenge is requested for this transaction NO_PREFERENCE- No PreferenceNO_CHALLENGE_REQUESTED- No Challenge RequestedCHALLENGE_PREFERENCE- Challenge requested (3DS Requestor preference)CHALLENGE_MANDATE- Challenge requested (Mandate)NO_CHALLENGE_RISK_ALREADY_ASSESSED- No Challenge requested (Transactional risk analysis is already performed)DATA_SHARE_ONLY- No Challenge requested (Data Share Only)OTHER- Other indicators not captured by above. These are rarely used
final Optional<ThreeDSAuthentication.AdditionalData>additionalData()Object containing additional data about the 3DS request that is beyond the EMV 3DS standard spec (e.g., specific fields that only certain card networks send but are not required across all 3DS requests). final Optional<ThreeDSAuthentication.App>app()Object containing data about the app used in the e-commerce transaction. final Optional<ThreeDSAuthentication.AuthenticationRequestType>authenticationRequestType()Type of authentication request - i.e., the type of transaction or interaction is causing the merchant to request an authentication. final Optional<ThreeDSAuthentication.Browser>browser()Object containing data about the browser used in the e-commerce transaction. final Optional<ThreeDSAuthentication.ChallengeMetadata>challengeMetadata()Metadata about the challenge method and delivery. final Optional<ThreeDSAuthentication.ChallengeOrchestratedBy>challengeOrchestratedBy()Entity that orchestrates the challenge. final Optional<ThreeDSAuthentication.DecisionMadeBy>decisionMadeBy()Entity that made the authentication decision. final Optional<ThreeDSAuthentication.ThreeRiRequestType>threeRiRequestType()Type of 3DS Requestor Initiated (3RI) request — i.e., a 3DS authentication that takes place at the initiation of the merchant rather than the cardholder. final Optional<ThreeDSAuthentication.Transaction>transaction()Object containing data about the e-commerce transaction for which the merchant is requesting authentication. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<ThreeDSAuthentication.AccountType>_accountType()Returns the raw JSON value of accountType. final JsonField<ThreeDSAuthentication.AuthenticationResult>_authenticationResult()Returns the raw JSON value of authenticationResult. final JsonField<ThreeDSAuthentication.CardExpiryCheck>_cardExpiryCheck()Returns the raw JSON value of cardExpiryCheck. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<ThreeDSAuthentication.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<ThreeDSAuthentication.Channel>_channel()Returns the raw JSON value of channel. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<ThreeDSAuthentication.Merchant>_merchant()Returns the raw JSON value of merchant. final JsonField<ThreeDSAuthentication.MessageCategory>_messageCategory()Returns the raw JSON value of messageCategory. final JsonField<ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator>_threeDSRequestorChallengeIndicator()Returns the raw JSON value of threeDSRequestorChallengeIndicator. final JsonField<ThreeDSAuthentication.AdditionalData>_additionalData()Returns the raw JSON value of additionalData. final JsonField<ThreeDSAuthentication.App>_app()Returns the raw JSON value of app. final JsonField<ThreeDSAuthentication.AuthenticationRequestType>_authenticationRequestType()Returns the raw JSON value of authenticationRequestType. final JsonField<ThreeDSAuthentication.Browser>_browser()Returns the raw JSON value of browser. final JsonField<ThreeDSAuthentication.ChallengeMetadata>_challengeMetadata()Returns the raw JSON value of challengeMetadata. final JsonField<ThreeDSAuthentication.ChallengeOrchestratedBy>_challengeOrchestratedBy()Returns the raw JSON value of challengeOrchestratedBy. final JsonField<ThreeDSAuthentication.DecisionMadeBy>_decisionMadeBy()Returns the raw JSON value of decisionMadeBy. final JsonField<ThreeDSAuthentication.ThreeRiRequestType>_threeRiRequestType()Returns the raw JSON value of threeRiRequestType. final JsonField<ThreeDSAuthentication.Transaction>_transaction()Returns the raw JSON value of transaction. final Map<String, JsonValue>_additionalProperties()final ThreeDSAuthentication.BuildertoBuilder()final ThreeDSAuthenticationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreeDSAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of ThreeDSAuthentication. -
-
Method Detail
-
token
final String token()
Globally unique identifier for the 3DS authentication. Permitted values: 36-digit version 4 UUID (including hyphens).
-
accountType
final Optional<ThreeDSAuthentication.AccountType> accountType()
Type of account/card that is being used for the transaction. Maps to EMV 3DS field
acctType.
-
authenticationResult
final ThreeDSAuthentication.AuthenticationResult authenticationResult()
Indicates the outcome of the 3DS authentication process.
-
cardExpiryCheck
final ThreeDSAuthentication.CardExpiryCheck cardExpiryCheck()
Indicates whether the expiration date provided by the cardholder during checkout matches Lithic's record of the card's expiration date.
-
cardToken
final String cardToken()
Globally unique identifier for the card on which the 3DS authentication has occurred. Permitted values: 36-digit version 4 UUID (including hyphens).
-
cardholder
final ThreeDSAuthentication.Cardholder cardholder()
Object containing data about the cardholder provided during the transaction.
-
channel
final ThreeDSAuthentication.Channel channel()
Channel in which the authentication occurs. Maps to EMV 3DS field
deviceChannel.
-
created
final OffsetDateTime created()
Date and time when the authentication was created in Lithic's system. Permitted values: Date string in the ISO 8601 format yyyy-MM-dd'T'hh:mm:ssZ.
-
merchant
final ThreeDSAuthentication.Merchant merchant()
Object containing data about the merchant involved in the e-commerce transaction.
-
messageCategory
final ThreeDSAuthentication.MessageCategory messageCategory()
Either PAYMENT_AUTHENTICATION or NON_PAYMENT_AUTHENTICATION. For NON_PAYMENT_AUTHENTICATION, additional_data and transaction fields are not populated.
-
threeDSRequestorChallengeIndicator
final ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator threeDSRequestorChallengeIndicator()
Indicates whether a challenge is requested for this transaction
NO_PREFERENCE- No PreferenceNO_CHALLENGE_REQUESTED- No Challenge RequestedCHALLENGE_PREFERENCE- Challenge requested (3DS Requestor preference)CHALLENGE_MANDATE- Challenge requested (Mandate)NO_CHALLENGE_RISK_ALREADY_ASSESSED- No Challenge requested (Transactional risk analysis is already performed)DATA_SHARE_ONLY- No Challenge requested (Data Share Only)OTHER- Other indicators not captured by above. These are rarely used
-
additionalData
final Optional<ThreeDSAuthentication.AdditionalData> additionalData()
Object containing additional data about the 3DS request that is beyond the EMV 3DS standard spec (e.g., specific fields that only certain card networks send but are not required across all 3DS requests).
-
app
final Optional<ThreeDSAuthentication.App> app()
Object containing data about the app used in the e-commerce transaction. Present if the channel is 'APP_BASED'.
-
authenticationRequestType
final Optional<ThreeDSAuthentication.AuthenticationRequestType> authenticationRequestType()
Type of authentication request - i.e., the type of transaction or interaction is causing the merchant to request an authentication. Maps to EMV 3DS field
threeDSRequestorAuthenticationInd.
-
browser
final Optional<ThreeDSAuthentication.Browser> browser()
Object containing data about the browser used in the e-commerce transaction. Present if the channel is 'BROWSER'.
-
challengeMetadata
final Optional<ThreeDSAuthentication.ChallengeMetadata> challengeMetadata()
Metadata about the challenge method and delivery. Only present when a challenge is triggered.
-
challengeOrchestratedBy
final Optional<ThreeDSAuthentication.ChallengeOrchestratedBy> challengeOrchestratedBy()
Entity that orchestrates the challenge. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
-
decisionMadeBy
final Optional<ThreeDSAuthentication.DecisionMadeBy> decisionMadeBy()
Entity that made the authentication decision. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
-
threeRiRequestType
final Optional<ThreeDSAuthentication.ThreeRiRequestType> threeRiRequestType()
Type of 3DS Requestor Initiated (3RI) request — i.e., a 3DS authentication that takes place at the initiation of the merchant rather than the cardholder. The most common example of this is where a merchant is authenticating before billing for a recurring transaction such as a pay TV subscription or a utility bill. Maps to EMV 3DS field
threeRIInd.
-
transaction
final Optional<ThreeDSAuthentication.Transaction> transaction()
Object containing data about the e-commerce transaction for which the merchant is requesting authentication.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<ThreeDSAuthentication.AccountType> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationResult
final JsonField<ThreeDSAuthentication.AuthenticationResult> _authenticationResult()
Returns the raw JSON value of authenticationResult.
Unlike authenticationResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardExpiryCheck
final JsonField<ThreeDSAuthentication.CardExpiryCheck> _cardExpiryCheck()
Returns the raw JSON value of cardExpiryCheck.
Unlike cardExpiryCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<ThreeDSAuthentication.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_channel
final JsonField<ThreeDSAuthentication.Channel> _channel()
Returns the raw JSON value of channel.
Unlike channel, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<ThreeDSAuthentication.Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_messageCategory
final JsonField<ThreeDSAuthentication.MessageCategory> _messageCategory()
Returns the raw JSON value of messageCategory.
Unlike messageCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_threeDSRequestorChallengeIndicator
final JsonField<ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator> _threeDSRequestorChallengeIndicator()
Returns the raw JSON value of threeDSRequestorChallengeIndicator.
Unlike threeDSRequestorChallengeIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalData
final JsonField<ThreeDSAuthentication.AdditionalData> _additionalData()
Returns the raw JSON value of additionalData.
Unlike additionalData, this method doesn't throw if the JSON field has an unexpected type.
-
_app
final JsonField<ThreeDSAuthentication.App> _app()
Returns the raw JSON value of app.
Unlike app, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticationRequestType
final JsonField<ThreeDSAuthentication.AuthenticationRequestType> _authenticationRequestType()
Returns the raw JSON value of authenticationRequestType.
Unlike authenticationRequestType, this method doesn't throw if the JSON field has an unexpected type.
-
_browser
final JsonField<ThreeDSAuthentication.Browser> _browser()
Returns the raw JSON value of browser.
Unlike browser, this method doesn't throw if the JSON field has an unexpected type.
-
_challengeMetadata
final JsonField<ThreeDSAuthentication.ChallengeMetadata> _challengeMetadata()
Returns the raw JSON value of challengeMetadata.
Unlike challengeMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_challengeOrchestratedBy
final JsonField<ThreeDSAuthentication.ChallengeOrchestratedBy> _challengeOrchestratedBy()
Returns the raw JSON value of challengeOrchestratedBy.
Unlike challengeOrchestratedBy, this method doesn't throw if the JSON field has an unexpected type.
-
_decisionMadeBy
final JsonField<ThreeDSAuthentication.DecisionMadeBy> _decisionMadeBy()
Returns the raw JSON value of decisionMadeBy.
Unlike decisionMadeBy, this method doesn't throw if the JSON field has an unexpected type.
-
_threeRiRequestType
final JsonField<ThreeDSAuthentication.ThreeRiRequestType> _threeRiRequestType()
Returns the raw JSON value of threeRiRequestType.
Unlike threeRiRequestType, this method doesn't throw if the JSON field has an unexpected type.
-
_transaction
final JsonField<ThreeDSAuthentication.Transaction> _transaction()
Returns the raw JSON value of transaction.
Unlike transaction, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthentication.Builder toBuilder()
-
validate
final ThreeDSAuthentication validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of ThreeDSAuthentication.
The following fields are required:
.token() .accountType() .authenticationResult() .cardExpiryCheck() .cardToken() .cardholder() .channel() .created() .merchant() .messageCategory() .threeDSRequestorChallengeIndicator()
-
-
-