Class ThreeDSAuthentication.ChallengeMetadata
-
- All Implemented Interfaces:
public final class ThreeDSAuthentication.ChallengeMetadataMetadata about the challenge method and delivery. Only present when a challenge is triggered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthentication.ChallengeMetadata.BuilderA builder for ChallengeMetadata.
public final classThreeDSAuthentication.ChallengeMetadata.MethodTypeThe type of challenge method used for authentication.
public final classThreeDSAuthentication.ChallengeMetadata.StatusIndicates the status of the challenge
SUCCESS - Cardholder completed the challenge successfully
PENDING - Challenge was issued to the cardholder and was not completed yet
SMS_DELIVERY_FAILED - Lithic confirmed undeliverability of the SMS to the provided phone number. Relevant only for SMS_OTP method
CARDHOLDER_TIMEOUT - Cardholder failed to complete the challenge within the given challenge TTL
CANCELED_VIA_CHALLENGE_UI - Cardholder canceled the challenge by selecting "cancel" on the challenge UI
CANCELED_OOB - Cardholder canceled the challenge out of band
ATTEMPTS_EXCEEDED - Cardholder failed the challenge by either entering an incorrect OTP more than the allowed number of times or requesting a new OTP more than the allowed number of times
ABORTED - Merchant aborted authentication after a challenge was requested
ERROR - The challenge failed for a reason different than those documented
-
Method Summary
Modifier and Type Method Description final ThreeDSAuthentication.ChallengeMetadata.MethodTypemethodType()The type of challenge method used for authentication. final ThreeDSAuthentication.ChallengeMetadata.Statusstatus()Indicates the status of the challenge SUCCESS - Cardholder completed the challenge successfully
PENDING - Challenge was issued to the cardholder and was not completed yet
SMS_DELIVERY_FAILED - Lithic confirmed undeliverability of the SMS to the provided phone number. Relevant only for SMS_OTP method
CARDHOLDER_TIMEOUT - Cardholder failed to complete the challenge within the given challenge TTL
CANCELED_VIA_CHALLENGE_UI - Cardholder canceled the challenge by selecting "cancel" on the challenge UI
CANCELED_OOB - Cardholder canceled the challenge out of band
ATTEMPTS_EXCEEDED - Cardholder failed the challenge by either entering an incorrect OTP more than the allowed number of times or requesting a new OTP more than the allowed number of times
ABORTED - Merchant aborted authentication after a challenge was requested
ERROR - The challenge failed for a reason different than those documented
final Optional<String>phoneNumber()The phone number used for delivering the OTP. final JsonField<ThreeDSAuthentication.ChallengeMetadata.MethodType>_methodType()Returns the raw JSON value of methodType. final JsonField<ThreeDSAuthentication.ChallengeMetadata.Status>_status()Returns the raw JSON value of status. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final ThreeDSAuthentication.ChallengeMetadata.BuildertoBuilder()final ThreeDSAuthentication.ChallengeMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreeDSAuthentication.ChallengeMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of ChallengeMetadata. -
-
Method Detail
-
methodType
final ThreeDSAuthentication.ChallengeMetadata.MethodType methodType()
The type of challenge method used for authentication.
-
status
final ThreeDSAuthentication.ChallengeMetadata.Status status()
Indicates the status of the challenge
SUCCESS - Cardholder completed the challenge successfully
PENDING - Challenge was issued to the cardholder and was not completed yet
SMS_DELIVERY_FAILED - Lithic confirmed undeliverability of the SMS to the provided phone number. Relevant only for SMS_OTP method
CARDHOLDER_TIMEOUT - Cardholder failed to complete the challenge within the given challenge TTL
CANCELED_VIA_CHALLENGE_UI - Cardholder canceled the challenge by selecting "cancel" on the challenge UI
CANCELED_OOB - Cardholder canceled the challenge out of band
ATTEMPTS_EXCEEDED - Cardholder failed the challenge by either entering an incorrect OTP more than the allowed number of times or requesting a new OTP more than the allowed number of times
ABORTED - Merchant aborted authentication after a challenge was requested
ERROR - The challenge failed for a reason different than those documented
-
phoneNumber
final Optional<String> phoneNumber()
The phone number used for delivering the OTP. Relevant only for SMS_OTP method.
-
_methodType
final JsonField<ThreeDSAuthentication.ChallengeMetadata.MethodType> _methodType()
Returns the raw JSON value of methodType.
Unlike methodType, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ThreeDSAuthentication.ChallengeMetadata.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthentication.ChallengeMetadata.Builder toBuilder()
-
validate
final ThreeDSAuthentication.ChallengeMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthentication.ChallengeMetadata.Builder builder()
Returns a mutable builder for constructing an instance of ChallengeMetadata.
The following fields are required:
.methodType() .status()
-
-
-