Class ThreeDSAuthenticationChallengeWebhookEvent.Challenge
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationChallengeWebhookEvent.ChallengeRepresents a challenge object for 3DS authentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthenticationChallengeWebhookEvent.Challenge.BuilderA builder for Challenge.
public final classThreeDSAuthenticationChallengeWebhookEvent.Challenge.ChallengeMethodTypeThe type of challenge method issued to the cardholder
-
Method Summary
-
-
Method Detail
-
challengeMethodType
final ThreeDSAuthenticationChallengeWebhookEvent.Challenge.ChallengeMethodType challengeMethodType()
The type of challenge method issued to the cardholder
-
expiryTime
final OffsetDateTime expiryTime()
ISO-8601 time at which the challenge expires
-
startTime
final OffsetDateTime startTime()
ISO-8601 time at which the challenge has started
-
appRequestorUrl
final Optional<String> appRequestorUrl()
Fully qualified app URL of the merchant app. This should be used to redirect the cardholder back to the merchant app after completing an app-based challenge. This URL will only be populated if the 3DS Requestor App is provided to the 3DS SDK.
-
_challengeMethodType
final JsonField<ThreeDSAuthenticationChallengeWebhookEvent.Challenge.ChallengeMethodType> _challengeMethodType()
Returns the raw JSON value of challengeMethodType.
Unlike challengeMethodType, this method doesn't throw if the JSON field has an unexpected type.
-
_expiryTime
final JsonField<OffsetDateTime> _expiryTime()
Returns the raw JSON value of expiryTime.
Unlike expiryTime, this method doesn't throw if the JSON field has an unexpected type.
-
_startTime
final JsonField<OffsetDateTime> _startTime()
Returns the raw JSON value of startTime.
Unlike startTime, this method doesn't throw if the JSON field has an unexpected type.
-
_appRequestorUrl
final JsonField<String> _appRequestorUrl()
Returns the raw JSON value of appRequestorUrl.
Unlike appRequestorUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthenticationChallengeWebhookEvent.Challenge.Builder toBuilder()
-
validate
final ThreeDSAuthenticationChallengeWebhookEvent.Challenge validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthenticationChallengeWebhookEvent.Challenge.Builder builder()
Returns a mutable builder for constructing an instance of Challenge.
The following fields are required:
.challengeMethodType() .expiryTime() .startTime()
-
-
-
-