Class ThreeDSAuthenticationSimulateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class ThreeDSAuthenticationSimulateParams implements Params
Simulates a 3DS authentication request from the payment network as if it came from an ACS. If you're configured for 3DS Customer Decisioning, simulating authentications requires your customer decisioning endpoint to be set up properly (respond with a valid JSON). If the authentication decision is to challenge, ensure that the account holder associated with the card transaction has a valid phone number configured to receive the OTP code via SMS.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthenticationSimulateParams.BuilderA builder for ThreeDSAuthenticationSimulateParams.
public final classThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequestRequest object for simulating a 3DS authentication
public final classThreeDSAuthenticationSimulateParams.MerchantMerchant information for the simulated transaction
public final classThreeDSAuthenticationSimulateParams.TransactionTransaction details for the simulation
public final classThreeDSAuthenticationSimulateParams.CardExpiryCheckWhen set will use the following values as part of the Simulated Authentication. When not set defaults to MATCH
-
Method Summary
Modifier and Type Method Description final ThreeDSAuthenticationSimulateParams.Merchantmerchant()Merchant information for the simulated transaction final Stringpan()Sixteen digit card number. final ThreeDSAuthenticationSimulateParams.Transactiontransaction()Transaction details for the simulation final Optional<ThreeDSAuthenticationSimulateParams.CardExpiryCheck>cardExpiryCheck()When set will use the following values as part of the Simulated Authentication. final JsonField<ThreeDSAuthenticationSimulateParams.Merchant>_merchant()Returns the raw JSON value of merchant. final JsonField<String>_pan()Returns the raw JSON value of pan. final JsonField<ThreeDSAuthenticationSimulateParams.Transaction>_transaction()Returns the raw JSON value of transaction. final JsonField<ThreeDSAuthenticationSimulateParams.CardExpiryCheck>_cardExpiryCheck()Returns the raw JSON value of cardExpiryCheck. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ThreeDSAuthenticationSimulateParams.BuildertoBuilder()final ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreeDSAuthenticationSimulateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ThreeDSAuthenticationSimulateParams. -
-
Method Detail
-
merchant
final ThreeDSAuthenticationSimulateParams.Merchant merchant()
Merchant information for the simulated transaction
-
transaction
final ThreeDSAuthenticationSimulateParams.Transaction transaction()
Transaction details for the simulation
-
cardExpiryCheck
final Optional<ThreeDSAuthenticationSimulateParams.CardExpiryCheck> cardExpiryCheck()
When set will use the following values as part of the Simulated Authentication. When not set defaults to MATCH
-
_merchant
final JsonField<ThreeDSAuthenticationSimulateParams.Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_transaction
final JsonField<ThreeDSAuthenticationSimulateParams.Transaction> _transaction()
Returns the raw JSON value of transaction.
Unlike transaction, this method doesn't throw if the JSON field has an unexpected type.
-
_cardExpiryCheck
final JsonField<ThreeDSAuthenticationSimulateParams.CardExpiryCheck> _cardExpiryCheck()
Returns the raw JSON value of cardExpiryCheck.
Unlike cardExpiryCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ThreeDSAuthenticationSimulateParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ThreeDSAuthenticationSimulateParams.Builder builder()
Returns a mutable builder for constructing an instance of ThreeDSAuthenticationSimulateParams.
The following fields are required:
.merchant() .pan() .transaction()
-
-
-
-