Class ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequestRequest object for simulating a 3DS authentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest.BuilderA builder for SimulateAuthenticationRequest.
-
Method Summary
-
-
Method Detail
-
merchant
final ThreeDSAuthenticationSimulateParams.Merchant merchant()
Merchant information for the simulated transaction
-
transaction
final ThreeDSAuthenticationSimulateParams.Transaction transaction()
Transaction details for the simulation
-
cardExpiryCheck
final Optional<ThreeDSAuthenticationSimulateParams.CardExpiryCheck> cardExpiryCheck()
When set will use the following values as part of the Simulated Authentication. When not set defaults to MATCH
-
_merchant
final JsonField<ThreeDSAuthenticationSimulateParams.Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_transaction
final JsonField<ThreeDSAuthenticationSimulateParams.Transaction> _transaction()
Returns the raw JSON value of transaction.
Unlike transaction, this method doesn't throw if the JSON field has an unexpected type.
-
_cardExpiryCheck
final JsonField<ThreeDSAuthenticationSimulateParams.CardExpiryCheck> _cardExpiryCheck()
Returns the raw JSON value of cardExpiryCheck.
Unlike cardExpiryCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest.Builder toBuilder()
-
validate
final ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthenticationSimulateParams.SimulateAuthenticationRequest.Builder builder()
Returns a mutable builder for constructing an instance of SimulateAuthenticationRequest.
The following fields are required:
.merchant() .pan() .transaction()
-
-
-
-