Package com.lithic.api.models
Class ThreeDSAuthenticationSimulateParams.Transaction
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationSimulateParams.TransactionTransaction details for the simulation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreeDSAuthenticationSimulateParams.Transaction.BuilderA builder for Transaction.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount (in cents) to authenticate. final Stringcurrency()3-character alphabetic ISO 4217 currency code. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final ThreeDSAuthenticationSimulateParams.Transaction.BuildertoBuilder()final ThreeDSAuthenticationSimulateParams.Transactionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreeDSAuthenticationSimulateParams.Transaction.Builderbuilder()Returns a mutable builder for constructing an instance of Transaction. -
-
Method Detail
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreeDSAuthenticationSimulateParams.Transaction.Builder toBuilder()
-
validate
final ThreeDSAuthenticationSimulateParams.Transaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreeDSAuthenticationSimulateParams.Transaction.Builder builder()
Returns a mutable builder for constructing an instance of Transaction.
The following fields are required:
.amount() .currency()
-
-
-
-