Class ThreeDSAuthenticationUpdatedWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class ThreeDSAuthenticationUpdatedWebhookEvent.BuilderA builder for ThreeDSAuthenticationUpdatedWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder token(String token)
Globally unique identifier for the 3DS authentication. Permitted values: 36-digit version 4 UUID (including hyphens).
-
token
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder accountType(ThreeDSAuthentication.AccountType accountType)
Type of account/card that is being used for the transaction. Maps to EMV 3DS field
acctType.
-
accountType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder accountType(Optional<ThreeDSAuthentication.AccountType> accountType)
Alias for calling Builder.accountType with
accountType.orElse(null).
-
accountType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder accountType(JsonField<ThreeDSAuthentication.AccountType> accountType)
Sets Builder.accountType to an arbitrary JSON value.
You should usually call Builder.accountType with a well-typed ThreeDSAuthentication.AccountType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationResult
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder authenticationResult(ThreeDSAuthentication.AuthenticationResult authenticationResult)
Indicates the outcome of the 3DS authentication process.
-
authenticationResult
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder authenticationResult(JsonField<ThreeDSAuthentication.AuthenticationResult> authenticationResult)
Sets Builder.authenticationResult to an arbitrary JSON value.
You should usually call Builder.authenticationResult with a well-typed ThreeDSAuthentication.AuthenticationResult value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardExpiryCheck
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardExpiryCheck(ThreeDSAuthentication.CardExpiryCheck cardExpiryCheck)
Indicates whether the expiration date provided by the cardholder during checkout matches Lithic's record of the card's expiration date.
-
cardExpiryCheck
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardExpiryCheck(JsonField<ThreeDSAuthentication.CardExpiryCheck> cardExpiryCheck)
Sets Builder.cardExpiryCheck to an arbitrary JSON value.
You should usually call Builder.cardExpiryCheck with a well-typed ThreeDSAuthentication.CardExpiryCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardToken(String cardToken)
Globally unique identifier for the card on which the 3DS authentication has occurred. Permitted values: 36-digit version 4 UUID (including hyphens).
-
cardToken
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholder
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardholder(ThreeDSAuthentication.Cardholder cardholder)
Object containing data about the cardholder provided during the transaction.
-
cardholder
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder cardholder(JsonField<ThreeDSAuthentication.Cardholder> cardholder)
Sets Builder.cardholder to an arbitrary JSON value.
You should usually call Builder.cardholder with a well-typed ThreeDSAuthentication.Cardholder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
channel
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder channel(ThreeDSAuthentication.Channel channel)
Channel in which the authentication occurs. Maps to EMV 3DS field
deviceChannel.
-
channel
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder channel(JsonField<ThreeDSAuthentication.Channel> channel)
Sets Builder.channel to an arbitrary JSON value.
You should usually call Builder.channel with a well-typed ThreeDSAuthentication.Channel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder created(OffsetDateTime created)
Date and time when the authentication was created in Lithic's system. Permitted values: Date string in the ISO 8601 format yyyy-MM-dd'T'hh:mm:ssZ.
-
created
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchant
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder merchant(ThreeDSAuthentication.Merchant merchant)
Object containing data about the merchant involved in the e-commerce transaction.
-
merchant
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder merchant(JsonField<ThreeDSAuthentication.Merchant> merchant)
Sets Builder.merchant to an arbitrary JSON value.
You should usually call Builder.merchant with a well-typed ThreeDSAuthentication.Merchant value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageCategory
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder messageCategory(ThreeDSAuthentication.MessageCategory messageCategory)
Either PAYMENT_AUTHENTICATION or NON_PAYMENT_AUTHENTICATION. For NON_PAYMENT_AUTHENTICATION, additional_data and transaction fields are not populated.
-
messageCategory
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder messageCategory(JsonField<ThreeDSAuthentication.MessageCategory> messageCategory)
Sets Builder.messageCategory to an arbitrary JSON value.
You should usually call Builder.messageCategory with a well-typed ThreeDSAuthentication.MessageCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSRequestorChallengeIndicator
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder threeDSRequestorChallengeIndicator(ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator threeDSRequestorChallengeIndicator)
Indicates whether a challenge is requested for this transaction
NO_PREFERENCE- No PreferenceNO_CHALLENGE_REQUESTED- No Challenge RequestedCHALLENGE_PREFERENCE- Challenge requested (3DS Requestor preference)CHALLENGE_MANDATE- Challenge requested (Mandate)NO_CHALLENGE_RISK_ALREADY_ASSESSED- No Challenge requested (Transactional risk analysis is already performed)DATA_SHARE_ONLY- No Challenge requested (Data Share Only)OTHER- Other indicators not captured by above. These are rarely used
-
threeDSRequestorChallengeIndicator
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder threeDSRequestorChallengeIndicator(JsonField<ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator> threeDSRequestorChallengeIndicator)
Sets Builder.threeDSRequestorChallengeIndicator to an arbitrary JSON value.
You should usually call Builder.threeDSRequestorChallengeIndicator with a well-typed ThreeDSAuthentication.ThreeDSRequestorChallengeIndicator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalData
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder additionalData(ThreeDSAuthentication.AdditionalData additionalData)
Object containing additional data about the 3DS request that is beyond the EMV 3DS standard spec (e.g., specific fields that only certain card networks send but are not required across all 3DS requests).
-
additionalData
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder additionalData(Optional<ThreeDSAuthentication.AdditionalData> additionalData)
Alias for calling Builder.additionalData with
additionalData.orElse(null).
-
additionalData
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder additionalData(JsonField<ThreeDSAuthentication.AdditionalData> additionalData)
Sets Builder.additionalData to an arbitrary JSON value.
You should usually call Builder.additionalData with a well-typed ThreeDSAuthentication.AdditionalData value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
app
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder app(ThreeDSAuthentication.App app)
Object containing data about the app used in the e-commerce transaction. Present if the channel is 'APP_BASED'.
-
app
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder app(Optional<ThreeDSAuthentication.App> app)
Alias for calling Builder.app with
app.orElse(null).
-
app
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder app(JsonField<ThreeDSAuthentication.App> app)
Sets Builder.app to an arbitrary JSON value.
You should usually call Builder.app with a well-typed ThreeDSAuthentication.App value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder authenticationRequestType(ThreeDSAuthentication.AuthenticationRequestType authenticationRequestType)
Type of authentication request - i.e., the type of transaction or interaction is causing the merchant to request an authentication. Maps to EMV 3DS field
threeDSRequestorAuthenticationInd.
-
authenticationRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder authenticationRequestType(Optional<ThreeDSAuthentication.AuthenticationRequestType> authenticationRequestType)
Alias for calling Builder.authenticationRequestType with
authenticationRequestType.orElse(null).
-
authenticationRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder authenticationRequestType(JsonField<ThreeDSAuthentication.AuthenticationRequestType> authenticationRequestType)
Sets Builder.authenticationRequestType to an arbitrary JSON value.
You should usually call Builder.authenticationRequestType with a well-typed ThreeDSAuthentication.AuthenticationRequestType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
browser
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder browser(ThreeDSAuthentication.Browser browser)
Object containing data about the browser used in the e-commerce transaction. Present if the channel is 'BROWSER'.
-
browser
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder browser(Optional<ThreeDSAuthentication.Browser> browser)
Alias for calling Builder.browser with
browser.orElse(null).
-
browser
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder browser(JsonField<ThreeDSAuthentication.Browser> browser)
Sets Builder.browser to an arbitrary JSON value.
You should usually call Builder.browser with a well-typed ThreeDSAuthentication.Browser value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challengeMetadata
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeMetadata(ThreeDSAuthentication.ChallengeMetadata challengeMetadata)
Metadata about the challenge method and delivery. Only present when a challenge is triggered.
-
challengeMetadata
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeMetadata(Optional<ThreeDSAuthentication.ChallengeMetadata> challengeMetadata)
Alias for calling Builder.challengeMetadata with
challengeMetadata.orElse(null).
-
challengeMetadata
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeMetadata(JsonField<ThreeDSAuthentication.ChallengeMetadata> challengeMetadata)
Sets Builder.challengeMetadata to an arbitrary JSON value.
You should usually call Builder.challengeMetadata with a well-typed ThreeDSAuthentication.ChallengeMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challengeOrchestratedBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeOrchestratedBy(ThreeDSAuthentication.ChallengeOrchestratedBy challengeOrchestratedBy)
Entity that orchestrates the challenge. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
-
challengeOrchestratedBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeOrchestratedBy(Optional<ThreeDSAuthentication.ChallengeOrchestratedBy> challengeOrchestratedBy)
Alias for calling Builder.challengeOrchestratedBy with
challengeOrchestratedBy.orElse(null).
-
challengeOrchestratedBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder challengeOrchestratedBy(JsonField<ThreeDSAuthentication.ChallengeOrchestratedBy> challengeOrchestratedBy)
Sets Builder.challengeOrchestratedBy to an arbitrary JSON value.
You should usually call Builder.challengeOrchestratedBy with a well-typed ThreeDSAuthentication.ChallengeOrchestratedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decisionMadeBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder decisionMadeBy(ThreeDSAuthentication.DecisionMadeBy decisionMadeBy)
Entity that made the authentication decision. This won't be set for authentications for which a decision has not yet been made (e.g. in-flight customer decisioning request).
-
decisionMadeBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder decisionMadeBy(Optional<ThreeDSAuthentication.DecisionMadeBy> decisionMadeBy)
Alias for calling Builder.decisionMadeBy with
decisionMadeBy.orElse(null).
-
decisionMadeBy
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder decisionMadeBy(JsonField<ThreeDSAuthentication.DecisionMadeBy> decisionMadeBy)
Sets Builder.decisionMadeBy to an arbitrary JSON value.
You should usually call Builder.decisionMadeBy with a well-typed ThreeDSAuthentication.DecisionMadeBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeRiRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder threeRiRequestType(ThreeDSAuthentication.ThreeRiRequestType threeRiRequestType)
Type of 3DS Requestor Initiated (3RI) request — i.e., a 3DS authentication that takes place at the initiation of the merchant rather than the cardholder. The most common example of this is where a merchant is authenticating before billing for a recurring transaction such as a pay TV subscription or a utility bill. Maps to EMV 3DS field
threeRIInd.
-
threeRiRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder threeRiRequestType(Optional<ThreeDSAuthentication.ThreeRiRequestType> threeRiRequestType)
Alias for calling Builder.threeRiRequestType with
threeRiRequestType.orElse(null).
-
threeRiRequestType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder threeRiRequestType(JsonField<ThreeDSAuthentication.ThreeRiRequestType> threeRiRequestType)
Sets Builder.threeRiRequestType to an arbitrary JSON value.
You should usually call Builder.threeRiRequestType with a well-typed ThreeDSAuthentication.ThreeRiRequestType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transaction
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder transaction(ThreeDSAuthentication.Transaction transaction)
Object containing data about the e-commerce transaction for which the merchant is requesting authentication.
-
transaction
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder transaction(Optional<ThreeDSAuthentication.Transaction> transaction)
Alias for calling Builder.transaction with
transaction.orElse(null).
-
transaction
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder transaction(JsonField<ThreeDSAuthentication.Transaction> transaction)
Sets Builder.transaction to an arbitrary JSON value.
You should usually call Builder.transaction with a well-typed ThreeDSAuthentication.Transaction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder eventType(ThreeDSAuthenticationUpdatedWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder eventType(JsonField<ThreeDSAuthenticationUpdatedWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ThreeDSAuthenticationUpdatedWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ThreeDSAuthenticationUpdatedWebhookEvent build()
Returns an immutable instance of ThreeDSAuthenticationUpdatedWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.token() .accountType() .authenticationResult() .cardExpiryCheck() .cardToken() .cardholder() .channel() .created() .merchant() .messageCategory() .threeDSRequestorChallengeIndicator() .eventType()
-
-
-
-