Class TokenInfo
-
- All Implemented Interfaces:
public final class TokenInfo
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenInfo.BuilderA builder for TokenInfo.
public final classTokenInfo.WalletTypeThe wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.
-
Method Summary
Modifier and Type Method Description final TokenInfo.WalletTypewalletType()The wallet_type field will indicate the source of the token. final JsonField<TokenInfo.WalletType>_walletType()Returns the raw JSON value of walletType. final Map<String, JsonValue>_additionalProperties()final TokenInfo.BuildertoBuilder()final TokenInfovalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenInfo.Builderbuilder()Returns a mutable builder for constructing an instance of TokenInfo. -
-
Method Detail
-
walletType
final TokenInfo.WalletType walletType()
The wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.
-
_walletType
final JsonField<TokenInfo.WalletType> _walletType()
Returns the raw JSON value of walletType.
Unlike walletType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenInfo.Builder toBuilder()
-
validate
final TokenInfo validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenInfo.Builder builder()
Returns a mutable builder for constructing an instance of TokenInfo.
The following fields are required:
.walletType()
-
-
-
-