Package com.lithic.api.models
Class TokenInfo.Builder
-
- All Implemented Interfaces:
public final class TokenInfo.BuilderA builder for TokenInfo.
-
-
Method Summary
Modifier and Type Method Description final TokenInfo.BuilderwalletType(TokenInfo.WalletType walletType)The wallet_type field will indicate the source of the token. final TokenInfo.BuilderwalletType(JsonField<TokenInfo.WalletType> walletType)Sets Builder.walletType to an arbitrary JSON value. final TokenInfo.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final TokenInfo.BuilderputAdditionalProperty(String key, JsonValue value)final TokenInfo.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final TokenInfo.BuilderremoveAdditionalProperty(String key)final TokenInfo.BuilderremoveAllAdditionalProperties(Set<String> keys)final TokenInfobuild()Returns an immutable instance of TokenInfo. -
-
Method Detail
-
walletType
final TokenInfo.Builder walletType(TokenInfo.WalletType walletType)
The wallet_type field will indicate the source of the token. Possible token sources include digital wallets (Apple, Google, or Samsung Pay), merchant tokenization, and “other” sources like in-flight commerce. Masterpass is not currently supported and is included for future use.
-
walletType
final TokenInfo.Builder walletType(JsonField<TokenInfo.WalletType> walletType)
Sets Builder.walletType to an arbitrary JSON value.
You should usually call Builder.walletType with a well-typed WalletType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenInfo.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenInfo.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenInfo.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenInfo.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenInfo.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-