Class TokenMetadata
-
- All Implemented Interfaces:
public final class TokenMetadataContains the metadata for the digital wallet being tokenized.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenMetadata.BuilderA builder for TokenMetadata.
public final classTokenMetadata.PaymentAccountInfoContains the information of the account responsible for the payment.
public final classTokenMetadata.TokenRequestorNameHuman-readable name of the wallet that the token_requestor_id maps to.
-
Method Summary
Modifier and Type Method Description final TokenMetadata.PaymentAccountInfopaymentAccountInfo()Contains the information of the account responsible for the payment. final Stringstatus()The current status of the digital wallet token. final Optional<String>paymentAppInstanceId()The identifier of the Payment App instance within a device that will be provisioned with a token final Optional<String>tokenRequestorId()The party that requested the digitization final Optional<TokenMetadata.TokenRequestorName>tokenRequestorName()Human-readable name of the wallet that the token_requestor_id maps to. final JsonField<TokenMetadata.PaymentAccountInfo>_paymentAccountInfo()Returns the raw JSON value of paymentAccountInfo. final JsonField<String>_status()Returns the raw JSON value of status. final JsonField<String>_paymentAppInstanceId()Returns the raw JSON value of paymentAppInstanceId. final JsonField<String>_tokenRequestorId()Returns the raw JSON value of tokenRequestorId. final JsonField<TokenMetadata.TokenRequestorName>_tokenRequestorName()Returns the raw JSON value of tokenRequestorName. final Map<String, JsonValue>_additionalProperties()final TokenMetadata.BuildertoBuilder()final TokenMetadatavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of TokenMetadata. -
-
Method Detail
-
paymentAccountInfo
final TokenMetadata.PaymentAccountInfo paymentAccountInfo()
Contains the information of the account responsible for the payment.
-
paymentAppInstanceId
final Optional<String> paymentAppInstanceId()
The identifier of the Payment App instance within a device that will be provisioned with a token
-
tokenRequestorId
final Optional<String> tokenRequestorId()
The party that requested the digitization
-
tokenRequestorName
final Optional<TokenMetadata.TokenRequestorName> tokenRequestorName()
Human-readable name of the wallet that the token_requestor_id maps to.
-
_paymentAccountInfo
final JsonField<TokenMetadata.PaymentAccountInfo> _paymentAccountInfo()
Returns the raw JSON value of paymentAccountInfo.
Unlike paymentAccountInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<String> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentAppInstanceId
final JsonField<String> _paymentAppInstanceId()
Returns the raw JSON value of paymentAppInstanceId.
Unlike paymentAppInstanceId, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenRequestorId
final JsonField<String> _tokenRequestorId()
Returns the raw JSON value of tokenRequestorId.
Unlike tokenRequestorId, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenRequestorName
final JsonField<TokenMetadata.TokenRequestorName> _tokenRequestorName()
Returns the raw JSON value of tokenRequestorName.
Unlike tokenRequestorName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenMetadata.Builder toBuilder()
-
validate
final TokenMetadata validate()
-
builder
final static TokenMetadata.Builder builder()
Returns a mutable builder for constructing an instance of TokenMetadata.
The following fields are required:
.paymentAccountInfo() .status()
-
-
-
-