Class TokenMetadata.Builder
-
- All Implemented Interfaces:
public final class TokenMetadata.BuilderA builder for TokenMetadata.
-
-
Method Summary
-
-
Method Detail
-
paymentAccountInfo
final TokenMetadata.Builder paymentAccountInfo(TokenMetadata.PaymentAccountInfo paymentAccountInfo)
Contains the information of the account responsible for the payment.
-
paymentAccountInfo
final TokenMetadata.Builder paymentAccountInfo(JsonField<TokenMetadata.PaymentAccountInfo> paymentAccountInfo)
Sets Builder.paymentAccountInfo to an arbitrary JSON value.
You should usually call Builder.paymentAccountInfo with a well-typed PaymentAccountInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final TokenMetadata.Builder status(String status)
The current status of the digital wallet token. Pending or declined.
-
status
final TokenMetadata.Builder status(JsonField<String> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentAppInstanceId
final TokenMetadata.Builder paymentAppInstanceId(String paymentAppInstanceId)
The identifier of the Payment App instance within a device that will be provisioned with a token
-
paymentAppInstanceId
final TokenMetadata.Builder paymentAppInstanceId(Optional<String> paymentAppInstanceId)
Alias for calling Builder.paymentAppInstanceId with
paymentAppInstanceId.orElse(null).
-
paymentAppInstanceId
final TokenMetadata.Builder paymentAppInstanceId(JsonField<String> paymentAppInstanceId)
Sets Builder.paymentAppInstanceId to an arbitrary JSON value.
You should usually call Builder.paymentAppInstanceId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenRequestorId
final TokenMetadata.Builder tokenRequestorId(String tokenRequestorId)
The party that requested the digitization
-
tokenRequestorId
final TokenMetadata.Builder tokenRequestorId(JsonField<String> tokenRequestorId)
Sets Builder.tokenRequestorId to an arbitrary JSON value.
You should usually call Builder.tokenRequestorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenRequestorName
final TokenMetadata.Builder tokenRequestorName(TokenMetadata.TokenRequestorName tokenRequestorName)
Human-readable name of the wallet that the token_requestor_id maps to.
-
tokenRequestorName
final TokenMetadata.Builder tokenRequestorName(JsonField<TokenMetadata.TokenRequestorName> tokenRequestorName)
Sets Builder.tokenRequestorName to an arbitrary JSON value.
You should usually call Builder.tokenRequestorName with a well-typed TokenRequestorName value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenMetadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenMetadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenMetadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenMetadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenMetadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenMetadata build()
Returns an immutable instance of TokenMetadata.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.paymentAccountInfo() .status()
-
-
-
-