Class TokenMetadata.PaymentAccountInfo.Builder
-
- All Implemented Interfaces:
public final class TokenMetadata.PaymentAccountInfo.BuilderA builder for PaymentAccountInfo.
-
-
Method Summary
-
-
Method Detail
-
accountHolderData
final TokenMetadata.PaymentAccountInfo.Builder accountHolderData(TokenMetadata.PaymentAccountInfo.AccountHolderData accountHolderData)
Additional information that can be used to identify the account holder, such as name, address, etc
-
accountHolderData
final TokenMetadata.PaymentAccountInfo.Builder accountHolderData(JsonField<TokenMetadata.PaymentAccountInfo.AccountHolderData> accountHolderData)
Sets Builder.accountHolderData to an arbitrary JSON value.
You should usually call Builder.accountHolderData with a well-typed AccountHolderData value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
panUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder panUniqueReference(String panUniqueReference)
Reference to the PAN that is unique per Wallet Provider
-
panUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder panUniqueReference(Optional<String> panUniqueReference)
Alias for calling Builder.panUniqueReference with
panUniqueReference.orElse(null).
-
panUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder panUniqueReference(JsonField<String> panUniqueReference)
Sets Builder.panUniqueReference to an arbitrary JSON value.
You should usually call Builder.panUniqueReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
paymentAccountReference
final TokenMetadata.PaymentAccountInfo.Builder paymentAccountReference(String paymentAccountReference)
The unique account reference assigned to the PAN
-
paymentAccountReference
final TokenMetadata.PaymentAccountInfo.Builder paymentAccountReference(Optional<String> paymentAccountReference)
Alias for calling Builder.paymentAccountReference with
paymentAccountReference.orElse(null).
-
paymentAccountReference
final TokenMetadata.PaymentAccountInfo.Builder paymentAccountReference(JsonField<String> paymentAccountReference)
Sets Builder.paymentAccountReference to an arbitrary JSON value.
You should usually call Builder.paymentAccountReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder tokenUniqueReference(String tokenUniqueReference)
A unique reference assigned following the allocation of a token used to identify the token for the duration of its lifetime.
-
tokenUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder tokenUniqueReference(Optional<String> tokenUniqueReference)
Alias for calling Builder.tokenUniqueReference with
tokenUniqueReference.orElse(null).
-
tokenUniqueReference
final TokenMetadata.PaymentAccountInfo.Builder tokenUniqueReference(JsonField<String> tokenUniqueReference)
Sets Builder.tokenUniqueReference to an arbitrary JSON value.
You should usually call Builder.tokenUniqueReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenMetadata.PaymentAccountInfo.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenMetadata.PaymentAccountInfo.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenMetadata.PaymentAccountInfo.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenMetadata.PaymentAccountInfo.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenMetadata.PaymentAccountInfo.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenMetadata.PaymentAccountInfo build()
Returns an immutable instance of PaymentAccountInfo.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountHolderData()
-
-
-
-