Class Tokenization.TokenizationEvent.Builder
-
- All Implemented Interfaces:
public final class Tokenization.TokenizationEvent.BuilderA builder for TokenizationEvent.
-
-
Method Summary
-
-
Method Detail
-
token
final Tokenization.TokenizationEvent.Builder token(String token)
Globally unique identifier for a Tokenization Event
-
token
final Tokenization.TokenizationEvent.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Tokenization.TokenizationEvent.Builder createdAt(OffsetDateTime createdAt)
Date and time when the tokenization event first occurred. UTC time zone.
-
createdAt
final Tokenization.TokenizationEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final Tokenization.TokenizationEvent.Builder result(Tokenization.TokenizationEvent.TokenizationEventOutcome result)
Enum representing the result of the tokenization event
-
result
final Tokenization.TokenizationEvent.Builder result(JsonField<Tokenization.TokenizationEvent.TokenizationEventOutcome> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed TokenizationEventOutcome value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ruleResults
final Tokenization.TokenizationEvent.Builder ruleResults(List<TokenizationRuleResult> ruleResults)
Results from rules that were evaluated for this tokenization
-
ruleResults
final Tokenization.TokenizationEvent.Builder ruleResults(JsonField<List<TokenizationRuleResult>> ruleResults)
Sets Builder.ruleResults to an arbitrary JSON value.
You should usually call Builder.ruleResults with a well-typed
List<TokenizationRuleResult>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRuleResult
final Tokenization.TokenizationEvent.Builder addRuleResult(TokenizationRuleResult ruleResult)
Adds a single TokenizationRuleResult to ruleResults.
-
tokenizationDeclineReasons
final Tokenization.TokenizationEvent.Builder tokenizationDeclineReasons(List<TokenizationDeclineReason> tokenizationDeclineReasons)
List of reasons why the tokenization was declined
-
tokenizationDeclineReasons
final Tokenization.TokenizationEvent.Builder tokenizationDeclineReasons(JsonField<List<TokenizationDeclineReason>> tokenizationDeclineReasons)
Sets Builder.tokenizationDeclineReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationDeclineReasons with a well-typed
List<TokenizationDeclineReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationDeclineReason
final Tokenization.TokenizationEvent.Builder addTokenizationDeclineReason(TokenizationDeclineReason tokenizationDeclineReason)
Adds a single TokenizationDeclineReason to tokenizationDeclineReasons.
-
tokenizationTfaReasons
final Tokenization.TokenizationEvent.Builder tokenizationTfaReasons(List<TokenizationTfaReason> tokenizationTfaReasons)
List of reasons why two-factor authentication was required
-
tokenizationTfaReasons
final Tokenization.TokenizationEvent.Builder tokenizationTfaReasons(JsonField<List<TokenizationTfaReason>> tokenizationTfaReasons)
Sets Builder.tokenizationTfaReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationTfaReasons with a well-typed
List<TokenizationTfaReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationTfaReason
final Tokenization.TokenizationEvent.Builder addTokenizationTfaReason(TokenizationTfaReason tokenizationTfaReason)
Adds a single TokenizationTfaReason to tokenizationTfaReasons.
-
type
final Tokenization.TokenizationEvent.Builder type(Tokenization.TokenizationEvent.Type type)
Enum representing the type of tokenization event that occurred
-
type
final Tokenization.TokenizationEvent.Builder type(JsonField<Tokenization.TokenizationEvent.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Tokenization.TokenizationEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Tokenization.TokenizationEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Tokenization.TokenizationEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Tokenization.TokenizationEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Tokenization.TokenizationEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Tokenization.TokenizationEvent build()
Returns an immutable instance of TokenizationEvent.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-