Class TokenizationApprovalRequestWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class TokenizationApprovalRequestWebhookEvent.BuilderA builder for TokenizationApprovalRequestWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final TokenizationApprovalRequestWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final TokenizationApprovalRequestWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final TokenizationApprovalRequestWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final TokenizationApprovalRequestWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final TokenizationApprovalRequestWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final TokenizationApprovalRequestWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerTokenizationDecision
final TokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(TokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision customerTokenizationDecision)
Contains the metadata for the customer tokenization decision.
-
customerTokenizationDecision
final TokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(Optional<TokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision)
Alias for calling Builder.customerTokenizationDecision with
customerTokenizationDecision.orElse(null).
-
customerTokenizationDecision
final TokenizationApprovalRequestWebhookEvent.Builder customerTokenizationDecision(JsonField<TokenizationApprovalRequestWebhookEvent.CustomerTokenizationDecision> customerTokenizationDecision)
Sets Builder.customerTokenizationDecision to an arbitrary JSON value.
You should usually call Builder.customerTokenizationDecision with a well-typed CustomerTokenizationDecision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final TokenizationApprovalRequestWebhookEvent.Builder eventType(TokenizationApprovalRequestWebhookEvent.EventType eventType)
The name of this event
-
eventType
final TokenizationApprovalRequestWebhookEvent.Builder eventType(JsonField<TokenizationApprovalRequestWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
issuerDecision
final TokenizationApprovalRequestWebhookEvent.Builder issuerDecision(TokenizationApprovalRequestWebhookEvent.IssuerDecision issuerDecision)
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
issuerDecision
final TokenizationApprovalRequestWebhookEvent.Builder issuerDecision(JsonField<TokenizationApprovalRequestWebhookEvent.IssuerDecision> issuerDecision)
Sets Builder.issuerDecision to an arbitrary JSON value.
You should usually call Builder.issuerDecision with a well-typed IssuerDecision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenMetadata
final TokenizationApprovalRequestWebhookEvent.Builder tokenMetadata(TokenMetadata tokenMetadata)
Contains the metadata for the digital wallet being tokenized.
-
tokenMetadata
final TokenizationApprovalRequestWebhookEvent.Builder tokenMetadata(JsonField<TokenMetadata> tokenMetadata)
Sets Builder.tokenMetadata to an arbitrary JSON value.
You should usually call Builder.tokenMetadata with a well-typed TokenMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationChannel
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationChannel(TokenizationApprovalRequestWebhookEvent.TokenizationChannel tokenizationChannel)
The channel through which the tokenization was made.
-
tokenizationChannel
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationChannel(JsonField<TokenizationApprovalRequestWebhookEvent.TokenizationChannel> tokenizationChannel)
Sets Builder.tokenizationChannel to an arbitrary JSON value.
You should usually call Builder.tokenizationChannel with a well-typed TokenizationChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the digital wallet token attempt
-
tokenizationToken
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
walletDecisioningInfo
final TokenizationApprovalRequestWebhookEvent.Builder walletDecisioningInfo(WalletDecisioningInfo walletDecisioningInfo)
-
walletDecisioningInfo
final TokenizationApprovalRequestWebhookEvent.Builder walletDecisioningInfo(JsonField<WalletDecisioningInfo> walletDecisioningInfo)
Sets Builder.walletDecisioningInfo to an arbitrary JSON value.
You should usually call Builder.walletDecisioningInfo with a well-typed WalletDecisioningInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
device
final TokenizationApprovalRequestWebhookEvent.Builder device(Device device)
-
device
final TokenizationApprovalRequestWebhookEvent.Builder device(JsonField<Device> device)
Sets Builder.device to an arbitrary JSON value.
You should usually call Builder.device with a well-typed Device value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ruleResults
final TokenizationApprovalRequestWebhookEvent.Builder ruleResults(List<TokenizationRuleResult> ruleResults)
Results from rules that were evaluated for this tokenization
-
ruleResults
final TokenizationApprovalRequestWebhookEvent.Builder ruleResults(JsonField<List<TokenizationRuleResult>> ruleResults)
Sets Builder.ruleResults to an arbitrary JSON value.
You should usually call Builder.ruleResults with a well-typed
List<TokenizationRuleResult>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addRuleResult
final TokenizationApprovalRequestWebhookEvent.Builder addRuleResult(TokenizationRuleResult ruleResult)
Adds a single TokenizationRuleResult to ruleResults.
-
tokenizationDeclineReasons
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationDeclineReasons(List<TokenizationDeclineReason> tokenizationDeclineReasons)
List of reasons why the tokenization was declined
-
tokenizationDeclineReasons
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationDeclineReasons(JsonField<List<TokenizationDeclineReason>> tokenizationDeclineReasons)
Sets Builder.tokenizationDeclineReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationDeclineReasons with a well-typed
List<TokenizationDeclineReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationDeclineReason
final TokenizationApprovalRequestWebhookEvent.Builder addTokenizationDeclineReason(TokenizationDeclineReason tokenizationDeclineReason)
Adds a single TokenizationDeclineReason to tokenizationDeclineReasons.
-
tokenizationSource
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationSource(TokenizationApprovalRequestWebhookEvent.TokenizationSource tokenizationSource)
The source of the tokenization.
-
tokenizationSource
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationSource(JsonField<TokenizationApprovalRequestWebhookEvent.TokenizationSource> tokenizationSource)
Sets Builder.tokenizationSource to an arbitrary JSON value.
You should usually call Builder.tokenizationSource with a well-typed TokenizationSource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationTfaReasons
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationTfaReasons(List<TokenizationTfaReason> tokenizationTfaReasons)
List of reasons why two-factor authentication was required
-
tokenizationTfaReasons
final TokenizationApprovalRequestWebhookEvent.Builder tokenizationTfaReasons(JsonField<List<TokenizationTfaReason>> tokenizationTfaReasons)
Sets Builder.tokenizationTfaReasons to an arbitrary JSON value.
You should usually call Builder.tokenizationTfaReasons with a well-typed
List<TokenizationTfaReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTokenizationTfaReason
final TokenizationApprovalRequestWebhookEvent.Builder addTokenizationTfaReason(TokenizationTfaReason tokenizationTfaReason)
Adds a single TokenizationTfaReason to tokenizationTfaReasons.
-
additionalProperties
final TokenizationApprovalRequestWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationApprovalRequestWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationApprovalRequestWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationApprovalRequestWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationApprovalRequestWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationApprovalRequestWebhookEvent build()
Returns an immutable instance of TokenizationApprovalRequestWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .cardToken() .created() .customerTokenizationDecision() .eventType() .issuerDecision() .tokenMetadata() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-