Class TokenizationDecisioningRequestWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class TokenizationDecisioningRequestWebhookEvent.BuilderA builder for TokenizationDecisioningRequestWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final TokenizationDecisioningRequestWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final TokenizationDecisioningRequestWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final TokenizationDecisioningRequestWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final TokenizationDecisioningRequestWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final TokenizationDecisioningRequestWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final TokenizationDecisioningRequestWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenMetadata
final TokenizationDecisioningRequestWebhookEvent.Builder digitalWalletTokenMetadata(TokenMetadata digitalWalletTokenMetadata)
Contains the metadata for the digital wallet being tokenized.
-
digitalWalletTokenMetadata
final TokenizationDecisioningRequestWebhookEvent.Builder digitalWalletTokenMetadata(JsonField<TokenMetadata> digitalWalletTokenMetadata)
Sets Builder.digitalWalletTokenMetadata to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenMetadata with a well-typed TokenMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final TokenizationDecisioningRequestWebhookEvent.Builder eventType(TokenizationDecisioningRequestWebhookEvent.EventType eventType)
The name of this event
-
eventType
final TokenizationDecisioningRequestWebhookEvent.Builder eventType(JsonField<TokenizationDecisioningRequestWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
issuerDecision
final TokenizationDecisioningRequestWebhookEvent.Builder issuerDecision(TokenizationDecisioningRequestWebhookEvent.IssuerDecision issuerDecision)
Whether Lithic decisioned on the token, and if so, what the decision was. APPROVED/VERIFICATION_REQUIRED/DENIED.
-
issuerDecision
final TokenizationDecisioningRequestWebhookEvent.Builder issuerDecision(JsonField<TokenizationDecisioningRequestWebhookEvent.IssuerDecision> issuerDecision)
Sets Builder.issuerDecision to an arbitrary JSON value.
You should usually call Builder.issuerDecision with a well-typed IssuerDecision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationChannel
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationChannel(TokenizationDecisioningRequestWebhookEvent.TokenizationChannel tokenizationChannel)
The channel through which the tokenization was made.
-
tokenizationChannel
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationChannel(JsonField<TokenizationDecisioningRequestWebhookEvent.TokenizationChannel> tokenizationChannel)
Sets Builder.tokenizationChannel to an arbitrary JSON value.
You should usually call Builder.tokenizationChannel with a well-typed TokenizationChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the digital wallet token attempt
-
tokenizationToken
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
walletDecisioningInfo
final TokenizationDecisioningRequestWebhookEvent.Builder walletDecisioningInfo(WalletDecisioningInfo walletDecisioningInfo)
-
walletDecisioningInfo
final TokenizationDecisioningRequestWebhookEvent.Builder walletDecisioningInfo(JsonField<WalletDecisioningInfo> walletDecisioningInfo)
Sets Builder.walletDecisioningInfo to an arbitrary JSON value.
You should usually call Builder.walletDecisioningInfo with a well-typed WalletDecisioningInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
device
final TokenizationDecisioningRequestWebhookEvent.Builder device(Device device)
-
device
final TokenizationDecisioningRequestWebhookEvent.Builder device(JsonField<Device> device)
Sets Builder.device to an arbitrary JSON value.
You should usually call Builder.device with a well-typed Device value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationSource
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationSource(TokenizationDecisioningRequestWebhookEvent.TokenizationSource tokenizationSource)
The source of the tokenization.
-
tokenizationSource
final TokenizationDecisioningRequestWebhookEvent.Builder tokenizationSource(JsonField<TokenizationDecisioningRequestWebhookEvent.TokenizationSource> tokenizationSource)
Sets Builder.tokenizationSource to an arbitrary JSON value.
You should usually call Builder.tokenizationSource with a well-typed TokenizationSource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenizationDecisioningRequestWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationDecisioningRequestWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationDecisioningRequestWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationDecisioningRequestWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationDecisioningRequestWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationDecisioningRequestWebhookEvent build()
Returns an immutable instance of TokenizationDecisioningRequestWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .cardToken() .created() .digitalWalletTokenMetadata() .eventType() .issuerDecision() .tokenizationChannel() .tokenizationToken() .walletDecisioningInfo()
-
-
-
-