Class TokenizationDeclineReason
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class TokenizationDeclineReason implements EnumReason code for why a tokenization was declined
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumTokenizationDeclineReason.KnownAn enum containing TokenizationDeclineReason's known values.
public enumTokenizationDeclineReason.ValueAn enum containing TokenizationDeclineReason's known values, as well as an _UNKNOWN member.
An instance of TokenizationDeclineReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static TokenizationDeclineReasonACCOUNT_SCORE_1public final static TokenizationDeclineReasonDEVICE_SCORE_1public final static TokenizationDeclineReasonALL_WALLET_DECLINE_REASONS_PRESENTpublic final static TokenizationDeclineReasonWALLET_RECOMMENDED_DECISION_REDpublic final static TokenizationDeclineReasonCVC_MISMATCHpublic final static TokenizationDeclineReasonCARD_EXPIRY_MONTH_MISMATCHpublic final static TokenizationDeclineReasonCARD_EXPIRY_YEAR_MISMATCHpublic final static TokenizationDeclineReasonCARD_INVALID_STATEpublic final static TokenizationDeclineReasonCUSTOMER_RED_PATHpublic final static TokenizationDeclineReasonINVALID_CUSTOMER_RESPONSEpublic final static TokenizationDeclineReasonNETWORK_FAILUREpublic final static TokenizationDeclineReasonGENERIC_DECLINEpublic final static TokenizationDeclineReasonDIGITAL_CARD_ART_REQUIRED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final TokenizationDeclineReason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final TokenizationDeclineReason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final TokenizationDeclineReasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationDeclineReasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final TokenizationDeclineReason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final TokenizationDeclineReason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final TokenizationDeclineReason validate()
-
of
final static TokenizationDeclineReason of(String value)
-
-
-
-