Package com.lithic.api.models
Class TokenizationListPageResponse
-
- All Implemented Interfaces:
public final class TokenizationListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationListPageResponse.BuilderA builder for TokenizationListPageResponse.
-
Method Summary
Modifier and Type Method Description final Optional<List<Tokenization>>data()final Optional<Boolean>hasMore()final JsonField<List<Tokenization>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TokenizationListPageResponse.BuildertoBuilder()final TokenizationListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationListPageResponse. -
-
Method Detail
-
data
final Optional<List<Tokenization>> data()
-
_data
final JsonField<List<Tokenization>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationListPageResponse.Builder toBuilder()
-
validate
final TokenizationListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationListPageResponse.
-
-
-
-