Package com.lithic.api.models
Class TokenizationResendActivationCodeParams.Body
-
- All Implemented Interfaces:
public final class TokenizationResendActivationCodeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationResendActivationCodeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<TokenizationResendActivationCodeParams.ActivationMethodType>activationMethodType()The communication method that the user has selected to use to receive the authentication code. final JsonField<TokenizationResendActivationCodeParams.ActivationMethodType>_activationMethodType()Returns the raw JSON value of activationMethodType. final Map<String, JsonValue>_additionalProperties()final TokenizationResendActivationCodeParams.Body.BuildertoBuilder()final TokenizationResendActivationCodeParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationResendActivationCodeParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
activationMethodType
final Optional<TokenizationResendActivationCodeParams.ActivationMethodType> activationMethodType()
The communication method that the user has selected to use to receive the authentication code. Supported Values: Sms = "TEXT_TO_CARDHOLDER_NUMBER". Email = "EMAIL_TO_CARDHOLDER_ADDRESS"
-
_activationMethodType
final JsonField<TokenizationResendActivationCodeParams.ActivationMethodType> _activationMethodType()
Returns the raw JSON value of activationMethodType.
Unlike activationMethodType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationResendActivationCodeParams.Body.Builder toBuilder()
-
validate
final TokenizationResendActivationCodeParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationResendActivationCodeParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-