Class TokenizationResultWebhookEvent.TokenizationResultDetails
-
- All Implemented Interfaces:
public final class TokenizationResultWebhookEvent.TokenizationResultDetailsThe result of the tokenization request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationResultWebhookEvent.TokenizationResultDetails.BuilderA builder for TokenizationResultDetails.
public final classTokenizationResultWebhookEvent.TokenizationResultDetails.TokenizationDeclineReason
-
Method Summary
-
-
Method Detail
-
issuerDecision
final String issuerDecision()
Lithic's tokenization decision.
-
tokenizationDeclineReasons
final List<TokenizationResultWebhookEvent.TokenizationResultDetails.TokenizationDeclineReason> tokenizationDeclineReasons()
List of reasons why the tokenization was declined
-
customerDecision
final Optional<String> customerDecision()
The customer's tokenization decision if applicable.
-
ruleResults
final Optional<List<TokenizationRuleResult>> ruleResults()
Results from rules that were evaluated for this tokenization
-
tokenActivatedDateTime
final Optional<OffsetDateTime> tokenActivatedDateTime()
An RFC 3339 timestamp indicating when the tokenization succeeded.
-
tokenizationTfaReasons
final Optional<List<TokenizationTfaReason>> tokenizationTfaReasons()
List of reasons why two-factor authentication was required
-
walletDecision
final Optional<String> walletDecision()
The wallet's recommended decision.
-
_issuerDecision
final JsonField<String> _issuerDecision()
Returns the raw JSON value of issuerDecision.
Unlike issuerDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationDeclineReasons
final JsonField<List<TokenizationResultWebhookEvent.TokenizationResultDetails.TokenizationDeclineReason>> _tokenizationDeclineReasons()
Returns the raw JSON value of tokenizationDeclineReasons.
Unlike tokenizationDeclineReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_customerDecision
final JsonField<String> _customerDecision()
Returns the raw JSON value of customerDecision.
Unlike customerDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleResults
final JsonField<List<TokenizationRuleResult>> _ruleResults()
Returns the raw JSON value of ruleResults.
Unlike ruleResults, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenActivatedDateTime
final JsonField<OffsetDateTime> _tokenActivatedDateTime()
Returns the raw JSON value of tokenActivatedDateTime.
Unlike tokenActivatedDateTime, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationTfaReasons
final JsonField<List<TokenizationTfaReason>> _tokenizationTfaReasons()
Returns the raw JSON value of tokenizationTfaReasons.
Unlike tokenizationTfaReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_walletDecision
final JsonField<String> _walletDecision()
Returns the raw JSON value of walletDecision.
Unlike walletDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationResultWebhookEvent.TokenizationResultDetails.Builder toBuilder()
-
validate
final TokenizationResultWebhookEvent.TokenizationResultDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationResultWebhookEvent.TokenizationResultDetails.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationResultDetails.
The following fields are required:
.issuerDecision() .tokenizationDeclineReasons()
-
-
-
-