Class TokenizationTfaReason
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class TokenizationTfaReason implements EnumReason code for why a tokenization required two-factor authentication
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumTokenizationTfaReason.KnownAn enum containing TokenizationTfaReason's known values.
public enumTokenizationTfaReason.ValueAn enum containing TokenizationTfaReason's known values, as well as an _UNKNOWN member.
An instance of TokenizationTfaReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static TokenizationTfaReasonWALLET_RECOMMENDED_TFApublic final static TokenizationTfaReasonSUSPICIOUS_ACTIVITYpublic final static TokenizationTfaReasonDEVICE_RECENTLY_LOSTpublic final static TokenizationTfaReasonTOO_MANY_RECENT_ATTEMPTSpublic final static TokenizationTfaReasonTOO_MANY_RECENT_TOKENSpublic final static TokenizationTfaReasonTOO_MANY_DIFFERENT_CARDHOLDERSpublic final static TokenizationTfaReasonOUTSIDE_HOME_TERRITORYpublic final static TokenizationTfaReasonHAS_SUSPENDED_TOKENSpublic final static TokenizationTfaReasonHIGH_RISKpublic final static TokenizationTfaReasonACCOUNT_SCORE_LOWpublic final static TokenizationTfaReasonDEVICE_SCORE_LOWpublic final static TokenizationTfaReasonCARD_STATE_TFApublic final static TokenizationTfaReasonHARDCODED_TFApublic final static TokenizationTfaReasonCUSTOMER_RULE_TFApublic final static TokenizationTfaReasonDEVICE_HOST_CARD_EMULATION
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final TokenizationTfaReason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final TokenizationTfaReason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final TokenizationTfaReasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TokenizationTfaReasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final TokenizationTfaReason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final TokenizationTfaReason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final TokenizationTfaReason validate()
-
of
final static TokenizationTfaReason of(String value)
-
-
-
-