Class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod
-
- All Implemented Interfaces:
public final class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.BuilderA builder for ActivationMethod.
public final classTokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.TypeThe communication method that the user has selected to use to receive the authentication code. Supported Values: Sms = "TEXT_TO_CARDHOLDER_NUMBER". Email = "EMAIL_TO_CARDHOLDER_ADDRESS"
-
Method Summary
-
-
Method Detail
-
type
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.Type type()
The communication method that the user has selected to use to receive the authentication code. Supported Values: Sms = "TEXT_TO_CARDHOLDER_NUMBER". Email = "EMAIL_TO_CARDHOLDER_ADDRESS"
-
value
final String value()
The location to which the authentication code was sent. The format depends on the ActivationMethod.Type field. If Type is Email, the Value will be the email address. If the Type is Sms, the Value will be the phone number.
-
_type
final JsonField<TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.Builder toBuilder()
-
validate
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod.Builder builder()
Returns a mutable builder for constructing an instance of ActivationMethod.
The following fields are required:
.type() .value()
-
-
-
-