Class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.BuilderA builder for TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
activationMethod
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder activationMethod(TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod activationMethod)
-
activationMethod
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder activationMethod(JsonField<TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.ActivationMethod> activationMethod)
Sets Builder.activationMethod to an arbitrary JSON value.
You should usually call Builder.activationMethod with a well-typed ActivationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder eventType(TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder eventType(JsonField<TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the tokenization
-
tokenizationToken
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationTwoFactorAuthenticationCodeSentWebhookEvent build()
Returns an immutable instance of TokenizationTwoFactorAuthenticationCodeSentWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .activationMethod() .cardToken() .created() .eventType() .tokenizationToken()
-
-
-
-