Class TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class TokenizationTwoFactorAuthenticationCodeWebhookEvent.BuilderA builder for TokenizationTwoFactorAuthenticationCodeWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
accountToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder accountToken(String accountToken)
Unique identifier for the user tokenizing a card
-
accountToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder accountToken(JsonField<String> accountToken)
Sets Builder.accountToken to an arbitrary JSON value.
You should usually call Builder.accountToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
activationMethod
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder activationMethod(TokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod activationMethod)
-
activationMethod
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder activationMethod(JsonField<TokenizationTwoFactorAuthenticationCodeWebhookEvent.ActivationMethod> activationMethod)
Sets Builder.activationMethod to an arbitrary JSON value.
You should usually call Builder.activationMethod with a well-typed ActivationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticationCode
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder authenticationCode(String authenticationCode)
Authentication code to provide to the user tokenizing a card.
-
authenticationCode
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder authenticationCode(JsonField<String> authenticationCode)
Sets Builder.authenticationCode to an arbitrary JSON value.
You should usually call Builder.authenticationCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder cardToken(String cardToken)
Unique identifier for the card being tokenized
-
cardToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder cardToken(JsonField<String> cardToken)
Sets Builder.cardToken to an arbitrary JSON value.
You should usually call Builder.cardToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder created(OffsetDateTime created)
Indicate when the request was received from Mastercard or Visa
-
created
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventType
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder eventType(TokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType eventType)
The type of event that occurred.
-
eventType
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder eventType(JsonField<TokenizationTwoFactorAuthenticationCodeWebhookEvent.EventType> eventType)
Sets Builder.eventType to an arbitrary JSON value.
You should usually call Builder.eventType with a well-typed EventType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenizationToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder tokenizationToken(String tokenizationToken)
Unique identifier for the tokenization
-
tokenizationToken
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder tokenizationToken(JsonField<String> tokenizationToken)
Sets Builder.tokenizationToken to an arbitrary JSON value.
You should usually call Builder.tokenizationToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TokenizationTwoFactorAuthenticationCodeWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TokenizationTwoFactorAuthenticationCodeWebhookEvent build()
Returns an immutable instance of TokenizationTwoFactorAuthenticationCodeWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountToken() .activationMethod() .authenticationCode() .cardToken() .created() .eventType() .tokenizationToken()
-
-
-
-