Class Transaction.Pos.PosEntryMode
-
- All Implemented Interfaces:
public final class Transaction.Pos.PosEntryMode
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Pos.PosEntryMode.BuilderA builder for PosEntryMode.
public final classTransaction.Pos.PosEntryMode.CardCard presence indicator
public final classTransaction.Pos.PosEntryMode.CardholderCardholder presence indicator
public final classTransaction.Pos.PosEntryMode.PanMethod of entry for the PAN
-
Method Summary
Modifier and Type Method Description final Transaction.Pos.PosEntryMode.Cardcard()Card presence indicator final Transaction.Pos.PosEntryMode.Cardholdercardholder()Cardholder presence indicator final Transaction.Pos.PosEntryMode.Panpan()Method of entry for the PAN final BooleanpinEntered()Indicates whether the cardholder entered the PIN. final JsonField<Transaction.Pos.PosEntryMode.Card>_card()Returns the raw JSON value of card. final JsonField<Transaction.Pos.PosEntryMode.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<Transaction.Pos.PosEntryMode.Pan>_pan()Returns the raw JSON value of pan. final JsonField<Boolean>_pinEntered()Returns the raw JSON value of pinEntered. final Map<String, JsonValue>_additionalProperties()final Transaction.Pos.PosEntryMode.BuildertoBuilder()final Transaction.Pos.PosEntryModevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Pos.PosEntryMode.Builderbuilder()Returns a mutable builder for constructing an instance of PosEntryMode. -
-
Method Detail
-
card
final Transaction.Pos.PosEntryMode.Card card()
Card presence indicator
-
cardholder
final Transaction.Pos.PosEntryMode.Cardholder cardholder()
Cardholder presence indicator
-
pan
final Transaction.Pos.PosEntryMode.Pan pan()
Method of entry for the PAN
-
pinEntered
final Boolean pinEntered()
Indicates whether the cardholder entered the PIN. True if the PIN was entered.
-
_card
final JsonField<Transaction.Pos.PosEntryMode.Card> _card()
Returns the raw JSON value of card.
Unlike card, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<Transaction.Pos.PosEntryMode.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<Transaction.Pos.PosEntryMode.Pan> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_pinEntered
final JsonField<Boolean> _pinEntered()
Returns the raw JSON value of pinEntered.
Unlike pinEntered, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Pos.PosEntryMode.Builder toBuilder()
-
validate
final Transaction.Pos.PosEntryMode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Pos.PosEntryMode.Builder builder()
Returns a mutable builder for constructing an instance of PosEntryMode.
The following fields are required:
.card() .cardholder() .pan() .pinEntered()
-
-
-
-