Class Transaction.ServiceLocation.Builder
-
- All Implemented Interfaces:
public final class Transaction.ServiceLocation.BuilderA builder for ServiceLocation.
-
-
Method Summary
-
-
Method Detail
-
city
final Transaction.ServiceLocation.Builder city(String city)
City of service location.
-
city
final Transaction.ServiceLocation.Builder city(Optional<String> city)
Alias for calling Builder.city with
city.orElse(null).
-
city
final Transaction.ServiceLocation.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final Transaction.ServiceLocation.Builder country(String country)
Country code of service location, ISO 3166-1 alpha-3.
-
country
final Transaction.ServiceLocation.Builder country(Optional<String> country)
Alias for calling Builder.country with
country.orElse(null).
-
country
final Transaction.ServiceLocation.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final Transaction.ServiceLocation.Builder postalCode(String postalCode)
Postal code of service location.
-
postalCode
final Transaction.ServiceLocation.Builder postalCode(Optional<String> postalCode)
Alias for calling Builder.postalCode with
postalCode.orElse(null).
-
postalCode
final Transaction.ServiceLocation.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Transaction.ServiceLocation.Builder state(String state)
State/province code of service location, ISO 3166-2.
-
state
final Transaction.ServiceLocation.Builder state(Optional<String> state)
Alias for calling Builder.state with
state.orElse(null).
-
state
final Transaction.ServiceLocation.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
streetAddress
final Transaction.ServiceLocation.Builder streetAddress(String streetAddress)
Street address of service location.
-
streetAddress
final Transaction.ServiceLocation.Builder streetAddress(Optional<String> streetAddress)
Alias for calling Builder.streetAddress with
streetAddress.orElse(null).
-
streetAddress
final Transaction.ServiceLocation.Builder streetAddress(JsonField<String> streetAddress)
Sets Builder.streetAddress to an arbitrary JSON value.
You should usually call Builder.streetAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.ServiceLocation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.ServiceLocation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.ServiceLocation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.ServiceLocation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.ServiceLocation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.ServiceLocation build()
Returns an immutable instance of ServiceLocation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .country() .postalCode() .state() .streetAddress()
-
-
-
-