Class Transaction.TransactionAmounts
-
- All Implemented Interfaces:
public final class Transaction.TransactionAmounts
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionAmounts.BuilderA builder for TransactionAmounts.
public final classTransaction.TransactionAmounts.Cardholderpublic final classTransaction.TransactionAmounts.Holdpublic final classTransaction.TransactionAmounts.Merchantpublic final classTransaction.TransactionAmounts.Settlement
-
Method Summary
-
-
Method Detail
-
cardholder
final Transaction.TransactionAmounts.Cardholder cardholder()
-
hold
final Transaction.TransactionAmounts.Hold hold()
-
merchant
final Transaction.TransactionAmounts.Merchant merchant()
-
settlement
final Transaction.TransactionAmounts.Settlement settlement()
-
_cardholder
final JsonField<Transaction.TransactionAmounts.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_hold
final JsonField<Transaction.TransactionAmounts.Hold> _hold()
Returns the raw JSON value of hold.
Unlike hold, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<Transaction.TransactionAmounts.Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_settlement
final JsonField<Transaction.TransactionAmounts.Settlement> _settlement()
Returns the raw JSON value of settlement.
Unlike settlement, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionAmounts.Builder toBuilder()
-
validate
final Transaction.TransactionAmounts validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.TransactionAmounts.Builder builder()
Returns a mutable builder for constructing an instance of TransactionAmounts.
The following fields are required:
.cardholder() .hold() .merchant() .settlement()
-
-
-
-