Class Transaction.TransactionEvent.NetworkInfo.Acquirer
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.NetworkInfo.Acquirer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionEvent.NetworkInfo.Acquirer.BuilderA builder for Acquirer.
-
Method Summary
Modifier and Type Method Description final Optional<String>acquirerReferenceNumber()Identifier assigned by the acquirer, applicable to dual-message transactions only. final Optional<String>retrievalReferenceNumber()Identifier assigned by the acquirer. final JsonField<String>_acquirerReferenceNumber()Returns the raw JSON value of acquirerReferenceNumber. final JsonField<String>_retrievalReferenceNumber()Returns the raw JSON value of retrievalReferenceNumber. final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionEvent.NetworkInfo.Acquirer.BuildertoBuilder()final Transaction.TransactionEvent.NetworkInfo.Acquirervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionEvent.NetworkInfo.Acquirer.Builderbuilder()Returns a mutable builder for constructing an instance of Acquirer. -
-
Method Detail
-
acquirerReferenceNumber
final Optional<String> acquirerReferenceNumber()
Identifier assigned by the acquirer, applicable to dual-message transactions only. The acquirer reference number (ARN) is only populated once a transaction has been cleared, and it is not available in all transactions (such as automated fuel dispenser transactions). A single transaction can contain multiple ARNs if the merchant sends multiple clearings.
-
retrievalReferenceNumber
final Optional<String> retrievalReferenceNumber()
Identifier assigned by the acquirer.
-
_acquirerReferenceNumber
final JsonField<String> _acquirerReferenceNumber()
Returns the raw JSON value of acquirerReferenceNumber.
Unlike acquirerReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_retrievalReferenceNumber
final JsonField<String> _retrievalReferenceNumber()
Returns the raw JSON value of retrievalReferenceNumber.
Unlike retrievalReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionEvent.NetworkInfo.Acquirer.Builder toBuilder()
-
validate
final Transaction.TransactionEvent.NetworkInfo.Acquirer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.TransactionEvent.NetworkInfo.Acquirer.Builder builder()
Returns a mutable builder for constructing an instance of Acquirer.
The following fields are required:
.acquirerReferenceNumber() .retrievalReferenceNumber()
-
-
-
-