Class Transaction.TransactionEvent.NetworkInfo.Visa
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.NetworkInfo.Visa
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionEvent.NetworkInfo.Visa.BuilderA builder for Visa.
-
Method Summary
Modifier and Type Method Description final Optional<String>originalTransactionId()Identifier assigned by Visa. final Optional<String>transactionId()Identifier assigned by Visa to link original messages to subsequent messages. final JsonField<String>_originalTransactionId()Returns the raw JSON value of originalTransactionId. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionEvent.NetworkInfo.Visa.BuildertoBuilder()final Transaction.TransactionEvent.NetworkInfo.Visavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionEvent.NetworkInfo.Visa.Builderbuilder()Returns a mutable builder for constructing an instance of Visa. -
-
Method Detail
-
originalTransactionId
final Optional<String> originalTransactionId()
Identifier assigned by Visa. Matches the
transaction_idof a prior related event. May be populated in incremental authorizations (authorization requests that augment a previously authorized amount), authorization advices, financial authorizations, and clearings.
-
transactionId
final Optional<String> transactionId()
Identifier assigned by Visa to link original messages to subsequent messages. Guaranteed by Visa to be unique for each original authorization and financial authorization.
-
_originalTransactionId
final JsonField<String> _originalTransactionId()
Returns the raw JSON value of originalTransactionId.
Unlike originalTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionEvent.NetworkInfo.Visa.Builder toBuilder()
-
validate
final Transaction.TransactionEvent.NetworkInfo.Visa validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.TransactionEvent.NetworkInfo.Visa.Builder builder()
Returns a mutable builder for constructing an instance of Visa.
The following fields are required:
.originalTransactionId() .transactionId()
-
-
-
-