Package com.lithic.api.models
Class Transaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult.BuilderA builder for OnBehalfServiceResult.
-
Method Summary
-
-
Method Detail
-
_result1
final JsonField<String> _result1()
Returns the raw JSON value of result1.
Unlike result1, this method doesn't throw if the JSON field has an unexpected type.
-
_result2
final JsonField<String> _result2()
Returns the raw JSON value of result2.
Unlike result2, this method doesn't throw if the JSON field has an unexpected type.
-
_service
final JsonField<String> _service()
Returns the raw JSON value of service.
Unlike service, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult.Builder toBuilder()
-
validate
final Transaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.TransactionEvent.NetworkSpecificData.MastercardNetworkSpecificData.OnBehalfServiceResult.Builder builder()
Returns a mutable builder for constructing an instance of OnBehalfServiceResult.
The following fields are required:
.result1() .result2() .service()
-
-
-
-