Class Transaction.TransactionEvent.RuleResult
-
- All Implemented Interfaces:
public final class Transaction.TransactionEvent.RuleResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.TransactionEvent.RuleResult.BuilderA builder for RuleResult.
public final classTransaction.TransactionEvent.RuleResult.DetailedResultThe detailed_result associated with this rule's decline.
-
Method Summary
Modifier and Type Method Description final Optional<String>authRuleToken()The Auth Rule Token associated with the rule from which the decline originated. final Optional<String>explanation()A human-readable explanation outlining the motivation for the rule's decline. final Optional<String>name()The name for the rule, if any was configured. final Transaction.TransactionEvent.RuleResult.DetailedResultresult()The detailed_result associated with this rule's decline. final JsonField<String>_authRuleToken()Returns the raw JSON value of authRuleToken. final JsonField<String>_explanation()Returns the raw JSON value of explanation. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Transaction.TransactionEvent.RuleResult.DetailedResult>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final Transaction.TransactionEvent.RuleResult.BuildertoBuilder()final Transaction.TransactionEvent.RuleResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.TransactionEvent.RuleResult.Builderbuilder()Returns a mutable builder for constructing an instance of RuleResult. -
-
Method Detail
-
authRuleToken
final Optional<String> authRuleToken()
The Auth Rule Token associated with the rule from which the decline originated. If this is set to null, then the decline was not associated with a customer-configured Auth Rule. This may happen in cases where a transaction is declined due to a Lithic-configured security or compliance rule, for example.
-
explanation
final Optional<String> explanation()
A human-readable explanation outlining the motivation for the rule's decline.
-
result
final Transaction.TransactionEvent.RuleResult.DetailedResult result()
The detailed_result associated with this rule's decline.
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_explanation
final JsonField<String> _explanation()
Returns the raw JSON value of explanation.
Unlike explanation, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Transaction.TransactionEvent.RuleResult.DetailedResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.TransactionEvent.RuleResult.Builder toBuilder()
-
validate
final Transaction.TransactionEvent.RuleResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.TransactionEvent.RuleResult.Builder builder()
Returns a mutable builder for constructing an instance of RuleResult.
The following fields are required:
.authRuleToken() .explanation() .name() .result()
-
-
-
-