Package com.lithic.api.models
Class TransactionListPageResponse
-
- All Implemented Interfaces:
public final class TransactionListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListPageResponse.BuilderA builder for TransactionListPageResponse.
-
Method Summary
Modifier and Type Method Description final Optional<List<Transaction>>data()final Optional<Boolean>hasMore()Indicates whether there are more transactions to be retrieved. final JsonField<List<Transaction>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TransactionListPageResponse.BuildertoBuilder()final TransactionListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionListPageResponse. -
-
Method Detail
-
data
final Optional<List<Transaction>> data()
-
hasMore
final Optional<Boolean> hasMore()
Indicates whether there are more transactions to be retrieved.
-
_data
final JsonField<List<Transaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionListPageResponse.Builder toBuilder()
-
validate
final TransactionListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionListPageResponse.
-
-
-
-