Package com.lithic.api.models
Class TransactionListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TransactionListPageResponse.BuilderA builder for TransactionListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TransactionListPageResponse.Builder data(List<Transaction> data)
-
data
final TransactionListPageResponse.Builder data(JsonField<List<Transaction>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Transaction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TransactionListPageResponse.Builder addData(Transaction data)
Adds a single Transaction to Builder.data.
-
hasMore
final TransactionListPageResponse.Builder hasMore(Boolean hasMore)
Indicates whether there are more transactions to be retrieved.
-
hasMore
final TransactionListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionListPageResponse build()
Returns an immutable instance of TransactionListPageResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-