Class TransactionMonitoringCaseCommentCreateParams.AddCommentRequest
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseCommentCreateParams.AddCommentRequestParameters for adding a comment to a case
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseCommentCreateParams.AddCommentRequest.BuilderA builder for AddCommentRequest.
-
Method Summary
Modifier and Type Method Description final Stringcomment()Text of the comment final Optional<String>actorToken()Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. final JsonField<String>_comment()Returns the raw JSON value of comment. final JsonField<String>_actorToken()Returns the raw JSON value of actorToken. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.BuildertoBuilder()final TransactionMonitoringCaseCommentCreateParams.AddCommentRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builderbuilder()Returns a mutable builder for constructing an instance of AddCommentRequest. -
-
Method Detail
-
actorToken
final Optional<String> actorToken()
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
_comment
final JsonField<String> _comment()
Returns the raw JSON value of comment.
Unlike comment, this method doesn't throw if the JSON field has an unexpected type.
-
_actorToken
final JsonField<String> _actorToken()
Returns the raw JSON value of actorToken.
Unlike actorToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder builder()
Returns a mutable builder for constructing an instance of AddCommentRequest.
The following fields are required:
.comment()
-
-
-
-