Class TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.BuilderA builder for AddCommentRequest.
-
-
Method Summary
-
-
Method Detail
-
comment
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder comment(String comment)
Text of the comment
-
comment
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder comment(JsonField<String> comment)
Sets Builder.comment to an arbitrary JSON value.
You should usually call Builder.comment with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actorToken
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder actorToken(String actorToken)
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
actorToken
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder actorToken(JsonField<String> actorToken)
Sets Builder.actorToken to an arbitrary JSON value.
You should usually call Builder.actorToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionMonitoringCaseCommentCreateParams.AddCommentRequest build()
Returns an immutable instance of AddCommentRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.comment()
-
-
-
-