Class TransactionMonitoringCaseCommentUpdateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class TransactionMonitoringCaseCommentUpdateParams implements Params
Edits an existing comment on a case.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseCommentUpdateParams.BuilderA builder for TransactionMonitoringCaseCommentUpdateParams.
public final classTransactionMonitoringCaseCommentUpdateParams.EditCommentRequestParameters for editing an existing comment on a case
-
Method Summary
Modifier and Type Method Description final StringcaseToken()final Optional<String>commentToken()final Stringcomment()New text of the comment final Optional<String>actorToken()Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. final JsonField<String>_comment()Returns the raw JSON value of comment. final JsonField<String>_actorToken()Returns the raw JSON value of actorToken. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TransactionMonitoringCaseCommentUpdateParams.BuildertoBuilder()final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseCommentUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseCommentUpdateParams. -
-
Method Detail
-
commentToken
final Optional<String> commentToken()
-
actorToken
final Optional<String> actorToken()
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
_comment
final JsonField<String> _comment()
Returns the raw JSON value of comment.
Unlike comment, this method doesn't throw if the JSON field has an unexpected type.
-
_actorToken
final JsonField<String> _actorToken()
Returns the raw JSON value of actorToken.
Unlike actorToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TransactionMonitoringCaseCommentUpdateParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static TransactionMonitoringCaseCommentUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseCommentUpdateParams.
The following fields are required:
.caseToken() .comment()
-
-
-
-