Class TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseCommentUpdateParams.EditCommentRequestParameters for editing an existing comment on a case
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.BuilderA builder for EditCommentRequest.
-
Method Summary
Modifier and Type Method Description final Stringcomment()New text of the comment final Optional<String>actorToken()Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. final JsonField<String>_comment()Returns the raw JSON value of comment. final JsonField<String>_actorToken()Returns the raw JSON value of actorToken. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.BuildertoBuilder()final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builderbuilder()Returns a mutable builder for constructing an instance of EditCommentRequest. -
-
Method Detail
-
actorToken
final Optional<String> actorToken()
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
_comment
final JsonField<String> _comment()
Returns the raw JSON value of comment.
Unlike comment, this method doesn't throw if the JSON field has an unexpected type.
-
_actorToken
final JsonField<String> _actorToken()
Returns the raw JSON value of actorToken.
Unlike actorToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder builder()
Returns a mutable builder for constructing an instance of EditCommentRequest.
The following fields are required:
.comment()
-
-
-
-