Class TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.BuilderA builder for EditCommentRequest.
-
-
Method Summary
-
-
Method Detail
-
comment
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder comment(String comment)
New text of the comment
-
comment
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder comment(JsonField<String> comment)
Sets Builder.comment to an arbitrary JSON value.
You should usually call Builder.comment with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actorToken
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder actorToken(String actorToken)
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
actorToken
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder actorToken(JsonField<String> actorToken)
Sets Builder.actorToken to an arbitrary JSON value.
You should usually call Builder.actorToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionMonitoringCaseCommentUpdateParams.EditCommentRequest build()
Returns an immutable instance of EditCommentRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.comment()
-
-
-
-