Package com.lithic.api.models
Class TransactionMonitoringCaseFileCreateParams.CreateFileRequest
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseFileCreateParams.CreateFileRequestParameters for creating a case file and starting an upload
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseFileCreateParams.CreateFileRequest.BuilderA builder for CreateFileRequest.
-
Method Summary
Modifier and Type Method Description final Stringname()Name of the file to upload final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseFileCreateParams.CreateFileRequest.BuildertoBuilder()final TransactionMonitoringCaseFileCreateParams.CreateFileRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseFileCreateParams.CreateFileRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateFileRequest. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringCaseFileCreateParams.CreateFileRequest.Builder toBuilder()
-
validate
final TransactionMonitoringCaseFileCreateParams.CreateFileRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseFileCreateParams.CreateFileRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateFileRequest.
The following fields are required:
.name()
-
-
-
-