Package com.lithic.api.models
Class TransactionMonitoringCaseFileListPageAsync.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseFileListPageAsync.BuilderA builder for TransactionMonitoringCaseFileListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringCaseFileListPageAsync.Builderservice(FileServiceAsync service)final TransactionMonitoringCaseFileListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TransactionMonitoringCaseFileListPageAsync.Builderparams(TransactionMonitoringCaseFileListParams params)The parameters that were used to request this page. final TransactionMonitoringCaseFileListPageAsync.Builderresponse(TransactionMonitoringCaseFileListPageResponse response)The response that this page was parsed from. final TransactionMonitoringCaseFileListPageAsyncbuild()Returns an immutable instance of TransactionMonitoringCaseFileListPageAsync. -
-
Method Detail
-
service
final TransactionMonitoringCaseFileListPageAsync.Builder service(FileServiceAsync service)
-
streamHandlerExecutor
final TransactionMonitoringCaseFileListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TransactionMonitoringCaseFileListPageAsync.Builder params(TransactionMonitoringCaseFileListParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseFileListPageAsync.Builder response(TransactionMonitoringCaseFileListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringCaseFileListPageAsync build()
Returns an immutable instance of TransactionMonitoringCaseFileListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-