Package com.lithic.api.models
Class TransactionMonitoringCaseFileListPageResponse
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseFileListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseFileListPageResponse.BuilderA builder for TransactionMonitoringCaseFileListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CaseFile>data()final BooleanhasMore()final JsonField<List<CaseFile>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseFileListPageResponse.BuildertoBuilder()final TransactionMonitoringCaseFileListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseFileListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseFileListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<CaseFile>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringCaseFileListPageResponse.Builder toBuilder()
-
validate
final TransactionMonitoringCaseFileListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseFileListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseFileListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-