Package com.lithic.api.models
Class TransactionMonitoringCaseFileListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseFileListPageResponse.BuilderA builder for TransactionMonitoringCaseFileListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TransactionMonitoringCaseFileListPageResponse.Builder data(List<CaseFile> data)
-
data
final TransactionMonitoringCaseFileListPageResponse.Builder data(JsonField<List<CaseFile>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<CaseFile>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TransactionMonitoringCaseFileListPageResponse.Builder addData(CaseFile data)
Adds a single CaseFile to Builder.data.
-
hasMore
final TransactionMonitoringCaseFileListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final TransactionMonitoringCaseFileListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionMonitoringCaseFileListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionMonitoringCaseFileListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionMonitoringCaseFileListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionMonitoringCaseFileListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionMonitoringCaseFileListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionMonitoringCaseFileListPageResponse build()
Returns an immutable instance of TransactionMonitoringCaseFileListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-