Class TransactionMonitoringCaseListPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class TransactionMonitoringCaseListPage implements Page<MonitoringCase>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseListPage.BuilderA builder for TransactionMonitoringCaseListPage.
-
Method Summary
Modifier and Type Method Description final List<MonitoringCase>data()Delegates to TransactionMonitoringCaseListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TransactionMonitoringCaseListPageResponse, but gracefully handles missing data. List<MonitoringCase>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final TransactionMonitoringCaseListParamsnextPageParams()TransactionMonitoringCaseListPagenextPage()Returns the page after this one by making another request. final AutoPager<MonitoringCase>autoPager()final TransactionMonitoringCaseListParamsparams()The parameters that were used to request this page. final TransactionMonitoringCaseListPageResponseresponse()The response that this page was parsed from. final TransactionMonitoringCaseListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseListPage.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListPage. -
-
Method Detail
-
data
final List<MonitoringCase> data()
Delegates to TransactionMonitoringCaseListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionMonitoringCaseListPageResponse, but gracefully handles missing data.
-
items
List<MonitoringCase> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final TransactionMonitoringCaseListParams nextPageParams()
-
nextPage
TransactionMonitoringCaseListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<MonitoringCase> autoPager()
-
params
final TransactionMonitoringCaseListParams params()
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionMonitoringCaseListPage.Builder toBuilder()
-
builder
final static TransactionMonitoringCaseListPage.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-