Package com.lithic.api.models
Class TransactionMonitoringCaseListPage.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListPage.BuilderA builder for TransactionMonitoringCaseListPage.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringCaseListPage.Builderservice(CaseService service)final TransactionMonitoringCaseListPage.Builderparams(TransactionMonitoringCaseListParams params)The parameters that were used to request this page. final TransactionMonitoringCaseListPage.Builderresponse(TransactionMonitoringCaseListPageResponse response)The response that this page was parsed from. final TransactionMonitoringCaseListPagebuild()Returns an immutable instance of TransactionMonitoringCaseListPage. -
-
Method Detail
-
service
final TransactionMonitoringCaseListPage.Builder service(CaseService service)
-
params
final TransactionMonitoringCaseListPage.Builder params(TransactionMonitoringCaseListParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseListPage.Builder response(TransactionMonitoringCaseListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringCaseListPage build()
Returns an immutable instance of TransactionMonitoringCaseListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-