Package com.lithic.api.models
Class TransactionMonitoringCaseListPageAsync.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListPageAsync.BuilderA builder for TransactionMonitoringCaseListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringCaseListPageAsync.Builderservice(CaseServiceAsync service)final TransactionMonitoringCaseListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TransactionMonitoringCaseListPageAsync.Builderparams(TransactionMonitoringCaseListParams params)The parameters that were used to request this page. final TransactionMonitoringCaseListPageAsync.Builderresponse(TransactionMonitoringCaseListPageResponse response)The response that this page was parsed from. final TransactionMonitoringCaseListPageAsyncbuild()Returns an immutable instance of TransactionMonitoringCaseListPageAsync. -
-
Method Detail
-
service
final TransactionMonitoringCaseListPageAsync.Builder service(CaseServiceAsync service)
-
streamHandlerExecutor
final TransactionMonitoringCaseListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TransactionMonitoringCaseListPageAsync.Builder params(TransactionMonitoringCaseListParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseListPageAsync.Builder response(TransactionMonitoringCaseListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringCaseListPageAsync build()
Returns an immutable instance of TransactionMonitoringCaseListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-