Package com.lithic.api.models
Class TransactionMonitoringCaseListPageResponse
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseListPageResponse.BuilderA builder for TransactionMonitoringCaseListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<MonitoringCase>data()final BooleanhasMore()final JsonField<List<MonitoringCase>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseListPageResponse.BuildertoBuilder()final TransactionMonitoringCaseListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListPageResponse. -
-
Method Detail
-
data
final List<MonitoringCase> data()
-
_data
final JsonField<List<MonitoringCase>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringCaseListPageResponse.Builder toBuilder()
-
validate
final TransactionMonitoringCaseListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-