Package com.lithic.api.models
Class TransactionMonitoringCaseListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListPageResponse.BuilderA builder for TransactionMonitoringCaseListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TransactionMonitoringCaseListPageResponse.Builder data(List<MonitoringCase> data)
-
data
final TransactionMonitoringCaseListPageResponse.Builder data(JsonField<List<MonitoringCase>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<MonitoringCase>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TransactionMonitoringCaseListPageResponse.Builder addData(MonitoringCase data)
Adds a single MonitoringCase to Builder.data.
-
hasMore
final TransactionMonitoringCaseListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final TransactionMonitoringCaseListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionMonitoringCaseListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionMonitoringCaseListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionMonitoringCaseListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionMonitoringCaseListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionMonitoringCaseListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionMonitoringCaseListPageResponse build()
Returns an immutable instance of TransactionMonitoringCaseListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-