Class TransactionMonitoringCaseListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class TransactionMonitoringCaseListParams implements Params
Lists transaction monitoring cases, optionally filtered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseListParams.BuilderA builder for TransactionMonitoringCaseListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()Only return cases that include transactions on the provided account. final Optional<String>assignee()Only return cases assigned to the provided value. final Optional<OffsetDateTime>begin()Date string in RFC 3339 format. final Optional<String>cardToken()Only return cases that include transactions on the provided card. final Optional<OffsetDateTime>end()Date string in RFC 3339 format. final Optional<String>endingBefore()A cursor representing an item's token before which a page of results should end. final Optional<String>entityToken()Only return cases associated with the provided entity. final Optional<Long>pageSize()Page size (for pagination). final Optional<String>queueToken()Only return cases belonging to the provided queue. final Optional<String>ruleToken()Only return cases triggered by the provided transaction monitoring rule. final Optional<CaseSortOrder>sortBy()Sort order for the returned cases. final Optional<String>startingAfter()A cursor representing an item's token after which a page of results should begin. final Optional<CaseStatus>status()Only return cases with the provided status. final Optional<String>transactionToken()Only return cases that include the provided transaction. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TransactionMonitoringCaseListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseListParamsnone()final static TransactionMonitoringCaseListParams.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListParams. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
Only return cases that include transactions on the provided account.
-
assignee
final Optional<String> assignee()
Only return cases assigned to the provided value. Pass an empty string to return only unassigned cases.
-
begin
final Optional<OffsetDateTime> begin()
Date string in RFC 3339 format. Only entries created after the specified time will be included. UTC time zone.
-
cardToken
final Optional<String> cardToken()
Only return cases that include transactions on the provided card.
-
end
final Optional<OffsetDateTime> end()
Date string in RFC 3339 format. Only entries created before the specified time will be included. UTC time zone.
-
endingBefore
final Optional<String> endingBefore()
A cursor representing an item's token before which a page of results should end. Used to retrieve the previous page of results before this item.
-
entityToken
final Optional<String> entityToken()
Only return cases associated with the provided entity.
-
queueToken
final Optional<String> queueToken()
Only return cases belonging to the provided queue.
-
ruleToken
final Optional<String> ruleToken()
Only return cases triggered by the provided transaction monitoring rule.
-
sortBy
final Optional<CaseSortOrder> sortBy()
Sort order for the returned cases.
-
startingAfter
final Optional<String> startingAfter()
A cursor representing an item's token after which a page of results should begin. Used to retrieve the next page of results after this item.
-
status
final Optional<CaseStatus> status()
Only return cases with the provided status.
-
transactionToken
final Optional<String> transactionToken()
Only return cases that include the provided transaction.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TransactionMonitoringCaseListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static TransactionMonitoringCaseListParams none()
-
builder
final static TransactionMonitoringCaseListParams.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListParams.
-
-
-
-