Class TransactionMonitoringCaseListTransactionsPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class TransactionMonitoringCaseListTransactionsPage implements Page<CaseTransaction>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseListTransactionsPage.BuilderA builder for TransactionMonitoringCaseListTransactionsPage.
-
Method Summary
-
-
Method Detail
-
data
final List<CaseTransaction> data()
Delegates to TransactionMonitoringCaseListTransactionsPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionMonitoringCaseListTransactionsPageResponse, but gracefully handles missing data.
-
items
List<CaseTransaction> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final TransactionMonitoringCaseListTransactionsParams nextPageParams()
-
nextPage
TransactionMonitoringCaseListTransactionsPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<CaseTransaction> autoPager()
-
params
final TransactionMonitoringCaseListTransactionsParams params()
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseListTransactionsPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionMonitoringCaseListTransactionsPage.Builder toBuilder()
-
builder
final static TransactionMonitoringCaseListTransactionsPage.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListTransactionsPage.
The following fields are required:
.service() .params() .response()
-
-
-
-