Package com.lithic.api.models
Class TransactionMonitoringCaseListTransactionsPageAsync.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListTransactionsPageAsync.BuilderA builder for TransactionMonitoringCaseListTransactionsPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringCaseListTransactionsPageAsync.Builderservice(CaseServiceAsync service)final TransactionMonitoringCaseListTransactionsPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TransactionMonitoringCaseListTransactionsPageAsync.Builderparams(TransactionMonitoringCaseListTransactionsParams params)The parameters that were used to request this page. final TransactionMonitoringCaseListTransactionsPageAsync.Builderresponse(TransactionMonitoringCaseListTransactionsPageResponse response)The response that this page was parsed from. final TransactionMonitoringCaseListTransactionsPageAsyncbuild()Returns an immutable instance of TransactionMonitoringCaseListTransactionsPageAsync. -
-
Method Detail
-
service
final TransactionMonitoringCaseListTransactionsPageAsync.Builder service(CaseServiceAsync service)
-
streamHandlerExecutor
final TransactionMonitoringCaseListTransactionsPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TransactionMonitoringCaseListTransactionsPageAsync.Builder params(TransactionMonitoringCaseListTransactionsParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringCaseListTransactionsPageAsync.Builder response(TransactionMonitoringCaseListTransactionsPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringCaseListTransactionsPageAsync build()
Returns an immutable instance of TransactionMonitoringCaseListTransactionsPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-