Package com.lithic.api.models
Class TransactionMonitoringCaseListTransactionsPageResponse
-
- All Implemented Interfaces:
public final class TransactionMonitoringCaseListTransactionsPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseListTransactionsPageResponse.BuilderA builder for TransactionMonitoringCaseListTransactionsPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CaseTransaction>data()final BooleanhasMore()final JsonField<List<CaseTransaction>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringCaseListTransactionsPageResponse.BuildertoBuilder()final TransactionMonitoringCaseListTransactionsPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseListTransactionsPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListTransactionsPageResponse. -
-
Method Detail
-
data
final List<CaseTransaction> data()
-
_data
final JsonField<List<CaseTransaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringCaseListTransactionsPageResponse.Builder toBuilder()
-
validate
final TransactionMonitoringCaseListTransactionsPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringCaseListTransactionsPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseListTransactionsPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-