Class TransactionMonitoringCaseUpdateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class TransactionMonitoringCaseUpdateParams implements Params
Updates a transaction monitoring case.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringCaseUpdateParams.BuilderA builder for TransactionMonitoringCaseUpdateParams.
public final classTransactionMonitoringCaseUpdateParams.UpdateCaseRequestParameters for updating a case. All fields are optional; omitted fields are left unchanged. The nullable fields
title,assignee, andsla_deadlinecan be cleared by sendingnull.public final classTransactionMonitoringCaseUpdateParams.TagsArbitrary key-value metadata to set on the case
-
Method Summary
Modifier and Type Method Description final Optional<String>caseToken()final Optional<String>actorToken()Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. final Optional<String>assignee()New assignee for the case, or nullto unassignfinal Optional<CasePriority>priority()Priority level of a case, controlling queue ordering and SLA urgency final Optional<ResolutionOutcome>resolution()Outcome recorded when a case is resolved: CONFIRMED_FRAUD- The reviewed activity was confirmed to be fraudulentSUSPICIOUS_ACTIVITY- The activity is suspicious but not confirmed fraudFALSE_POSITIVE- The activity was legitimate and the alert was a false positiveNO_ACTION_REQUIRED- No further action is requiredESCALATED_EXTERNAL- The case was escalated to an external party
final Optional<String>resolutionNotes()Notes describing the resolution final Optional<OffsetDateTime>slaDeadline()New SLA deadline for the case, or nullto clear itfinal Optional<CaseStatus>status()Status of a case as it progresses through the review workflow: OPEN- The case has been created and is still collecting matching transactionsASSIGNED- An analyst has been assigned and transaction collection has stoppedIN_REVIEW- The case is actively being investigatedESCALATED- The case has been reviewed and requires additional oversightRESOLVED- A determination has been made and a resolution recordedCLOSED- The case is finalized
final Optional<TransactionMonitoringCaseUpdateParams.Tags>tags()Arbitrary key-value metadata to set on the case final Optional<String>title()New title for the case, or nullto clear itfinal JsonField<String>_actorToken()Returns the raw JSON value of actorToken. final JsonField<String>_assignee()Returns the raw JSON value of assignee. final JsonField<CasePriority>_priority()Returns the raw JSON value of priority. final JsonField<ResolutionOutcome>_resolution()Returns the raw JSON value of resolution. final JsonField<String>_resolutionNotes()Returns the raw JSON value of resolutionNotes. final JsonField<OffsetDateTime>_slaDeadline()Returns the raw JSON value of slaDeadline. final JsonField<CaseStatus>_status()Returns the raw JSON value of status. final JsonField<TransactionMonitoringCaseUpdateParams.Tags>_tags()Returns the raw JSON value of tags. final JsonField<String>_title()Returns the raw JSON value of title. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TransactionMonitoringCaseUpdateParams.BuildertoBuilder()final TransactionMonitoringCaseUpdateParams.UpdateCaseRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringCaseUpdateParamsnone()final static TransactionMonitoringCaseUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringCaseUpdateParams. -
-
Method Detail
-
actorToken
final Optional<String> actorToken()
Optional client-provided identifier for the actor performing this action, recorded on the resulting activity entry. This value is supplied by the client (for example, your own internal user ID) and is not authenticated by Lithic
-
priority
final Optional<CasePriority> priority()
Priority level of a case, controlling queue ordering and SLA urgency
-
resolution
final Optional<ResolutionOutcome> resolution()
Outcome recorded when a case is resolved:
CONFIRMED_FRAUD- The reviewed activity was confirmed to be fraudulentSUSPICIOUS_ACTIVITY- The activity is suspicious but not confirmed fraudFALSE_POSITIVE- The activity was legitimate and the alert was a false positiveNO_ACTION_REQUIRED- No further action is requiredESCALATED_EXTERNAL- The case was escalated to an external party
-
resolutionNotes
final Optional<String> resolutionNotes()
Notes describing the resolution
-
slaDeadline
final Optional<OffsetDateTime> slaDeadline()
New SLA deadline for the case, or
nullto clear it
-
status
final Optional<CaseStatus> status()
Status of a case as it progresses through the review workflow:
OPEN- The case has been created and is still collecting matching transactionsASSIGNED- An analyst has been assigned and transaction collection has stoppedIN_REVIEW- The case is actively being investigatedESCALATED- The case has been reviewed and requires additional oversightRESOLVED- A determination has been made and a resolution recordedCLOSED- The case is finalized
-
tags
final Optional<TransactionMonitoringCaseUpdateParams.Tags> tags()
Arbitrary key-value metadata to set on the case
-
_actorToken
final JsonField<String> _actorToken()
Returns the raw JSON value of actorToken.
Unlike actorToken, this method doesn't throw if the JSON field has an unexpected type.
-
_assignee
final JsonField<String> _assignee()
Returns the raw JSON value of assignee.
Unlike assignee, this method doesn't throw if the JSON field has an unexpected type.
-
_priority
final JsonField<CasePriority> _priority()
Returns the raw JSON value of priority.
Unlike priority, this method doesn't throw if the JSON field has an unexpected type.
-
_resolution
final JsonField<ResolutionOutcome> _resolution()
Returns the raw JSON value of resolution.
Unlike resolution, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionNotes
final JsonField<String> _resolutionNotes()
Returns the raw JSON value of resolutionNotes.
Unlike resolutionNotes, this method doesn't throw if the JSON field has an unexpected type.
-
_slaDeadline
final JsonField<OffsetDateTime> _slaDeadline()
Returns the raw JSON value of slaDeadline.
Unlike slaDeadline, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CaseStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<TransactionMonitoringCaseUpdateParams.Tags> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TransactionMonitoringCaseUpdateParams.Builder toBuilder()
-
_body
final TransactionMonitoringCaseUpdateParams.UpdateCaseRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static TransactionMonitoringCaseUpdateParams none()
-
builder
final static TransactionMonitoringCaseUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringCaseUpdateParams.
-
-
-