Package com.lithic.api.models
Class TransactionMonitoringQueueCreateParams.CreateQueueRequest
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueCreateParams.CreateQueueRequestParameters for creating a queue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringQueueCreateParams.CreateQueueRequest.BuilderA builder for CreateQueueRequest.
-
Method Summary
Modifier and Type Method Description final Stringname()Human-readable name of the queue final Optional<String>description()Optional description of the queue final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringQueueCreateParams.CreateQueueRequest.BuildertoBuilder()final TransactionMonitoringQueueCreateParams.CreateQueueRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringQueueCreateParams.CreateQueueRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateQueueRequest. -
-
Method Detail
-
description
final Optional<String> description()
Optional description of the queue
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringQueueCreateParams.CreateQueueRequest.Builder toBuilder()
-
validate
final TransactionMonitoringQueueCreateParams.CreateQueueRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringQueueCreateParams.CreateQueueRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateQueueRequest.
The following fields are required:
.name()
-
-
-
-