Class TransactionMonitoringQueueListPage
-
- All Implemented Interfaces:
-
com.lithic.api.core.Page
public final class TransactionMonitoringQueueListPage implements Page<Queue>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringQueueListPage.BuilderA builder for TransactionMonitoringQueueListPage.
-
Method Summary
Modifier and Type Method Description final List<Queue>data()Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data. List<Queue>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final TransactionMonitoringQueueListParamsnextPageParams()TransactionMonitoringQueueListPagenextPage()Returns the page after this one by making another request. final AutoPager<Queue>autoPager()final TransactionMonitoringQueueListParamsparams()The parameters that were used to request this page. final TransactionMonitoringQueueListPageResponseresponse()The response that this page was parsed from. final TransactionMonitoringQueueListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringQueueListPage.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringQueueListPage. -
-
Method Detail
-
data
final List<Queue> data()
Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final TransactionMonitoringQueueListParams nextPageParams()
-
nextPage
TransactionMonitoringQueueListPage nextPage()
Returns the page after this one by making another request.
-
params
final TransactionMonitoringQueueListParams params()
The parameters that were used to request this page.
-
response
final TransactionMonitoringQueueListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionMonitoringQueueListPage.Builder toBuilder()
-
builder
final static TransactionMonitoringQueueListPage.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringQueueListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-