Package com.lithic.api.models
Class TransactionMonitoringQueueListPage.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueListPage.BuilderA builder for TransactionMonitoringQueueListPage.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringQueueListPage.Builderservice(QueueService service)final TransactionMonitoringQueueListPage.Builderparams(TransactionMonitoringQueueListParams params)The parameters that were used to request this page. final TransactionMonitoringQueueListPage.Builderresponse(TransactionMonitoringQueueListPageResponse response)The response that this page was parsed from. final TransactionMonitoringQueueListPagebuild()Returns an immutable instance of TransactionMonitoringQueueListPage. -
-
Method Detail
-
service
final TransactionMonitoringQueueListPage.Builder service(QueueService service)
-
params
final TransactionMonitoringQueueListPage.Builder params(TransactionMonitoringQueueListParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringQueueListPage.Builder response(TransactionMonitoringQueueListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringQueueListPage build()
Returns an immutable instance of TransactionMonitoringQueueListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-