Class TransactionMonitoringQueueListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class TransactionMonitoringQueueListPageAsync implements PageAsync<Queue>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringQueueListPageAsync.BuilderA builder for TransactionMonitoringQueueListPageAsync.
-
Method Summary
-
-
Method Detail
-
data
final List<Queue> data()
Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransactionMonitoringQueueListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final TransactionMonitoringQueueListParams nextPageParams()
-
nextPage
CompletableFuture<TransactionMonitoringQueueListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Queue> autoPager()
-
params
final TransactionMonitoringQueueListParams params()
The parameters that were used to request this page.
-
response
final TransactionMonitoringQueueListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final TransactionMonitoringQueueListPageAsync.Builder toBuilder()
-
builder
final static TransactionMonitoringQueueListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringQueueListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-