Package com.lithic.api.models
Class TransactionMonitoringQueueListPageAsync.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueListPageAsync.BuilderA builder for TransactionMonitoringQueueListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final TransactionMonitoringQueueListPageAsync.Builderservice(QueueServiceAsync service)final TransactionMonitoringQueueListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final TransactionMonitoringQueueListPageAsync.Builderparams(TransactionMonitoringQueueListParams params)The parameters that were used to request this page. final TransactionMonitoringQueueListPageAsync.Builderresponse(TransactionMonitoringQueueListPageResponse response)The response that this page was parsed from. final TransactionMonitoringQueueListPageAsyncbuild()Returns an immutable instance of TransactionMonitoringQueueListPageAsync. -
-
Method Detail
-
service
final TransactionMonitoringQueueListPageAsync.Builder service(QueueServiceAsync service)
-
streamHandlerExecutor
final TransactionMonitoringQueueListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final TransactionMonitoringQueueListPageAsync.Builder params(TransactionMonitoringQueueListParams params)
The parameters that were used to request this page.
-
response
final TransactionMonitoringQueueListPageAsync.Builder response(TransactionMonitoringQueueListPageResponse response)
The response that this page was parsed from.
-
build
final TransactionMonitoringQueueListPageAsync build()
Returns an immutable instance of TransactionMonitoringQueueListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-