Package com.lithic.api.models
Class TransactionMonitoringQueueListPageResponse
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringQueueListPageResponse.BuilderA builder for TransactionMonitoringQueueListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Queue>data()final BooleanhasMore()final JsonField<List<Queue>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringQueueListPageResponse.BuildertoBuilder()final TransactionMonitoringQueueListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringQueueListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionMonitoringQueueListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Queue>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringQueueListPageResponse.Builder toBuilder()
-
validate
final TransactionMonitoringQueueListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringQueueListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionMonitoringQueueListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-