Package com.lithic.api.models
Class TransactionMonitoringQueueListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueListPageResponse.BuilderA builder for TransactionMonitoringQueueListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TransactionMonitoringQueueListPageResponse.Builder data(List<Queue> data)
-
data
final TransactionMonitoringQueueListPageResponse.Builder data(JsonField<List<Queue>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Queue>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TransactionMonitoringQueueListPageResponse.Builder addData(Queue data)
Adds a single Queue to Builder.data.
-
hasMore
final TransactionMonitoringQueueListPageResponse.Builder hasMore(Boolean hasMore)
-
hasMore
final TransactionMonitoringQueueListPageResponse.Builder hasMore(JsonField<Boolean> hasMore)
Sets Builder.hasMore to an arbitrary JSON value.
You should usually call Builder.hasMore with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionMonitoringQueueListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionMonitoringQueueListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionMonitoringQueueListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionMonitoringQueueListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionMonitoringQueueListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionMonitoringQueueListPageResponse build()
Returns an immutable instance of TransactionMonitoringQueueListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .hasMore()
-
-
-
-