Package com.lithic.api.models
Class TransactionMonitoringQueueUpdateParams.UpdateQueueRequest
-
- All Implemented Interfaces:
public final class TransactionMonitoringQueueUpdateParams.UpdateQueueRequestParameters for updating a queue. All fields are optional; omitted fields are left unchanged
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringQueueUpdateParams.UpdateQueueRequest.BuilderA builder for UpdateQueueRequest.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()New description for the queue, or nullto clear itfinal Optional<String>name()New name for the queue final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final TransactionMonitoringQueueUpdateParams.UpdateQueueRequest.BuildertoBuilder()final TransactionMonitoringQueueUpdateParams.UpdateQueueRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionMonitoringQueueUpdateParams.UpdateQueueRequest.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateQueueRequest. -
-
Method Detail
-
description
final Optional<String> description()
New description for the queue, or
nullto clear it
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionMonitoringQueueUpdateParams.UpdateQueueRequest.Builder toBuilder()
-
validate
final TransactionMonitoringQueueUpdateParams.UpdateQueueRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionMonitoringQueueUpdateParams.UpdateQueueRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateQueueRequest.
-
-
-
-