Package com.lithic.api.models
Class TransactionRouteParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class TransactionRouteParams implements Params
Route a card transaction to a financial account. Only available for select use cases and programs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionRouteParams.BuilderA builder for TransactionRouteParams.
public final classTransactionRouteParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>transactionToken()final StringfinancialAccountToken()The token of the financial account to route the transaction to. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TransactionRouteParams.BuildertoBuilder()final TransactionRouteParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionRouteParams.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionRouteParams. -
-
Method Detail
-
transactionToken
final Optional<String> transactionToken()
-
financialAccountToken
final String financialAccountToken()
The token of the financial account to route the transaction to.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TransactionRouteParams.Builder toBuilder()
-
_body
final TransactionRouteParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static TransactionRouteParams.Builder builder()
Returns a mutable builder for constructing an instance of TransactionRouteParams.
The following fields are required:
.financialAccountToken()
-
-
-
-