Package com.lithic.api.models
Class TransactionRouteParams.Body
-
- All Implemented Interfaces:
public final class TransactionRouteParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionRouteParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringfinancialAccountToken()The token of the financial account to route the transaction to. final JsonField<String>_financialAccountToken()Returns the raw JSON value of financialAccountToken. final Map<String, JsonValue>_additionalProperties()final TransactionRouteParams.Body.BuildertoBuilder()final TransactionRouteParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionRouteParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
financialAccountToken
final String financialAccountToken()
The token of the financial account to route the transaction to.
-
_financialAccountToken
final JsonField<String> _financialAccountToken()
Returns the raw JSON value of financialAccountToken.
Unlike financialAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionRouteParams.Body.Builder toBuilder()
-
validate
final TransactionRouteParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionRouteParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.financialAccountToken()
-
-
-
-