Package com.lithic.api.models
Class TransactionSimulateAuthorizationAdviceParams.Body
-
- All Implemented Interfaces:
public final class TransactionSimulateAuthorizationAdviceParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateAuthorizationAdviceParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringtoken()The transaction token returned from the /v1/simulate/authorize. final Longamount()Amount (in cents) to authorize. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateAuthorizationAdviceParams.Body.BuildertoBuilder()final TransactionSimulateAuthorizationAdviceParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateAuthorizationAdviceParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
token
final String token()
The transaction token returned from the /v1/simulate/authorize. response.
-
amount
final Long amount()
Amount (in cents) to authorize. This amount will override the transaction's amount that was originally set by /v1/simulate/authorize.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateAuthorizationAdviceParams.Body.Builder toBuilder()
-
validate
final TransactionSimulateAuthorizationAdviceParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateAuthorizationAdviceParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.token() .amount()
-
-
-
-