Class TransactionSimulateAuthorizationParams.Body
-
- All Implemented Interfaces:
public final class TransactionSimulateAuthorizationParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateAuthorizationParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount (in cents) to authorize. final Stringdescriptor()Merchant descriptor. final Stringpan()Sixteen digit card number. final Optional<String>mcc()Merchant category code for the transaction to be simulated. final Optional<String>merchantAcceptorCity()Merchant acceptor city final Optional<String>merchantAcceptorCountry()Merchant acceptor country code (ISO 3166-1 alpha-3) final Optional<String>merchantAcceptorId()Unique identifier to identify the payment card acceptor. final Optional<String>merchantAcceptorState()Merchant acceptor state/province (ISO 3166-2 subdivision code) final Optional<Long>merchantAmount()Amount of the transaction to be simulated in currency specified in merchant_currency, including any acquirer fees. final Optional<String>merchantCurrency()3-character alphabetic ISO 4217 currency code. final Optional<Boolean>partialApprovalCapable()Set to true if the terminal is capable of partial approval otherwise false. final Optional<String>pin()Simulate entering a PIN. final Optional<TransactionSimulateAuthorizationParams.Status>status()Type of event to simulate. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_pan()Returns the raw JSON value of pan. final JsonField<String>_mcc()Returns the raw JSON value of mcc. final JsonField<String>_merchantAcceptorCity()Returns the raw JSON value of merchantAcceptorCity. final JsonField<String>_merchantAcceptorCountry()Returns the raw JSON value of merchantAcceptorCountry. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantAcceptorState()Returns the raw JSON value of merchantAcceptorState. final JsonField<Long>_merchantAmount()Returns the raw JSON value of merchantAmount. final JsonField<String>_merchantCurrency()Returns the raw JSON value of merchantCurrency. final JsonField<Boolean>_partialApprovalCapable()Returns the raw JSON value of partialApprovalCapable. final JsonField<String>_pin()Returns the raw JSON value of pin. final JsonField<TransactionSimulateAuthorizationParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateAuthorizationParams.Body.BuildertoBuilder()final TransactionSimulateAuthorizationParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateAuthorizationParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Long amount()
Amount (in cents) to authorize. For credit authorizations and financial credit authorizations, any value entered will be converted into a negative amount in the simulated transaction. For example, entering 100 in this field will result in a -100 amount in the transaction. For balance inquiries, this field must be set to 0.
-
descriptor
final String descriptor()
Merchant descriptor.
-
mcc
final Optional<String> mcc()
Merchant category code for the transaction to be simulated. A four-digit number listed in ISO 18245. Supported merchant category codes can be found here.
-
merchantAcceptorCity
final Optional<String> merchantAcceptorCity()
Merchant acceptor city
-
merchantAcceptorCountry
final Optional<String> merchantAcceptorCountry()
Merchant acceptor country code (ISO 3166-1 alpha-3)
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
Unique identifier to identify the payment card acceptor.
-
merchantAcceptorState
final Optional<String> merchantAcceptorState()
Merchant acceptor state/province (ISO 3166-2 subdivision code)
-
merchantAmount
final Optional<Long> merchantAmount()
Amount of the transaction to be simulated in currency specified in merchant_currency, including any acquirer fees.
-
merchantCurrency
final Optional<String> merchantCurrency()
3-character alphabetic ISO 4217 currency code. Note: Simulator only accepts USD, GBP, EUR and defaults to GBP if another ISO 4217 code is provided
-
partialApprovalCapable
final Optional<Boolean> partialApprovalCapable()
Set to true if the terminal is capable of partial approval otherwise false. Partial approval is when part of a transaction is approved and another payment must be used for the remainder.
-
pin
final Optional<String> pin()
Simulate entering a PIN. If omitted, PIN check will not be performed.
-
status
final Optional<TransactionSimulateAuthorizationParams.Status> status()
Type of event to simulate.
AUTHORIZATIONis a dual message purchase authorization, meaning a subsequent clearing step is required to settle the transaction.BALANCE_INQUIRYis a $0 authorization requesting the balance held on the card, and is most often observed when a cardholder requests to view a card's balance at an ATM.CREDIT_AUTHORIZATIONis a dual message request from a merchant to authorize a refund, meaning a subsequent clearing step is required to settle the transaction.FINANCIAL_AUTHORIZATIONis a single message request from a merchant to debit funds immediately (such as an ATM withdrawal), and no subsequent clearing is required to settle the transaction.FINANCIAL_CREDIT_AUTHORIZATIONis a single message request from a merchant to credit funds immediately, and no subsequent clearing is required to settle the transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_mcc
final JsonField<String> _mcc()
Returns the raw JSON value of mcc.
Unlike mcc, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorCity
final JsonField<String> _merchantAcceptorCity()
Returns the raw JSON value of merchantAcceptorCity.
Unlike merchantAcceptorCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorCountry
final JsonField<String> _merchantAcceptorCountry()
Returns the raw JSON value of merchantAcceptorCountry.
Unlike merchantAcceptorCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorState
final JsonField<String> _merchantAcceptorState()
Returns the raw JSON value of merchantAcceptorState.
Unlike merchantAcceptorState, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAmount
final JsonField<Long> _merchantAmount()
Returns the raw JSON value of merchantAmount.
Unlike merchantAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCurrency
final JsonField<String> _merchantCurrency()
Returns the raw JSON value of merchantCurrency.
Unlike merchantCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_partialApprovalCapable
final JsonField<Boolean> _partialApprovalCapable()
Returns the raw JSON value of partialApprovalCapable.
Unlike partialApprovalCapable, this method doesn't throw if the JSON field has an unexpected type.
-
_pin
final JsonField<String> _pin()
Returns the raw JSON value of pin.
Unlike pin, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<TransactionSimulateAuthorizationParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateAuthorizationParams.Body.Builder toBuilder()
-
validate
final TransactionSimulateAuthorizationParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateAuthorizationParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .descriptor() .pan()
-
-
-
-