Package com.lithic.api.models
Class TransactionSimulateCreditAuthorizationAdviceResponse
-
- All Implemented Interfaces:
public final class TransactionSimulateCreditAuthorizationAdviceResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateCreditAuthorizationAdviceResponse.BuilderA builder for TransactionSimulateCreditAuthorizationAdviceResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>token()A unique token to reference this transaction. final Optional<String>debuggingRequestId()Debugging request ID to share with Lithic Support team. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_debuggingRequestId()Returns the raw JSON value of debuggingRequestId. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateCreditAuthorizationAdviceResponse.BuildertoBuilder()final TransactionSimulateCreditAuthorizationAdviceResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateCreditAuthorizationAdviceResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSimulateCreditAuthorizationAdviceResponse. -
-
Method Detail
-
debuggingRequestId
final Optional<String> debuggingRequestId()
Debugging request ID to share with Lithic Support team.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_debuggingRequestId
final JsonField<String> _debuggingRequestId()
Returns the raw JSON value of debuggingRequestId.
Unlike debuggingRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateCreditAuthorizationAdviceResponse.Builder toBuilder()
-
validate
final TransactionSimulateCreditAuthorizationAdviceResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateCreditAuthorizationAdviceResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSimulateCreditAuthorizationAdviceResponse.
-
-
-
-