Class TransactionSimulateCreditAuthorizationParams.Body
-
- All Implemented Interfaces:
public final class TransactionSimulateCreditAuthorizationParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateCreditAuthorizationParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount (in cents). final Stringdescriptor()Merchant descriptor. final Stringpan()Sixteen digit card number. final Optional<String>mcc()Merchant category code for the transaction to be simulated. final Optional<String>merchantAcceptorCity()Merchant acceptor city final Optional<String>merchantAcceptorCountry()Merchant acceptor country code (ISO 3166-1 alpha-3) final Optional<String>merchantAcceptorId()Unique identifier to identify the payment card acceptor. final Optional<String>merchantAcceptorState()Merchant acceptor state/province (ISO 3166-2 subdivision code) final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_pan()Returns the raw JSON value of pan. final JsonField<String>_mcc()Returns the raw JSON value of mcc. final JsonField<String>_merchantAcceptorCity()Returns the raw JSON value of merchantAcceptorCity. final JsonField<String>_merchantAcceptorCountry()Returns the raw JSON value of merchantAcceptorCountry. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantAcceptorState()Returns the raw JSON value of merchantAcceptorState. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateCreditAuthorizationParams.Body.BuildertoBuilder()final TransactionSimulateCreditAuthorizationParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateCreditAuthorizationParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Long amount()
Amount (in cents). Any value entered will be converted into a negative amount in the simulated transaction. For example, entering 100 in this field will appear as a -100 amount in the transaction.
-
descriptor
final String descriptor()
Merchant descriptor.
-
mcc
final Optional<String> mcc()
Merchant category code for the transaction to be simulated. A four-digit number listed in ISO 18245. Supported merchant category codes can be found here.
-
merchantAcceptorCity
final Optional<String> merchantAcceptorCity()
Merchant acceptor city
-
merchantAcceptorCountry
final Optional<String> merchantAcceptorCountry()
Merchant acceptor country code (ISO 3166-1 alpha-3)
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
Unique identifier to identify the payment card acceptor.
-
merchantAcceptorState
final Optional<String> merchantAcceptorState()
Merchant acceptor state/province (ISO 3166-2 subdivision code)
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_mcc
final JsonField<String> _mcc()
Returns the raw JSON value of mcc.
Unlike mcc, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorCity
final JsonField<String> _merchantAcceptorCity()
Returns the raw JSON value of merchantAcceptorCity.
Unlike merchantAcceptorCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorCountry
final JsonField<String> _merchantAcceptorCountry()
Returns the raw JSON value of merchantAcceptorCountry.
Unlike merchantAcceptorCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorState
final JsonField<String> _merchantAcceptorState()
Returns the raw JSON value of merchantAcceptorState.
Unlike merchantAcceptorState, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateCreditAuthorizationParams.Body.Builder toBuilder()
-
validate
final TransactionSimulateCreditAuthorizationParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateCreditAuthorizationParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .descriptor() .pan()
-
-
-
-