Package com.lithic.api.models
Class TransactionSimulateReturnParams.Body
-
- All Implemented Interfaces:
public final class TransactionSimulateReturnParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateReturnParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount (in cents) to authorize. final Stringdescriptor()Merchant descriptor. final Stringpan()Sixteen digit card number. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_descriptor()Returns the raw JSON value of descriptor. final JsonField<String>_pan()Returns the raw JSON value of pan. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateReturnParams.Body.BuildertoBuilder()final TransactionSimulateReturnParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateReturnParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
descriptor
final String descriptor()
Merchant descriptor.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<String> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateReturnParams.Body.Builder toBuilder()
-
validate
final TransactionSimulateReturnParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateReturnParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .descriptor() .pan()
-
-
-
-