Package com.lithic.api.models
Class TransactionSimulateReturnResponse
-
- All Implemented Interfaces:
public final class TransactionSimulateReturnResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateReturnResponse.BuilderA builder for TransactionSimulateReturnResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>token()A unique token to reference this transaction. final Optional<String>debuggingRequestId()Debugging request ID to share with Lithic Support team. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_debuggingRequestId()Returns the raw JSON value of debuggingRequestId. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateReturnResponse.BuildertoBuilder()final TransactionSimulateReturnResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateReturnResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSimulateReturnResponse. -
-
Method Detail
-
debuggingRequestId
final Optional<String> debuggingRequestId()
Debugging request ID to share with Lithic Support team.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_debuggingRequestId
final JsonField<String> _debuggingRequestId()
Returns the raw JSON value of debuggingRequestId.
Unlike debuggingRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateReturnResponse.Builder toBuilder()
-
validate
final TransactionSimulateReturnResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateReturnResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSimulateReturnResponse.
-
-
-
-