Package com.lithic.api.models
Class TransactionSimulateReturnReversalParams.Body
-
- All Implemented Interfaces:
public final class TransactionSimulateReturnReversalParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateReturnReversalParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringtoken()The transaction token returned from the /v1/simulate/authorize response. final JsonField<String>_token()Returns the raw JSON value of token. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateReturnReversalParams.Body.BuildertoBuilder()final TransactionSimulateReturnReversalParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateReturnReversalParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateReturnReversalParams.Body.Builder toBuilder()
-
validate
final TransactionSimulateReturnReversalParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateReturnReversalParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.token()
-
-
-
-