Package com.lithic.api.models
Class TransactionSimulateReturnReversalResponse
-
- All Implemented Interfaces:
public final class TransactionSimulateReturnReversalResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateReturnReversalResponse.BuilderA builder for TransactionSimulateReturnReversalResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>debuggingRequestId()Debugging request ID to share with Lithic Support team. final JsonField<String>_debuggingRequestId()Returns the raw JSON value of debuggingRequestId. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateReturnReversalResponse.BuildertoBuilder()final TransactionSimulateReturnReversalResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateReturnReversalResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSimulateReturnReversalResponse. -
-
Method Detail
-
debuggingRequestId
final Optional<String> debuggingRequestId()
Debugging request ID to share with Lithic Support team.
-
_debuggingRequestId
final JsonField<String> _debuggingRequestId()
Returns the raw JSON value of debuggingRequestId.
Unlike debuggingRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateReturnReversalResponse.Builder toBuilder()
-
validate
final TransactionSimulateReturnReversalResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateReturnReversalResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSimulateReturnReversalResponse.
-
-
-
-