Package com.lithic.api.models
Class TransactionSimulateVoidResponse
-
- All Implemented Interfaces:
public final class TransactionSimulateVoidResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionSimulateVoidResponse.BuilderA builder for TransactionSimulateVoidResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>debuggingRequestId()Debugging request ID to share with Lithic Support team. final JsonField<String>_debuggingRequestId()Returns the raw JSON value of debuggingRequestId. final Map<String, JsonValue>_additionalProperties()final TransactionSimulateVoidResponse.BuildertoBuilder()final TransactionSimulateVoidResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionSimulateVoidResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionSimulateVoidResponse. -
-
Method Detail
-
debuggingRequestId
final Optional<String> debuggingRequestId()
Debugging request ID to share with Lithic Support team.
-
_debuggingRequestId
final JsonField<String> _debuggingRequestId()
Returns the raw JSON value of debuggingRequestId.
Unlike debuggingRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransactionSimulateVoidResponse.Builder toBuilder()
-
validate
final TransactionSimulateVoidResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransactionSimulateVoidResponse.Builder builder()
Returns a mutable builder for constructing an instance of TransactionSimulateVoidResponse.
-
-
-
-