Class Transfer.Builder
-
- All Implemented Interfaces:
public final class Transfer.BuilderA builder for Transfer.
-
-
Method Summary
Modifier and Type Method Description final Transfer.Buildertoken(String token)Globally unique identifier for the transfer event. final Transfer.Buildertoken(JsonField<String> token)Sets Builder.token to an arbitrary JSON value. final Transfer.Buildercategory(Transfer.Category category)Status types: TRANSFER- Internal transfer of funds between financial accounts in your program.
final Transfer.Buildercategory(JsonField<Transfer.Category> category)Sets Builder.category to an arbitrary JSON value. final Transfer.Buildercreated(OffsetDateTime created)Date and time when the transfer occurred. final Transfer.Buildercreated(JsonField<OffsetDateTime> created)Sets Builder.created to an arbitrary JSON value. final Transfer.Buildercurrency(String currency)3-character alphabetic ISO 4217 code for the settling currency of the transaction. final Transfer.Buildercurrency(JsonField<String> currency)Sets Builder.currency to an arbitrary JSON value. final Transfer.Builderdescriptor(String descriptor)A string that provides a description of the transfer; may be useful to display to users. final Transfer.Builderdescriptor(JsonField<String> descriptor)Sets Builder.descriptor to an arbitrary JSON value. final Transfer.Builderevents(List<FinancialEvent> events)A list of all financial events that have modified this trasnfer. final Transfer.Builderevents(JsonField<List<FinancialEvent>> events)Sets Builder.events to an arbitrary JSON value. final Transfer.BuilderaddEvent(FinancialEvent event)Adds a single FinancialEvent to events. final Transfer.BuilderfromBalance(List<Balance> fromBalance)The updated balance of the sending financial account. final Transfer.BuilderfromBalance(JsonField<List<Balance>> fromBalance)Sets Builder.fromBalance to an arbitrary JSON value. final Transfer.BuilderaddFromBalance(Balance fromBalance)Adds a single Balance to Builder.fromBalance. final Transfer.BuilderpendingAmount(Long pendingAmount)Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. final Transfer.BuilderpendingAmount(JsonField<Long> pendingAmount)Sets Builder.pendingAmount to an arbitrary JSON value. final Transfer.Builderresult(Transfer.Result result)APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network. final Transfer.Builderresult(JsonField<Transfer.Result> result)Sets Builder.result to an arbitrary JSON value. final Transfer.BuildersettledAmount(Long settledAmount)Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents). final Transfer.BuildersettledAmount(JsonField<Long> settledAmount)Sets Builder.settledAmount to an arbitrary JSON value. final Transfer.Builderstatus(Transfer.Status status)Status types: DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
final Transfer.Builderstatus(JsonField<Transfer.Status> status)Sets Builder.status to an arbitrary JSON value. final Transfer.BuildertoBalance(List<Balance> toBalance)The updated balance of the receiving financial account. final Transfer.BuildertoBalance(JsonField<List<Balance>> toBalance)Sets Builder.toBalance to an arbitrary JSON value. final Transfer.BuilderaddToBalance(Balance toBalance)Adds a single Balance to Builder.toBalance. final Transfer.Builderupdated(OffsetDateTime updated)Date and time when the financial transaction was last updated. final Transfer.Builderupdated(JsonField<OffsetDateTime> updated)Sets Builder.updated to an arbitrary JSON value. final Transfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transfer.BuilderputAdditionalProperty(String key, JsonValue value)final Transfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transfer.BuilderremoveAdditionalProperty(String key)final Transfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transferbuild()Returns an immutable instance of Transfer. -
-
Method Detail
-
token
final Transfer.Builder token(String token)
Globally unique identifier for the transfer event.
-
token
final Transfer.Builder token(JsonField<String> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Transfer.Builder category(Transfer.Category category)
Status types:
TRANSFER- Internal transfer of funds between financial accounts in your program.
-
category
final Transfer.Builder category(JsonField<Transfer.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
created
final Transfer.Builder created(OffsetDateTime created)
Date and time when the transfer occurred. UTC time zone.
-
created
final Transfer.Builder created(JsonField<OffsetDateTime> created)
Sets Builder.created to an arbitrary JSON value.
You should usually call Builder.created with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transfer.Builder currency(String currency)
3-character alphabetic ISO 4217 code for the settling currency of the transaction.
-
currency
final Transfer.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
descriptor
final Transfer.Builder descriptor(String descriptor)
A string that provides a description of the transfer; may be useful to display to users.
-
descriptor
final Transfer.Builder descriptor(JsonField<String> descriptor)
Sets Builder.descriptor to an arbitrary JSON value.
You should usually call Builder.descriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
events
final Transfer.Builder events(List<FinancialEvent> events)
A list of all financial events that have modified this trasnfer.
-
events
final Transfer.Builder events(JsonField<List<FinancialEvent>> events)
Sets Builder.events to an arbitrary JSON value.
You should usually call Builder.events with a well-typed
List<FinancialEvent>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEvent
final Transfer.Builder addEvent(FinancialEvent event)
Adds a single FinancialEvent to events.
-
fromBalance
final Transfer.Builder fromBalance(List<Balance> fromBalance)
The updated balance of the sending financial account.
-
fromBalance
final Transfer.Builder fromBalance(JsonField<List<Balance>> fromBalance)
Sets Builder.fromBalance to an arbitrary JSON value.
You should usually call Builder.fromBalance with a well-typed
List<Balance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addFromBalance
final Transfer.Builder addFromBalance(Balance fromBalance)
Adds a single Balance to Builder.fromBalance.
-
pendingAmount
final Transfer.Builder pendingAmount(Long pendingAmount)
Pending amount of the transaction in the currency's smallest unit (e.g., cents), including any acquirer fees. The value of this field will go to zero over time once the financial transaction is settled.
-
pendingAmount
final Transfer.Builder pendingAmount(JsonField<Long> pendingAmount)
Sets Builder.pendingAmount to an arbitrary JSON value.
You should usually call Builder.pendingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final Transfer.Builder result(Transfer.Result result)
APPROVED transactions were successful while DECLINED transactions were declined by user, Lithic, or the network.
-
result
final Transfer.Builder result(JsonField<Transfer.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final Transfer.Builder settledAmount(Long settledAmount)
Amount of the transaction that has been settled in the currency's smallest unit (e.g., cents).
-
settledAmount
final Transfer.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Transfer.Builder status(Transfer.Status status)
Status types:
DECLINED- The transfer was declined.EXPIRED- The transfer was held in pending for too long and expired.PENDING- The transfer is pending release from a hold.SETTLED- The transfer is completed.VOIDED- The transfer was reversed before it settled.
-
status
final Transfer.Builder status(JsonField<Transfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
toBalance
final Transfer.Builder toBalance(List<Balance> toBalance)
The updated balance of the receiving financial account.
-
toBalance
final Transfer.Builder toBalance(JsonField<List<Balance>> toBalance)
Sets Builder.toBalance to an arbitrary JSON value.
You should usually call Builder.toBalance with a well-typed
List<Balance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addToBalance
final Transfer.Builder addToBalance(Balance toBalance)
Adds a single Balance to Builder.toBalance.
-
updated
final Transfer.Builder updated(OffsetDateTime updated)
Date and time when the financial transaction was last updated. UTC time zone.
-
updated
final Transfer.Builder updated(JsonField<OffsetDateTime> updated)
Sets Builder.updated to an arbitrary JSON value.
You should usually call Builder.updated with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-