Class TransferLimitListPageAsync
-
- All Implemented Interfaces:
-
com.lithic.api.core.PageAsync
public final class TransferLimitListPageAsync implements PageAsync<TransferLimitsResponse.TransferLimitItem>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransferLimitListPageAsync.BuilderA builder for TransferLimitListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<TransferLimitsResponse.TransferLimitItem>data()Delegates to TransferLimitsResponse, but gracefully handles missing data. final Optional<Boolean>hasMore()Delegates to TransferLimitsResponse, but gracefully handles missing data. List<TransferLimitsResponse.TransferLimitItem>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final TransferLimitListParamsnextPageParams()CompletableFuture<TransferLimitListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<TransferLimitsResponse.TransferLimitItem>autoPager()final TransferLimitListParamsparams()The parameters that were used to request this page. final TransferLimitsResponseresponse()The response that this page was parsed from. final TransferLimitListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransferLimitListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of TransferLimitListPageAsync. -
-
Method Detail
-
data
final List<TransferLimitsResponse.TransferLimitItem> data()
Delegates to TransferLimitsResponse, but gracefully handles missing data.
-
hasMore
final Optional<Boolean> hasMore()
Delegates to TransferLimitsResponse, but gracefully handles missing data.
-
items
List<TransferLimitsResponse.TransferLimitItem> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final TransferLimitListParams nextPageParams()
-
nextPage
CompletableFuture<TransferLimitListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<TransferLimitsResponse.TransferLimitItem> autoPager()
-
params
final TransferLimitListParams params()
The parameters that were used to request this page.
-
response
final TransferLimitsResponse response()
The response that this page was parsed from.
-
toBuilder
final TransferLimitListPageAsync.Builder toBuilder()
-
builder
final static TransferLimitListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of TransferLimitListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-