Class TransferLimitsResponse.TransferLimitItem
-
- All Implemented Interfaces:
public final class TransferLimitsResponse.TransferLimitItem
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransferLimitsResponse.TransferLimitItem.BuilderA builder for TransferLimitItem.
public final classTransferLimitsResponse.TransferLimitItem.DirectionalLimitsDaily limits with progress
-
Method Summary
-
-
Method Detail
-
dailyLimit
final TransferLimitsResponse.TransferLimitItem.DirectionalLimits dailyLimit()
Daily limits with progress
-
monthlyLimit
final TransferLimitsResponse.TransferLimitItem.DirectionalLimits monthlyLimit()
Monthly limits with progress
-
programLimitPerTransaction
final TransferLimitsResponse.TransferLimitItem.DirectionalLimits programLimitPerTransaction()
Program transaction limits
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyLimit
final JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> _dailyLimit()
Returns the raw JSON value of dailyLimit.
Unlike dailyLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_isFbo
final JsonField<Boolean> _isFbo()
Returns the raw JSON value of isFbo.
Unlike isFbo, this method doesn't throw if the JSON field has an unexpected type.
-
_monthlyLimit
final JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> _monthlyLimit()
Returns the raw JSON value of monthlyLimit.
Unlike monthlyLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_programLimitPerTransaction
final JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> _programLimitPerTransaction()
Returns the raw JSON value of programLimitPerTransaction.
Unlike programLimitPerTransaction, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TransferLimitsResponse.TransferLimitItem.Builder toBuilder()
-
validate
final TransferLimitsResponse.TransferLimitItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TransferLimitsResponse.TransferLimitItem.Builder builder()
Returns a mutable builder for constructing an instance of TransferLimitItem.
The following fields are required:
.companyId() .dailyLimit() .date() .isFbo() .monthlyLimit() .programLimitPerTransaction()
-
-
-
-