Class TransferLimitsResponse.TransferLimitItem.Builder
-
- All Implemented Interfaces:
public final class TransferLimitsResponse.TransferLimitItem.BuilderA builder for TransferLimitItem.
-
-
Method Summary
-
-
Method Detail
-
companyId
final TransferLimitsResponse.TransferLimitItem.Builder companyId(String companyId)
Company ID
-
companyId
final TransferLimitsResponse.TransferLimitItem.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dailyLimit
final TransferLimitsResponse.TransferLimitItem.Builder dailyLimit(TransferLimitsResponse.TransferLimitItem.DirectionalLimits dailyLimit)
Daily limits with progress
-
dailyLimit
final TransferLimitsResponse.TransferLimitItem.Builder dailyLimit(JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> dailyLimit)
Sets Builder.dailyLimit to an arbitrary JSON value.
You should usually call Builder.dailyLimit with a well-typed DirectionalLimits value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
date
final TransferLimitsResponse.TransferLimitItem.Builder date(LocalDate date)
The date for the limit view (ISO format)
-
date
final TransferLimitsResponse.TransferLimitItem.Builder date(JsonField<LocalDate> date)
Sets Builder.date to an arbitrary JSON value.
You should usually call Builder.date with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isFbo
final TransferLimitsResponse.TransferLimitItem.Builder isFbo(Boolean isFbo)
Whether the company is a FBO; based on the company ID prefix
-
isFbo
final TransferLimitsResponse.TransferLimitItem.Builder isFbo(JsonField<Boolean> isFbo)
Sets Builder.isFbo to an arbitrary JSON value.
You should usually call Builder.isFbo with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
monthlyLimit
final TransferLimitsResponse.TransferLimitItem.Builder monthlyLimit(TransferLimitsResponse.TransferLimitItem.DirectionalLimits monthlyLimit)
Monthly limits with progress
-
monthlyLimit
final TransferLimitsResponse.TransferLimitItem.Builder monthlyLimit(JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> monthlyLimit)
Sets Builder.monthlyLimit to an arbitrary JSON value.
You should usually call Builder.monthlyLimit with a well-typed DirectionalLimits value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programLimitPerTransaction
final TransferLimitsResponse.TransferLimitItem.Builder programLimitPerTransaction(TransferLimitsResponse.TransferLimitItem.DirectionalLimits programLimitPerTransaction)
Program transaction limits
-
programLimitPerTransaction
final TransferLimitsResponse.TransferLimitItem.Builder programLimitPerTransaction(JsonField<TransferLimitsResponse.TransferLimitItem.DirectionalLimits> programLimitPerTransaction)
Sets Builder.programLimitPerTransaction to an arbitrary JSON value.
You should usually call Builder.programLimitPerTransaction with a well-typed DirectionalLimits value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransferLimitsResponse.TransferLimitItem.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransferLimitsResponse.TransferLimitItem.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransferLimitsResponse.TransferLimitItem.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransferLimitsResponse.TransferLimitItem.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransferLimitsResponse.TransferLimitItem.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransferLimitsResponse.TransferLimitItem build()
Returns an immutable instance of TransferLimitItem.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.companyId() .dailyLimit() .date() .isFbo() .monthlyLimit() .programLimitPerTransaction()
-
-
-
-