Class V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction
-
- All Implemented Interfaces:
public final class V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.BuilderA builder for CreateCaseAction.
public final classV2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.ScopeThe scope of the case to create
public final classV2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.TypeCreate a case for the transaction
-
Method Summary
-
-
Method Detail
-
queueToken
final String queueToken()
The token of the queue to create the case in
-
scope
final V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Scope scope()
The scope of the case to create
-
type
final V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Type type()
Create a case for the transaction
-
explanation
final Optional<String> explanation()
Optional explanation for why this action was taken
-
_queueToken
final JsonField<String> _queueToken()
Returns the raw JSON value of queueToken.
Unlike queueToken, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_explanation
final JsonField<String> _explanation()
Returns the raw JSON value of explanation.
Unlike explanation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Builder toBuilder()
-
validate
final V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2ListResultsResponse.CardTransactionUpdateResult.Action.CreateCaseAction.Builder builder()
Returns a mutable builder for constructing an instance of CreateCaseAction.
The following fields are required:
.queueToken() .scope() .type()
-
-
-
-