Class V2ListResultsResponse.TokenizationResult
-
- All Implemented Interfaces:
public final class V2ListResultsResponse.TokenizationResult
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ListResultsResponse.TokenizationResult.BuilderA builder for TokenizationResult.
public final classV2ListResultsResponse.TokenizationResult.Actionpublic final classV2ListResultsResponse.TokenizationResult.EventStreamThe event stream during which the rule was evaluated
public final classV2ListResultsResponse.TokenizationResult.AuthRuleStateThe state of the Auth Rule
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier for the evaluation final List<V2ListResultsResponse.TokenizationResult.Action>actions()Actions returned by the rule evaluation final StringauthRuleToken()The Auth Rule token final OffsetDateTimeevaluationTime()Timestamp of the rule evaluation final V2ListResultsResponse.TokenizationResult.EventStreameventStream()The event stream during which the rule was evaluated final StringeventToken()Token of the event that triggered the evaluation final V2ListResultsResponse.TokenizationResult.AuthRuleStatemode()The state of the Auth Rule final LongruleVersion()Version of the rule that was evaluated final Optional<String>transactionToken()The token of the transaction that triggered the rule evaluation final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<List<V2ListResultsResponse.TokenizationResult.Action>>_actions()Returns the raw JSON value of actions. final JsonField<String>_authRuleToken()Returns the raw JSON value of authRuleToken. final JsonField<OffsetDateTime>_evaluationTime()Returns the raw JSON value of evaluationTime. final JsonField<V2ListResultsResponse.TokenizationResult.EventStream>_eventStream()Returns the raw JSON value of eventStream. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<V2ListResultsResponse.TokenizationResult.AuthRuleState>_mode()Returns the raw JSON value of mode. final JsonField<Long>_ruleVersion()Returns the raw JSON value of ruleVersion. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final Map<String, JsonValue>_additionalProperties()final V2ListResultsResponse.TokenizationResult.BuildertoBuilder()final V2ListResultsResponse.TokenizationResultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2ListResultsResponse.TokenizationResult.Builderbuilder()Returns a mutable builder for constructing an instance of TokenizationResult. -
-
Method Detail
-
actions
final List<V2ListResultsResponse.TokenizationResult.Action> actions()
Actions returned by the rule evaluation
-
authRuleToken
final String authRuleToken()
The Auth Rule token
-
evaluationTime
final OffsetDateTime evaluationTime()
Timestamp of the rule evaluation
-
eventStream
final V2ListResultsResponse.TokenizationResult.EventStream eventStream()
The event stream during which the rule was evaluated
-
eventToken
final String eventToken()
Token of the event that triggered the evaluation
-
mode
final V2ListResultsResponse.TokenizationResult.AuthRuleState mode()
The state of the Auth Rule
-
ruleVersion
final Long ruleVersion()
Version of the rule that was evaluated
-
transactionToken
final Optional<String> transactionToken()
The token of the transaction that triggered the rule evaluation
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_actions
final JsonField<List<V2ListResultsResponse.TokenizationResult.Action>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_evaluationTime
final JsonField<OffsetDateTime> _evaluationTime()
Returns the raw JSON value of evaluationTime.
Unlike evaluationTime, this method doesn't throw if the JSON field has an unexpected type.
-
_eventStream
final JsonField<V2ListResultsResponse.TokenizationResult.EventStream> _eventStream()
Returns the raw JSON value of eventStream.
Unlike eventStream, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_mode
final JsonField<V2ListResultsResponse.TokenizationResult.AuthRuleState> _mode()
Returns the raw JSON value of mode.
Unlike mode, this method doesn't throw if the JSON field has an unexpected type.
-
_ruleVersion
final JsonField<Long> _ruleVersion()
Returns the raw JSON value of ruleVersion.
Unlike ruleVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2ListResultsResponse.TokenizationResult.Builder toBuilder()
-
validate
final V2ListResultsResponse.TokenizationResult validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2ListResultsResponse.TokenizationResult.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationResult.
The following fields are required:
.token() .actions() .authRuleToken() .evaluationTime() .eventStream() .eventToken() .mode() .ruleVersion() .transactionToken()
-
-
-
-