Package com.lithic.api.models
Class V2ListVersionsResponse
-
- All Implemented Interfaces:
public final class V2ListVersionsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ListVersionsResponse.BuilderA builder for V2ListVersionsResponse.
-
Method Summary
Modifier and Type Method Description final List<AuthRuleVersion>data()final JsonField<List<AuthRuleVersion>>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final V2ListVersionsResponse.BuildertoBuilder()final V2ListVersionsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2ListVersionsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2ListVersionsResponse. -
-
Method Detail
-
data
final List<AuthRuleVersion> data()
-
_data
final JsonField<List<AuthRuleVersion>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2ListVersionsResponse.Builder toBuilder()
-
validate
final V2ListVersionsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2ListVersionsResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2ListVersionsResponse.
The following fields are required:
.data()
-
-
-
-