Class V2RetrieveReportResponse
-
- All Implemented Interfaces:
public final class V2RetrieveReportResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveReportResponse.BuilderA builder for V2RetrieveReportResponse.
public final classV2RetrieveReportResponse.DailyStatistic
-
Method Summary
Modifier and Type Method Description final StringauthRuleToken()Auth Rule Token final LocalDatebegin()The start date (UTC) of the report. final List<V2RetrieveReportResponse.DailyStatistic>dailyStatistics()Daily evaluation statistics for the Auth Rule. final LocalDateend()The end date (UTC) of the report. final JsonField<String>_authRuleToken()Returns the raw JSON value of authRuleToken. final JsonField<LocalDate>_begin()Returns the raw JSON value of begin. final JsonField<List<V2RetrieveReportResponse.DailyStatistic>>_dailyStatistics()Returns the raw JSON value of dailyStatistics. final JsonField<LocalDate>_end()Returns the raw JSON value of end. final Map<String, JsonValue>_additionalProperties()final V2RetrieveReportResponse.BuildertoBuilder()final V2RetrieveReportResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2RetrieveReportResponse.Builderbuilder()Returns a mutable builder for constructing an instance of V2RetrieveReportResponse. -
-
Method Detail
-
authRuleToken
final String authRuleToken()
Auth Rule Token
-
dailyStatistics
final List<V2RetrieveReportResponse.DailyStatistic> dailyStatistics()
Daily evaluation statistics for the Auth Rule.
-
_authRuleToken
final JsonField<String> _authRuleToken()
Returns the raw JSON value of authRuleToken.
Unlike authRuleToken, this method doesn't throw if the JSON field has an unexpected type.
-
_begin
final JsonField<LocalDate> _begin()
Returns the raw JSON value of begin.
Unlike begin, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyStatistics
final JsonField<List<V2RetrieveReportResponse.DailyStatistic>> _dailyStatistics()
Returns the raw JSON value of dailyStatistics.
Unlike dailyStatistics, this method doesn't throw if the JSON field has an unexpected type.
-
_end
final JsonField<LocalDate> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveReportResponse.Builder toBuilder()
-
validate
final V2RetrieveReportResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static V2RetrieveReportResponse.Builder builder()
Returns a mutable builder for constructing an instance of V2RetrieveReportResponse.
The following fields are required:
.authRuleToken() .begin() .dailyStatistics() .end()
-
-
-
-