Package com.lithic.api.models
Class V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example
-
- All Implemented Interfaces:
public final class V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example.BuilderA builder for Example.
public final classV2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example.Action
-
Method Summary
-
-
Method Detail
-
actions
final List<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example.Action> actions()
The actions taken by this version for this event.
-
eventToken
final String eventToken()
The event token.
-
timestamp
final OffsetDateTime timestamp()
The timestamp of the event.
-
_actions
final JsonField<List<V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example.Action>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example validate()
-
builder
final static V2RetrieveReportResponse.DailyStatistic.ReportStatsV2.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
The following fields are required:
.actions() .eventToken() .timestamp()
-
-
-
-