Package com.lithic.api.models
Class VelocityLimitPeriod.FixedWindowDay.Builder
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowDay.BuilderA builder for FixedWindowDay.
-
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriod.FixedWindowDay.Buildertype(VelocityLimitPeriod.FixedWindowDay.Type type)final VelocityLimitPeriod.FixedWindowDay.Buildertype(JsonField<VelocityLimitPeriod.FixedWindowDay.Type> type)Sets Builder.type to an arbitrary JSON value. final VelocityLimitPeriod.FixedWindowDay.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final VelocityLimitPeriod.FixedWindowDay.BuilderputAdditionalProperty(String key, JsonValue value)final VelocityLimitPeriod.FixedWindowDay.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final VelocityLimitPeriod.FixedWindowDay.BuilderremoveAdditionalProperty(String key)final VelocityLimitPeriod.FixedWindowDay.BuilderremoveAllAdditionalProperties(Set<String> keys)final VelocityLimitPeriod.FixedWindowDaybuild()Returns an immutable instance of FixedWindowDay. -
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowDay.Builder type(VelocityLimitPeriod.FixedWindowDay.Type type)
-
type
final VelocityLimitPeriod.FixedWindowDay.Builder type(JsonField<VelocityLimitPeriod.FixedWindowDay.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VelocityLimitPeriod.FixedWindowDay.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VelocityLimitPeriod.FixedWindowDay.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VelocityLimitPeriod.FixedWindowDay.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VelocityLimitPeriod.FixedWindowDay.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VelocityLimitPeriod.FixedWindowDay.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VelocityLimitPeriod.FixedWindowDay build()
Returns an immutable instance of FixedWindowDay.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-