Class VelocityLimitPeriod.FixedWindowMonth
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowMonthVelocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitPeriod.FixedWindowMonth.BuilderA builder for FixedWindowMonth.
public final classVelocityLimitPeriod.FixedWindowMonth.Type
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriod.FixedWindowMonth.Typetype()final Optional<Long>dayOfMonth()The day of the month to start from. final JsonField<VelocityLimitPeriod.FixedWindowMonth.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_dayOfMonth()Returns the raw JSON value of dayOfMonth. final Map<String, JsonValue>_additionalProperties()final VelocityLimitPeriod.FixedWindowMonth.BuildertoBuilder()final VelocityLimitPeriod.FixedWindowMonthvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitPeriod.FixedWindowMonth.Builderbuilder()Returns a mutable builder for constructing an instance of FixedWindowMonth. -
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowMonth.Type type()
-
dayOfMonth
final Optional<Long> dayOfMonth()
The day of the month to start from. Accepts values from 1 to 31, and will reset at the end of the month if the day exceeds the number of days in the month. Defaults to the 1st of the month if not specified.
-
_type
final JsonField<VelocityLimitPeriod.FixedWindowMonth.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_dayOfMonth
final JsonField<Long> _dayOfMonth()
Returns the raw JSON value of dayOfMonth.
Unlike dayOfMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitPeriod.FixedWindowMonth.Builder toBuilder()
-
validate
final VelocityLimitPeriod.FixedWindowMonth validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VelocityLimitPeriod.FixedWindowMonth.Builder builder()
Returns a mutable builder for constructing an instance of FixedWindowMonth.
The following fields are required:
.type()
-
-
-
-