Class VelocityLimitPeriod.FixedWindowMonth.Builder
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowMonth.BuilderA builder for FixedWindowMonth.
-
-
Method Summary
-
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowMonth.Builder type(VelocityLimitPeriod.FixedWindowMonth.Type type)
-
type
final VelocityLimitPeriod.FixedWindowMonth.Builder type(JsonField<VelocityLimitPeriod.FixedWindowMonth.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dayOfMonth
final VelocityLimitPeriod.FixedWindowMonth.Builder dayOfMonth(Long dayOfMonth)
The day of the month to start from. Accepts values from 1 to 31, and will reset at the end of the month if the day exceeds the number of days in the month. Defaults to the 1st of the month if not specified.
-
dayOfMonth
final VelocityLimitPeriod.FixedWindowMonth.Builder dayOfMonth(JsonField<Long> dayOfMonth)
Sets Builder.dayOfMonth to an arbitrary JSON value.
You should usually call Builder.dayOfMonth with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VelocityLimitPeriod.FixedWindowMonth.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VelocityLimitPeriod.FixedWindowMonth.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VelocityLimitPeriod.FixedWindowMonth.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VelocityLimitPeriod.FixedWindowMonth.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VelocityLimitPeriod.FixedWindowMonth.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VelocityLimitPeriod.FixedWindowMonth build()
Returns an immutable instance of FixedWindowMonth.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-