Class VelocityLimitPeriod.FixedWindowWeek
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.FixedWindowWeekVelocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_week
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitPeriod.FixedWindowWeek.BuilderA builder for FixedWindowWeek.
public final classVelocityLimitPeriod.FixedWindowWeek.Type
-
Method Summary
Modifier and Type Method Description final VelocityLimitPeriod.FixedWindowWeek.Typetype()final Optional<Long>dayOfWeek()The day of the week to start the week from. final JsonField<VelocityLimitPeriod.FixedWindowWeek.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_dayOfWeek()Returns the raw JSON value of dayOfWeek. final Map<String, JsonValue>_additionalProperties()final VelocityLimitPeriod.FixedWindowWeek.BuildertoBuilder()final VelocityLimitPeriod.FixedWindowWeekvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitPeriod.FixedWindowWeek.Builderbuilder()Returns a mutable builder for constructing an instance of FixedWindowWeek. -
-
Method Detail
-
type
final VelocityLimitPeriod.FixedWindowWeek.Type type()
-
dayOfWeek
final Optional<Long> dayOfWeek()
The day of the week to start the week from. Following ISO-8601, 1 is Monday and 7 is Sunday. Defaults to Monday if not specified.
-
_type
final JsonField<VelocityLimitPeriod.FixedWindowWeek.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_dayOfWeek
final JsonField<Long> _dayOfWeek()
Returns the raw JSON value of dayOfWeek.
Unlike dayOfWeek, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitPeriod.FixedWindowWeek.Builder toBuilder()
-
validate
final VelocityLimitPeriod.FixedWindowWeek validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VelocityLimitPeriod.FixedWindowWeek.Builder builder()
Returns a mutable builder for constructing an instance of FixedWindowWeek.
The following fields are required:
.type()
-
-
-
-