Package com.lithic.api.models
Class VelocityLimitPeriod.TrailingWindowObject
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.TrailingWindowObject
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVelocityLimitPeriod.TrailingWindowObject.BuilderA builder for TrailingWindowObject.
public final classVelocityLimitPeriod.TrailingWindowObject.Type
-
Method Summary
Modifier and Type Method Description final Longduration()The size of the trailing window to calculate Spend Velocity over in seconds. final VelocityLimitPeriod.TrailingWindowObject.Typetype()final JsonField<Long>_duration()Returns the raw JSON value of duration. final JsonField<VelocityLimitPeriod.TrailingWindowObject.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final VelocityLimitPeriod.TrailingWindowObject.BuildertoBuilder()final VelocityLimitPeriod.TrailingWindowObjectvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VelocityLimitPeriod.TrailingWindowObject.Builderbuilder()Returns a mutable builder for constructing an instance of TrailingWindowObject. -
-
Method Detail
-
duration
final Long duration()
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
type
final VelocityLimitPeriod.TrailingWindowObject.Type type()
-
_duration
final JsonField<Long> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<VelocityLimitPeriod.TrailingWindowObject.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VelocityLimitPeriod.TrailingWindowObject.Builder toBuilder()
-
validate
final VelocityLimitPeriod.TrailingWindowObject validate()
-
builder
final static VelocityLimitPeriod.TrailingWindowObject.Builder builder()
Returns a mutable builder for constructing an instance of TrailingWindowObject.
The following fields are required:
.duration() .type()
-
-
-
-