Class VelocityLimitPeriod.TrailingWindowObject.Builder
-
- All Implemented Interfaces:
public final class VelocityLimitPeriod.TrailingWindowObject.BuilderA builder for TrailingWindowObject.
-
-
Method Summary
-
-
Method Detail
-
duration
final VelocityLimitPeriod.TrailingWindowObject.Builder duration(Long duration)
The size of the trailing window to calculate Spend Velocity over in seconds. The minimum value is 10 seconds, and the maximum value is 2678400 seconds (31 days).
-
duration
final VelocityLimitPeriod.TrailingWindowObject.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final VelocityLimitPeriod.TrailingWindowObject.Builder type(VelocityLimitPeriod.TrailingWindowObject.Type type)
-
type
final VelocityLimitPeriod.TrailingWindowObject.Builder type(JsonField<VelocityLimitPeriod.TrailingWindowObject.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VelocityLimitPeriod.TrailingWindowObject.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VelocityLimitPeriod.TrailingWindowObject.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VelocityLimitPeriod.TrailingWindowObject.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VelocityLimitPeriod.TrailingWindowObject.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VelocityLimitPeriod.TrailingWindowObject.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VelocityLimitPeriod.TrailingWindowObject build()
Returns an immutable instance of TrailingWindowObject.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.duration() .type()
-
-
-
-