Interface VelocityLimitPeriod.Visitor
-
- All Implemented Interfaces:
public interface VelocityLimitPeriod.Visitor<T extends Object>An interface that defines how to map each variant of VelocityLimitPeriod to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitTrailingWindowObject(VelocityLimitPeriod.TrailingWindowObject trailingWindowObject)abstract TvisitFixedWindowDay(VelocityLimitPeriod.FixedWindowDay fixedWindowDay)Velocity over the current day since 00:00 / 12 AM in Eastern Time abstract TvisitFixedWindowWeek(VelocityLimitPeriod.FixedWindowWeek fixedWindowWeek)Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified day_of_weekabstract TvisitFixedWindowMonth(VelocityLimitPeriod.FixedWindowMonth fixedWindowMonth)Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified day_of_month.abstract TvisitFixedWindowYear(VelocityLimitPeriod.FixedWindowYear fixedWindowYear)Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified monthandday_of_month.Tunknown(JsonValue json)Maps an unknown variant of VelocityLimitPeriod to a value of type T. -
-
Method Detail
-
visitTrailingWindowObject
abstract T visitTrailingWindowObject(VelocityLimitPeriod.TrailingWindowObject trailingWindowObject)
-
visitFixedWindowDay
abstract T visitFixedWindowDay(VelocityLimitPeriod.FixedWindowDay fixedWindowDay)
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
visitFixedWindowWeek
abstract T visitFixedWindowWeek(VelocityLimitPeriod.FixedWindowWeek fixedWindowWeek)
Velocity over the current week since 00:00 / 12 AM in Eastern Time on specified
day_of_week
-
visitFixedWindowMonth
abstract T visitFixedWindowMonth(VelocityLimitPeriod.FixedWindowMonth fixedWindowMonth)
Velocity over the current month since 00:00 / 12 AM in Eastern Time on specified
day_of_month.
-
visitFixedWindowYear
abstract T visitFixedWindowYear(VelocityLimitPeriod.FixedWindowYear fixedWindowYear)
Velocity over the current year since 00:00 / 12 AM in Eastern Time on specified
monthandday_of_month. This validates the month and day of the year to start from is a real date. In the event that February 29th is selected, in non-leap years, the window will start from February 28th.
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of VelocityLimitPeriod to a value of type T.
An instance of VelocityLimitPeriod can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-