Class WalletDecisioningInfo
-
- All Implemented Interfaces:
public final class WalletDecisioningInfo
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWalletDecisioningInfo.BuilderA builder for WalletDecisioningInfo.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountScore()Score given to the account by the Wallet Provider final Optional<String>deviceScore()Score given to the device by the Wallet Provider final Optional<String>recommendedDecision()The decision recommended by the Wallet Provider final Optional<List<String>>recommendationReasons()Reasons provided to the Wallet Provider on how the recommended decision was reached final JsonField<String>_accountScore()Returns the raw JSON value of accountScore. final JsonField<String>_deviceScore()Returns the raw JSON value of deviceScore. final JsonField<String>_recommendedDecision()Returns the raw JSON value of recommendedDecision. final JsonField<List<String>>_recommendationReasons()Returns the raw JSON value of recommendationReasons. final Map<String, JsonValue>_additionalProperties()final WalletDecisioningInfo.BuildertoBuilder()final WalletDecisioningInfovalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WalletDecisioningInfo.Builderbuilder()Returns a mutable builder for constructing an instance of WalletDecisioningInfo. -
-
Method Detail
-
accountScore
final Optional<String> accountScore()
Score given to the account by the Wallet Provider
-
deviceScore
final Optional<String> deviceScore()
Score given to the device by the Wallet Provider
-
recommendedDecision
final Optional<String> recommendedDecision()
The decision recommended by the Wallet Provider
-
recommendationReasons
final Optional<List<String>> recommendationReasons()
Reasons provided to the Wallet Provider on how the recommended decision was reached
-
_accountScore
final JsonField<String> _accountScore()
Returns the raw JSON value of accountScore.
Unlike accountScore, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceScore
final JsonField<String> _deviceScore()
Returns the raw JSON value of deviceScore.
Unlike deviceScore, this method doesn't throw if the JSON field has an unexpected type.
-
_recommendedDecision
final JsonField<String> _recommendedDecision()
Returns the raw JSON value of recommendedDecision.
Unlike recommendedDecision, this method doesn't throw if the JSON field has an unexpected type.
-
_recommendationReasons
final JsonField<List<String>> _recommendationReasons()
Returns the raw JSON value of recommendationReasons.
Unlike recommendationReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WalletDecisioningInfo.Builder toBuilder()
-
validate
final WalletDecisioningInfo validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WalletDecisioningInfo.Builder builder()
Returns a mutable builder for constructing an instance of WalletDecisioningInfo.
The following fields are required:
.accountScore() .deviceScore() .recommendedDecision()
-
-
-
-