Interface AccountHolderServiceAsync
-
- All Implemented Interfaces:
public interface AccountHolderServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountHolderServiceAsync.WithRawResponseA view of AccountHolderServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountHolderServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountHolderServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
entities
abstract EntityServiceAsync entities()
-
create
CompletableFuture<AccountHolderCreateResponse> create(AccountHolderCreateParams params)
Create an account holder and initiate the appropriate onboarding workflow. Account holders and accounts have a 1:1 relationship. When an account holder is successfully created an associated account is also created. All calls to this endpoint will return a synchronous response. The response time will depend on the workflow. In some cases, the response may indicate the workflow is under review or further action will be needed to complete the account creation process. This endpoint can only be used on accounts that are part of the program that the calling API key manages.
-
create
abstract CompletableFuture<AccountHolderCreateResponse> create(AccountHolderCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(AccountHolderCreateParams.Body body, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(Kyb kyb, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(Kyb kyb)
-
create
CompletableFuture<AccountHolderCreateResponse> create(AccountHolderCreateParams.Body.KybDelegated kybDelegated, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(AccountHolderCreateParams.Body.KybDelegated kybDelegated)
-
create
CompletableFuture<AccountHolderCreateResponse> create(Kyc kyc, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(Kyc kyc)
-
create
CompletableFuture<AccountHolderCreateResponse> create(KycExempt kycExempt, RequestOptions requestOptions)
-
create
CompletableFuture<AccountHolderCreateResponse> create(KycExempt kycExempt)
-
retrieve
CompletableFuture<AccountHolder> retrieve(String accountHolderToken)
Get an Individual or Business Account Holder and/or their KYC or KYB evaluation status.
-
retrieve
CompletableFuture<AccountHolder> retrieve(String accountHolderToken, AccountHolderRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AccountHolder> retrieve(String accountHolderToken, AccountHolderRetrieveParams params)
-
retrieve
abstract CompletableFuture<AccountHolder> retrieve(AccountHolderRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AccountHolder> retrieve(AccountHolderRetrieveParams params)
-
retrieve
CompletableFuture<AccountHolder> retrieve(String accountHolderToken, RequestOptions requestOptions)
-
update
CompletableFuture<AccountHolderUpdateResponse> update(String accountHolderToken, AccountHolderUpdateParams params)
Update the information associated with a particular account holder (including business owners and control persons associated to a business account). If Lithic is performing KYB or KYC and additional verification is required we will run the individual's or business's updated information again and return whether the status is accepted or pending (i.e., further action required). All calls to this endpoint will return a synchronous response. The response time will depend on the workflow. In some cases, the response may indicate the workflow is under review or further action will be needed to complete the account creation process. This endpoint can only be used on existing accounts that are part of the program that the calling API key manages.
-
update
CompletableFuture<AccountHolderUpdateResponse> update(String accountHolderToken, AccountHolderUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AccountHolderUpdateResponse> update(AccountHolderUpdateParams params)
-
update
abstract CompletableFuture<AccountHolderUpdateResponse> update(AccountHolderUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountHolderListPageAsync> list()
Get a list of individual or business account holders and their KYC or KYB evaluation status.
-
list
abstract CompletableFuture<AccountHolderListPageAsync> list(AccountHolderListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountHolderListPageAsync> list(RequestOptions requestOptions)
-
listDocuments
CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(String accountHolderToken)
Retrieve the status of account holder document uploads, or retrieve the upload URLs to process your image uploads.
Note that this is not equivalent to checking the status of the KYC evaluation overall (a document may be successfully uploaded but not be sufficient for KYC to pass).
In the event your upload URLs have expired, calling this endpoint will refresh them. Similarly, in the event a previous account holder document upload has failed, you can use this endpoint to get a new upload URL for the failed image upload.
When a new document upload is generated for a failed attempt, the response will show an additional entry in the
required_document_uploadslist in aPENDINGstate for the correspondingimage_type.
-
listDocuments
CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(String accountHolderToken, AccountHolderListDocumentsParams params, RequestOptions requestOptions)
-
listDocuments
CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(String accountHolderToken, AccountHolderListDocumentsParams params)
-
listDocuments
abstract CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(AccountHolderListDocumentsParams params, RequestOptions requestOptions)
-
listDocuments
CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(AccountHolderListDocumentsParams params)
-
listDocuments
CompletableFuture<AccountHolderListDocumentsResponse> listDocuments(String accountHolderToken, RequestOptions requestOptions)
-
retrieveDocument
CompletableFuture<Document> retrieveDocument(String documentToken, AccountHolderRetrieveDocumentParams params)
Check the status of an account holder document upload, or retrieve the upload URLs to process your image uploads.
Note that this is not equivalent to checking the status of the KYC evaluation overall (a document may be successfully uploaded but not be sufficient for KYC to pass).
In the event your upload URLs have expired, calling this endpoint will refresh them. Similarly, in the event a document upload has failed, you can use this endpoint to get a new upload URL for the failed image upload.
When a new account holder document upload is generated for a failed attempt, the response will show an additional entry in the
required_document_uploadsarray in aPENDINGstate for the correspondingimage_type.
-
retrieveDocument
CompletableFuture<Document> retrieveDocument(String documentToken, AccountHolderRetrieveDocumentParams params, RequestOptions requestOptions)
-
retrieveDocument
CompletableFuture<Document> retrieveDocument(AccountHolderRetrieveDocumentParams params)
-
retrieveDocument
abstract CompletableFuture<Document> retrieveDocument(AccountHolderRetrieveDocumentParams params, RequestOptions requestOptions)
-
simulateEnrollmentDocumentReview
CompletableFuture<Document> simulateEnrollmentDocumentReview(AccountHolderSimulateEnrollmentDocumentReviewParams params)
Simulates a review for an account holder document upload.
-
simulateEnrollmentDocumentReview
abstract CompletableFuture<Document> simulateEnrollmentDocumentReview(AccountHolderSimulateEnrollmentDocumentReviewParams params, RequestOptions requestOptions)
-
simulateEnrollmentReview
CompletableFuture<AccountHolderSimulateEnrollmentReviewResponse> simulateEnrollmentReview()
Simulates an enrollment review for an account holder. This endpoint is only applicable for workflows that may required intervention such as
KYB_BASIC.
-
simulateEnrollmentReview
abstract CompletableFuture<AccountHolderSimulateEnrollmentReviewResponse> simulateEnrollmentReview(AccountHolderSimulateEnrollmentReviewParams params, RequestOptions requestOptions)
-
simulateEnrollmentReview
CompletableFuture<AccountHolderSimulateEnrollmentReviewResponse> simulateEnrollmentReview(AccountHolderSimulateEnrollmentReviewParams params)
-
simulateEnrollmentReview
CompletableFuture<AccountHolderSimulateEnrollmentReviewResponse> simulateEnrollmentReview(RequestOptions requestOptions)
-
uploadDocument
CompletableFuture<Document> uploadDocument(String accountHolderToken, AccountHolderUploadDocumentParams params)
Use this endpoint to identify which type of supported government-issued documentation you will upload for further verification. It will return two URLs to upload your document images to - one for the front image and one for the back image.
This endpoint is only valid for evaluations in a
PENDING_DOCUMENTstate.Supported file types include
jpg,png, andpdf. Each file must be less than 15 MiB. Once both required uploads have been successfully completed, your document will be run through KYC verification.If you have registered a webhook, you will receive evaluation updates for any document submission evaluations, as well as for any failed document uploads.
Two document submission attempts are permitted via this endpoint before a
REJECTEDstatus is returned and the account creation process is ended. Currently only one type of account holder document is supported per KYC verification.
-
uploadDocument
CompletableFuture<Document> uploadDocument(String accountHolderToken, AccountHolderUploadDocumentParams params, RequestOptions requestOptions)
-
uploadDocument
CompletableFuture<Document> uploadDocument(AccountHolderUploadDocumentParams params)
-
uploadDocument
abstract CompletableFuture<Document> uploadDocument(AccountHolderUploadDocumentParams params, RequestOptions requestOptions)
-
-
-
-