Package com.lithic.api.services.async
Interface CardAuthorizationServiceAsync
-
- All Implemented Interfaces:
public interface CardAuthorizationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardAuthorizationServiceAsync.WithRawResponseA view of CardAuthorizationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardAuthorizationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)Card program's response to Authorization Challenge. CompletableFuture<Void>challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)CompletableFuture<Void>challengeResponse(CardAuthorizationChallengeResponseParams params)abstract CompletableFuture<Void>challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardAuthorizationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardAuthorizationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
CompletableFuture<Void> challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)
Card program's response to Authorization Challenge. Programs that have Authorization Challenges configured as Out of Band receive a card_authorization.challenge webhook when an authorization attempt triggers a challenge. The card program should respond using this endpoint after the cardholder completes the challenge.
-
challengeResponse
CompletableFuture<Void> challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
challengeResponse
CompletableFuture<Void> challengeResponse(CardAuthorizationChallengeResponseParams params)
-
challengeResponse
abstract CompletableFuture<Void> challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-