Package com.lithic.api.services.async
Interface CardAuthorizationServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CardAuthorizationServiceAsync.WithRawResponseA view of CardAuthorizationServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponse>challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)Returns a raw HTTP response for post /v1/card_authorizations/{event_token}/challenge_response, but is otherwise the same as CardAuthorizationServiceAsync.challengeResponse.CompletableFuture<HttpResponse>challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>challengeResponse(CardAuthorizationChallengeResponseParams params)abstract CompletableFuture<HttpResponse>challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardAuthorizationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
CompletableFuture<HttpResponse> challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)
Returns a raw HTTP response for
post /v1/card_authorizations/{event_token}/challenge_response, but is otherwise the same as CardAuthorizationServiceAsync.challengeResponse.
-
challengeResponse
CompletableFuture<HttpResponse> challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
challengeResponse
CompletableFuture<HttpResponse> challengeResponse(CardAuthorizationChallengeResponseParams params)
-
challengeResponse
abstract CompletableFuture<HttpResponse> challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-