Package com.lithic.api.services.async
Class CardAuthorizationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.CardAuthorizationServiceAsync
public final class CardAuthorizationServiceAsyncImpl implements CardAuthorizationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthorizationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Void>challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardAuthorizationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardAuthorizationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
CompletableFuture<Void> challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-