Package com.lithic.api.services.async
Class CardBulkOrderServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.CardBulkOrderServiceAsync
public final class CardBulkOrderServiceAsyncImpl implements CardBulkOrderServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBulkOrderServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardBulkOrderServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardBulkOrderServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardBulkOrder>create(CardBulkOrderCreateParams params, RequestOptions requestOptions)CompletableFuture<CardBulkOrder>retrieve(CardBulkOrderRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardBulkOrder>update(CardBulkOrderUpdateParams params, RequestOptions requestOptions)CompletableFuture<CardBulkOrderListPageAsync>list(CardBulkOrderListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.CardBulkOrderServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardBulkOrderServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardBulkOrderServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardBulkOrder> create(CardBulkOrderCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardBulkOrder> retrieve(CardBulkOrderRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CardBulkOrder> update(CardBulkOrderUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardBulkOrderListPageAsync> list(CardBulkOrderListParams params, RequestOptions requestOptions)
-
-
-
-