Package com.lithic.api.services.async
Class CardBulkOrderServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.CardBulkOrderServiceAsync.WithRawResponse
public final class CardBulkOrderServiceAsyncImpl.WithRawResponseImpl implements CardBulkOrderServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardBulkOrderServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardBulkOrder>>create(CardBulkOrderCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardBulkOrder>>retrieve(CardBulkOrderRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardBulkOrder>>update(CardBulkOrderUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardBulkOrderListPageAsync>>list(CardBulkOrderListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.CardBulkOrderServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardBulkOrderServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardBulkOrder>> create(CardBulkOrderCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<CardBulkOrder>> retrieve(CardBulkOrderRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<CardBulkOrder>> update(CardBulkOrderUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CardBulkOrderListPageAsync>> list(CardBulkOrderListParams params, RequestOptions requestOptions)
-
-
-
-