Package com.lithic.api.services.async
Interface CreditProductServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CreditProductServiceAsync.WithRawResponseA view of CreditProductServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CreditProductServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract ExtendedCreditServiceAsync.WithRawResponseextendedCredit()abstract PrimeRateServiceAsync.WithRawResponseprimeRates()-
-
Method Detail
-
withOptions
abstract CreditProductServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extendedCredit
abstract ExtendedCreditServiceAsync.WithRawResponse extendedCredit()
-
primeRates
abstract PrimeRateServiceAsync.WithRawResponse primeRates()
-
-
-
-