Package com.lithic.api.services.async
Class DisputesV2ServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.DisputesV2ServiceAsync
public final class DisputesV2ServiceAsyncImpl implements DisputesV2ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputesV2ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DisputesV2ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DisputesV2ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DisputeV2>retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)CompletableFuture<DisputesV2ListPageAsync>list(DisputesV2ListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DisputesV2ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DisputesV2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<DisputeV2> retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DisputesV2ListPageAsync> list(DisputesV2ListParams params, RequestOptions requestOptions)
-
-
-
-