Package com.lithic.api.services.async
Class DisputesV2ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.DisputesV2ServiceAsync.WithRawResponse
public final class DisputesV2ServiceAsyncImpl.WithRawResponseImpl implements DisputesV2ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DisputesV2ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<DisputeV2>>retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<DisputesV2ListPageAsync>>list(DisputesV2ListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.DisputesV2ServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DisputesV2ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<DisputeV2>> retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<DisputesV2ListPageAsync>> list(DisputesV2ListParams params, RequestOptions requestOptions)
-
-
-
-