Package com.lithic.api.services.async
Class ExternalBankAccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.ExternalBankAccountServiceAsync.WithRawResponse
public final class ExternalBankAccountServiceAsyncImpl.WithRawResponseImpl implements ExternalBankAccountServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class com.lithic.api.services.async.ExternalBankAccountServiceAsync.WithRawResponse
create, create, create, create, create, create, create, create, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryMicroDeposits, retryPrenote, retryPrenote, retryPrenote, retryPrenote, retryPrenote, setVerificationMethod, setVerificationMethod, setVerificationMethod, unpause, unpause, unpause, unpause, unpause, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ExternalBankAccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
microDeposits
MicroDepositServiceAsync.WithRawResponse microDeposits()
-
create
CompletableFuture<HttpResponseFor<ExternalBankAccountCreateResponse>> create(ExternalBankAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<ExternalBankAccountRetrieveResponse>> retrieve(ExternalBankAccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<ExternalBankAccountUpdateResponse>> update(ExternalBankAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<ExternalBankAccountListPageAsync>> list(ExternalBankAccountListParams params, RequestOptions requestOptions)
-
retryMicroDeposits
CompletableFuture<HttpResponseFor<ExternalBankAccountRetryMicroDepositsResponse>> retryMicroDeposits(ExternalBankAccountRetryMicroDepositsParams params, RequestOptions requestOptions)
-
retryPrenote
CompletableFuture<HttpResponseFor<ExternalBankAccount>> retryPrenote(ExternalBankAccountRetryPrenoteParams params, RequestOptions requestOptions)
-
setVerificationMethod
CompletableFuture<HttpResponseFor<ExternalBankAccount>> setVerificationMethod(ExternalBankAccountSetVerificationMethodParams params, RequestOptions requestOptions)
-
unpause
CompletableFuture<HttpResponseFor<ExternalBankAccount>> unpause(ExternalBankAccountUnpauseParams params, RequestOptions requestOptions)
-
-
-
-