Package com.lithic.api.services.async
Interface HoldServiceAsync
-
- All Implemented Interfaces:
public interface HoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceHoldServiceAsync.WithRawResponseA view of HoldServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract HoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract HoldServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Hold> create(String financialAccountToken, HoldCreateParams params)
Create a hold on a financial account. Holds reserve funds by moving them from available to pending balance. They can be resolved via settlement (linked to a payment or book transfer), voiding, or expiration.
-
create
CompletableFuture<Hold> create(String financialAccountToken, HoldCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Hold> create(HoldCreateParams params)
-
create
abstract CompletableFuture<Hold> create(HoldCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Hold> retrieve(String holdToken)
Get hold by token.
-
retrieve
CompletableFuture<Hold> retrieve(String holdToken, HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Hold> retrieve(String holdToken, HoldRetrieveParams params)
-
retrieve
abstract CompletableFuture<Hold> retrieve(HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Hold> retrieve(HoldRetrieveParams params)
-
retrieve
CompletableFuture<Hold> retrieve(String holdToken, RequestOptions requestOptions)
-
list
CompletableFuture<HoldListPageAsync> list(String financialAccountToken)
List holds for a financial account.
-
list
CompletableFuture<HoldListPageAsync> list(String financialAccountToken, HoldListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HoldListPageAsync> list(String financialAccountToken, HoldListParams params)
-
list
abstract CompletableFuture<HoldListPageAsync> list(HoldListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HoldListPageAsync> list(HoldListParams params)
-
list
CompletableFuture<HoldListPageAsync> list(String financialAccountToken, RequestOptions requestOptions)
-
void_
CompletableFuture<Hold> void_(String holdToken)
Void an active hold. This returns the held funds from pending back to available balance. Only holds in PENDING status can be voided.
-
void_
CompletableFuture<Hold> void_(String holdToken, HoldVoidParams params, RequestOptions requestOptions)
-
void_
CompletableFuture<Hold> void_(String holdToken, HoldVoidParams params)
-
void_
abstract CompletableFuture<Hold> void_(HoldVoidParams params, RequestOptions requestOptions)
-
void_
CompletableFuture<Hold> void_(HoldVoidParams params)
-
void_
CompletableFuture<Hold> void_(String holdToken, RequestOptions requestOptions)
-
-
-
-