Package com.lithic.api.services.async
Class HoldServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.HoldServiceAsync
public final class HoldServiceAsyncImpl implements HoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description HoldServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HoldServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Hold>create(HoldCreateParams params, RequestOptions requestOptions)CompletableFuture<Hold>retrieve(HoldRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HoldListPageAsync>list(HoldListParams params, RequestOptions requestOptions)CompletableFuture<Hold>void_(HoldVoidParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.HoldServiceAsync
create, create, create, list, list, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, void_, void_, void_, void_, void_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
HoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
HoldServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Hold> create(HoldCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Hold> retrieve(HoldRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HoldListPageAsync> list(HoldListParams params, RequestOptions requestOptions)
-
void_
CompletableFuture<Hold> void_(HoldVoidParams params, RequestOptions requestOptions)
-
-
-
-