Package com.lithic.api.services.async
Interface InternalTransactionServiceAsync
-
- All Implemented Interfaces:
public interface InternalTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInternalTransactionServiceAsync.WithRawResponseA view of InternalTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InternalTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InternalTransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. -
-
Method Detail
-
withRawResponse
abstract InternalTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InternalTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-