Package com.lithic.api.services.async
Class InternalTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.InternalTransactionServiceAsync
public final class InternalTransactionServiceAsyncImpl implements InternalTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInternalTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InternalTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InternalTransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. -
-
Method Detail
-
withRawResponse
InternalTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InternalTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-