Interface PaymentServiceAsync
-
- All Implemented Interfaces:
public interface PaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePaymentServiceAsync.WithRawResponseA view of PaymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PaymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PaymentCreateResponse> create(PaymentCreateParams params)
Initiates a payment between a financial account and an external bank account.
-
create
abstract CompletableFuture<PaymentCreateResponse> create(PaymentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Payment> retrieve(String paymentToken)
Get the payment by token.
-
retrieve
CompletableFuture<Payment> retrieve(String paymentToken, PaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Payment> retrieve(String paymentToken, PaymentRetrieveParams params)
-
retrieve
abstract CompletableFuture<Payment> retrieve(PaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Payment> retrieve(PaymentRetrieveParams params)
-
retrieve
CompletableFuture<Payment> retrieve(String paymentToken, RequestOptions requestOptions)
-
list
CompletableFuture<PaymentListPageAsync> list()
List all the payments for the provided search criteria.
-
list
abstract CompletableFuture<PaymentListPageAsync> list(PaymentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PaymentListPageAsync> list(PaymentListParams params)
-
list
CompletableFuture<PaymentListPageAsync> list(RequestOptions requestOptions)
-
retry
CompletableFuture<PaymentRetryResponse> retry(String paymentToken)
Retry an origination which has been returned.
-
retry
CompletableFuture<PaymentRetryResponse> retry(String paymentToken, PaymentRetryParams params, RequestOptions requestOptions)
-
retry
CompletableFuture<PaymentRetryResponse> retry(String paymentToken, PaymentRetryParams params)
-
retry
abstract CompletableFuture<PaymentRetryResponse> retry(PaymentRetryParams params, RequestOptions requestOptions)
-
retry
CompletableFuture<PaymentRetryResponse> retry(PaymentRetryParams params)
-
retry
CompletableFuture<PaymentRetryResponse> retry(String paymentToken, RequestOptions requestOptions)
-
return_
CompletableFuture<Payment> return_(String paymentToken, PaymentReturnParams params)
Return an ACH payment with a specified return reason code. Returns must be initiated within the time window specified by NACHA rules for each return code (typically 2 banking days for most codes, 60 calendar days for unauthorized debits). For a complete list of return codes and their meanings, see the ACH Return Reasons documentation.
Note:
This endpoint does not modify the state of the financial account associated with the payment. If you would like to change the account state, use the Update financial account status endpoint.
By default this endpoint is not enabled for your account. Please contact your implementations manager to enable this feature.
-
return_
CompletableFuture<Payment> return_(String paymentToken, PaymentReturnParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<Payment> return_(PaymentReturnParams params)
-
return_
abstract CompletableFuture<Payment> return_(PaymentReturnParams params, RequestOptions requestOptions)
-
simulateAction
CompletableFuture<PaymentSimulateActionResponse> simulateAction(String paymentToken, PaymentSimulateActionParams params)
Simulate payment lifecycle event
-
simulateAction
CompletableFuture<PaymentSimulateActionResponse> simulateAction(String paymentToken, PaymentSimulateActionParams params, RequestOptions requestOptions)
-
simulateAction
CompletableFuture<PaymentSimulateActionResponse> simulateAction(PaymentSimulateActionParams params)
-
simulateAction
abstract CompletableFuture<PaymentSimulateActionResponse> simulateAction(PaymentSimulateActionParams params, RequestOptions requestOptions)
-
simulateReceipt
CompletableFuture<PaymentSimulateReceiptResponse> simulateReceipt(PaymentSimulateReceiptParams params)
Simulates a receipt of a Payment.
-
simulateReceipt
abstract CompletableFuture<PaymentSimulateReceiptResponse> simulateReceipt(PaymentSimulateReceiptParams params, RequestOptions requestOptions)
-
simulateRelease
CompletableFuture<PaymentSimulateReleaseResponse> simulateRelease(PaymentSimulateReleaseParams params)
Simulates a release of a Payment.
-
simulateRelease
abstract CompletableFuture<PaymentSimulateReleaseResponse> simulateRelease(PaymentSimulateReleaseParams params, RequestOptions requestOptions)
-
simulateReturn
CompletableFuture<PaymentSimulateReturnResponse> simulateReturn(PaymentSimulateReturnParams params)
Simulates a return of a Payment.
-
simulateReturn
abstract CompletableFuture<PaymentSimulateReturnResponse> simulateReturn(PaymentSimulateReturnParams params, RequestOptions requestOptions)
-
-
-
-