Package com.lithic.api.services.async
Interface TransactionMonitoringServiceAsync
-
- All Implemented Interfaces:
public interface TransactionMonitoringServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransactionMonitoringServiceAsync.WithRawResponseA view of TransactionMonitoringServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TransactionMonitoringServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract TransactionMonitoringServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CaseServiceAsynccases()abstract QueueServiceAsyncqueues()-
-
Method Detail
-
withRawResponse
abstract TransactionMonitoringServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract TransactionMonitoringServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
abstract CaseServiceAsync cases()
-
queues
abstract QueueServiceAsync queues()
-
-
-
-