Package com.lithic.api.services.async
Interface TransactionMonitoringServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface TransactionMonitoringServiceAsync.WithRawResponseA view of TransactionMonitoringServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract TransactionMonitoringServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CaseServiceAsync.WithRawResponsecases()abstract QueueServiceAsync.WithRawResponsequeues()-
-
Method Detail
-
withOptions
abstract TransactionMonitoringServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
abstract CaseServiceAsync.WithRawResponse cases()
-
queues
abstract QueueServiceAsync.WithRawResponse queues()
-
-
-
-