Package com.lithic.api.services.async
Class TransactionMonitoringServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.TransactionMonitoringServiceAsync
public final class TransactionMonitoringServiceAsyncImpl implements TransactionMonitoringServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TransactionMonitoringServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TransactionMonitoringServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CaseServiceAsynccases()QueueServiceAsyncqueues()-
-
Method Detail
-
withRawResponse
TransactionMonitoringServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TransactionMonitoringServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
CaseServiceAsync cases()
-
queues
QueueServiceAsync queues()
-
-
-
-