Package com.lithic.api.services.async
Class TransactionMonitoringServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.TransactionMonitoringServiceAsync.WithRawResponse
public final class TransactionMonitoringServiceAsyncImpl.WithRawResponseImpl implements TransactionMonitoringServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TransactionMonitoringServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CaseServiceAsync.WithRawResponsecases()QueueServiceAsync.WithRawResponsequeues()-
-
Method Detail
-
withOptions
TransactionMonitoringServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
queues
QueueServiceAsync.WithRawResponse queues()
-
-
-
-