Package com.lithic.api.services.async
Interface TransferLimitServiceAsync
-
- All Implemented Interfaces:
public interface TransferLimitServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransferLimitServiceAsync.WithRawResponseA view of TransferLimitServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TransferLimitServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract TransferLimitServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<TransferLimitListPageAsync>list()Get transfer limits for a specified date abstract CompletableFuture<TransferLimitListPageAsync>list(TransferLimitListParams params, RequestOptions requestOptions)CompletableFuture<TransferLimitListPageAsync>list(TransferLimitListParams params)CompletableFuture<TransferLimitListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract TransferLimitServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract TransferLimitServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<TransferLimitListPageAsync> list()
Get transfer limits for a specified date
-
list
abstract CompletableFuture<TransferLimitListPageAsync> list(TransferLimitListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<TransferLimitListPageAsync> list(RequestOptions requestOptions)
-
-
-
-