Package com.lithic.api.services.async
Interface TransferLimitServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface TransferLimitServiceAsync.WithRawResponseA view of TransferLimitServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract TransferLimitServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>>list()Returns a raw HTTP response for get /v1/transfer_limits, but is otherwise the same as TransferLimitServiceAsync.list.abstract CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>>list(TransferLimitListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>>list(TransferLimitListParams params)CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract TransferLimitServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>> list()
Returns a raw HTTP response for
get /v1/transfer_limits, but is otherwise the same as TransferLimitServiceAsync.list.
-
list
abstract CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>> list(TransferLimitListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>> list(TransferLimitListParams params)
-
list
CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>> list(RequestOptions requestOptions)
-
-
-
-