Package com.lithic.api.services.async
Class TransferLimitServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.TransferLimitServiceAsync.WithRawResponse
public final class TransferLimitServiceAsyncImpl.WithRawResponseImpl implements TransferLimitServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TransferLimitServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>>list(TransferLimitListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
TransferLimitServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<TransferLimitListPageAsync>> list(TransferLimitListParams params, RequestOptions requestOptions)
-
-
-
-