Package com.lithic.api.services.async
Class WebhookServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.WebhookServiceAsync
public final class WebhookServiceAsyncImpl implements WebhookServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhookServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhookServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. JsonValueunwrap(String payload, Headers headers, String secret)UnitverifySignature(String payload, Headers headers, String secret)ParsedWebhookEventparse(String body, Headers headers, String secret)Parses a webhook event and verifies the signtature. ParsedWebhookEventparseUnsafe(String body)Parses a webhook event without validating the signature. -
-
Method Detail
-
withRawResponse
WebhookServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
verifySignature
Unit verifySignature(String payload, Headers headers, String secret)
-
parse
ParsedWebhookEvent parse(String body, Headers headers, String secret)
Parses a webhook event and verifies the signtature.
-
parseUnsafe
ParsedWebhookEvent parseUnsafe(String body)
Parses a webhook event without validating the signature.
-
-
-
-