Interface V2ServiceAsync
-
- All Implemented Interfaces:
public interface V2ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV2ServiceAsync.WithRawResponseA view of V2ServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract V2ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
backtests
abstract BacktestServiceAsync backtests()
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams params)
Creates a new V2 Auth rule in draft mode
-
create
abstract CompletableFuture<AuthRule> create(AuthRuleV2CreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body body, RequestOptions requestOptions)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body body)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.AccountLevelRule accountLevelRule, RequestOptions requestOptions)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.AccountLevelRule accountLevelRule)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.CardLevelRule cardLevelRule, RequestOptions requestOptions)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.CardLevelRule cardLevelRule)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.ProgramLevelRule programLevelRule, RequestOptions requestOptions)
-
create
CompletableFuture<AuthRule> create(AuthRuleV2CreateParams.Body.ProgramLevelRule programLevelRule)
-
retrieve
CompletableFuture<AuthRule> retrieve(String authRuleToken)
Fetches a V2 Auth rule by its token
-
retrieve
CompletableFuture<AuthRule> retrieve(String authRuleToken, AuthRuleV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AuthRule> retrieve(String authRuleToken, AuthRuleV2RetrieveParams params)
-
retrieve
abstract CompletableFuture<AuthRule> retrieve(AuthRuleV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AuthRule> retrieve(AuthRuleV2RetrieveParams params)
-
retrieve
CompletableFuture<AuthRule> retrieve(String authRuleToken, RequestOptions requestOptions)
-
update
CompletableFuture<AuthRule> update(String authRuleToken, AuthRuleV2UpdateParams params)
Updates a V2 Auth rule's properties
If
account_tokens,card_tokens,program_level, orexcluded_card_tokensis provided, this will replace existing associations with the provided list of entities.
-
update
CompletableFuture<AuthRule> update(String authRuleToken, AuthRuleV2UpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<AuthRule> update(AuthRuleV2UpdateParams params)
-
update
abstract CompletableFuture<AuthRule> update(AuthRuleV2UpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AuthRuleV2ListPageAsync> list()
Lists V2 Auth rules
-
list
abstract CompletableFuture<AuthRuleV2ListPageAsync> list(AuthRuleV2ListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AuthRuleV2ListPageAsync> list(AuthRuleV2ListParams params)
-
list
CompletableFuture<AuthRuleV2ListPageAsync> list(RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String authRuleToken)
Deletes a V2 Auth rule
-
delete
CompletableFuture<Void> delete(String authRuleToken, AuthRuleV2DeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String authRuleToken, AuthRuleV2DeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(AuthRuleV2DeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(AuthRuleV2DeleteParams params)
-
delete
CompletableFuture<Void> delete(String authRuleToken, RequestOptions requestOptions)
-
draft
CompletableFuture<AuthRule> draft(String authRuleToken)
Creates a new draft version of a rule that will be ran in shadow mode.
This can also be utilized to reset the draft parameters, causing a draft version to no longer be ran in shadow mode.
-
draft
CompletableFuture<AuthRule> draft(String authRuleToken, AuthRuleV2DraftParams params, RequestOptions requestOptions)
-
draft
CompletableFuture<AuthRule> draft(String authRuleToken, AuthRuleV2DraftParams params)
-
draft
abstract CompletableFuture<AuthRule> draft(AuthRuleV2DraftParams params, RequestOptions requestOptions)
-
draft
CompletableFuture<AuthRule> draft(AuthRuleV2DraftParams params)
-
draft
CompletableFuture<AuthRule> draft(String authRuleToken, RequestOptions requestOptions)
-
listResults
CompletableFuture<AuthRuleV2ListResultsPageAsync> listResults()
Lists Auth Rule evaluation results.
Limitations:
Results are available for the past 3 months only
At least one filter (
event_tokenorauth_rule_token) must be providedWhen filtering by
event_token, pagination is not supported
-
listResults
abstract CompletableFuture<AuthRuleV2ListResultsPageAsync> listResults(AuthRuleV2ListResultsParams params, RequestOptions requestOptions)
-
listResults
CompletableFuture<AuthRuleV2ListResultsPageAsync> listResults(AuthRuleV2ListResultsParams params)
-
listResults
CompletableFuture<AuthRuleV2ListResultsPageAsync> listResults(RequestOptions requestOptions)
-
promote
CompletableFuture<AuthRule> promote(String authRuleToken)
Promotes the draft version of an Auth rule to the currently active version such that it is enforced in the respective stream.
-
promote
CompletableFuture<AuthRule> promote(String authRuleToken, AuthRuleV2PromoteParams params, RequestOptions requestOptions)
-
promote
CompletableFuture<AuthRule> promote(String authRuleToken, AuthRuleV2PromoteParams params)
-
promote
abstract CompletableFuture<AuthRule> promote(AuthRuleV2PromoteParams params, RequestOptions requestOptions)
-
promote
CompletableFuture<AuthRule> promote(AuthRuleV2PromoteParams params)
-
promote
CompletableFuture<AuthRule> promote(String authRuleToken, RequestOptions requestOptions)
-
retrieveFeatures
CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(String authRuleToken)
Fetches the current calculated Feature values for the given Auth Rule
This only calculates the features for the active version.
VelocityLimit Rules calculates the current Velocity Feature data. This requires a
card_tokenoraccount_tokenmatching what the rule is Scoped to.ConditionalBlock Rules calculates the CARD_TRANSACTION_COUNT_* attributes on the rule. This requires a
card_token
-
retrieveFeatures
CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(String authRuleToken, AuthRuleV2RetrieveFeaturesParams params, RequestOptions requestOptions)
-
retrieveFeatures
CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(String authRuleToken, AuthRuleV2RetrieveFeaturesParams params)
-
retrieveFeatures
abstract CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(AuthRuleV2RetrieveFeaturesParams params, RequestOptions requestOptions)
-
retrieveFeatures
CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(AuthRuleV2RetrieveFeaturesParams params)
-
retrieveFeatures
CompletableFuture<V2RetrieveFeaturesResponse> retrieveFeatures(String authRuleToken, RequestOptions requestOptions)
-
retrieveReport
CompletableFuture<V2RetrieveReportResponse> retrieveReport(String authRuleToken, AuthRuleV2RetrieveReportParams params)
Retrieves a performance report for an Auth rule containing daily statistics and evaluation outcomes.
Time Range Limitations:
Reports are supported for the past 3 months only
Maximum interval length is 1 month
Report data is available only through the previous day in UTC (current day data is not available)
The report provides daily statistics for both current and draft versions of the Auth rule, including approval, decline, and challenge counts along with sample events.
-
retrieveReport
CompletableFuture<V2RetrieveReportResponse> retrieveReport(String authRuleToken, AuthRuleV2RetrieveReportParams params, RequestOptions requestOptions)
-
retrieveReport
CompletableFuture<V2RetrieveReportResponse> retrieveReport(AuthRuleV2RetrieveReportParams params)
-
retrieveReport
abstract CompletableFuture<V2RetrieveReportResponse> retrieveReport(AuthRuleV2RetrieveReportParams params, RequestOptions requestOptions)
-
-
-
-