Interface FinancialTransactionServiceAsync
-
- All Implemented Interfaces:
public interface FinancialTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinancialTransactionServiceAsync.WithRawResponseA view of FinancialTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FinancialTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FinancialTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(String financialTransactionToken, CardFinancialTransactionRetrieveParams params)
Get the card financial transaction for the provided token.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(String financialTransactionToken, CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(CardFinancialTransactionRetrieveParams params)
-
retrieve
abstract CompletableFuture<FinancialTransaction> retrieve(CardFinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(String cardToken)
List the financial transactions for a given card.
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(String cardToken, CardFinancialTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(String cardToken, CardFinancialTransactionListParams params)
-
list
abstract CompletableFuture<CardFinancialTransactionListPageAsync> list(CardFinancialTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(CardFinancialTransactionListParams params)
-
list
CompletableFuture<CardFinancialTransactionListPageAsync> list(String cardToken, RequestOptions requestOptions)
-
-
-
-