Interface MicroDepositServiceAsync
-
- All Implemented Interfaces:
public interface MicroDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMicroDepositServiceAsync.WithRawResponseA view of MicroDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MicroDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MicroDepositServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<MicroDepositCreateResponse>create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params)Verify the external bank account by providing the micro deposit amounts. CompletableFuture<MicroDepositCreateResponse>create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)CompletableFuture<MicroDepositCreateResponse>create(ExternalBankAccountMicroDepositCreateParams params)abstract CompletableFuture<MicroDepositCreateResponse>create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MicroDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MicroDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<MicroDepositCreateResponse> create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params)
Verify the external bank account by providing the micro deposit amounts.
-
create
CompletableFuture<MicroDepositCreateResponse> create(String externalBankAccountToken, ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<MicroDepositCreateResponse> create(ExternalBankAccountMicroDepositCreateParams params)
-
create
abstract CompletableFuture<MicroDepositCreateResponse> create(ExternalBankAccountMicroDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-