Interface FinancialTransactionServiceAsync
-
- All Implemented Interfaces:
public interface FinancialTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFinancialTransactionServiceAsync.WithRawResponseA view of FinancialTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FinancialTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FinancialTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(String financialTransactionToken, FinancialTransactionRetrieveParams params)
Get the financial transaction for the provided token.
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(String financialTransactionToken, FinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<FinancialTransaction> retrieve(FinancialTransactionRetrieveParams params)
-
retrieve
abstract CompletableFuture<FinancialTransaction> retrieve(FinancialTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(String financialAccountToken)
List the financial transactions for a given financial account.
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(String financialAccountToken, FinancialTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(String financialAccountToken, FinancialTransactionListParams params)
-
list
abstract CompletableFuture<FinancialTransactionListPageAsync> list(FinancialTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(FinancialTransactionListParams params)
-
list
CompletableFuture<FinancialTransactionListPageAsync> list(String financialAccountToken, RequestOptions requestOptions)
-
-
-
-