Interface StatementServiceAsync
-
- All Implemented Interfaces:
public interface StatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceStatementServiceAsync.WithRawResponseA view of StatementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract StatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract StatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lineItems
abstract LineItemServiceAsync lineItems()
-
retrieve
CompletableFuture<Statement> retrieve(String statementToken, FinancialAccountStatementRetrieveParams params)
Get a specific statement for a given financial account.
-
retrieve
CompletableFuture<Statement> retrieve(String statementToken, FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Statement> retrieve(FinancialAccountStatementRetrieveParams params)
-
retrieve
abstract CompletableFuture<Statement> retrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(String financialAccountToken)
List the statements for a given financial account.
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(String financialAccountToken, FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(String financialAccountToken, FinancialAccountStatementListParams params)
-
list
abstract CompletableFuture<FinancialAccountStatementListPageAsync> list(FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(FinancialAccountStatementListParams params)
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(String financialAccountToken, RequestOptions requestOptions)
-
-
-
-