Class StatementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.financialAccounts.StatementServiceAsync
public final class StatementServiceAsyncImpl implements StatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStatementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description StatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. StatementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. LineItemServiceAsynclineItems()CompletableFuture<Statement>retrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FinancialAccountStatementListPageAsync>list(FinancialAccountStatementListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
StatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
StatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lineItems
LineItemServiceAsync lineItems()
-
retrieve
CompletableFuture<Statement> retrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FinancialAccountStatementListPageAsync> list(FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
-
-
-