Class SettlementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.reports.SettlementServiceAsync
public final class SettlementServiceAsyncImpl implements SettlementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettlementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SettlementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SettlementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. NetworkTotalServiceAsyncnetworkTotals()CompletableFuture<ReportSettlementListDetailsPageAsync>listDetails(ReportSettlementListDetailsParams params, RequestOptions requestOptions)CompletableFuture<SettlementReport>summary(ReportSettlementSummaryParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.reports.SettlementServiceAsync
listDetails, listDetails, listDetails, listDetails, listDetails, summary, summary, summary, summary, summary -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SettlementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SettlementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
networkTotals
NetworkTotalServiceAsync networkTotals()
-
listDetails
CompletableFuture<ReportSettlementListDetailsPageAsync> listDetails(ReportSettlementListDetailsParams params, RequestOptions requestOptions)
-
summary
CompletableFuture<SettlementReport> summary(ReportSettlementSummaryParams params, RequestOptions requestOptions)
-
-
-
-