Interface NetworkTotalServiceAsync
-
- All Implemented Interfaces:
public interface NetworkTotalServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceNetworkTotalServiceAsync.WithRawResponseA view of NetworkTotalServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract NetworkTotalServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract NetworkTotalServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<NetworkTotal> retrieve(String token)
Retrieve a specific network total record by token. Not available in sandbox.
-
retrieve
CompletableFuture<NetworkTotal> retrieve(String token, ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<NetworkTotal> retrieve(String token, ReportSettlementNetworkTotalRetrieveParams params)
-
retrieve
abstract CompletableFuture<NetworkTotal> retrieve(ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<NetworkTotal> retrieve(ReportSettlementNetworkTotalRetrieveParams params)
-
retrieve
CompletableFuture<NetworkTotal> retrieve(String token, RequestOptions requestOptions)
-
list
CompletableFuture<ReportSettlementNetworkTotalListPageAsync> list()
List network total records with optional filters. Not available in sandbox.
-
list
abstract CompletableFuture<ReportSettlementNetworkTotalListPageAsync> list(ReportSettlementNetworkTotalListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ReportSettlementNetworkTotalListPageAsync> list(ReportSettlementNetworkTotalListParams params)
-
list
CompletableFuture<ReportSettlementNetworkTotalListPageAsync> list(RequestOptions requestOptions)
-
-
-
-