Interface CommentServiceAsync
-
- All Implemented Interfaces:
public interface CommentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCommentServiceAsync.WithRawResponseA view of CommentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CommentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CommentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CaseActivityEntry> create(String caseToken, TransactionMonitoringCaseCommentCreateParams params)
Adds a comment to a case.
-
create
CompletableFuture<CaseActivityEntry> create(String caseToken, TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<CaseActivityEntry> create(TransactionMonitoringCaseCommentCreateParams params)
-
create
abstract CompletableFuture<CaseActivityEntry> create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CaseActivityEntry> update(String commentToken, TransactionMonitoringCaseCommentUpdateParams params)
Edits an existing comment on a case.
-
update
CompletableFuture<CaseActivityEntry> update(String commentToken, TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CaseActivityEntry> update(TransactionMonitoringCaseCommentUpdateParams params)
-
update
abstract CompletableFuture<CaseActivityEntry> update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String commentToken, TransactionMonitoringCaseCommentDeleteParams params)
Deletes a comment from a case.
-
delete
CompletableFuture<Void> delete(String commentToken, TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(TransactionMonitoringCaseCommentDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
-
-
-