Class CommentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.transactionMonitoring.cases.CommentServiceAsync
public final class CommentServiceAsyncImpl implements CommentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CommentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CommentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CaseActivityEntry>create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)CompletableFuture<CaseActivityEntry>update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.transactionMonitoring.cases.CommentServiceAsync
create, create, create, delete, delete, delete, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CommentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CommentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CaseActivityEntry> create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CaseActivityEntry> update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
-
-
-