Class CommentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.async.transactionMonitoring.cases.CommentServiceAsync.WithRawResponse
public final class CommentServiceAsyncImpl.WithRawResponseImpl implements CommentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CommentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CaseActivityEntry>>create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CaseActivityEntry>>update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.async.transactionMonitoring.cases.CommentServiceAsync.WithRawResponse
create, create, create, delete, delete, delete, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CommentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CaseActivityEntry>> create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<CaseActivityEntry>> update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
-
-
-