Interface AccountService
-
- All Implemented Interfaces:
public interface AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountService.WithRawResponseA view of AccountService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Account retrieve(String accountToken, AccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Account retrieve(String accountToken, AccountRetrieveParams params)
-
retrieve
abstract Account retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Account retrieve(AccountRetrieveParams params)
-
retrieve
Account retrieve(String accountToken, RequestOptions requestOptions)
-
update
Account update(String accountToken)
Update account configuration such as state or spend limits. Can only be run on accounts that are part of the program managed by this API key. Accounts that are in the
PAUSEDstate will not be able to transact or create new cards.
-
update
Account update(String accountToken, AccountUpdateParams params, RequestOptions requestOptions)
-
update
Account update(String accountToken, AccountUpdateParams params)
-
update
abstract Account update(AccountUpdateParams params, RequestOptions requestOptions)
-
update
Account update(AccountUpdateParams params)
-
update
Account update(String accountToken, RequestOptions requestOptions)
-
list
AccountListPage list()
List account configurations.
-
list
abstract AccountListPage list(AccountListParams params, RequestOptions requestOptions)
-
list
AccountListPage list(AccountListParams params)
-
list
AccountListPage list(RequestOptions requestOptions)
-
retrieveSignals
SignalsResponse retrieveSignals(String accountToken)
Returns behavioral feature state derived from an account's transaction history.
These signals expose the same data used by behavioral rule attributes (e.g.
AMOUNT_Z_SCOREwithscope: ACCOUNT,IS_NEW_COUNTRYwithscope: ACCOUNT) and custom codeTRANSACTION_HISTORY_SIGNALSfeatures, allowing clients to inspect feature values before writing rules and debug rule behavior.Note: 3DS fields are not available at the account scope and will be null.
-
retrieveSignals
SignalsResponse retrieveSignals(String accountToken, AccountRetrieveSignalsParams params, RequestOptions requestOptions)
-
retrieveSignals
SignalsResponse retrieveSignals(String accountToken, AccountRetrieveSignalsParams params)
-
retrieveSignals
abstract SignalsResponse retrieveSignals(AccountRetrieveSignalsParams params, RequestOptions requestOptions)
-
retrieveSignals
SignalsResponse retrieveSignals(AccountRetrieveSignalsParams params)
-
retrieveSignals
SignalsResponse retrieveSignals(String accountToken, RequestOptions requestOptions)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(String accountToken)
Get an Account's available spend limits, which is based on the spend limit configured on the Account and the amount already spent over the spend limit's duration. For example, if the Account has a daily spend limit of
$1000 configured, and has spent $
600 in the last 24 hours, the available spend limit returned would be $400.
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(String accountToken, AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(String accountToken, AccountRetrieveSpendLimitsParams params)
-
retrieveSpendLimits
abstract AccountSpendLimits retrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(AccountRetrieveSpendLimitsParams params)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(String accountToken, RequestOptions requestOptions)
-
-
-
-