Package com.lithic.api.services.blocking
Class AccountServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.AccountService
public final class AccountServiceImpl implements AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Accountretrieve(AccountRetrieveParams params, RequestOptions requestOptions)Accountupdate(AccountUpdateParams params, RequestOptions requestOptions)AccountListPagelist(AccountListParams params, RequestOptions requestOptions)AccountSpendLimitsretrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.AccountService
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, retrieveSpendLimits, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Account retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
update
Account update(AccountUpdateParams params, RequestOptions requestOptions)
-
list
AccountListPage list(AccountListParams params, RequestOptions requestOptions)
-
retrieveSpendLimits
AccountSpendLimits retrieveSpendLimits(AccountRetrieveSpendLimitsParams params, RequestOptions requestOptions)
-
-
-
-