Package com.lithic.api.services.blocking
Interface CardAuthorizationService
-
- All Implemented Interfaces:
public interface CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardAuthorizationService.WithRawResponseA view of CardAuthorizationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardAuthorizationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnitchallengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)Card program's response to Authorization Challenge. UnitchallengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)UnitchallengeResponse(CardAuthorizationChallengeResponseParams params)abstract UnitchallengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardAuthorizationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
Unit challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)
Card program's response to Authorization Challenge. Programs that have Authorization Challenges configured as Out of Band receive a card_authorization.challenge webhook when an authorization attempt triggers a challenge. The card program should respond using this endpoint after the cardholder completes the challenge.
-
challengeResponse
Unit challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
challengeResponse
Unit challengeResponse(CardAuthorizationChallengeResponseParams params)
-
challengeResponse
abstract Unit challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-