Package com.lithic.api.services.blocking
Interface CardAuthorizationService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardAuthorizationService.WithRawResponseA view of CardAuthorizationService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsechallengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)Returns a raw HTTP response for post /v1/card_authorizations/{event_token}/challenge_response, but is otherwise the same as CardAuthorizationService.challengeResponse.HttpResponsechallengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)HttpResponsechallengeResponse(CardAuthorizationChallengeResponseParams params)abstract HttpResponsechallengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardAuthorizationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
@MustBeClosed() HttpResponse challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params)
Returns a raw HTTP response for
post /v1/card_authorizations/{event_token}/challenge_response, but is otherwise the same as CardAuthorizationService.challengeResponse.
-
challengeResponse
@MustBeClosed() HttpResponse challengeResponse(String eventToken, CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
challengeResponse
@MustBeClosed() HttpResponse challengeResponse(CardAuthorizationChallengeResponseParams params)
-
challengeResponse
@MustBeClosed() abstract HttpResponse challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-