Package com.lithic.api.services.blocking
Class CardAuthorizationServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.CardAuthorizationService
public final class CardAuthorizationServiceImpl implements CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthorizationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnitchallengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardAuthorizationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
Unit challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-