Package com.lithic.api.services.blocking
Class CardAuthorizationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.CardAuthorizationService.WithRawResponse
public final class CardAuthorizationServiceImpl.WithRawResponseImpl implements CardAuthorizationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponsechallengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardAuthorizationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
challengeResponse
HttpResponse challengeResponse(CardAuthorizationChallengeResponseParams params, RequestOptions requestOptions)
-
-
-
-