Package com.lithic.api.services.blocking
Class CreditProductServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.CreditProductService
public final class CreditProductServiceImpl implements CreditProductService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCreditProductServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CreditProductService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CreditProductServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ExtendedCreditServiceextendedCredit()PrimeRateServiceprimeRates()-
-
Method Detail
-
withRawResponse
CreditProductService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CreditProductService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extendedCredit
ExtendedCreditService extendedCredit()
-
primeRates
PrimeRateService primeRates()
-
-
-
-