Package com.lithic.api.services.blocking
Class CreditProductServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.CreditProductService.WithRawResponse
public final class CreditProductServiceImpl.WithRawResponseImpl implements CreditProductService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CreditProductService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ExtendedCreditService.WithRawResponseextendedCredit()PrimeRateService.WithRawResponseprimeRates()-
-
Method Detail
-
withOptions
CreditProductService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
extendedCredit
ExtendedCreditService.WithRawResponse extendedCredit()
-
primeRates
PrimeRateService.WithRawResponse primeRates()
-
-
-
-