Package com.lithic.api.services.blocking
Class DisputesV2ServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.DisputesV2Service
public final class DisputesV2ServiceImpl implements DisputesV2Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputesV2ServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DisputesV2Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DisputesV2ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DisputeV2retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)DisputesV2ListPagelist(DisputesV2ListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DisputesV2Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DisputesV2Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
DisputeV2 retrieve(DisputesV2RetrieveParams params, RequestOptions requestOptions)
-
list
DisputesV2ListPage list(DisputesV2ListParams params, RequestOptions requestOptions)
-
-
-
-