Package com.lithic.api.services.blocking
Class FundingEventServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.FundingEventService
public final class FundingEventServiceImpl implements FundingEventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFundingEventServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FundingEventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FundingEventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FundingEventretrieve(FundingEventRetrieveParams params, RequestOptions requestOptions)FundingEventListPagelist(FundingEventListParams params, RequestOptions requestOptions)FundingEventRetrieveDetailsResponseretrieveDetails(FundingEventRetrieveDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.FundingEventService
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveDetails, retrieveDetails, retrieveDetails, retrieveDetails, retrieveDetails -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
FundingEventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FundingEventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
FundingEvent retrieve(FundingEventRetrieveParams params, RequestOptions requestOptions)
-
list
FundingEventListPage list(FundingEventListParams params, RequestOptions requestOptions)
-
retrieveDetails
FundingEventRetrieveDetailsResponse retrieveDetails(FundingEventRetrieveDetailsParams params, RequestOptions requestOptions)
-
-
-
-