Package com.lithic.api.services.blocking
Interface HoldService
-
- All Implemented Interfaces:
public interface HoldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceHoldService.WithRawResponseA view of HoldService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract HoldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract HoldServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Holdcreate(String financialAccountToken, HoldCreateParams params)Create a hold on a financial account. Holdcreate(String financialAccountToken, HoldCreateParams params, RequestOptions requestOptions)Holdcreate(HoldCreateParams params)abstract Holdcreate(HoldCreateParams params, RequestOptions requestOptions)Holdretrieve(String holdToken)Get hold by token. Holdretrieve(String holdToken, HoldRetrieveParams params, RequestOptions requestOptions)Holdretrieve(String holdToken, HoldRetrieveParams params)abstract Holdretrieve(HoldRetrieveParams params, RequestOptions requestOptions)Holdretrieve(HoldRetrieveParams params)Holdretrieve(String holdToken, RequestOptions requestOptions)HoldListPagelist(String financialAccountToken)List holds for a financial account. HoldListPagelist(String financialAccountToken, HoldListParams params, RequestOptions requestOptions)HoldListPagelist(String financialAccountToken, HoldListParams params)abstract HoldListPagelist(HoldListParams params, RequestOptions requestOptions)HoldListPagelist(HoldListParams params)HoldListPagelist(String financialAccountToken, RequestOptions requestOptions)Holdvoid_(String holdToken)Void an active hold. Holdvoid_(String holdToken, HoldVoidParams params, RequestOptions requestOptions)Holdvoid_(String holdToken, HoldVoidParams params)abstract Holdvoid_(HoldVoidParams params, RequestOptions requestOptions)Holdvoid_(HoldVoidParams params)Holdvoid_(String holdToken, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract HoldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract HoldService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Hold create(String financialAccountToken, HoldCreateParams params)
Create a hold on a financial account. Holds reserve funds by moving them from available to pending balance. They can be resolved via settlement (linked to a payment or book transfer), voiding, or expiration.
-
create
Hold create(String financialAccountToken, HoldCreateParams params, RequestOptions requestOptions)
-
create
Hold create(HoldCreateParams params)
-
create
abstract Hold create(HoldCreateParams params, RequestOptions requestOptions)
-
retrieve
Hold retrieve(String holdToken, HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Hold retrieve(String holdToken, HoldRetrieveParams params)
-
retrieve
abstract Hold retrieve(HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Hold retrieve(HoldRetrieveParams params)
-
retrieve
Hold retrieve(String holdToken, RequestOptions requestOptions)
-
list
HoldListPage list(String financialAccountToken)
List holds for a financial account.
-
list
HoldListPage list(String financialAccountToken, HoldListParams params, RequestOptions requestOptions)
-
list
HoldListPage list(String financialAccountToken, HoldListParams params)
-
list
abstract HoldListPage list(HoldListParams params, RequestOptions requestOptions)
-
list
HoldListPage list(HoldListParams params)
-
list
HoldListPage list(String financialAccountToken, RequestOptions requestOptions)
-
void_
Hold void_(String holdToken)
Void an active hold. This returns the held funds from pending back to available balance. Only holds in PENDING status can be voided.
-
void_
Hold void_(String holdToken, HoldVoidParams params, RequestOptions requestOptions)
-
void_
Hold void_(String holdToken, HoldVoidParams params)
-
void_
abstract Hold void_(HoldVoidParams params, RequestOptions requestOptions)
-
void_
Hold void_(HoldVoidParams params)
-
void_
Hold void_(String holdToken, RequestOptions requestOptions)
-
-
-
-