Package com.lithic.api.services.blocking
Interface HoldService.WithRawResponse
-
- All Implemented Interfaces:
public interface HoldService.WithRawResponseA view of HoldService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract HoldService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Hold>create(String financialAccountToken, HoldCreateParams params)Returns a raw HTTP response for post /v1/financial_accounts/{financial_account_token}/holds, but is otherwise the same as HoldService.create.HttpResponseFor<Hold>create(String financialAccountToken, HoldCreateParams params, RequestOptions requestOptions)HttpResponseFor<Hold>create(HoldCreateParams params)abstract HttpResponseFor<Hold>create(HoldCreateParams params, RequestOptions requestOptions)HttpResponseFor<Hold>retrieve(String holdToken)Returns a raw HTTP response for get /v1/holds/{hold_token}, but is otherwise the same as HoldService.retrieve.HttpResponseFor<Hold>retrieve(String holdToken, HoldRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<Hold>retrieve(String holdToken, HoldRetrieveParams params)abstract HttpResponseFor<Hold>retrieve(HoldRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<Hold>retrieve(HoldRetrieveParams params)HttpResponseFor<Hold>retrieve(String holdToken, RequestOptions requestOptions)HttpResponseFor<HoldListPage>list(String financialAccountToken)Returns a raw HTTP response for get /v1/financial_accounts/{financial_account_token}/holds, but is otherwise the same as HoldService.list.HttpResponseFor<HoldListPage>list(String financialAccountToken, HoldListParams params, RequestOptions requestOptions)HttpResponseFor<HoldListPage>list(String financialAccountToken, HoldListParams params)abstract HttpResponseFor<HoldListPage>list(HoldListParams params, RequestOptions requestOptions)HttpResponseFor<HoldListPage>list(HoldListParams params)HttpResponseFor<HoldListPage>list(String financialAccountToken, RequestOptions requestOptions)HttpResponseFor<Hold>void_(String holdToken)Returns a raw HTTP response for post /v1/holds/{hold_token}/void, but is otherwise the same as HoldService.void_.HttpResponseFor<Hold>void_(String holdToken, HoldVoidParams params, RequestOptions requestOptions)HttpResponseFor<Hold>void_(String holdToken, HoldVoidParams params)abstract HttpResponseFor<Hold>void_(HoldVoidParams params, RequestOptions requestOptions)HttpResponseFor<Hold>void_(HoldVoidParams params)HttpResponseFor<Hold>void_(String holdToken, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract HoldService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<Hold> create(String financialAccountToken, HoldCreateParams params)
Returns a raw HTTP response for
post /v1/financial_accounts/{financial_account_token}/holds, but is otherwise the same as HoldService.create.
-
create
@MustBeClosed() HttpResponseFor<Hold> create(String financialAccountToken, HoldCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<Hold> create(HoldCreateParams params)
-
create
@MustBeClosed() abstract HttpResponseFor<Hold> create(HoldCreateParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponseFor<Hold> retrieve(String holdToken)
Returns a raw HTTP response for
get /v1/holds/{hold_token}, but is otherwise the same as HoldService.retrieve.
-
retrieve
@MustBeClosed() HttpResponseFor<Hold> retrieve(String holdToken, HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponseFor<Hold> retrieve(String holdToken, HoldRetrieveParams params)
-
retrieve
@MustBeClosed() abstract HttpResponseFor<Hold> retrieve(HoldRetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponseFor<Hold> retrieve(HoldRetrieveParams params)
-
retrieve
@MustBeClosed() HttpResponseFor<Hold> retrieve(String holdToken, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<HoldListPage> list(String financialAccountToken)
Returns a raw HTTP response for
get /v1/financial_accounts/{financial_account_token}/holds, but is otherwise the same as HoldService.list.
-
list
@MustBeClosed() HttpResponseFor<HoldListPage> list(String financialAccountToken, HoldListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<HoldListPage> list(String financialAccountToken, HoldListParams params)
-
list
@MustBeClosed() abstract HttpResponseFor<HoldListPage> list(HoldListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<HoldListPage> list(HoldListParams params)
-
list
@MustBeClosed() HttpResponseFor<HoldListPage> list(String financialAccountToken, RequestOptions requestOptions)
-
void_
@MustBeClosed() HttpResponseFor<Hold> void_(String holdToken)
Returns a raw HTTP response for
post /v1/holds/{hold_token}/void, but is otherwise the same as HoldService.void_.
-
void_
@MustBeClosed() HttpResponseFor<Hold> void_(String holdToken, HoldVoidParams params, RequestOptions requestOptions)
-
void_
@MustBeClosed() HttpResponseFor<Hold> void_(String holdToken, HoldVoidParams params)
-
void_
@MustBeClosed() abstract HttpResponseFor<Hold> void_(HoldVoidParams params, RequestOptions requestOptions)
-
void_
@MustBeClosed() HttpResponseFor<Hold> void_(HoldVoidParams params)
-
void_
@MustBeClosed() HttpResponseFor<Hold> void_(String holdToken, RequestOptions requestOptions)
-
-
-
-