Package com.lithic.api.services.blocking
Class HoldServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.HoldService
public final class HoldServiceImpl implements HoldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description HoldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. HoldServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Holdcreate(HoldCreateParams params, RequestOptions requestOptions)Holdretrieve(HoldRetrieveParams params, RequestOptions requestOptions)HoldListPagelist(HoldListParams params, RequestOptions requestOptions)Holdvoid_(HoldVoidParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.HoldService
create, create, create, list, list, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, void_, void_, void_, void_, void_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
HoldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
HoldService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Hold create(HoldCreateParams params, RequestOptions requestOptions)
-
retrieve
Hold retrieve(HoldRetrieveParams params, RequestOptions requestOptions)
-
list
HoldListPage list(HoldListParams params, RequestOptions requestOptions)
-
void_
Hold void_(HoldVoidParams params, RequestOptions requestOptions)
-
-
-
-