Package com.lithic.api.services.blocking
Interface TransactionMonitoringService
-
- All Implemented Interfaces:
public interface TransactionMonitoringService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransactionMonitoringService.WithRawResponseA view of TransactionMonitoringService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TransactionMonitoringService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract TransactionMonitoringServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CaseServicecases()abstract QueueServicequeues()-
-
Method Detail
-
withRawResponse
abstract TransactionMonitoringService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract TransactionMonitoringService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
abstract CaseService cases()
-
queues
abstract QueueService queues()
-
-
-
-