Package com.lithic.api.services.blocking
Interface TransactionMonitoringService.WithRawResponse
-
- All Implemented Interfaces:
public interface TransactionMonitoringService.WithRawResponseA view of TransactionMonitoringService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract TransactionMonitoringService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CaseService.WithRawResponsecases()abstract QueueService.WithRawResponsequeues()-
-
Method Detail
-
withOptions
abstract TransactionMonitoringService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
abstract CaseService.WithRawResponse cases()
-
queues
abstract QueueService.WithRawResponse queues()
-
-
-
-