Package com.lithic.api.services.blocking
Class TransactionMonitoringServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.TransactionMonitoringService
public final class TransactionMonitoringServiceImpl implements TransactionMonitoringService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionMonitoringServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TransactionMonitoringService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TransactionMonitoringServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CaseServicecases()QueueServicequeues()-
-
Method Detail
-
withRawResponse
TransactionMonitoringService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TransactionMonitoringService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
cases
CaseService cases()
-
queues
QueueService queues()
-
-
-
-