Package com.lithic.api.services.blocking
Interface TransferLimitService.WithRawResponse
-
- All Implemented Interfaces:
public interface TransferLimitService.WithRawResponseA view of TransferLimitService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract TransferLimitService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<TransferLimitListPage>list()Returns a raw HTTP response for get /v1/transfer_limits, but is otherwise the same as TransferLimitService.list.abstract HttpResponseFor<TransferLimitListPage>list(TransferLimitListParams params, RequestOptions requestOptions)HttpResponseFor<TransferLimitListPage>list(TransferLimitListParams params)HttpResponseFor<TransferLimitListPage>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract TransferLimitService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
@MustBeClosed() HttpResponseFor<TransferLimitListPage> list()
Returns a raw HTTP response for
get /v1/transfer_limits, but is otherwise the same as TransferLimitService.list.
-
list
@MustBeClosed() abstract HttpResponseFor<TransferLimitListPage> list(TransferLimitListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<TransferLimitListPage> list(TransferLimitListParams params)
-
list
@MustBeClosed() HttpResponseFor<TransferLimitListPage> list(RequestOptions requestOptions)
-
-
-
-