Package com.lithic.api.services.blocking
Class TransferLimitServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.TransferLimitService
public final class TransferLimitServiceImpl implements TransferLimitService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransferLimitServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TransferLimitService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TransferLimitServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TransferLimitListPagelist(TransferLimitListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
TransferLimitService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TransferLimitService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
TransferLimitListPage list(TransferLimitListParams params, RequestOptions requestOptions)
-
-
-
-