Package com.lithic.api.services.blocking
Class TransferLimitServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.TransferLimitService.WithRawResponse
public final class TransferLimitServiceImpl.WithRawResponseImpl implements TransferLimitService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TransferLimitService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<TransferLimitListPage>list(TransferLimitListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
TransferLimitService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<TransferLimitListPage> list(TransferLimitListParams params, RequestOptions requestOptions)
-
-
-
-