Package com.lithic.api.services.blocking
Interface WebhookService
-
- All Implemented Interfaces:
public interface WebhookService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWebhookService.WithRawResponseA view of WebhookService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WebhookService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WebhookServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract JsonValueunwrap(String payload, Headers headers, String secret)abstract UnitverifySignature(String payload, Headers headers, String secret)abstract ParsedWebhookEventparse(String body, Headers headers, String secret)Parses a webhook event and verifies the signtature. abstract ParsedWebhookEventparseUnsafe(String body)Parses a webhook event without validating the signature. -
-
Method Detail
-
withRawResponse
abstract WebhookService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
verifySignature
abstract Unit verifySignature(String payload, Headers headers, String secret)
-
parse
abstract ParsedWebhookEvent parse(String body, Headers headers, String secret)
Parses a webhook event and verifies the signtature.
-
parseUnsafe
abstract ParsedWebhookEvent parseUnsafe(String body)
Parses a webhook event without validating the signature.
-
-
-
-