Package com.lithic.api.services.blocking
Class WebhookServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.WebhookService
public final class WebhookServiceImpl implements WebhookService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhookService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhookServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. JsonValueunwrap(String payload, Headers headers, String secret)UnitverifySignature(String payload, Headers headers, String secret)ParsedWebhookEventparse(String body, Headers headers, String secret)Unwraps a webhook event from its JSON representation. ParsedWebhookEventparseUnsafe(String body)Unwraps a webhook event from its JSON representation without verifying the signature. -
-
Method Detail
-
withRawResponse
WebhookService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
verifySignature
Unit verifySignature(String payload, Headers headers, String secret)
-
parse
ParsedWebhookEvent parse(String body, Headers headers, String secret)
Unwraps a webhook event from its JSON representation.
-
parseUnsafe
ParsedWebhookEvent parseUnsafe(String body)
Unwraps a webhook event from its JSON representation without verifying the signature.
-
-
-
-