Interface V2Service
-
- All Implemented Interfaces:
public interface V2Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV2Service.WithRawResponseA view of V2Service that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract V2Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V2Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
backtests
abstract BacktestService backtests()
-
create
AuthRule create(AuthRuleV2CreateParams params)
Creates a new V2 Auth rule in draft mode
-
create
abstract AuthRule create(AuthRuleV2CreateParams params, RequestOptions requestOptions)
-
create
AuthRule create(AuthRuleV2CreateParams.Body body, RequestOptions requestOptions)
-
create
AuthRule create(AuthRuleV2CreateParams.Body body)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.AccountLevelRule accountLevelRule, RequestOptions requestOptions)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.AccountLevelRule accountLevelRule)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.CardLevelRule cardLevelRule, RequestOptions requestOptions)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.CardLevelRule cardLevelRule)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.ProgramLevelRule programLevelRule, RequestOptions requestOptions)
-
create
AuthRule create(AuthRuleV2CreateParams.Body.ProgramLevelRule programLevelRule)
-
retrieve
AuthRule retrieve(String authRuleToken, AuthRuleV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
AuthRule retrieve(String authRuleToken, AuthRuleV2RetrieveParams params)
-
retrieve
abstract AuthRule retrieve(AuthRuleV2RetrieveParams params, RequestOptions requestOptions)
-
retrieve
AuthRule retrieve(AuthRuleV2RetrieveParams params)
-
retrieve
AuthRule retrieve(String authRuleToken, RequestOptions requestOptions)
-
update
AuthRule update(String authRuleToken, AuthRuleV2UpdateParams params)
Updates a V2 Auth rule's properties
If
account_tokens,card_tokens,program_level, orexcluded_card_tokensis provided, this will replace existing associations with the provided list of entities.
-
update
AuthRule update(String authRuleToken, AuthRuleV2UpdateParams params, RequestOptions requestOptions)
-
update
AuthRule update(AuthRuleV2UpdateParams params)
-
update
abstract AuthRule update(AuthRuleV2UpdateParams params, RequestOptions requestOptions)
-
list
AuthRuleV2ListPage list()
Lists V2 Auth rules
-
list
abstract AuthRuleV2ListPage list(AuthRuleV2ListParams params, RequestOptions requestOptions)
-
list
AuthRuleV2ListPage list(AuthRuleV2ListParams params)
-
list
AuthRuleV2ListPage list(RequestOptions requestOptions)
-
delete
Unit delete(String authRuleToken, AuthRuleV2DeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String authRuleToken, AuthRuleV2DeleteParams params)
-
delete
abstract Unit delete(AuthRuleV2DeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(AuthRuleV2DeleteParams params)
-
delete
Unit delete(String authRuleToken, RequestOptions requestOptions)
-
draft
AuthRule draft(String authRuleToken)
Creates a new draft version of a rule that will be ran in shadow mode.
This can also be utilized to reset the draft parameters, causing a draft version to no longer be ran in shadow mode.
-
draft
AuthRule draft(String authRuleToken, AuthRuleV2DraftParams params, RequestOptions requestOptions)
-
draft
AuthRule draft(String authRuleToken, AuthRuleV2DraftParams params)
-
draft
abstract AuthRule draft(AuthRuleV2DraftParams params, RequestOptions requestOptions)
-
draft
AuthRule draft(AuthRuleV2DraftParams params)
-
draft
AuthRule draft(String authRuleToken, RequestOptions requestOptions)
-
listResults
AuthRuleV2ListResultsPage listResults()
Lists Auth Rule evaluation results.
Limitations:
Results are available for the past 3 months only
At least one filter (
event_tokenorauth_rule_token) must be providedWhen filtering by
event_token, pagination is not supported
-
listResults
abstract AuthRuleV2ListResultsPage listResults(AuthRuleV2ListResultsParams params, RequestOptions requestOptions)
-
listResults
AuthRuleV2ListResultsPage listResults(AuthRuleV2ListResultsParams params)
-
listResults
AuthRuleV2ListResultsPage listResults(RequestOptions requestOptions)
-
promote
AuthRule promote(String authRuleToken)
Promotes the draft version of an Auth rule to the currently active version such that it is enforced in the respective stream.
-
promote
AuthRule promote(String authRuleToken, AuthRuleV2PromoteParams params, RequestOptions requestOptions)
-
promote
AuthRule promote(String authRuleToken, AuthRuleV2PromoteParams params)
-
promote
abstract AuthRule promote(AuthRuleV2PromoteParams params, RequestOptions requestOptions)
-
promote
AuthRule promote(AuthRuleV2PromoteParams params)
-
promote
AuthRule promote(String authRuleToken, RequestOptions requestOptions)
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(String authRuleToken)
Fetches the current calculated Feature values for the given Auth Rule
This only calculates the features for the active version.
VelocityLimit Rules calculates the current Velocity Feature data. This requires a
card_tokenoraccount_tokenmatching what the rule is Scoped to.ConditionalBlock Rules calculates the CARD_TRANSACTION_COUNT_* attributes on the rule. This requires a
card_token
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(String authRuleToken, AuthRuleV2RetrieveFeaturesParams params, RequestOptions requestOptions)
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(String authRuleToken, AuthRuleV2RetrieveFeaturesParams params)
-
retrieveFeatures
abstract V2RetrieveFeaturesResponse retrieveFeatures(AuthRuleV2RetrieveFeaturesParams params, RequestOptions requestOptions)
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(AuthRuleV2RetrieveFeaturesParams params)
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(String authRuleToken, RequestOptions requestOptions)
-
retrieveReport
V2RetrieveReportResponse retrieveReport(String authRuleToken, AuthRuleV2RetrieveReportParams params)
Retrieves a performance report for an Auth rule containing daily statistics and evaluation outcomes.
Time Range Limitations:
Reports are supported for the past 3 months only
Maximum interval length is 1 month
Report data is available only through the previous day in UTC (current day data is not available)
The report provides daily statistics for both current and draft versions of the Auth rule, including approval, decline, and challenge counts along with sample events.
-
retrieveReport
V2RetrieveReportResponse retrieveReport(String authRuleToken, AuthRuleV2RetrieveReportParams params, RequestOptions requestOptions)
-
retrieveReport
V2RetrieveReportResponse retrieveReport(AuthRuleV2RetrieveReportParams params)
-
retrieveReport
abstract V2RetrieveReportResponse retrieveReport(AuthRuleV2RetrieveReportParams params, RequestOptions requestOptions)
-
-
-
-