Class V2ServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.authRules.V2Service
public final class V2ServiceImpl implements V2Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.lithic.api.services.blocking.authRules.V2Service
create, create, create, create, create, create, create, create, create, delete, delete, delete, delete, delete, draft, draft, draft, draft, draft, list, list, list, listResults, listResults, listResults, promote, promote, promote, promote, promote, retrieve, retrieve, retrieve, retrieve, retrieve, retrieveFeatures, retrieveFeatures, retrieveFeatures, retrieveFeatures, retrieveFeatures, retrieveReport, retrieveReport, retrieveReport, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
V2Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V2Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
backtests
BacktestService backtests()
-
create
AuthRule create(AuthRuleV2CreateParams params, RequestOptions requestOptions)
-
retrieve
AuthRule retrieve(AuthRuleV2RetrieveParams params, RequestOptions requestOptions)
-
update
AuthRule update(AuthRuleV2UpdateParams params, RequestOptions requestOptions)
-
list
AuthRuleV2ListPage list(AuthRuleV2ListParams params, RequestOptions requestOptions)
-
delete
Unit delete(AuthRuleV2DeleteParams params, RequestOptions requestOptions)
-
draft
AuthRule draft(AuthRuleV2DraftParams params, RequestOptions requestOptions)
-
listResults
AuthRuleV2ListResultsPage listResults(AuthRuleV2ListResultsParams params, RequestOptions requestOptions)
-
promote
AuthRule promote(AuthRuleV2PromoteParams params, RequestOptions requestOptions)
-
retrieveFeatures
V2RetrieveFeaturesResponse retrieveFeatures(AuthRuleV2RetrieveFeaturesParams params, RequestOptions requestOptions)
-
retrieveReport
V2RetrieveReportResponse retrieveReport(AuthRuleV2RetrieveReportParams params, RequestOptions requestOptions)
-
-
-
-