Interface BalanceService
-
- All Implemented Interfaces:
public interface BalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBalanceService.WithRawResponseA view of BalanceService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BalanceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardBalanceListPagelist(String cardToken)Get the balances for a given card. CardBalanceListPagelist(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)CardBalanceListPagelist(String cardToken, CardBalanceListParams params)abstract CardBalanceListPagelist(CardBalanceListParams params, RequestOptions requestOptions)CardBalanceListPagelist(CardBalanceListParams params)CardBalanceListPagelist(String cardToken, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BalanceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CardBalanceListPage list(String cardToken)
Get the balances for a given card.
-
list
CardBalanceListPage list(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)
-
list
CardBalanceListPage list(String cardToken, CardBalanceListParams params)
-
list
abstract CardBalanceListPage list(CardBalanceListParams params, RequestOptions requestOptions)
-
list
CardBalanceListPage list(CardBalanceListParams params)
-
list
CardBalanceListPage list(String cardToken, RequestOptions requestOptions)
-
-
-
-