Interface BalanceService.WithRawResponse
-
- All Implemented Interfaces:
public interface BalanceService.WithRawResponseA view of BalanceService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract BalanceService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardBalanceListPage>list(String cardToken)Returns a raw HTTP response for get /v1/cards/{card_token}/balances, but is otherwise the same as BalanceService.list.HttpResponseFor<CardBalanceListPage>list(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)HttpResponseFor<CardBalanceListPage>list(String cardToken, CardBalanceListParams params)abstract HttpResponseFor<CardBalanceListPage>list(CardBalanceListParams params, RequestOptions requestOptions)HttpResponseFor<CardBalanceListPage>list(CardBalanceListParams params)HttpResponseFor<CardBalanceListPage>list(String cardToken, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract BalanceService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
@MustBeClosed() HttpResponseFor<CardBalanceListPage> list(String cardToken)
Returns a raw HTTP response for
get /v1/cards/{card_token}/balances, but is otherwise the same as BalanceService.list.
-
list
@MustBeClosed() HttpResponseFor<CardBalanceListPage> list(String cardToken, CardBalanceListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<CardBalanceListPage> list(String cardToken, CardBalanceListParams params)
-
list
@MustBeClosed() abstract HttpResponseFor<CardBalanceListPage> list(CardBalanceListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<CardBalanceListPage> list(CardBalanceListParams params)
-
list
@MustBeClosed() HttpResponseFor<CardBalanceListPage> list(String cardToken, RequestOptions requestOptions)
-
-
-
-