Interface BalanceService
-
- All Implemented Interfaces:
public interface BalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBalanceService.WithRawResponseA view of BalanceService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BalanceServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FinancialAccountBalanceListPagelist(String financialAccountToken)Get the balances for a given financial account. FinancialAccountBalanceListPagelist(String financialAccountToken, FinancialAccountBalanceListParams params, RequestOptions requestOptions)FinancialAccountBalanceListPagelist(String financialAccountToken, FinancialAccountBalanceListParams params)abstract FinancialAccountBalanceListPagelist(FinancialAccountBalanceListParams params, RequestOptions requestOptions)FinancialAccountBalanceListPagelist(FinancialAccountBalanceListParams params)FinancialAccountBalanceListPagelist(String financialAccountToken, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BalanceService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
FinancialAccountBalanceListPage list(String financialAccountToken)
Get the balances for a given financial account.
-
list
FinancialAccountBalanceListPage list(String financialAccountToken, FinancialAccountBalanceListParams params, RequestOptions requestOptions)
-
list
FinancialAccountBalanceListPage list(String financialAccountToken, FinancialAccountBalanceListParams params)
-
list
abstract FinancialAccountBalanceListPage list(FinancialAccountBalanceListParams params, RequestOptions requestOptions)
-
list
FinancialAccountBalanceListPage list(String financialAccountToken, RequestOptions requestOptions)
-
-
-
-