Interface StatementService
-
- All Implemented Interfaces:
public interface StatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceStatementService.WithRawResponseA view of StatementService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract StatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract StatementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
lineItems
abstract LineItemService lineItems()
-
retrieve
Statement retrieve(String statementToken, FinancialAccountStatementRetrieveParams params)
Get a specific statement for a given financial account.
-
retrieve
Statement retrieve(String statementToken, FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Statement retrieve(FinancialAccountStatementRetrieveParams params)
-
retrieve
abstract Statement retrieve(FinancialAccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
FinancialAccountStatementListPage list(String financialAccountToken)
List the statements for a given financial account.
-
list
FinancialAccountStatementListPage list(String financialAccountToken, FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
list
FinancialAccountStatementListPage list(String financialAccountToken, FinancialAccountStatementListParams params)
-
list
abstract FinancialAccountStatementListPage list(FinancialAccountStatementListParams params, RequestOptions requestOptions)
-
list
FinancialAccountStatementListPage list(String financialAccountToken, RequestOptions requestOptions)
-
-
-
-