Class TransactionServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.fraud.TransactionService
public final class TransactionServiceImpl implements TransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TransactionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TransactionRetrieveResponseretrieve(FraudTransactionRetrieveParams params, RequestOptions requestOptions)TransactionReportResponsereport(FraudTransactionReportParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
TransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TransactionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
TransactionRetrieveResponse retrieve(FraudTransactionRetrieveParams params, RequestOptions requestOptions)
-
report
TransactionReportResponse report(FraudTransactionReportParams params, RequestOptions requestOptions)
-
-
-
-