Interface SettlementService
-
- All Implemented Interfaces:
public interface SettlementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSettlementService.WithRawResponseA view of SettlementService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SettlementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SettlementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
networkTotals
abstract NetworkTotalService networkTotals()
-
listDetails
ReportSettlementListDetailsPage listDetails(LocalDate reportDate)
List details.
-
listDetails
ReportSettlementListDetailsPage listDetails(LocalDate reportDate, ReportSettlementListDetailsParams params, RequestOptions requestOptions)
-
listDetails
ReportSettlementListDetailsPage listDetails(LocalDate reportDate, ReportSettlementListDetailsParams params)
-
listDetails
abstract ReportSettlementListDetailsPage listDetails(ReportSettlementListDetailsParams params, RequestOptions requestOptions)
-
listDetails
ReportSettlementListDetailsPage listDetails(ReportSettlementListDetailsParams params)
-
listDetails
ReportSettlementListDetailsPage listDetails(LocalDate reportDate, RequestOptions requestOptions)
-
summary
SettlementReport summary(LocalDate reportDate)
Get the settlement report for a specified report date. Not available in sandbox.
-
summary
SettlementReport summary(LocalDate reportDate, ReportSettlementSummaryParams params, RequestOptions requestOptions)
-
summary
SettlementReport summary(LocalDate reportDate, ReportSettlementSummaryParams params)
-
summary
abstract SettlementReport summary(ReportSettlementSummaryParams params, RequestOptions requestOptions)
-
summary
SettlementReport summary(ReportSettlementSummaryParams params)
-
summary
SettlementReport summary(LocalDate reportDate, RequestOptions requestOptions)
-
-
-
-