Class SettlementServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.reports.SettlementService
public final class SettlementServiceImpl implements SettlementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSettlementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SettlementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SettlementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. NetworkTotalServicenetworkTotals()ReportSettlementListDetailsPagelistDetails(ReportSettlementListDetailsParams params, RequestOptions requestOptions)SettlementReportsummary(ReportSettlementSummaryParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.reports.SettlementService
listDetails, listDetails, listDetails, listDetails, listDetails, summary, summary, summary, summary, summary -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SettlementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SettlementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
networkTotals
NetworkTotalService networkTotals()
-
listDetails
ReportSettlementListDetailsPage listDetails(ReportSettlementListDetailsParams params, RequestOptions requestOptions)
-
summary
SettlementReport summary(ReportSettlementSummaryParams params, RequestOptions requestOptions)
-
-
-
-