Class NetworkTotalServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.reports.settlement.NetworkTotalService
public final class NetworkTotalServiceImpl implements NetworkTotalService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classNetworkTotalServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description NetworkTotalService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. NetworkTotalServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. NetworkTotalretrieve(ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)ReportSettlementNetworkTotalListPagelist(ReportSettlementNetworkTotalListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.reports.settlement.NetworkTotalService
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
NetworkTotalService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
NetworkTotalService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
NetworkTotal retrieve(ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)
-
list
ReportSettlementNetworkTotalListPage list(ReportSettlementNetworkTotalListParams params, RequestOptions requestOptions)
-
-
-
-