Class NetworkTotalServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.reports.settlement.NetworkTotalService.WithRawResponse
public final class NetworkTotalServiceImpl.WithRawResponseImpl implements NetworkTotalService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description NetworkTotalService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<NetworkTotal>retrieve(ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<ReportSettlementNetworkTotalListPage>list(ReportSettlementNetworkTotalListParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.reports.settlement.NetworkTotalService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
NetworkTotalService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<NetworkTotal> retrieve(ReportSettlementNetworkTotalRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<ReportSettlementNetworkTotalListPage> list(ReportSettlementNetworkTotalListParams params, RequestOptions requestOptions)
-
-
-
-