Interface CommentService
-
- All Implemented Interfaces:
public interface CommentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCommentService.WithRawResponseA view of CommentService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CommentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CommentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CaseActivityEntry create(String caseToken, TransactionMonitoringCaseCommentCreateParams params)
Adds a comment to a case.
-
create
CaseActivityEntry create(String caseToken, TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
create
CaseActivityEntry create(TransactionMonitoringCaseCommentCreateParams params)
-
create
abstract CaseActivityEntry create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
update
CaseActivityEntry update(String commentToken, TransactionMonitoringCaseCommentUpdateParams params)
Edits an existing comment on a case.
-
update
CaseActivityEntry update(String commentToken, TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
update
CaseActivityEntry update(TransactionMonitoringCaseCommentUpdateParams params)
-
update
abstract CaseActivityEntry update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
delete
Unit delete(String commentToken, TransactionMonitoringCaseCommentDeleteParams params)
Deletes a comment from a case.
-
delete
Unit delete(String commentToken, TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(TransactionMonitoringCaseCommentDeleteParams params)
-
delete
abstract Unit delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
-
-
-