Class CommentServiceImpl
-
- All Implemented Interfaces:
-
com.lithic.api.services.blocking.transactionMonitoring.cases.CommentService
public final class CommentServiceImpl implements CommentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CommentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CommentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CaseActivityEntrycreate(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)CaseActivityEntryupdate(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)Unitdelete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.lithic.api.services.blocking.transactionMonitoring.cases.CommentService
create, create, create, delete, delete, delete, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CommentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CommentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CaseActivityEntry create(TransactionMonitoringCaseCommentCreateParams params, RequestOptions requestOptions)
-
update
CaseActivityEntry update(TransactionMonitoringCaseCommentUpdateParams params, RequestOptions requestOptions)
-
delete
Unit delete(TransactionMonitoringCaseCommentDeleteParams params, RequestOptions requestOptions)
-
-
-
-