Package com.lithic.api.models
Class AccountActivityListPageResponse
-
- All Implemented Interfaces:
public final class AccountActivityListPageResponseA response containing a list of transactions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountActivityListPageResponse.BuilderA builder for AccountActivityListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<AccountActivityListResponse>data()final BooleanhasMore()Indicates if there are more transactions available for pagination final JsonField<List<AccountActivityListResponse>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final AccountActivityListPageResponse.BuildertoBuilder()final AccountActivityListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountActivityListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountActivityListPageResponse. -
-
Method Detail
-
data
final List<AccountActivityListResponse> data()
-
_data
final JsonField<List<AccountActivityListResponse>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountActivityListPageResponse.Builder toBuilder()
-
validate
final AccountActivityListPageResponse validate()
-
builder
final static AccountActivityListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountActivityListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-