Class AccountActivityRetrieveTransactionResponse
-
- All Implemented Interfaces:
public final class AccountActivityRetrieveTransactionResponseResponse containing multiple transaction types. The
familyfield determines which transaction type is returned: INTERNAL returns FinancialTransaction, TRANSFER returns BookTransferTransaction, CARD returns CardTransaction, PAYMENT returns PaymentTransaction, EXTERNAL_PAYMENT returns ExternalPaymentResponse, and MANAGEMENT_OPERATION returns ManagementOperationTransaction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountActivityRetrieveTransactionResponse.VisitorAn interface that defines how to map each variant of AccountActivityRetrieveTransactionResponse to a value of type T.
public final classAccountActivityRetrieveTransactionResponse.FinancialTransactionFinancial transaction with inheritance from unified base transaction
public final classAccountActivityRetrieveTransactionResponse.CardTransactionCard transaction with ledger base properties
-
Method Summary
-
-
Method Detail
-
internal_
final Optional<AccountActivityRetrieveTransactionResponse.FinancialTransaction> internal_()
Financial transaction with inheritance from unified base transaction
-
transfer
final Optional<BookTransferResponse> transfer()
Book transfer transaction
-
card
final Optional<AccountActivityRetrieveTransactionResponse.CardTransaction> card()
Card transaction with ledger base properties
-
externalPayment
final Optional<ExternalPayment> externalPayment()
-
managementOperation
final Optional<ManagementOperationTransaction> managementOperation()
-
isInternal
final Boolean isInternal()
-
isTransfer
final Boolean isTransfer()
-
isExternalPayment
final Boolean isExternalPayment()
-
isManagementOperation
final Boolean isManagementOperation()
-
asInternal
final AccountActivityRetrieveTransactionResponse.FinancialTransaction asInternal()
Financial transaction with inheritance from unified base transaction
-
asTransfer
final BookTransferResponse asTransfer()
Book transfer transaction
-
asCard
final AccountActivityRetrieveTransactionResponse.CardTransaction asCard()
Card transaction with ledger base properties
-
asExternalPayment
final ExternalPayment asExternalPayment()
-
asManagementOperation
final ManagementOperationTransaction asManagementOperation()
-
accept
final <T extends Any> T accept(AccountActivityRetrieveTransactionResponse.Visitor<T> visitor)
-
validate
final AccountActivityRetrieveTransactionResponse validate()
-
ofInternal
final static AccountActivityRetrieveTransactionResponse ofInternal(AccountActivityRetrieveTransactionResponse.FinancialTransaction internal_)
Financial transaction with inheritance from unified base transaction
-
ofTransfer
final static AccountActivityRetrieveTransactionResponse ofTransfer(BookTransferResponse transfer)
Book transfer transaction
-
ofCard
final static AccountActivityRetrieveTransactionResponse ofCard(AccountActivityRetrieveTransactionResponse.CardTransaction card)
Card transaction with ledger base properties
-
ofPayment
final static AccountActivityRetrieveTransactionResponse ofPayment(Payment payment)
Payment transaction
-
ofExternalPayment
final static AccountActivityRetrieveTransactionResponse ofExternalPayment(ExternalPayment externalPayment)
-
ofManagementOperation
final static AccountActivityRetrieveTransactionResponse ofManagementOperation(ManagementOperationTransaction managementOperation)
-
-
-
-