Class AccountHolderDocumentUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class AccountHolderDocumentUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderDocumentUpdatedWebhookEvent.BuilderA builder for AccountHolderDocumentUpdatedWebhookEvent.
public final classAccountHolderDocumentUpdatedWebhookEvent.EventTypeThe type of event that occurred.
public final classAccountHolderDocumentUpdatedWebhookEvent.DocumentTypeType of documentation to be submitted for verification of an account holder
public final classAccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUploadA document upload that belongs to the overall account holder document
-
Method Summary
-
-
Method Detail
-
eventType
final AccountHolderDocumentUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
accountHolderToken
final Optional<String> accountHolderToken()
The token of the account_holder that the document belongs to
-
created
final Optional<OffsetDateTime> created()
When the account_holder was created
-
documentType
final Optional<AccountHolderDocumentUpdatedWebhookEvent.DocumentType> documentType()
Type of documentation to be submitted for verification of an account holder
-
entityToken
final Optional<String> entityToken()
The token of the entity that the document belongs to
-
requiredDocumentUploads
final Optional<List<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload>> requiredDocumentUploads()
-
_eventType
final JsonField<AccountHolderDocumentUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolderToken
final JsonField<String> _accountHolderToken()
Returns the raw JSON value of accountHolderToken.
Unlike accountHolderToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_documentType
final JsonField<AccountHolderDocumentUpdatedWebhookEvent.DocumentType> _documentType()
Returns the raw JSON value of documentType.
Unlike documentType, this method doesn't throw if the JSON field has an unexpected type.
-
_entityToken
final JsonField<String> _entityToken()
Returns the raw JSON value of entityToken.
Unlike entityToken, this method doesn't throw if the JSON field has an unexpected type.
-
_requiredDocumentUploads
final JsonField<List<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload>> _requiredDocumentUploads()
Returns the raw JSON value of requiredDocumentUploads.
Unlike requiredDocumentUploads, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderDocumentUpdatedWebhookEvent.Builder toBuilder()
-
validate
final AccountHolderDocumentUpdatedWebhookEvent validate()
-
builder
final static AccountHolderDocumentUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderDocumentUpdatedWebhookEvent.
The following fields are required:
.eventType()
-
-
-
-