Class AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload
-
- All Implemented Interfaces:
public final class AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUploadA document upload that belongs to the overall account holder document
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.BuilderA builder for RequiredDocumentUpload.
public final classAccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.ImageTypeThe type of image that was uploaded
public final classAccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.DocumentUploadStatusThe status of the document upload
-
Method Summary
-
-
Method Detail
-
acceptedEntityStatusReasons
final Optional<List<String>> acceptedEntityStatusReasons()
-
created
final Optional<OffsetDateTime> created()
When the document upload was created
-
imageType
final Optional<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.ImageType> imageType()
The type of image that was uploaded
-
rejectedEntityStatusReasons
final Optional<List<String>> rejectedEntityStatusReasons()
-
status
final Optional<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.DocumentUploadStatus> status()
The status of the document upload
-
statusReasons
final Optional<List<String>> statusReasons()
-
updated
final Optional<OffsetDateTime> updated()
When the document upload was last updated
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptedEntityStatusReasons
final JsonField<List<String>> _acceptedEntityStatusReasons()
Returns the raw JSON value of acceptedEntityStatusReasons.
Unlike acceptedEntityStatusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_imageType
final JsonField<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.ImageType> _imageType()
Returns the raw JSON value of imageType.
Unlike imageType, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectedEntityStatusReasons
final JsonField<List<String>> _rejectedEntityStatusReasons()
Returns the raw JSON value of rejectedEntityStatusReasons.
Unlike rejectedEntityStatusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.DocumentUploadStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusReasons
final JsonField<List<String>> _statusReasons()
Returns the raw JSON value of statusReasons.
Unlike statusReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload validate()
-
builder
final static AccountHolderDocumentUpdatedWebhookEvent.RequiredDocumentUpload.Builder builder()
Returns a mutable builder for constructing an instance of RequiredDocumentUpload.
-
-
-
-