Class AccountHolderEntityCreateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountHolderEntityCreateParams implements Params
Create a new beneficial owner individual or replace the control person entity on an existing KYB account holder. This endpoint is only applicable for account holders enrolled through a KYB workflow with the Persona KYB provider. A new control person can only replace the existing one. A maximum of 4 beneficial owners can be associated with an account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderEntityCreateParams.BuilderA builder for AccountHolderEntityCreateParams.
public final classAccountHolderEntityCreateParams.CreateEntityRequestRequest body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.
public final classAccountHolderEntityCreateParams.AddressIndividual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
public final classAccountHolderEntityCreateParams.EntityTypeThe type of entity to create on the account holder
-
Method Summary
Modifier and Type Method Description final Optional<String>accountHolderToken()final AccountHolderEntityCreateParams.Addressaddress()Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final Stringdob()Individual's date of birth, as an RFC 3339 date. final Stringemail()Individual's email address. final StringfirstName()Individual's first name, as it appears on government-issued identity documents. final StringgovernmentId()Government-issued identification number (required for identity verification and compliance with banking regulations). final StringlastName()Individual's last name, as it appears on government-issued identity documents. final StringphoneNumber()Individual's phone number, entered in E.164 format. final AccountHolderEntityCreateParams.EntityTypetype()The type of entity to create on the account holder final JsonField<AccountHolderEntityCreateParams.Address>_address()Returns the raw JSON value of address. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_governmentId()Returns the raw JSON value of governmentId. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<AccountHolderEntityCreateParams.EntityType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountHolderEntityCreateParams.BuildertoBuilder()final AccountHolderEntityCreateParams.CreateEntityRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderEntityCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountHolderEntityCreateParams. -
-
Method Detail
-
accountHolderToken
final Optional<String> accountHolderToken()
-
address
final AccountHolderEntityCreateParams.Address address()
Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
email
final String email()
Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
-
firstName
final String firstName()
Individual's first name, as it appears on government-issued identity documents.
-
governmentId
final String governmentId()
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
-
lastName
final String lastName()
Individual's last name, as it appears on government-issued identity documents.
-
phoneNumber
final String phoneNumber()
Individual's phone number, entered in E.164 format.
-
type
final AccountHolderEntityCreateParams.EntityType type()
The type of entity to create on the account holder
-
_address
final JsonField<AccountHolderEntityCreateParams.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentId
final JsonField<String> _governmentId()
Returns the raw JSON value of governmentId.
Unlike governmentId, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountHolderEntityCreateParams.EntityType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountHolderEntityCreateParams.Builder toBuilder()
-
_body
final AccountHolderEntityCreateParams.CreateEntityRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountHolderEntityCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountHolderEntityCreateParams.
The following fields are required:
.address() .dob() .email() .firstName() .governmentId() .lastName() .phoneNumber() .type()
-
-
-
-