Class AccountHolderEntityCreateParams.CreateEntityRequest
-
- All Implemented Interfaces:
public final class AccountHolderEntityCreateParams.CreateEntityRequestRequest body for creating a new beneficial owner or replacing the control person entity on an existing KYB account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderEntityCreateParams.CreateEntityRequest.BuilderA builder for CreateEntityRequest.
-
Method Summary
Modifier and Type Method Description final AccountHolderEntityCreateParams.Addressaddress()Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. final Stringdob()Individual's date of birth, as an RFC 3339 date. final Stringemail()Individual's email address. final StringfirstName()Individual's first name, as it appears on government-issued identity documents. final StringgovernmentId()Government-issued identification number (required for identity verification and compliance with banking regulations). final StringlastName()Individual's last name, as it appears on government-issued identity documents. final StringphoneNumber()Individual's phone number, entered in E.164 format. final AccountHolderEntityCreateParams.EntityTypetype()The type of entity to create on the account holder final JsonField<AccountHolderEntityCreateParams.Address>_address()Returns the raw JSON value of address. final JsonField<String>_dob()Returns the raw JSON value of dob. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_governmentId()Returns the raw JSON value of governmentId. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<AccountHolderEntityCreateParams.EntityType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountHolderEntityCreateParams.CreateEntityRequest.BuildertoBuilder()final AccountHolderEntityCreateParams.CreateEntityRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderEntityCreateParams.CreateEntityRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateEntityRequest. -
-
Method Detail
-
address
final AccountHolderEntityCreateParams.Address address()
Individual's current address - PO boxes, UPS drops, and FedEx drops are not acceptable; APO/FPO are acceptable. Only USA addresses are currently supported.
-
email
final String email()
Individual's email address. If utilizing Lithic for chargeback processing, this customer email address may be used to communicate dispute status and resolution.
-
firstName
final String firstName()
Individual's first name, as it appears on government-issued identity documents.
-
governmentId
final String governmentId()
Government-issued identification number (required for identity verification and compliance with banking regulations). Social Security Numbers (SSN) and Individual Taxpayer Identification Numbers (ITIN) are currently supported, entered as full nine-digits, with or without hyphens
-
lastName
final String lastName()
Individual's last name, as it appears on government-issued identity documents.
-
phoneNumber
final String phoneNumber()
Individual's phone number, entered in E.164 format.
-
type
final AccountHolderEntityCreateParams.EntityType type()
The type of entity to create on the account holder
-
_address
final JsonField<AccountHolderEntityCreateParams.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dob
final JsonField<String> _dob()
Returns the raw JSON value of dob.
Unlike dob, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentId
final JsonField<String> _governmentId()
Returns the raw JSON value of governmentId.
Unlike governmentId, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountHolderEntityCreateParams.EntityType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderEntityCreateParams.CreateEntityRequest.Builder toBuilder()
-
validate
final AccountHolderEntityCreateParams.CreateEntityRequest validate()
-
builder
final static AccountHolderEntityCreateParams.CreateEntityRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateEntityRequest.
The following fields are required:
.address() .dob() .email() .firstName() .governmentId() .lastName() .phoneNumber() .type()
-
-
-
-