Package com.lithic.api.models
Class AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest
-
- All Implemented Interfaces:
public final class AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequestOriginal request to update the account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.BuilderA builder for UpdateRequest.
public final classAccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.IndividualInformation on the individual for whom the account is being opened and KYC is being run.
-
Method Summary
Modifier and Type Method Description final Optional<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual>individual()Information on the individual for whom the account is being opened and KYC is being run. final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual>_individual()Returns the raw JSON value of individual. final Map<String, JsonValue>_additionalProperties()final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.BuildertoBuilder()final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateRequest. -
-
Method Detail
-
individual
final Optional<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual> individual()
Information on the individual for whom the account is being opened and KYC is being run.
-
_individual
final JsonField<AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Individual> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Builder toBuilder()
-
validate
final AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest validate()
-
builder
final static AccountHolderUpdatedWebhookEvent.KycPayload.UpdateRequest.Builder builder()
Returns a mutable builder for constructing an instance of UpdateRequest.
-
-
-
-