Package com.lithic.api.models
Class AccountListPageResponse
-
- All Implemented Interfaces:
public final class AccountListPageResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPageResponse.BuilderA builder for AccountListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Account>data()final BooleanhasMore()Whether there are more accounts to be retrieved. final JsonField<List<Account>>_data()Returns the raw JSON value of data. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final Map<String, JsonValue>_additionalProperties()final AccountListPageResponse.BuildertoBuilder()final AccountListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPageResponse. -
-
Method Detail
-
_data
final JsonField<List<Account>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountListPageResponse.Builder toBuilder()
-
validate
final AccountListPageResponse validate()
-
builder
final static AccountListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPageResponse.
The following fields are required:
.data() .hasMore()
-
-
-
-