Class AccountRetrieveSignalsParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class AccountRetrieveSignalsParams implements Params
Returns behavioral feature state derived from an account's transaction history.
These signals expose the same data used by behavioral rule attributes (e.g.
AMOUNT_Z_SCOREwithscope: ACCOUNT,IS_NEW_COUNTRYwithscope: ACCOUNT) and custom codeTRANSACTION_HISTORY_SIGNALSfeatures, allowing clients to inspect feature values before writing rules and debug rule behavior.Note: 3DS fields are not available at the account scope and will be null.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountRetrieveSignalsParams.BuilderA builder for AccountRetrieveSignalsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountToken()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountRetrieveSignalsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountRetrieveSignalsParamsnone()final static AccountRetrieveSignalsParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountRetrieveSignalsParams. -
-
Method Detail
-
accountToken
final Optional<String> accountToken()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountRetrieveSignalsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountRetrieveSignalsParams none()
-
builder
final static AccountRetrieveSignalsParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountRetrieveSignalsParams.
-
-
-
-