Package com.lithic.api.models
Class AuthRule.DraftVersion
-
- All Implemented Interfaces:
public final class AuthRule.DraftVersion
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRule.DraftVersion.BuilderA builder for DraftVersion.
public final classAuthRule.DraftVersion.ParametersParameters for the Auth Rule
-
Method Summary
Modifier and Type Method Description final AuthRule.DraftVersion.Parametersparameters()Parameters for the Auth Rule final Longversion()The version of the rule, this is incremented whenever the rule's parameters change. final JsonField<AuthRule.DraftVersion.Parameters>_parameters()Returns the raw JSON value of parameters. final JsonField<Long>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final AuthRule.DraftVersion.BuildertoBuilder()final AuthRule.DraftVersionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AuthRule.DraftVersion.Builderbuilder()Returns a mutable builder for constructing an instance of DraftVersion. -
-
Method Detail
-
parameters
final AuthRule.DraftVersion.Parameters parameters()
Parameters for the Auth Rule
-
version
final Long version()
The version of the rule, this is incremented whenever the rule's parameters change.
-
_parameters
final JsonField<AuthRule.DraftVersion.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<Long> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRule.DraftVersion.Builder toBuilder()
-
validate
final AuthRule.DraftVersion validate()
-
builder
final static AuthRule.DraftVersion.Builder builder()
Returns a mutable builder for constructing an instance of DraftVersion.
The following fields are required:
.parameters() .version()
-
-
-
-