Class AuthRulesBacktestReportCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class AuthRulesBacktestReportCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAuthRulesBacktestReportCreatedWebhookEvent.BuilderA builder for AuthRulesBacktestReportCreatedWebhookEvent.
public final classAuthRulesBacktestReportCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
toBacktestResults
final BacktestResults toBacktestResults()
-
backtestToken
final String backtestToken()
Auth Rule Backtest Token
-
results
final BacktestResults.Results results()
-
simulationParameters
final BacktestResults.SimulationParameters simulationParameters()
-
eventType
final AuthRulesBacktestReportCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_backtestToken
final JsonField<String> _backtestToken()
Returns the raw JSON value of backtestToken.
Unlike backtestToken, this method doesn't throw if the JSON field has an unexpected type.
-
_results
final JsonField<BacktestResults.Results> _results()
Returns the raw JSON value of results.
Unlike results, this method doesn't throw if the JSON field has an unexpected type.
-
_simulationParameters
final JsonField<BacktestResults.SimulationParameters> _simulationParameters()
Returns the raw JSON value of simulationParameters.
Unlike simulationParameters, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<AuthRulesBacktestReportCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AuthRulesBacktestReportCreatedWebhookEvent.Builder toBuilder()
-
validate
final AuthRulesBacktestReportCreatedWebhookEvent validate()
-
builder
final static AuthRulesBacktestReportCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of AuthRulesBacktestReportCreatedWebhookEvent.
The following fields are required:
.backtestToken() .results() .simulationParameters() .eventType()
-
-
-
-