Package com.lithic.api.models
Class BacktestResults.BacktestSimulationParameters
-
- All Implemented Interfaces:
public final class BacktestResults.BacktestSimulationParameters
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestResults.BacktestSimulationParameters.BuilderA builder for BacktestSimulationParameters.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeend()The end time of the simulation final OffsetDateTimestart()The start time of the simulation final JsonField<OffsetDateTime>_end()Returns the raw JSON value of end. final JsonField<OffsetDateTime>_start()Returns the raw JSON value of start. final Map<String, JsonValue>_additionalProperties()final BacktestResults.BacktestSimulationParameters.BuildertoBuilder()final BacktestResults.BacktestSimulationParametersvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestResults.BacktestSimulationParameters.Builderbuilder()Returns a mutable builder for constructing an instance of BacktestSimulationParameters. -
-
Method Detail
-
end
final OffsetDateTime end()
The end time of the simulation
-
start
final OffsetDateTime start()
The start time of the simulation
-
_end
final JsonField<OffsetDateTime> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_start
final JsonField<OffsetDateTime> _start()
Returns the raw JSON value of start.
Unlike start, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestResults.BacktestSimulationParameters.Builder toBuilder()
-
validate
final BacktestResults.BacktestSimulationParameters validate()
-
builder
final static BacktestResults.BacktestSimulationParameters.Builder builder()
Returns a mutable builder for constructing an instance of BacktestSimulationParameters.
The following fields are required:
.end() .start()
-
-
-
-