Class BacktestStats.Example
-
- All Implemented Interfaces:
public final class BacktestStats.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBacktestStats.Example.BuilderA builder for Example.
public final classBacktestStats.Example.DecisionThe decision made by the rule for this event.
-
Method Summary
Modifier and Type Method Description final Optional<BacktestStats.Example.Decision>decision()The decision made by the rule for this event. final Optional<String>eventToken()The event token. final Optional<OffsetDateTime>timestamp()The timestamp of the event. final Optional<String>transactionToken()The token of the transaction associated with the event final JsonField<BacktestStats.Example.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final JsonField<String>_transactionToken()Returns the raw JSON value of transactionToken. final Map<String, JsonValue>_additionalProperties()final BacktestStats.Example.BuildertoBuilder()final BacktestStats.Examplevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BacktestStats.Example.Builderbuilder()Returns a mutable builder for constructing an instance of Example. -
-
Method Detail
-
decision
final Optional<BacktestStats.Example.Decision> decision()
The decision made by the rule for this event.
-
eventToken
final Optional<String> eventToken()
The event token.
-
timestamp
final Optional<OffsetDateTime> timestamp()
The timestamp of the event.
-
transactionToken
final Optional<String> transactionToken()
The token of the transaction associated with the event
-
_decision
final JsonField<BacktestStats.Example.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BacktestStats.Example.Builder toBuilder()
-
validate
final BacktestStats.Example validate()
-
builder
final static BacktestStats.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
-
-
-
-