Package com.lithic.api.models
Class BalanceUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class BalanceUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceUpdatedWebhookEvent.BuilderA builder for BalanceUpdatedWebhookEvent.
public final classBalanceUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final List<FinancialAccountBalance>data()final BalanceUpdatedWebhookEvent.EventTypeeventType()The type of event that occurred. final JsonField<List<FinancialAccountBalance>>_data()Returns the raw JSON value of data. final JsonField<BalanceUpdatedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final BalanceUpdatedWebhookEvent.BuildertoBuilder()final BalanceUpdatedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceUpdatedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceUpdatedWebhookEvent. -
-
Method Detail
-
data
final List<FinancialAccountBalance> data()
-
eventType
final BalanceUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_data
final JsonField<List<FinancialAccountBalance>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<BalanceUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BalanceUpdatedWebhookEvent.Builder toBuilder()
-
validate
final BalanceUpdatedWebhookEvent validate()
-
builder
final static BalanceUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of BalanceUpdatedWebhookEvent.
The following fields are required:
.data() .eventType()
-
-
-
-