Class CardAuthorization.NameValidation
-
- All Implemented Interfaces:
public final class CardAuthorization.NameValidationNetwork name validation data, present when the card network requested name validation for this transaction. Contains the cardholder name provided by the network and Lithic's computed match result against KYC data on file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorization.NameValidation.BuilderA builder for NameValidation.
public final classCardAuthorization.NameValidation.NameCardholder name as provided by the card network.
public final classCardAuthorization.NameValidation.NameValidationResultLithic's computed match result comparing the network-provided name to the name on file.
-
Method Summary
Modifier and Type Method Description final CardAuthorization.NameValidation.Namename()Cardholder name as provided by the card network. final CardAuthorization.NameValidation.NameValidationResultnameOnFileMatch()Lithic's computed match result comparing the network-provided name to the name on file. final JsonField<CardAuthorization.NameValidation.Name>_name()Returns the raw JSON value of name. final JsonField<CardAuthorization.NameValidation.NameValidationResult>_nameOnFileMatch()Returns the raw JSON value of nameOnFileMatch. final Map<String, JsonValue>_additionalProperties()final CardAuthorization.NameValidation.BuildertoBuilder()final CardAuthorization.NameValidationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorization.NameValidation.Builderbuilder()Returns a mutable builder for constructing an instance of NameValidation. -
-
Method Detail
-
name
final CardAuthorization.NameValidation.Name name()
Cardholder name as provided by the card network.
-
nameOnFileMatch
final CardAuthorization.NameValidation.NameValidationResult nameOnFileMatch()
Lithic's computed match result comparing the network-provided name to the name on file.
-
_name
final JsonField<CardAuthorization.NameValidation.Name> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_nameOnFileMatch
final JsonField<CardAuthorization.NameValidation.NameValidationResult> _nameOnFileMatch()
Returns the raw JSON value of nameOnFileMatch.
Unlike nameOnFileMatch, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorization.NameValidation.Builder toBuilder()
-
validate
final CardAuthorization.NameValidation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorization.NameValidation.Builder builder()
Returns a mutable builder for constructing an instance of NameValidation.
The following fields are required:
.name() .nameOnFileMatch()
-
-
-
-