Class CardAuthorizationApprovalRequestWebhookEvent
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.BuilderA builder for CardAuthorizationApprovalRequestWebhookEvent.
public final classCardAuthorizationApprovalRequestWebhookEvent.AmountsStructured amounts for this authorization. The
cardholderandmerchantamounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), theholdamount may exceed thecardholderandmerchantamounts to account for anticipated final transaction amounts such as tips or fuel fill-upspublic final classCardAuthorizationApprovalRequestWebhookEvent.Avspublic final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestCardCard object in ASA
public final classCardAuthorizationApprovalRequestWebhookEvent.EventTypepublic final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestStatusThe type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.public final classCardAuthorizationApprovalRequestWebhookEvent.TransactionInitiatorThe entity that initiated the transaction.
public final classCardAuthorizationApprovalRequestWebhookEvent.AccountTypepublic final classCardAuthorizationApprovalRequestWebhookEvent.AsaRequestFleetInfoOptional Object containing information if the Card is a part of a Fleet managed program
public final classCardAuthorizationApprovalRequestWebhookEvent.LatestChallengeThe latest Authorization Challenge that was issued to the cardholder for this merchant.
public final classCardAuthorizationApprovalRequestWebhookEvent.NetworkCard network of the authorization.
public final classCardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificDataContains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos
-
Method Summary
-
-
Method Detail
-
acquirerFee
final Long acquirerFee()
Fee (in cents) assessed by the merchant and paid for by the cardholder. Will be zero if no fee is assessed. Rebates may be transmitted as a negative value to indicate credited fees.
-
amount
@Deprecated(message = "deprecated") final Long amount()
Deprecated, use
amounts. Authorization amount of the transaction (in cents), including any acquirer fees. The contents of this field are identical toauthorization_amount.
-
amounts
final CardAuthorizationApprovalRequestWebhookEvent.Amounts amounts()
Structured amounts for this authorization. The
cardholderandmerchantamounts reflect the original network authorization values. For programs with hold adjustments enabled (e.g., automated fuel dispensers or tipping MCCs), theholdamount may exceed thecardholderandmerchantamounts to account for anticipated final transaction amounts such as tips or fuel fill-ups
-
authorizationAmount
@Deprecated(message = "deprecated") final Long authorizationAmount()
Deprecated, use
amounts. The base transaction amount (in cents) plus the acquirer fee field. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.
-
avs
final CardAuthorizationApprovalRequestWebhookEvent.Avs avs()
-
card
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard card()
Card object in ASA
-
cardholderCurrency
@Deprecated(message = "deprecated") final String cardholderCurrency()
Deprecated, use
amounts. 3-character alphabetic ISO 4217 code for cardholder's billing currency.
-
cashAmount
final Long cashAmount()
The portion of the transaction requested as cash back by the cardholder, and does not include any acquirer fees. The amount field includes the purchase amount, the requested cash back amount, and any acquirer fees.
If no cash back was requested, the value of this field will be 0, and the field will always be present.
-
created
final OffsetDateTime created()
Date and time when the transaction first occurred in UTC.
-
eventType
final CardAuthorizationApprovalRequestWebhookEvent.EventType eventType()
-
merchantAmount
@Deprecated(message = "deprecated") final Long merchantAmount()
Deprecated, use
amounts. The amount that the merchant will receive, denominated inmerchant_currencyand in the smallest currency unit. Note the amount includesacquirer_fee, similar toauthorization_amount. It will be different fromauthorization_amountif the merchant is taking payment in a different currency.
-
merchantCurrency
@Deprecated(message = "deprecated") final String merchantCurrency()
3-character alphabetic ISO 4217 code for the local currency of the transaction.
-
settledAmount
@Deprecated(message = "deprecated") final Long settledAmount()
Deprecated, use
amounts. Amount (in cents) of the transaction that has been settled, including any acquirer fees.
-
status
final CardAuthorizationApprovalRequestWebhookEvent.AsaRequestStatus status()
The type of authorization request that this request is for. Note that
CREDIT_AUTHORIZATIONandFINANCIAL_CREDIT_AUTHORIZATIONis only available to users with credit decisioning via ASA enabled.
-
transactionInitiator
final CardAuthorizationApprovalRequestWebhookEvent.TransactionInitiator transactionInitiator()
The entity that initiated the transaction.
-
accountType
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AccountType> accountType()
-
cardholderAuthentication
final Optional<CardholderAuthentication> cardholderAuthentication()
-
conversionRate
@Deprecated(message = "deprecated") final Optional<Double> conversionRate()
Deprecated, use
amounts. If the transaction was requested in a currency other than the settlement currency, this field will be populated to indicate the rate used to translate the merchant_amount to the amount (i.e.,merchant_amountxconversion_rate=amount). Note that themerchant_amountis in the local currency and the amount is in the settlement currency.
-
eventToken
final Optional<String> eventToken()
The event token associated with the authorization. This field is only set for programs enrolled into the beta.
-
fleetInfo
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestFleetInfo> fleetInfo()
Optional Object containing information if the Card is a part of a Fleet managed program
-
latestChallenge
final Optional<CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge> latestChallenge()
The latest Authorization Challenge that was issued to the cardholder for this merchant.
-
network
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Network> network()
Card network of the authorization.
-
networkRiskScore
final Optional<Long> networkRiskScore()
Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.
-
networkSpecificData
final Optional<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData> networkSpecificData()
Contains raw data provided by the card network, including attributes that provide further context about the authorization. If populated by the network, data is organized by Lithic and passed through without further modification. Please consult the official network documentation for more details about these values and how to use them. This object is only available to certain programs- contact your Customer Success Manager to discuss enabling access.
-
pos
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos> pos()
-
ttl
final Optional<OffsetDateTime> ttl()
Deprecated: approximate time-to-live for the authorization.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_acquirerFee
final JsonField<Long> _acquirerFee()
Returns the raw JSON value of acquirerFee.
Unlike acquirerFee, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
@Deprecated(message = "deprecated") final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_amounts
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Amounts> _amounts()
Returns the raw JSON value of amounts.
Unlike amounts, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationAmount
@Deprecated(message = "deprecated") final JsonField<Long> _authorizationAmount()
Returns the raw JSON value of authorizationAmount.
Unlike authorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_avs
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Avs> _avs()
Returns the raw JSON value of avs.
Unlike avs, this method doesn't throw if the JSON field has an unexpected type.
-
_card
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestCard> _card()
Returns the raw JSON value of card.
Unlike card, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderCurrency
@Deprecated(message = "deprecated") final JsonField<String> _cardholderCurrency()
Returns the raw JSON value of cardholderCurrency.
Unlike cardholderCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_cashAmount
final JsonField<Long> _cashAmount()
Returns the raw JSON value of cashAmount.
Unlike cashAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_merchant
final JsonField<Merchant> _merchant()
Returns the raw JSON value of merchant.
Unlike merchant, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAmount
@Deprecated(message = "deprecated") final JsonField<Long> _merchantAmount()
Returns the raw JSON value of merchantAmount.
Unlike merchantAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCurrency
@Deprecated(message = "deprecated") final JsonField<String> _merchantCurrency()
Returns the raw JSON value of merchantCurrency.
Unlike merchantCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
@Deprecated(message = "deprecated") final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionInitiator
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.TransactionInitiator> _transactionInitiator()
Returns the raw JSON value of transactionInitiator.
Unlike transactionInitiator, this method doesn't throw if the JSON field has an unexpected type.
-
_accountType
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AccountType> _accountType()
Returns the raw JSON value of accountType.
Unlike accountType, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderAuthentication
final JsonField<CardholderAuthentication> _cardholderAuthentication()
Returns the raw JSON value of cardholderAuthentication.
Unlike cardholderAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_cashback
final JsonField<Long> _cashback()
Returns the raw JSON value of cashback.
Unlike cashback, this method doesn't throw if the JSON field has an unexpected type.
-
_conversionRate
@Deprecated(message = "deprecated") final JsonField<Double> _conversionRate()
Returns the raw JSON value of conversionRate.
Unlike conversionRate, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_fleetInfo
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaRequestFleetInfo> _fleetInfo()
Returns the raw JSON value of fleetInfo.
Unlike fleetInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_latestChallenge
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge> _latestChallenge()
Returns the raw JSON value of latestChallenge.
Unlike latestChallenge, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_networkSpecificData
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.AsaNetworkSpecificData> _networkSpecificData()
Returns the raw JSON value of networkSpecificData.
Unlike networkSpecificData, this method doesn't throw if the JSON field has an unexpected type.
-
_pos
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos> _pos()
Returns the raw JSON value of pos.
Unlike pos, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenInfo
final JsonField<TokenInfo> _tokenInfo()
Returns the raw JSON value of tokenInfo.
Unlike tokenInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_ttl
final JsonField<OffsetDateTime> _ttl()
Returns the raw JSON value of ttl.
Unlike ttl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent validate()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationApprovalRequestWebhookEvent.
The following fields are required:
.token() .acquirerFee() .amount() .amounts() .authorizationAmount() .avs() .card() .cardholderCurrency() .cashAmount() .created() .eventType() .merchant() .merchantAmount() .merchantCurrency() .settledAmount() .status() .transactionInitiator()
-
-
-
-