Class CardAuthorizationApprovalRequestWebhookEvent.Avs
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Avs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.Avs.BuilderA builder for Avs.
public final classCardAuthorizationApprovalRequestWebhookEvent.Avs.AddressMatchResultLithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
Method Summary
-
-
Method Detail
-
addressOnFileMatch
final CardAuthorizationApprovalRequestWebhookEvent.Avs.AddressMatchResult addressOnFileMatch()
Lithic's evaluation result comparing the transaction's address data with the cardholder KYC data if it exists. In the event Lithic does not have any Cardholder KYC data, or the transaction does not contain any address data, NOT_PRESENT will be returned
-
_address
final JsonField<String> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_addressOnFileMatch
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Avs.AddressMatchResult> _addressOnFileMatch()
Returns the raw JSON value of addressOnFileMatch.
Unlike addressOnFileMatch, this method doesn't throw if the JSON field has an unexpected type.
-
_zipcode
final JsonField<String> _zipcode()
Returns the raw JSON value of zipcode.
Unlike zipcode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder toBuilder()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.Avs validate()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Avs.Builder builder()
Returns a mutable builder for constructing an instance of Avs.
The following fields are required:
.address() .addressOnFileMatch() .zipcode()
-
-
-
-