Class CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.LatestChallengeThe latest Authorization Challenge that was issued to the cardholder for this merchant.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.BuilderA builder for LatestChallenge.
public final classCardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.StatusThe status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
Method Summary
Modifier and Type Method Description final StringphoneNumber()The phone number used for sending Authorization Challenge SMS. final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Statusstatus()The status of the Authorization Challenge COMPLETED- Challenge was successfully completed by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
final Optional<OffsetDateTime>completedAt()The date and time when the Authorization Challenge was completed in UTC. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final JsonField<CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Status>_status()Returns the raw JSON value of status. final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final Map<String, JsonValue>_additionalProperties()final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.BuildertoBuilder()final CardAuthorizationApprovalRequestWebhookEvent.LatestChallengevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builderbuilder()Returns a mutable builder for constructing an instance of LatestChallenge. -
-
Method Detail
-
phoneNumber
final String phoneNumber()
The phone number used for sending Authorization Challenge SMS.
-
status
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Status status()
The status of the Authorization Challenge
COMPLETED- Challenge was successfully completed by the cardholderPENDING- Challenge is still openEXPIRED- Challenge has expired without being completedERROR- There was an error processing the challenge
-
completedAt
final Optional<OffsetDateTime> completedAt()
The date and time when the Authorization Challenge was completed in UTC. Present only if the status is
COMPLETED.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge validate()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.LatestChallenge.Builder builder()
Returns a mutable builder for constructing an instance of LatestChallenge.
The following fields are required:
.phoneNumber() .status()
-
-
-