Class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode
-
- All Implemented Interfaces:
public final class CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryModePOS Entry Mode object in ASA
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.BuilderA builder for AsaRequestPosEntryMode.
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.CardCard Presence Indicator
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.CardholderCardholder Presence Indicator
public final classCardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.PanMethod of entry for the PAN
-
Method Summary
-
-
Method Detail
-
card
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card> card()
Card Presence Indicator
-
cardholder
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardholder> cardholder()
Cardholder Presence Indicator
-
pan
final Optional<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Pan> pan()
Method of entry for the PAN
-
pinEntered
final Optional<Boolean> pinEntered()
Indicates whether the cardholder entered the PIN. True if the PIN was entered.
-
_card
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Card> _card()
Returns the raw JSON value of card.
Unlike card, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_pan
final JsonField<CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Pan> _pan()
Returns the raw JSON value of pan.
Unlike pan, this method doesn't throw if the JSON field has an unexpected type.
-
_pinEntered
final JsonField<Boolean> _pinEntered()
Returns the raw JSON value of pinEntered.
Unlike pinEntered, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder toBuilder()
-
builder
final static CardAuthorizationApprovalRequestWebhookEvent.Pos.AsaRequestPosEntryMode.Builder builder()
Returns a mutable builder for constructing an instance of AsaRequestPosEntryMode.
-
-
-
-