Class CardBulkOrderCreateParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class CardBulkOrderCreateParams implements Params
Create a new bulk order for physical card shipments BETA. Cards can be added to the order via the POST /v1/cards endpoint by specifying the bulk_order_token. Lock the order via PATCH /v1/card_bulk_orders/{bulk_order_token} to prepare for shipment. Please work with your Customer Success Manager and card personalization bureau to ensure bulk shipping is supported for your program.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBulkOrderCreateParams.BuilderA builder for CardBulkOrderCreateParams.
public final classCardBulkOrderCreateParams.CreateBulkOrderRequestRequest to create a new bulk order for physical card shipments. Please work with your Customer Success Manager and card personalization bureau to ensure bulk shipping is supported for your program.
public final classCardBulkOrderCreateParams.ShippingMethodShipping method for all cards in this bulk order
-
Method Summary
Modifier and Type Method Description final StringcustomerProductId()Customer-specified product configuration for physical card manufacturing. final JsonValue_shippingAddress()Shipping address for all cards in this bulk orderThis arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = cardBulkOrderCreateParams.shippingAddress().convert(MyClass.class);final CardBulkOrderCreateParams.ShippingMethodshippingMethod()Shipping method for all cards in this bulk order final JsonField<String>_customerProductId()Returns the raw JSON value of customerProductId. final JsonField<CardBulkOrderCreateParams.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardBulkOrderCreateParams.BuildertoBuilder()final CardBulkOrderCreateParams.CreateBulkOrderRequest_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardBulkOrderCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardBulkOrderCreateParams. -
-
Method Detail
-
customerProductId
final String customerProductId()
Customer-specified product configuration for physical card manufacturing. This must be configured with Lithic before use
-
_shippingAddress
final JsonValue _shippingAddress()
Shipping address for all cards in this bulk order
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = cardBulkOrderCreateParams.shippingAddress().convert(MyClass.class);
-
shippingMethod
final CardBulkOrderCreateParams.ShippingMethod shippingMethod()
Shipping method for all cards in this bulk order
-
_customerProductId
final JsonField<String> _customerProductId()
Returns the raw JSON value of customerProductId.
Unlike customerProductId, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CardBulkOrderCreateParams.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardBulkOrderCreateParams.Builder toBuilder()
-
_body
final CardBulkOrderCreateParams.CreateBulkOrderRequest _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardBulkOrderCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardBulkOrderCreateParams.
The following fields are required:
.customerProductId() .shippingAddress() .shippingMethod()
-
-
-
-