Class CardRenewedWebhookEvent
-
- All Implemented Interfaces:
public final class CardRenewedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRenewedWebhookEvent.BuilderA builder for CardRenewedWebhookEvent.
public final classCardRenewedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final CardRenewedWebhookEvent.EventTypeeventType()The type of event that occurred. final Optional<String>cardToken()The token of the card that was renewed. final Optional<String>expMonth()The new expiration month of the card. final Optional<String>expYear()The new expiration year of the card. final Optional<String>previousExpMonth()The previous expiration month of the card. final Optional<String>previousExpYear()The previous expiration year of the card. final JsonField<CardRenewedWebhookEvent.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_cardToken()Returns the raw JSON value of cardToken. final JsonField<String>_expMonth()Returns the raw JSON value of expMonth. final JsonField<String>_expYear()Returns the raw JSON value of expYear. final JsonField<String>_previousExpMonth()Returns the raw JSON value of previousExpMonth. final JsonField<String>_previousExpYear()Returns the raw JSON value of previousExpYear. final Map<String, JsonValue>_additionalProperties()final CardRenewedWebhookEvent.BuildertoBuilder()final CardRenewedWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRenewedWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of CardRenewedWebhookEvent. -
-
Method Detail
-
eventType
final CardRenewedWebhookEvent.EventType eventType()
The type of event that occurred.
-
previousExpMonth
final Optional<String> previousExpMonth()
The previous expiration month of the card.
-
previousExpYear
final Optional<String> previousExpYear()
The previous expiration year of the card.
-
_eventType
final JsonField<CardRenewedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_expMonth
final JsonField<String> _expMonth()
Returns the raw JSON value of expMonth.
Unlike expMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_expYear
final JsonField<String> _expYear()
Returns the raw JSON value of expYear.
Unlike expYear, this method doesn't throw if the JSON field has an unexpected type.
-
_previousExpMonth
final JsonField<String> _previousExpMonth()
Returns the raw JSON value of previousExpMonth.
Unlike previousExpMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_previousExpYear
final JsonField<String> _previousExpYear()
Returns the raw JSON value of previousExpYear.
Unlike previousExpYear, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardRenewedWebhookEvent.Builder toBuilder()
-
validate
final CardRenewedWebhookEvent validate()
-
builder
final static CardRenewedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardRenewedWebhookEvent.
The following fields are required:
.eventType()
-
-
-
-