Package com.lithic.api.models
Class CardSpendLimits.SpendLimit
-
- All Implemented Interfaces:
public final class CardSpendLimits.SpendLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSpendLimits.SpendLimit.BuilderA builder for SpendLimit.
-
Method Summary
Modifier and Type Method Description final Optional<Long>annually()The configured annual spend limit (in cents) on the Card. final Optional<Long>forever()The configured forever spend limit (in cents) on the Card. final Optional<Long>monthly()The configured monthly spend limit (in cents) on the Card. final JsonField<Long>_annually()Returns the raw JSON value of annually. final JsonField<Long>_forever()Returns the raw JSON value of forever. final JsonField<Long>_monthly()Returns the raw JSON value of monthly. final Map<String, JsonValue>_additionalProperties()final CardSpendLimits.SpendLimit.BuildertoBuilder()final CardSpendLimits.SpendLimitvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSpendLimits.SpendLimit.Builderbuilder()Returns a mutable builder for constructing an instance of SpendLimit. -
-
Method Detail
-
_annually
final JsonField<Long> _annually()
Returns the raw JSON value of annually.
Unlike annually, this method doesn't throw if the JSON field has an unexpected type.
-
_forever
final JsonField<Long> _forever()
Returns the raw JSON value of forever.
Unlike forever, this method doesn't throw if the JSON field has an unexpected type.
-
_monthly
final JsonField<Long> _monthly()
Returns the raw JSON value of monthly.
Unlike monthly, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSpendLimits.SpendLimit.Builder toBuilder()
-
validate
final CardSpendLimits.SpendLimit validate()
-
builder
final static CardSpendLimits.SpendLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendLimit.
-
-
-
-