Class CardTransactionEnhancedDataCreatedWebhookEvent
-
- All Implemented Interfaces:
public final class CardTransactionEnhancedDataCreatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTransactionEnhancedDataCreatedWebhookEvent.BuilderA builder for CardTransactionEnhancedDataCreatedWebhookEvent.
public final classCardTransactionEnhancedDataCreatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
toEnhancedData
final EnhancedData toEnhancedData()
-
common
final EnhancedData.CommonData common()
-
eventToken
final String eventToken()
The token of the event that the enhanced data is associated with.
-
fleet
final List<EnhancedData.Fleet> fleet()
-
transactionToken
final String transactionToken()
The token of the transaction that the enhanced data is associated with.
-
eventType
final CardTransactionEnhancedDataCreatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_common
final JsonField<EnhancedData.CommonData> _common()
Returns the raw JSON value of common.
Unlike common, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_fleet
final JsonField<List<EnhancedData.Fleet>> _fleet()
Returns the raw JSON value of fleet.
Unlike fleet, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionToken
final JsonField<String> _transactionToken()
Returns the raw JSON value of transactionToken.
Unlike transactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<CardTransactionEnhancedDataCreatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTransactionEnhancedDataCreatedWebhookEvent.Builder toBuilder()
-
validate
final CardTransactionEnhancedDataCreatedWebhookEvent validate()
-
builder
final static CardTransactionEnhancedDataCreatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of CardTransactionEnhancedDataCreatedWebhookEvent.
The following fields are required:
.token() .common() .eventToken() .fleet() .transactionToken() .eventType()
-
-
-
-