Class CardWebProvisionParams.Body
-
- All Implemented Interfaces:
public final class CardWebProvisionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardWebProvisionParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
clientDeviceId
final Optional<String> clientDeviceId()
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning device identifier required for the tokenization flow
-
clientWalletAccountId
final Optional<String> clientWalletAccountId()
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning wallet account identifier required for the tokenization flow
-
digitalWallet
final Optional<CardWebProvisionParams.DigitalWallet> digitalWallet()
Name of digital wallet provider.
-
serverSessionId
final Optional<String> serverSessionId()
Only applicable if
digital_walletis GOOGLE_PAY. Google Pay Web Push Provisioning session identifier required for the FPAN flow.
-
_clientDeviceId
final JsonField<String> _clientDeviceId()
Returns the raw JSON value of clientDeviceId.
Unlike clientDeviceId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientWalletAccountId
final JsonField<String> _clientWalletAccountId()
Returns the raw JSON value of clientWalletAccountId.
Unlike clientWalletAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardWebProvisionParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_serverSessionId
final JsonField<String> _serverSessionId()
Returns the raw JSON value of serverSessionId.
Unlike serverSessionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardWebProvisionParams.Body.Builder toBuilder()
-
validate
final CardWebProvisionParams.Body validate()
-
builder
final static CardWebProvisionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-