Class CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws
-
- All Implemented Interfaces:
public final class CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJwsJWS object required for handoff to Apple's script.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.BuilderA builder for WebPushProvisioningResponseJws.
public final classCardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.WebPushProvisioningResponseHeaderJWS unprotected headers containing header parameters that aren't integrity-protected by the JWS signature.
-
Method Summary
-
-
Method Detail
-
header
final Optional<CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.WebPushProvisioningResponseHeader> header()
JWS unprotected headers containing header parameters that aren't integrity-protected by the JWS signature.
-
payload
final Optional<String> payload()
Base64url encoded JSON object containing the provisioning payload.
-
protected_
final Optional<String> protected_()
Base64url encoded JWS protected headers containing the header parameters that are integrity-protected by the JWS signature.
-
_header
final JsonField<CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.WebPushProvisioningResponseHeader> _header()
Returns the raw JSON value of header.
Unlike header, this method doesn't throw if the JSON field has an unexpected type.
-
_payload
final JsonField<String> _payload()
Returns the raw JSON value of payload.
Unlike payload, this method doesn't throw if the JSON field has an unexpected type.
-
_protected_
final JsonField<String> _protected_()
Returns the raw JSON value of protected_.
Unlike protected_, this method doesn't throw if the JSON field has an unexpected type.
-
_signature
final JsonField<String> _signature()
Returns the raw JSON value of signature.
Unlike signature, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.Builder toBuilder()
-
validate
final CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws validate()
-
builder
final static CardWebProvisionResponse.AppleWebPushProvisioningResponse.WebPushProvisioningResponseJws.Builder builder()
Returns a mutable builder for constructing an instance of WebPushProvisioningResponseJws.
-
-
-
-