Package com.lithic.api.models
Class CardWebProvisionResponse.GoogleWebPushProvisioningResponse
-
- All Implemented Interfaces:
public final class CardWebProvisionResponse.GoogleWebPushProvisioningResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardWebProvisionResponse.GoogleWebPushProvisioningResponse.BuilderA builder for GoogleWebPushProvisioningResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>googleOpc()A base64 encoded and encrypted payload representing card data for the Google Pay UWPP FPAN flow. final Optional<String>tspOpc()A base64 encoded and encrypted payload representing card data for the Google Pay UWPP tokenization flow. final JsonField<String>_googleOpc()Returns the raw JSON value of googleOpc. final JsonField<String>_tspOpc()Returns the raw JSON value of tspOpc. final Map<String, JsonValue>_additionalProperties()final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.BuildertoBuilder()final CardWebProvisionResponse.GoogleWebPushProvisioningResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builderbuilder()Returns a mutable builder for constructing an instance of GoogleWebPushProvisioningResponse. -
-
Method Detail
-
googleOpc
final Optional<String> googleOpc()
A base64 encoded and encrypted payload representing card data for the Google Pay UWPP FPAN flow.
-
tspOpc
final Optional<String> tspOpc()
A base64 encoded and encrypted payload representing card data for the Google Pay UWPP tokenization flow.
-
_googleOpc
final JsonField<String> _googleOpc()
Returns the raw JSON value of googleOpc.
Unlike googleOpc, this method doesn't throw if the JSON field has an unexpected type.
-
_tspOpc
final JsonField<String> _tspOpc()
Returns the raw JSON value of tspOpc.
Unlike tspOpc, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder toBuilder()
-
validate
final CardWebProvisionResponse.GoogleWebPushProvisioningResponse validate()
-
builder
final static CardWebProvisionResponse.GoogleWebPushProvisioningResponse.Builder builder()
Returns a mutable builder for constructing an instance of GoogleWebPushProvisioningResponse.
-
-
-
-