Class ConditionalAchActionParameters.Condition
-
- All Implemented Interfaces:
public final class ConditionalAchActionParameters.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAchActionParameters.Condition.BuilderA builder for Condition.
public final classConditionalAchActionParameters.Condition.AttributeThe attribute to target.
The following attributes may be targeted:
COMPANY_NAME: The name of the company initiating the ACH transaction.COMPANY_ID: The company ID (also known as Standard Entry Class (SEC) Company ID) of the entity initiating the ACH transaction.TIMESTAMP: The timestamp of the ACH transaction in ISO 8601 format.TRANSACTION_AMOUNT: The amount of the ACH transaction in minor units (cents).SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.MEMO: Optional memo or description field included with the ACH transaction.
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalAchActionParameters.Condition.Attribute attribute()
The attribute to target.
The following attributes may be targeted:
COMPANY_NAME: The name of the company initiating the ACH transaction.COMPANY_ID: The company ID (also known as Standard Entry Class (SEC) Company ID) of the entity initiating the ACH transaction.TIMESTAMP: The timestamp of the ACH transaction in ISO 8601 format.TRANSACTION_AMOUNT: The amount of the ACH transaction in minor units (cents).SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.MEMO: Optional memo or description field included with the ACH transaction.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
_attribute
final JsonField<ConditionalAchActionParameters.Condition.Attribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAchActionParameters.Condition.Builder toBuilder()
-
validate
final ConditionalAchActionParameters.Condition validate()
-
builder
final static ConditionalAchActionParameters.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-