Class ConditionalAchActionParameters.Condition.Attribute
-
- All Implemented Interfaces:
-
com.lithic.api.core.Enum
public final class ConditionalAchActionParameters.Condition.Attribute implements EnumThe attribute to target.
The following attributes may be targeted:
COMPANY_NAME: The name of the company initiating the ACH transaction.COMPANY_ID: The company ID (also known as Standard Entry Class (SEC) Company ID) of the entity initiating the ACH transaction.TIMESTAMP: The timestamp of the ACH transaction in ISO 8601 format.TRANSACTION_AMOUNT: The amount of the ACH transaction in minor units (cents).SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.MEMO: Optional memo or description field included with the ACH transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumConditionalAchActionParameters.Condition.Attribute.KnownAn enum containing Attribute's known values.
public enumConditionalAchActionParameters.Condition.Attribute.ValueAn enum containing Attribute's known values, as well as an _UNKNOWN member.
An instance of Attribute can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static ConditionalAchActionParameters.Condition.AttributeCOMPANY_NAMEpublic final static ConditionalAchActionParameters.Condition.AttributeCOMPANY_IDpublic final static ConditionalAchActionParameters.Condition.AttributeTIMESTAMPpublic final static ConditionalAchActionParameters.Condition.AttributeTRANSACTION_AMOUNTpublic final static ConditionalAchActionParameters.Condition.AttributeSEC_CODEpublic final static ConditionalAchActionParameters.Condition.AttributeMEMO
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final ConditionalAchActionParameters.Condition.Attribute.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final ConditionalAchActionParameters.Condition.Attribute.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final ConditionalAchActionParameters.Condition.Attributevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConditionalAchActionParameters.Condition.Attributeof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final ConditionalAchActionParameters.Condition.Attribute.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final ConditionalAchActionParameters.Condition.Attribute.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final ConditionalAchActionParameters.Condition.Attribute validate()
-
of
final static ConditionalAchActionParameters.Condition.Attribute of(String value)
-
-
-
-