Class ConditionalAchPaymentUpdateActionParameters.Condition
-
- All Implemented Interfaces:
public final class ConditionalAchPaymentUpdateActionParameters.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAchPaymentUpdateActionParameters.Condition.BuilderA builder for Condition.
public final classConditionalAchPaymentUpdateActionParameters.Condition.AttributeThe attribute to target.
The following attributes may be targeted:
TRANSACTION_AMOUNT: The total amount of the ACH payment in minor units (cents), calculated as the sum of the settled and pending amounts. Use an integer value.SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.RETURN_REASON_CODE: NACHA return reason code associated with the payment (for example,R01).ACCOUNT_AGE: The age of the account in seconds at the time of the payment. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.EXTERNAL_BANK_ACCOUNT_AGE: The age of the external bank account in seconds at the time of the payment. Use an integer value.EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD: The method used to verify the external bank account. Valid values areMANUAL,MICRO_DEPOSIT,PRENOTE,EXTERNALLY_VERIFIED, orUNVERIFIED.EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE: The verification state of the external bank account. Valid values arePENDING,ENABLED,FAILED_VERIFICATION, orINSUFFICIENT_FUNDS.EXTERNAL_BANK_ACCOUNT_OWNER_TYPE: The owner type of the external bank account. Valid values areINDIVIDUALorBUSINESS.ACH_EVENT_TYPE: The type of ACH payment event being evaluated. Valid values includeACH_ORIGINATION_INITIATED,ACH_ORIGINATION_REVIEWED,ACH_ORIGINATION_CANCELLED,ACH_ORIGINATION_PROCESSED,ACH_ORIGINATION_SETTLED,ACH_ORIGINATION_RELEASED,ACH_ORIGINATION_REJECTED,ACH_RECEIPT_PROCESSED,ACH_RECEIPT_SETTLED,ACH_RECEIPT_RELEASED,ACH_RECEIPT_RELEASED_EARLY,ACH_RETURN_INITIATED,ACH_RETURN_PROCESSED,ACH_RETURN_SETTLED, andACH_RETURN_REJECTED.
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalAchPaymentUpdateActionParameters.Condition.Attribute attribute()
The attribute to target.
The following attributes may be targeted:
TRANSACTION_AMOUNT: The total amount of the ACH payment in minor units (cents), calculated as the sum of the settled and pending amounts. Use an integer value.SEC_CODE: Standard Entry Class code indicating the type of ACH transaction. Valid values include PPD (Prearranged Payment and Deposit Entry), CCD (Corporate Credit or Debit Entry), WEB (Internet-Initiated/Mobile Entry), TEL (Telephone-Initiated Entry), and others.RETURN_REASON_CODE: NACHA return reason code associated with the payment (for example,R01).ACCOUNT_AGE: The age of the account in seconds at the time of the payment. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.EXTERNAL_BANK_ACCOUNT_AGE: The age of the external bank account in seconds at the time of the payment. Use an integer value.EXTERNAL_BANK_ACCOUNT_VERIFICATION_METHOD: The method used to verify the external bank account. Valid values areMANUAL,MICRO_DEPOSIT,PRENOTE,EXTERNALLY_VERIFIED, orUNVERIFIED.EXTERNAL_BANK_ACCOUNT_VERIFICATION_STATE: The verification state of the external bank account. Valid values arePENDING,ENABLED,FAILED_VERIFICATION, orINSUFFICIENT_FUNDS.EXTERNAL_BANK_ACCOUNT_OWNER_TYPE: The owner type of the external bank account. Valid values areINDIVIDUALorBUSINESS.ACH_EVENT_TYPE: The type of ACH payment event being evaluated. Valid values includeACH_ORIGINATION_INITIATED,ACH_ORIGINATION_REVIEWED,ACH_ORIGINATION_CANCELLED,ACH_ORIGINATION_PROCESSED,ACH_ORIGINATION_SETTLED,ACH_ORIGINATION_RELEASED,ACH_ORIGINATION_REJECTED,ACH_RECEIPT_PROCESSED,ACH_RECEIPT_SETTLED,ACH_RECEIPT_RELEASED,ACH_RECEIPT_RELEASED_EARLY,ACH_RETURN_INITIATED,ACH_RETURN_PROCESSED,ACH_RETURN_SETTLED, andACH_RETURN_REJECTED.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
_attribute
final JsonField<ConditionalAchPaymentUpdateActionParameters.Condition.Attribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalAchPaymentUpdateActionParameters.Condition.Builder toBuilder()
-
validate
final ConditionalAchPaymentUpdateActionParameters.Condition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAchPaymentUpdateActionParameters.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-