Class ConditionalAuthorizationActionParameters.Condition

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public final class ConditionalAuthorizationActionParameters.Condition.Builder

      A builder for Condition.

      public final class ConditionalAuthorizationActionParameters.Condition.Attribute

      The attribute to target.

      The following attributes may be targeted:

      • MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.

      • COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.

      • CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.

      • MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).

      • DESCRIPTOR: Short description of card acceptor.

      • LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values are NONE, 3DS_AUTHENTICATED, or TOKEN_AUTHENTICATED.

      • PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values are AUTO_ENTRY, BAR_CODE, CONTACTLESS, ECOMMERCE, ERROR_KEYED, ERROR_MAGNETIC_STRIPE, ICC, KEY_ENTERED, MAGNETIC_STRIPE, MANUAL, OCR, SECURE_CARDLESS, UNSPECIFIED, UNKNOWN, CREDENTIAL_ON_FILE, or ECOMMERCE.

      • TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.

      • CASH_AMOUNT: The cash amount of the transaction in minor units (cents). This represents the amount of cash being withdrawn or advanced.

      • RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.

      • CARD_TRANSACTION_COUNT_15M: The number of transactions on the card in the trailing 15 minutes before the authorization.

      • CARD_TRANSACTION_COUNT_1H: The number of transactions on the card in the trailing hour up and until the authorization.

      • CARD_TRANSACTION_COUNT_24H: The number of transactions on the card in the trailing 24 hours up and until the authorization.

      • CARD_STATE: The current state of the card associated with the transaction. Valid values are CLOSED, OPEN, PAUSED, PENDING_ACTIVATION, PENDING_FULFILLMENT.

      • PIN_ENTERED: Indicates whether a PIN was entered during the transaction. Valid values are TRUE, FALSE.

      • PIN_STATUS: The current state of card's PIN. Valid values are NOT_SET, OK, BLOCKED.

      • WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values are APPLE_PAY, GOOGLE_PAY, SAMSUNG_PAY, MASTERPASS, MERCHANT, OTHER, NONE.

      • TRANSACTION_INITIATOR: The entity that initiated the transaction indicates the source of the token. Valid values are CARDHOLDER, MERCHANT, UNKNOWN.

      • ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values are MATCH, MATCH_ADDRESS_ONLY, MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Constructor Detail

    • Method Detail

      • attribute

         final ConditionalAuthorizationActionParameters.Condition.Attribute attribute()

        The attribute to target.

        The following attributes may be targeted:

        • MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.

        • COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.

        • CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.

        • MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).

        • DESCRIPTOR: Short description of card acceptor.

        • LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values are NONE, 3DS_AUTHENTICATED, or TOKEN_AUTHENTICATED.

        • PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values are AUTO_ENTRY, BAR_CODE, CONTACTLESS, ECOMMERCE, ERROR_KEYED, ERROR_MAGNETIC_STRIPE, ICC, KEY_ENTERED, MAGNETIC_STRIPE, MANUAL, OCR, SECURE_CARDLESS, UNSPECIFIED, UNKNOWN, CREDENTIAL_ON_FILE, or ECOMMERCE.

        • TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.

        • CASH_AMOUNT: The cash amount of the transaction in minor units (cents). This represents the amount of cash being withdrawn or advanced.

        • RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.

        • CARD_TRANSACTION_COUNT_15M: The number of transactions on the card in the trailing 15 minutes before the authorization.

        • CARD_TRANSACTION_COUNT_1H: The number of transactions on the card in the trailing hour up and until the authorization.

        • CARD_TRANSACTION_COUNT_24H: The number of transactions on the card in the trailing 24 hours up and until the authorization.

        • CARD_STATE: The current state of the card associated with the transaction. Valid values are CLOSED, OPEN, PAUSED, PENDING_ACTIVATION, PENDING_FULFILLMENT.

        • PIN_ENTERED: Indicates whether a PIN was entered during the transaction. Valid values are TRUE, FALSE.

        • PIN_STATUS: The current state of card's PIN. Valid values are NOT_SET, OK, BLOCKED.

        • WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values are APPLE_PAY, GOOGLE_PAY, SAMSUNG_PAY, MASTERPASS, MERCHANT, OTHER, NONE.

        • TRANSACTION_INITIATOR: The entity that initiated the transaction indicates the source of the token. Valid values are CARDHOLDER, MERCHANT, UNKNOWN.

        • ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values are MATCH, MATCH_ADDRESS_ONLY, MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.