Class ConditionalAuthorizationActionParameters.Condition.Builder
-
- All Implemented Interfaces:
public final class ConditionalAuthorizationActionParameters.Condition.BuilderA builder for Condition.
-
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalAuthorizationActionParameters.Condition.Builder attribute(ConditionalAuthorizationActionParameters.Condition.Attribute attribute)
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN,CREDENTIAL_ON_FILE, orECOMMERCE.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.CASH_AMOUNT: The cash amount of the transaction in minor units (cents). This represents the amount of cash being withdrawn or advanced.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.CARD_TRANSACTION_COUNT_15M: The number of transactions on the card in the trailing 15 minutes before the authorization.CARD_TRANSACTION_COUNT_1H: The number of transactions on the card in the trailing hour up and until the authorization.CARD_TRANSACTION_COUNT_24H: The number of transactions on the card in the trailing 24 hours up and until the authorization.CARD_DECLINE_COUNT_15M: The number of declined transactions on the card in the trailing 15 minutes before the authorization.CARD_DECLINE_COUNT_1H: The number of declined transactions on the card in the trailing hour up and until the authorization.CARD_DECLINE_COUNT_24H: The number of declined transactions on the card in the trailing 24 hours up and until the authorization.CARD_STATE: The current state of the card associated with the transaction. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.PIN_ENTERED: Indicates whether a PIN was entered during the transaction. Valid values areTRUE,FALSE.PIN_STATUS: The current state of card's PIN. Valid values areNOT_SET,OK,BLOCKED.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.TRANSACTION_INITIATOR: The entity that initiated the transaction indicates the source of the token. Valid values areCARDHOLDER,MERCHANT,UNKNOWN.ADDRESS_MATCH: Lithic's evaluation result comparing transaction's address data with the cardholder KYC data if it exists. Valid values areMATCH,MATCH_ADDRESS_ONLY,MATCH_ZIP_ONLY,MISMATCH,NOT_PRESENT.SERVICE_LOCATION_STATE: The state/province code (ISO 3166-2) where the cardholder received the service, e.g. "NY". When a service location is present in the network data, the service location state is used. Otherwise, falls back to the card acceptor state.SERVICE_LOCATION_POSTAL_CODE: The postal code where the cardholder received the service, e.g. "10001". When a service location is present in the network data, the service location postal code is used. Otherwise, falls back to the card acceptor postal code.CARD_AGE: The age of the card in seconds at the time of the authorization.ACCOUNT_AGE: The age of the account holder's account in seconds at the time of the authorization.AMOUNT_Z_SCORE: The z-score of the transaction amount relative to the entity's transaction history. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval.AVG_TRANSACTION_AMOUNT: The average approved transaction amount for the entity over the specified window, in cents. Requiresparameters.scopeandparameters.interval.STDEV_TRANSACTION_AMOUNT: The standard deviation of approved transaction amounts for the entity over the specified window, in cents. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval.IS_NEW_COUNTRY: Whether the transaction's merchant country has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_NEW_MCC: Whether the transaction's MCC has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_FIRST_TRANSACTION: Whether this is the first transaction for the entity. Valid values areTRUE,FALSE. Requiresparameters.scope.CONSECUTIVE_DECLINES: The number of consecutive declined transactions for the entity over the last 30 days (rolling). Requiresparameters.scope. Not supported forBUSINESS_ACCOUNTscope.TIME_SINCE_LAST_TRANSACTION: The number of days since the last approved transaction for the entity. Requiresparameters.scope.DISTINCT_COUNTRY_COUNT: The number of distinct merchant countries seen in the entity's transaction history. Requiresparameters.scope.IS_NEW_MERCHANT: Whether the card acceptor ID has not been seen in the card's approved transaction history (capped at the 1000 most recently seen merchants). Valid values areTRUE,FALSE. Card-scoped only; noparametersrequired.THREE_DS_SUCCESS_RATE: The 3DS authentication success rate for the card, as a percentage from 0.0 to 100.0. Card-scoped only; noparametersrequired.TRAVEL_SPEED: The estimated speed of travel derived from the distance between the postal code centers of the last card-present transaction and the current transaction, divided by the elapsed time. Null if there is no prior card-present transaction, if either postal code cannot be geocoded, or if elapsed time is zero. Requiresparameters.unitset toMPHorKPH.DISTANCE_FROM_LAST_TRANSACTION: The estimated distance between the postal code centers of the last card-present transaction and the current transaction. Null if there is no prior card-present transaction or if either postal code cannot be geocoded. Requiresparameters.unitset toMILESorKILOMETERS.
-
attribute
final ConditionalAuthorizationActionParameters.Condition.Builder attribute(JsonField<ConditionalAuthorizationActionParameters.Condition.Attribute> attribute)
Sets Builder.attribute to an arbitrary JSON value.
You should usually call Builder.attribute with a well-typed Attribute value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final ConditionalAuthorizationActionParameters.Condition.Builder operation(ConditionalOperation operation)
The operation to apply to the attribute
-
operation
final ConditionalAuthorizationActionParameters.Condition.Builder operation(JsonField<ConditionalOperation> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed ConditionalOperation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalAuthorizationActionParameters.Condition.Builder value(ConditionalValue value)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
value
final ConditionalAuthorizationActionParameters.Condition.Builder value(JsonField<ConditionalValue> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed ConditionalValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalAuthorizationActionParameters.Condition.Builder value(String regex)
Alias for calling value with
ConditionalValue.ofRegex(regex).
-
value
final ConditionalAuthorizationActionParameters.Condition.Builder value(Long number)
Alias for calling value with
ConditionalValue.ofNumber(number).
-
value
final ConditionalAuthorizationActionParameters.Condition.Builder value(OffsetDateTime timestamp)
Alias for calling value with
ConditionalValue.ofTimestamp(timestamp).
-
valueOfListOfStrings
final ConditionalAuthorizationActionParameters.Condition.Builder valueOfListOfStrings(List<String> listOfStrings)
Alias for calling value with
ConditionalValue.ofListOfStrings(listOfStrings).
-
parameters
final ConditionalAuthorizationActionParameters.Condition.Builder parameters(ConditionalAuthorizationActionParameters.Condition.Parameters parameters)
Additional parameters for certain attributes. Required when
attributeis one ofAMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT(requirescope); orTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION(requireunit). Not used for other attributes.
-
parameters
final ConditionalAuthorizationActionParameters.Condition.Builder parameters(JsonField<ConditionalAuthorizationActionParameters.Condition.Parameters> parameters)
Sets Builder.parameters to an arbitrary JSON value.
You should usually call Builder.parameters with a well-typed Parameters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ConditionalAuthorizationActionParameters.Condition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConditionalAuthorizationActionParameters.Condition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConditionalAuthorizationActionParameters.Condition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConditionalAuthorizationActionParameters.Condition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConditionalAuthorizationActionParameters.Condition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConditionalAuthorizationActionParameters.Condition build()
Returns an immutable instance of Condition.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-