Class ConditionalAuthorizationActionParameters.Condition.Parameters
-
- All Implemented Interfaces:
public final class ConditionalAuthorizationActionParameters.Condition.ParametersAdditional parameters required for transaction history signal attributes. Required when
attributeis one ofAMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT. Not used for other attributes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalAuthorizationActionParameters.Condition.Parameters.BuilderA builder for Parameters.
public final classConditionalAuthorizationActionParameters.Condition.Parameters.IntervalThe time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).public final classConditionalAuthorizationActionParameters.Condition.Parameters.ScopeThe entity scope to evaluate the attribute against.
-
Method Summary
-
-
Method Detail
-
interval
final Optional<ConditionalAuthorizationActionParameters.Condition.Parameters.Interval> interval()
The time window for statistical attributes (
AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT). UseLIFETIMEfor all-time history or a specific window (7D,30D,90D).
-
scope
final Optional<ConditionalAuthorizationActionParameters.Condition.Parameters.Scope> scope()
The entity scope to evaluate the attribute against.
-
_interval
final JsonField<ConditionalAuthorizationActionParameters.Condition.Parameters.Interval> _interval()
Returns the raw JSON value of interval.
Unlike interval, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<ConditionalAuthorizationActionParameters.Condition.Parameters.Scope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ConditionalAuthorizationActionParameters.Condition.Parameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalAuthorizationActionParameters.Condition.Parameters.Builder builder()
Returns a mutable builder for constructing an instance of Parameters.
-
-
-
-