Class ConditionalCardTransactionUpdateActionParameters.Condition
-
- All Implemented Interfaces:
public final class ConditionalCardTransactionUpdateActionParameters.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalCardTransactionUpdateActionParameters.Condition.BuilderA builder for Condition.
public final classConditionalCardTransactionUpdateActionParameters.Condition.AttributeThe attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x. Use an integer value.TRANSACTION_STATUS: The status of the transaction. Valid values arePENDING,VOIDED,SETTLING,SETTLED,BOUNCED,RETURNED,DECLINED,EXPIRED.LAST_EVENT_TYPE: The type of the most recent event on the transaction. Valid values areAUTHORIZATION,AUTHORIZATION_ADVICE,AUTHORIZATION_EXPIRY,AUTHORIZATION_REVERSAL,BALANCE_INQUIRY,CLEARING,CORRECTION_CREDIT,CORRECTION_DEBIT,CREDIT_AUTHORIZATION,CREDIT_AUTHORIZATION_ADVICE,FINANCIAL_AUTHORIZATION,FINANCIAL_CREDIT_AUTHORIZATION,RETURN,RETURN_REVERSAL.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN, orCREDENTIAL_ON_FILE.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.CARD_AGE: The age of the card in seconds at the time of the transaction. Use an integer value.ACCOUNT_AGE: The age of the account in seconds at the time of the transaction. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.SPEND_VELOCITY_COUNT: The number of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters. Use an integer value.SPEND_VELOCITY_AMOUNT: The total spend amount (in cents) of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters. Use an integer value.AMOUNT_Z_SCORE: The z-score of the transaction amount relative to the entity's transaction history. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval. Use a decimal value.AVG_TRANSACTION_AMOUNT: The average approved transaction amount for the entity over the specified window, in cents. Requiresparameters.scopeandparameters.interval. Use a decimal value.STDEV_TRANSACTION_AMOUNT: The standard deviation of approved transaction amounts for the entity over the specified window, in cents. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval. Use a decimal value.IS_NEW_COUNTRY: Whether the transaction's merchant country has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_NEW_MCC: Whether the transaction's MCC has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_FIRST_TRANSACTION: Whether this is the first transaction for the entity. Valid values areTRUE,FALSE. Requiresparameters.scope.CONSECUTIVE_DECLINES: The number of consecutive declined transactions for the entity over the last 30 days (rolling). Requiresparameters.scope. Use an integer value.TIME_SINCE_LAST_TRANSACTION: The number of days since the last approved transaction for the entity, rounded to the nearest whole day. Requiresparameters.scope. Use an integer value.DISTINCT_COUNTRY_COUNT: The number of distinct merchant countries seen in the entity's transaction history. Requiresparameters.scope. Use an integer value.IS_NEW_MERCHANT: Whether the card acceptor ID has not been seen in the card's approved transaction history (capped at the 1000 most recently seen merchants). Valid values areTRUE,FALSE. Card-scoped only; noparametersrequired.THREE_DS_SUCCESS_RATE: The 3DS authentication success rate for the card, as a percentage from 0.0 to 100.0. Card-scoped only; noparametersrequired. Use a decimal value.TRAVEL_SPEED: The estimated speed of travel derived from the distance between the postal code centers of the last card-present transaction and the current transaction, divided by the elapsed time. Null if there is no prior card-present transaction, if either postal code cannot be geocoded, or if elapsed time is zero. Requiresparameters.unitset toMPHorKPH. Use a decimal value.DISTANCE_FROM_LAST_TRANSACTION: The estimated distance between the postal code centers of the last card-present transaction and the current transaction. Null if there is no prior card-present transaction or if either postal code cannot be geocoded. Requiresparameters.unitset toMILESorKILOMETERS. Use a decimal value.
public final classConditionalCardTransactionUpdateActionParameters.Condition.ParametersAdditional parameters for certain attributes. Required when
attributeisSPEND_VELOCITY_COUNTorSPEND_VELOCITY_AMOUNT(requirescope,period, and optionalfilters);AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT(requirescope, and additionallyintervalfor the statistical attributes); orTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION(requireunit). Not used for other attributes.
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalCardTransactionUpdateActionParameters.Condition.Attribute attribute()
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder. Use an integer value.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x. Use an integer value.TRANSACTION_STATUS: The status of the transaction. Valid values arePENDING,VOIDED,SETTLING,SETTLED,BOUNCED,RETURNED,DECLINED,EXPIRED.LAST_EVENT_TYPE: The type of the most recent event on the transaction. Valid values areAUTHORIZATION,AUTHORIZATION_ADVICE,AUTHORIZATION_EXPIRY,AUTHORIZATION_REVERSAL,BALANCE_INQUIRY,CLEARING,CORRECTION_CREDIT,CORRECTION_DEBIT,CREDIT_AUTHORIZATION,CREDIT_AUTHORIZATION_ADVICE,FINANCIAL_AUTHORIZATION,FINANCIAL_CREDIT_AUTHORIZATION,RETURN,RETURN_REVERSAL.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN, orCREDENTIAL_ON_FILE.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.CARD_AGE: The age of the card in seconds at the time of the transaction. Use an integer value.ACCOUNT_AGE: The age of the account in seconds at the time of the transaction. Use an integer value. For programs where Lithic does not manage or retain account holder data, this attribute does not evaluate.SPEND_VELOCITY_COUNT: The number of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters. Use an integer value.SPEND_VELOCITY_AMOUNT: The total spend amount (in cents) of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters. Use an integer value.AMOUNT_Z_SCORE: The z-score of the transaction amount relative to the entity's transaction history. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval. Use a decimal value.AVG_TRANSACTION_AMOUNT: The average approved transaction amount for the entity over the specified window, in cents. Requiresparameters.scopeandparameters.interval. Use a decimal value.STDEV_TRANSACTION_AMOUNT: The standard deviation of approved transaction amounts for the entity over the specified window, in cents. Null if fewer than 30 approved transactions in the specified window. Requiresparameters.scopeandparameters.interval. Use a decimal value.IS_NEW_COUNTRY: Whether the transaction's merchant country has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_NEW_MCC: Whether the transaction's MCC has not been seen in the entity's transaction history. Valid values areTRUE,FALSE. Requiresparameters.scope.IS_FIRST_TRANSACTION: Whether this is the first transaction for the entity. Valid values areTRUE,FALSE. Requiresparameters.scope.CONSECUTIVE_DECLINES: The number of consecutive declined transactions for the entity over the last 30 days (rolling). Requiresparameters.scope. Use an integer value.TIME_SINCE_LAST_TRANSACTION: The number of days since the last approved transaction for the entity, rounded to the nearest whole day. Requiresparameters.scope. Use an integer value.DISTINCT_COUNTRY_COUNT: The number of distinct merchant countries seen in the entity's transaction history. Requiresparameters.scope. Use an integer value.IS_NEW_MERCHANT: Whether the card acceptor ID has not been seen in the card's approved transaction history (capped at the 1000 most recently seen merchants). Valid values areTRUE,FALSE. Card-scoped only; noparametersrequired.THREE_DS_SUCCESS_RATE: The 3DS authentication success rate for the card, as a percentage from 0.0 to 100.0. Card-scoped only; noparametersrequired. Use a decimal value.TRAVEL_SPEED: The estimated speed of travel derived from the distance between the postal code centers of the last card-present transaction and the current transaction, divided by the elapsed time. Null if there is no prior card-present transaction, if either postal code cannot be geocoded, or if elapsed time is zero. Requiresparameters.unitset toMPHorKPH. Use a decimal value.DISTANCE_FROM_LAST_TRANSACTION: The estimated distance between the postal code centers of the last card-present transaction and the current transaction. Null if there is no prior card-present transaction or if either postal code cannot be geocoded. Requiresparameters.unitset toMILESorKILOMETERS. Use a decimal value.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
parameters
final Optional<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters> parameters()
Additional parameters for certain attributes. Required when
attributeisSPEND_VELOCITY_COUNTorSPEND_VELOCITY_AMOUNT(requirescope,period, and optionalfilters);AMOUNT_Z_SCORE,AVG_TRANSACTION_AMOUNT,STDEV_TRANSACTION_AMOUNT,IS_NEW_COUNTRY,IS_NEW_MCC,IS_FIRST_TRANSACTION,CONSECUTIVE_DECLINES,TIME_SINCE_LAST_TRANSACTION, orDISTINCT_COUNTRY_COUNT(requirescope, and additionallyintervalfor the statistical attributes); orTRAVEL_SPEEDorDISTANCE_FROM_LAST_TRANSACTION(requireunit). Not used for other attributes.
-
_attribute
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Attribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_parameters
final JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder toBuilder()
-
validate
final ConditionalCardTransactionUpdateActionParameters.Condition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ConditionalCardTransactionUpdateActionParameters.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-