Class ConditionalCardTransactionUpdateActionParameters.Condition.Builder
-
- All Implemented Interfaces:
public final class ConditionalCardTransactionUpdateActionParameters.Condition.BuilderA builder for Condition.
-
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder attribute(ConditionalCardTransactionUpdateActionParameters.Condition.Attribute attribute)
The attribute to target.
The following attributes may be targeted:
MCC: A four-digit number listed in ISO 18245. An MCC is used to classify a business by the types of goods or services it provides.COUNTRY: Country of entity of card acceptor. Possible values are: (1) all ISO 3166-1 alpha-3 country codes, (2) QZZ for Kosovo, and (3) ANT for Netherlands Antilles.CURRENCY: 3-character alphabetic ISO 4217 code for the merchant currency of the transaction.MERCHANT_ID: Unique alphanumeric identifier for the payment card acceptor (merchant).DESCRIPTOR: Short description of card acceptor.TRANSACTION_AMOUNT: The base transaction amount (in cents) plus the acquirer fee field in the settlement/cardholder billing currency. This is the amount the issuer should authorize against unless the issuer is paying the acquirer fee on behalf of the cardholder.RISK_SCORE: Network-provided score assessing risk level associated with a given authorization. Scores are on a range of 0-999, with 0 representing the lowest risk and 999 representing the highest risk. For Visa transactions, where the raw score has a range of 0-99, Lithic will normalize the score by multiplying the raw score by 10x.TRANSACTION_STATUS: The status of the transaction. Valid values arePENDING,VOIDED,SETTLING,SETTLED,BOUNCED,RETURNED,DECLINED,EXPIRED.LAST_EVENT_TYPE: The type of the most recent event on the transaction. Valid values areAUTHORIZATION,AUTHORIZATION_ADVICE,AUTHORIZATION_EXPIRY,AUTHORIZATION_REVERSAL,BALANCE_INQUIRY,CLEARING,CORRECTION_CREDIT,CORRECTION_DEBIT,CREDIT_AUTHORIZATION,CREDIT_AUTHORIZATION_ADVICE,FINANCIAL_AUTHORIZATION,FINANCIAL_CREDIT_AUTHORIZATION,RETURN,RETURN_REVERSAL.LIABILITY_SHIFT: Indicates whether chargeback liability shift to the issuer applies to the transaction. Valid values areNONE,3DS_AUTHENTICATED, orTOKEN_AUTHENTICATED.PAN_ENTRY_MODE: The method by which the cardholder's primary account number (PAN) was entered. Valid values areAUTO_ENTRY,BAR_CODE,CONTACTLESS,ECOMMERCE,ERROR_KEYED,ERROR_MAGNETIC_STRIPE,ICC,KEY_ENTERED,MAGNETIC_STRIPE,MANUAL,OCR,SECURE_CARDLESS,UNSPECIFIED,UNKNOWN, orCREDENTIAL_ON_FILE.WALLET_TYPE: For transactions using a digital wallet token, indicates the source of the token. Valid values areAPPLE_PAY,GOOGLE_PAY,SAMSUNG_PAY,MASTERPASS,MERCHANT,OTHER,NONE.CARD_AGE: The age of the card in seconds at the time of the transaction.ACCOUNT_AGE: The age of the account in seconds at the time of the transaction.SPEND_VELOCITY_COUNT: The number of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters.SPEND_VELOCITY_AMOUNT: The total spend amount (in cents) of transactions matching the specified filters within the given period. Requiresparameterswithscope,period, and optionalfilters.
-
attribute
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder attribute(JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Attribute> attribute)
Sets Builder.attribute to an arbitrary JSON value.
You should usually call Builder.attribute with a well-typed Attribute value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
operation
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder operation(ConditionalOperation operation)
The operation to apply to the attribute
-
operation
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder operation(JsonField<ConditionalOperation> operation)
Sets Builder.operation to an arbitrary JSON value.
You should usually call Builder.operation with a well-typed ConditionalOperation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder value(ConditionalValue value)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
value
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder value(JsonField<ConditionalValue> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed ConditionalValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder value(String regex)
Alias for calling value with
ConditionalValue.ofRegex(regex).
-
value
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder value(Long number)
Alias for calling value with
ConditionalValue.ofNumber(number).
-
value
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder value(OffsetDateTime timestamp)
Alias for calling value with
ConditionalValue.ofTimestamp(timestamp).
-
valueOfListOfStrings
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder valueOfListOfStrings(List<String> listOfStrings)
Alias for calling value with
ConditionalValue.ofListOfStrings(listOfStrings).
-
parameters
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder parameters(ConditionalCardTransactionUpdateActionParameters.Condition.Parameters parameters)
Additional parameters for spend velocity attributes. Required when
attributeisSPEND_VELOCITY_COUNTorSPEND_VELOCITY_AMOUNT. Not used for other attributes.
-
parameters
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder parameters(JsonField<ConditionalCardTransactionUpdateActionParameters.Condition.Parameters> parameters)
Sets Builder.parameters to an arbitrary JSON value.
You should usually call Builder.parameters with a well-typed Parameters value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ConditionalCardTransactionUpdateActionParameters.Condition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ConditionalCardTransactionUpdateActionParameters.Condition build()
Returns an immutable instance of Condition.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-