Class ConditionalTokenizationActionParameters.Condition
-
- All Implemented Interfaces:
public final class ConditionalTokenizationActionParameters.Condition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classConditionalTokenizationActionParameters.Condition.BuilderA builder for Condition.
public final classConditionalTokenizationActionParameters.Condition.AttributeThe attribute to target.
The following attributes may be targeted:
TIMESTAMP: The timestamp of the tokenization request in ISO 8601 format.TOKENIZATION_CHANNEL: The channel through which the tokenization request was initiated. Valid values areDIGITAL_WALLET,MERCHANT.TOKENIZATION_SOURCE: The source of the tokenization request. Valid values areACCOUNT_ON_FILE,MANUAL_PROVISION,PUSH_PROVISION,CHIP_DIP,CONTACTLESS_TAP,TOKEN,UNKNOWN.TOKEN_REQUESTOR_NAME: The name of the entity requesting the token. Valid values areALT_ID,AMAZON_ONE,AMERICAN_EXPRESS_TOKEN_SERVICE,ANDROID_PAY,APPLE_PAY,FACEBOOK,FITBIT_PAY,GARMIN_PAY,GOOGLE_PAY,GOOGLE_VCN,ISSUER_HCE,MICROSOFT_PAY,NETFLIX,SAMSUNG_PAY,UNKNOWN,VISA_CHECKOUT.WALLET_ACCOUNT_SCORE: Risk score for the account in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).WALLET_DEVICE_SCORE: Risk score for the device in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).WALLET_RECOMMENDED_DECISION: The decision recommended by the digital wallet provider. Valid values include APPROVE, DECLINE, REQUIRE_ADDITIONAL_AUTHENTICATION.WALLET_RECOMMENDATION_REASONS: List of reasons provided by the digital wallet provider for the recommended decision. Valid values are:TOKEN_REQUESTOR_ID: Unique identifier for the entity requesting the token.WALLET_TOKEN_STATUS: The current status of the wallet token.CARD_STATE: The state of the card being tokenized. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.
-
Method Summary
-
-
Method Detail
-
attribute
final ConditionalTokenizationActionParameters.Condition.Attribute attribute()
The attribute to target.
The following attributes may be targeted:
TIMESTAMP: The timestamp of the tokenization request in ISO 8601 format.TOKENIZATION_CHANNEL: The channel through which the tokenization request was initiated. Valid values areDIGITAL_WALLET,MERCHANT.TOKENIZATION_SOURCE: The source of the tokenization request. Valid values areACCOUNT_ON_FILE,MANUAL_PROVISION,PUSH_PROVISION,CHIP_DIP,CONTACTLESS_TAP,TOKEN,UNKNOWN.TOKEN_REQUESTOR_NAME: The name of the entity requesting the token. Valid values areALT_ID,AMAZON_ONE,AMERICAN_EXPRESS_TOKEN_SERVICE,ANDROID_PAY,APPLE_PAY,FACEBOOK,FITBIT_PAY,GARMIN_PAY,GOOGLE_PAY,GOOGLE_VCN,ISSUER_HCE,MICROSOFT_PAY,NETFLIX,SAMSUNG_PAY,UNKNOWN,VISA_CHECKOUT.WALLET_ACCOUNT_SCORE: Risk score for the account in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).WALLET_DEVICE_SCORE: Risk score for the device in the digital wallet. Numeric value where lower numbers indicate higher risk (e.g., 1 = high risk, 2 = medium risk).WALLET_RECOMMENDED_DECISION: The decision recommended by the digital wallet provider. Valid values include APPROVE, DECLINE, REQUIRE_ADDITIONAL_AUTHENTICATION.WALLET_RECOMMENDATION_REASONS: List of reasons provided by the digital wallet provider for the recommended decision. Valid values are:TOKEN_REQUESTOR_ID: Unique identifier for the entity requesting the token.WALLET_TOKEN_STATUS: The current status of the wallet token.CARD_STATE: The state of the card being tokenized. Valid values areCLOSED,OPEN,PAUSED,PENDING_ACTIVATION,PENDING_FULFILLMENT.
-
operation
final ConditionalOperation operation()
The operation to apply to the attribute
-
value
final ConditionalValue value()
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
_attribute
final JsonField<ConditionalTokenizationActionParameters.Condition.Attribute> _attribute()
Returns the raw JSON value of attribute.
Unlike attribute, this method doesn't throw if the JSON field has an unexpected type.
-
_operation
final JsonField<ConditionalOperation> _operation()
Returns the raw JSON value of operation.
Unlike operation, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ConditionalValue> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ConditionalTokenizationActionParameters.Condition.Builder toBuilder()
-
validate
final ConditionalTokenizationActionParameters.Condition validate()
-
builder
final static ConditionalTokenizationActionParameters.Condition.Builder builder()
Returns a mutable builder for constructing an instance of Condition.
The following fields are required:
.attribute() .operation() .value()
-
-
-
-