Class ConditionalValue
-
- All Implemented Interfaces:
public final class ConditionalValueA regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceConditionalValue.VisitorAn interface that defines how to map each variant of ConditionalValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>regex()A regex string, to be used with MATCHESorDOES_NOT_MATCHfinal Optional<Long>number()A number, to be used with IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TOfinal Optional<List<String>>listOfStrings()An array of strings, to be used with IS_ONE_OForIS_NOT_ONE_OFfinal Optional<OffsetDateTime>timestamp()A timestamp, to be used with IS_AFTERorIS_BEFOREfinal BooleanisRegex()final BooleanisNumber()final BooleanisListOfStrings()final BooleanisTimestamp()final StringasRegex()A regex string, to be used with MATCHESorDOES_NOT_MATCHfinal LongasNumber()A number, to be used with IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TOfinal List<String>asListOfStrings()An array of strings, to be used with IS_ONE_OForIS_NOT_ONE_OFfinal OffsetDateTimeasTimestamp()A timestamp, to be used with IS_AFTERorIS_BEFOREfinal Optional<JsonValue>_json()final <T extends Any> Taccept(ConditionalValue.Visitor<T> visitor)final ConditionalValuevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ConditionalValueofRegex(String regex)A regex string, to be used with MATCHESorDOES_NOT_MATCHfinal static ConditionalValueofNumber(Long number)A number, to be used with IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TOfinal static ConditionalValueofListOfStrings(List<String> listOfStrings)An array of strings, to be used with IS_ONE_OForIS_NOT_ONE_OFfinal static ConditionalValueofTimestamp(OffsetDateTime timestamp)A timestamp, to be used with IS_AFTERorIS_BEFORE-
-
Method Detail
-
number
final Optional<Long> number()
A number, to be used with
IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TO
-
listOfStrings
final Optional<List<String>> listOfStrings()
An array of strings, to be used with
IS_ONE_OForIS_NOT_ONE_OF
-
timestamp
final Optional<OffsetDateTime> timestamp()
A timestamp, to be used with
IS_AFTERorIS_BEFORE
-
isListOfStrings
final Boolean isListOfStrings()
-
isTimestamp
final Boolean isTimestamp()
-
asNumber
final Long asNumber()
A number, to be used with
IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TO
-
asListOfStrings
final List<String> asListOfStrings()
An array of strings, to be used with
IS_ONE_OForIS_NOT_ONE_OF
-
asTimestamp
final OffsetDateTime asTimestamp()
A timestamp, to be used with
IS_AFTERorIS_BEFORE
-
accept
final <T extends Any> T accept(ConditionalValue.Visitor<T> visitor)
-
validate
final ConditionalValue validate()
-
ofRegex
final static ConditionalValue ofRegex(String regex)
A regex string, to be used with
MATCHESorDOES_NOT_MATCH
-
ofNumber
final static ConditionalValue ofNumber(Long number)
A number, to be used with
IS_GREATER_THAN,IS_GREATER_THAN_OR_EQUAL_TO,IS_LESS_THAN,IS_LESS_THAN_OR_EQUAL_TO,IS_EQUAL_TO, orIS_NOT_EQUAL_TO
-
ofListOfStrings
final static ConditionalValue ofListOfStrings(List<String> listOfStrings)
An array of strings, to be used with
IS_ONE_OForIS_NOT_ONE_OF
-
ofTimestamp
final static ConditionalValue ofTimestamp(OffsetDateTime timestamp)
A timestamp, to be used with
IS_AFTERorIS_BEFORE
-
-
-
-