Class DisputeEvidence
-
- All Implemented Interfaces:
public final class DisputeEvidenceDispute evidence.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDisputeEvidence.BuilderA builder for DisputeEvidence.
public final classDisputeEvidence.UploadStatusUpload status types:
DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final OffsetDateTimecreated()Timestamp of when dispute evidence was created. final StringdisputeToken()Dispute token evidence is attached to. final DisputeEvidence.UploadStatusuploadStatus()Upload status types: DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
final Optional<String>downloadUrl()URL to download evidence. final Optional<String>filename()File name of evidence. final Optional<String>uploadUrl()URL to upload evidence. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_disputeToken()Returns the raw JSON value of disputeToken. final JsonField<DisputeEvidence.UploadStatus>_uploadStatus()Returns the raw JSON value of uploadStatus. final JsonField<String>_downloadUrl()Returns the raw JSON value of downloadUrl. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_uploadUrl()Returns the raw JSON value of uploadUrl. final Map<String, JsonValue>_additionalProperties()final DisputeEvidence.BuildertoBuilder()final DisputeEvidencevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DisputeEvidence.Builderbuilder()Returns a mutable builder for constructing an instance of DisputeEvidence. -
-
Method Detail
-
created
final OffsetDateTime created()
Timestamp of when dispute evidence was created.
-
disputeToken
final String disputeToken()
Dispute token evidence is attached to.
-
uploadStatus
final DisputeEvidence.UploadStatus uploadStatus()
Upload status types:
DELETED- Evidence was deleted.ERROR- Evidence upload failed.PENDING- Evidence is pending upload.REJECTED- Evidence was rejected.UPLOADED- Evidence was uploaded.
-
downloadUrl
final Optional<String> downloadUrl()
URL to download evidence. Only shown when
upload_statusisUPLOADED.
-
filename
final Optional<String> filename()
File name of evidence. Recommended to give the dispute evidence a human-readable identifier.
-
uploadUrl
final Optional<String> uploadUrl()
URL to upload evidence. Only shown when
upload_statusisPENDING.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_disputeToken
final JsonField<String> _disputeToken()
Returns the raw JSON value of disputeToken.
Unlike disputeToken, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadStatus
final JsonField<DisputeEvidence.UploadStatus> _uploadStatus()
Returns the raw JSON value of uploadStatus.
Unlike uploadStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_downloadUrl
final JsonField<String> _downloadUrl()
Returns the raw JSON value of downloadUrl.
Unlike downloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_uploadUrl
final JsonField<String> _uploadUrl()
Returns the raw JSON value of uploadUrl.
Unlike uploadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DisputeEvidence.Builder toBuilder()
-
validate
final DisputeEvidence validate()
-
builder
final static DisputeEvidence.Builder builder()
Returns a mutable builder for constructing an instance of DisputeEvidence.
The following fields are required:
.token() .created() .disputeToken() .uploadStatus()
-
-
-