Package com.lithic.api.models
Class EnhancedData.Fleet.FuelData
-
- All Implemented Interfaces:
public final class EnhancedData.Fleet.FuelData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEnhancedData.Fleet.FuelData.BuilderA builder for FuelData.
public final classEnhancedData.Fleet.FuelData.FuelTypeThe type of fuel purchased.
public final classEnhancedData.Fleet.FuelData.FuelUnitOfMeasureUnit of measure for fuel disbursement.
-
Method Summary
-
-
Method Detail
-
type
final Optional<EnhancedData.Fleet.FuelData.FuelType> type()
The type of fuel purchased.
-
unitOfMeasure
final Optional<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> unitOfMeasure()
Unit of measure for fuel disbursement.
-
_quantity
final JsonField<String> _quantity()
Returns the raw JSON value of quantity.
Unlike quantity, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EnhancedData.Fleet.FuelData.FuelType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_unitOfMeasure
final JsonField<EnhancedData.Fleet.FuelData.FuelUnitOfMeasure> _unitOfMeasure()
Returns the raw JSON value of unitOfMeasure.
Unlike unitOfMeasure, this method doesn't throw if the JSON field has an unexpected type.
-
_unitPrice
final JsonField<Long> _unitPrice()
Returns the raw JSON value of unitPrice.
Unlike unitPrice, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EnhancedData.Fleet.FuelData.Builder toBuilder()
-
validate
final EnhancedData.Fleet.FuelData validate()
-
builder
final static EnhancedData.Fleet.FuelData.Builder builder()
Returns a mutable builder for constructing an instance of FuelData.
-
-
-
-