Class FinancialAccountInterestTierScheduleListParams
-
- All Implemented Interfaces:
-
com.lithic.api.core.Params
public final class FinancialAccountInterestTierScheduleListParams implements Params
List interest tier schedules for a financial account with optional date filtering.
If no date parameters are provided, returns all tier schedules. If date parameters are provided, uses filtering to return matching schedules (max 100).
for_date: Returns exact match (takes precedence over other dates)
before_date: Returns schedules with effective_date <= before_date
after_date: Returns schedules with effective_date >= after_date
Both before_date and after_date: Returns schedules in range
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFinancialAccountInterestTierScheduleListParams.BuilderA builder for FinancialAccountInterestTierScheduleListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>financialAccountToken()final Optional<LocalDate>afterDate()Return schedules with effective_date >= after_date (ISO format YYYY-MM-DD) final Optional<LocalDate>beforeDate()Return schedules with effective_date <= before_date (ISO format YYYY-MM-DD) final Optional<LocalDate>forDate()Return schedule with effective_date == for_date (ISO format YYYY-MM-DD) final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FinancialAccountInterestTierScheduleListParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FinancialAccountInterestTierScheduleListParamsnone()final static FinancialAccountInterestTierScheduleListParams.Builderbuilder()Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleListParams. -
-
Method Detail
-
financialAccountToken
final Optional<String> financialAccountToken()
-
afterDate
final Optional<LocalDate> afterDate()
Return schedules with effective_date >= after_date (ISO format YYYY-MM-DD)
-
beforeDate
final Optional<LocalDate> beforeDate()
Return schedules with effective_date <= before_date (ISO format YYYY-MM-DD)
-
forDate
final Optional<LocalDate> forDate()
Return schedule with effective_date == for_date (ISO format YYYY-MM-DD)
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FinancialAccountInterestTierScheduleListParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static FinancialAccountInterestTierScheduleListParams none()
-
builder
final static FinancialAccountInterestTierScheduleListParams.Builder builder()
Returns a mutable builder for constructing an instance of FinancialAccountInterestTierScheduleListParams.
-
-
-
-