Class HoldCreateParams.CreateHoldRequest
-
- All Implemented Interfaces:
public final class HoldCreateParams.CreateHoldRequestRequest to create a new hold on a financial account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldCreateParams.CreateHoldRequest.BuilderA builder for CreateHoldRequest.
-
Method Summary
Modifier and Type Method Description final Longamount()Amount to hold in cents final Optional<String>token()Customer-provided token for idempotency. final Optional<OffsetDateTime>expirationDatetime()When the hold should auto-expire final Optional<String>memo()Reason for the hold final Optional<String>userDefinedId()User-provided identifier for the hold final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<OffsetDateTime>_expirationDatetime()Returns the raw JSON value of expirationDatetime. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<String>_userDefinedId()Returns the raw JSON value of userDefinedId. final Map<String, JsonValue>_additionalProperties()final HoldCreateParams.CreateHoldRequest.BuildertoBuilder()final HoldCreateParams.CreateHoldRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldCreateParams.CreateHoldRequest.Builderbuilder()Returns a mutable builder for constructing an instance of CreateHoldRequest. -
-
Method Detail
-
token
final Optional<String> token()
Customer-provided token for idempotency. Becomes the hold token.
-
expirationDatetime
final Optional<OffsetDateTime> expirationDatetime()
When the hold should auto-expire
-
userDefinedId
final Optional<String> userDefinedId()
User-provided identifier for the hold
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDatetime
final JsonField<OffsetDateTime> _expirationDatetime()
Returns the raw JSON value of expirationDatetime.
Unlike expirationDatetime, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_userDefinedId
final JsonField<String> _userDefinedId()
Returns the raw JSON value of userDefinedId.
Unlike userDefinedId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HoldCreateParams.CreateHoldRequest.Builder toBuilder()
-
validate
final HoldCreateParams.CreateHoldRequest validate()
-
builder
final static HoldCreateParams.CreateHoldRequest.Builder builder()
Returns a mutable builder for constructing an instance of CreateHoldRequest.
The following fields are required:
.amount()
-
-
-
-