Class HoldEvent
-
- All Implemented Interfaces:
public final class HoldEventEvent representing a lifecycle change to a hold
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classHoldEvent.BuilderA builder for HoldEvent.
public final classHoldEvent.DetailedResultspublic final classHoldEvent.TransactionResultpublic final classHoldEvent.HoldEventTypeType of hold lifecycle event
-
Method Summary
Modifier and Type Method Description final Stringtoken()final Longamount()Amount in cents final OffsetDateTimecreated()final List<HoldEvent.DetailedResults>detailedResults()final Optional<String>memo()final HoldEvent.TransactionResultresult()final Optional<String>settlingTransactionToken()Transaction token of the payment that settled this hold (only populated for HOLD_SETTLED events) final HoldEvent.HoldEventTypetype()Type of hold lifecycle event final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<List<HoldEvent.DetailedResults>>_detailedResults()Returns the raw JSON value of detailedResults. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<HoldEvent.TransactionResult>_result()Returns the raw JSON value of result. final JsonField<String>_settlingTransactionToken()Returns the raw JSON value of settlingTransactionToken. final JsonField<HoldEvent.HoldEventType>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final HoldEvent.BuildertoBuilder()final HoldEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static HoldEvent.Builderbuilder()Returns a mutable builder for constructing an instance of HoldEvent. -
-
Method Detail
-
created
final OffsetDateTime created()
-
detailedResults
final List<HoldEvent.DetailedResults> detailedResults()
-
result
final HoldEvent.TransactionResult result()
-
settlingTransactionToken
final Optional<String> settlingTransactionToken()
Transaction token of the payment that settled this hold (only populated for HOLD_SETTLED events)
-
type
final HoldEvent.HoldEventType type()
Type of hold lifecycle event
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_detailedResults
final JsonField<List<HoldEvent.DetailedResults>> _detailedResults()
Returns the raw JSON value of detailedResults.
Unlike detailedResults, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<HoldEvent.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settlingTransactionToken
final JsonField<String> _settlingTransactionToken()
Returns the raw JSON value of settlingTransactionToken.
Unlike settlingTransactionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<HoldEvent.HoldEventType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final HoldEvent.Builder toBuilder()
-
builder
final static HoldEvent.Builder builder()
Returns a mutable builder for constructing an instance of HoldEvent.
The following fields are required:
.token() .amount() .created() .detailedResults() .memo() .result() .settlingTransactionToken() .type()
-
-
-
-