Class InterestTierSchedule
-
- All Implemented Interfaces:
public final class InterestTierScheduleEntry in the Tier Schedule of an account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInterestTierSchedule.BuilderA builder for InterestTierSchedule.
-
Method Summary
Modifier and Type Method Description final StringcreditProductToken()Globally unique identifier for a credit product final LocalDateeffectiveDate()Date the tier should be effective in YYYY-MM-DD format final Optional<String>tierName()Name of a tier contained in the credit product. final JsonValue_tierRates()Custom rates per category. final JsonField<String>_creditProductToken()Returns the raw JSON value of creditProductToken. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_tierName()Returns the raw JSON value of tierName. final Map<String, JsonValue>_additionalProperties()final InterestTierSchedule.BuildertoBuilder()final InterestTierSchedulevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InterestTierSchedule.Builderbuilder()Returns a mutable builder for constructing an instance of InterestTierSchedule. -
-
Method Detail
-
creditProductToken
final String creditProductToken()
Globally unique identifier for a credit product
-
effectiveDate
final LocalDate effectiveDate()
Date the tier should be effective in YYYY-MM-DD format
-
tierName
final Optional<String> tierName()
Name of a tier contained in the credit product. Mutually exclusive with tier_rates
-
_tierRates
final JsonValue _tierRates()
Custom rates per category. Mutually exclusive with tier_name
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = interestTierSchedule.tierRates().convert(MyClass.class);
-
_creditProductToken
final JsonField<String> _creditProductToken()
Returns the raw JSON value of creditProductToken.
Unlike creditProductToken, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_tierName
final JsonField<String> _tierName()
Returns the raw JSON value of tierName.
Unlike tierName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InterestTierSchedule.Builder toBuilder()
-
validate
final InterestTierSchedule validate()
-
builder
final static InterestTierSchedule.Builder builder()
Returns a mutable builder for constructing an instance of InterestTierSchedule.
The following fields are required:
.creditProductToken() .effectiveDate()
-
-
-
-