Package com.lithic.api.models
Class InternalTransaction.InternalAdjustmentEvent
-
- All Implemented Interfaces:
public final class InternalTransaction.InternalAdjustmentEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInternalTransaction.InternalAdjustmentEvent.BuilderA builder for InternalAdjustmentEvent.
public final classInternalTransaction.InternalAdjustmentEvent.TransactionResultpublic final classInternalTransaction.InternalAdjustmentEvent.Type
-
Method Summary
-
-
Method Detail
-
created
final OffsetDateTime created()
-
type
final InternalTransaction.InternalAdjustmentEvent.Type type()
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<InternalTransaction.InternalAdjustmentEvent.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InternalTransaction.InternalAdjustmentEvent.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InternalTransaction.InternalAdjustmentEvent.Builder toBuilder()
-
validate
final InternalTransaction.InternalAdjustmentEvent validate()
-
builder
final static InternalTransaction.InternalAdjustmentEvent.Builder builder()
Returns a mutable builder for constructing an instance of InternalAdjustmentEvent.
The following fields are required:
.token() .amount() .created() .result() .type()
-
-
-
-