Class InternalTransactionUpdatedWebhookEvent
-
- All Implemented Interfaces:
public final class InternalTransactionUpdatedWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInternalTransactionUpdatedWebhookEvent.BuilderA builder for InternalTransactionUpdatedWebhookEvent.
public final classInternalTransactionUpdatedWebhookEvent.EventTypeThe type of event that occurred.
-
Method Summary
-
-
Method Detail
-
toInternalTransaction
final InternalTransaction toInternalTransaction()
-
category
final InternalTransaction.Category category()
-
created
final OffsetDateTime created()
-
descriptor
final String descriptor()
-
events
final List<InternalTransaction.InternalAdjustmentEvent> events()
-
pendingAmount
final Long pendingAmount()
-
result
final InternalTransaction.TransactionResult result()
-
settledAmount
final Long settledAmount()
-
status
final InternalTransaction.TransactionStatus status()
-
updated
final OffsetDateTime updated()
-
eventType
final InternalTransactionUpdatedWebhookEvent.EventType eventType()
The type of event that occurred.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<InternalTransaction.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_descriptor
final JsonField<String> _descriptor()
Returns the raw JSON value of descriptor.
Unlike descriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_events
final JsonField<List<InternalTransaction.InternalAdjustmentEvent>> _events()
Returns the raw JSON value of events.
Unlike events, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingAmount
final JsonField<Long> _pendingAmount()
Returns the raw JSON value of pendingAmount.
Unlike pendingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<InternalTransaction.TransactionResult> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InternalTransaction.TransactionStatus> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_updated
final JsonField<OffsetDateTime> _updated()
Returns the raw JSON value of updated.
Unlike updated, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<InternalTransactionUpdatedWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InternalTransactionUpdatedWebhookEvent.Builder toBuilder()
-
validate
final InternalTransactionUpdatedWebhookEvent validate()
-
builder
final static InternalTransactionUpdatedWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of InternalTransactionUpdatedWebhookEvent.
The following fields are required:
.token() .category() .created() .currency() .descriptor() .events() .pendingAmount() .result() .settledAmount() .status() .updated() .eventType()
-
-
-
-