Class ParsedWebhookEvent.KycPayload
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.KycPayloadKYC payload for an updated account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classParsedWebhookEvent.KycPayload.BuilderA builder for KycPayload.
public final classParsedWebhookEvent.KycPayload.UpdateRequestOriginal request to update the account holder.
public final classParsedWebhookEvent.KycPayload.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final Stringtoken()The token of the account_holder that was created. final ParsedWebhookEvent.KycPayload.UpdateRequestupdateRequest()Original request to update the account holder. final Optional<ParsedWebhookEvent.KycPayload.EventType>eventType()The type of event that occurred. final Optional<String>externalId()A user provided id that can be used to link an account holder with an external system final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<ParsedWebhookEvent.KycPayload.UpdateRequest>_updateRequest()Returns the raw JSON value of updateRequest. final JsonField<ParsedWebhookEvent.KycPayload.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final Map<String, JsonValue>_additionalProperties()final ParsedWebhookEvent.KycPayload.BuildertoBuilder()final ParsedWebhookEvent.KycPayloadvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ParsedWebhookEvent.KycPayload.Builderbuilder()Returns a mutable builder for constructing an instance of KycPayload. -
-
Method Detail
-
updateRequest
final ParsedWebhookEvent.KycPayload.UpdateRequest updateRequest()
Original request to update the account holder.
-
eventType
final Optional<ParsedWebhookEvent.KycPayload.EventType> eventType()
The type of event that occurred.
-
externalId
final Optional<String> externalId()
A user provided id that can be used to link an account holder with an external system
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_updateRequest
final JsonField<ParsedWebhookEvent.KycPayload.UpdateRequest> _updateRequest()
Returns the raw JSON value of updateRequest.
Unlike updateRequest, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ParsedWebhookEvent.KycPayload.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ParsedWebhookEvent.KycPayload.Builder toBuilder()
-
validate
final ParsedWebhookEvent.KycPayload validate()
-
builder
final static ParsedWebhookEvent.KycPayload.Builder builder()
Returns a mutable builder for constructing an instance of KycPayload.
The following fields are required:
.token() .updateRequest()
-
-
-
-