Class ParsedWebhookEvent.LegacyPayload
-
- All Implemented Interfaces:
public final class ParsedWebhookEvent.LegacyPayloadLegacy payload for an updated account holder.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classParsedWebhookEvent.LegacyPayload.BuilderA builder for LegacyPayload.
public final classParsedWebhookEvent.LegacyPayload.EventTypeThe type of event that occurred.
-
Method Summary
Modifier and Type Method Description final Stringtoken()The token of the account_holder that was created. final Optional<String>businessAccountToken()If applicable, represents the business account token associated with the account_holder. final Optional<OffsetDateTime>created()When the account_holder updated event was created final Optional<String>email()If updated, the newly updated email associated with the account_holder otherwise the existing email is provided. final Optional<ParsedWebhookEvent.LegacyPayload.EventType>eventType()The type of event that occurred. final Optional<String>externalId()If applicable, represents the external_id associated with the account_holder. final Optional<String>firstName()If applicable, represents the account_holder's first name. final Optional<String>lastName()If applicable, represents the account_holder's last name. final Optional<String>legalBusinessName()If applicable, represents the account_holder's business name. final Optional<String>phoneNumber()If updated, the newly updated phone_number associated with the account_holder otherwise the existing phone_number is provided. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<String>_businessAccountToken()Returns the raw JSON value of businessAccountToken. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<ParsedWebhookEvent.LegacyPayload.EventType>_eventType()Returns the raw JSON value of eventType. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final JsonField<String>_legalBusinessName()Returns the raw JSON value of legalBusinessName. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final ParsedWebhookEvent.LegacyPayload.BuildertoBuilder()final ParsedWebhookEvent.LegacyPayloadvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ParsedWebhookEvent.LegacyPayload.Builderbuilder()Returns a mutable builder for constructing an instance of LegacyPayload. -
-
Method Detail
-
businessAccountToken
final Optional<String> businessAccountToken()
If applicable, represents the business account token associated with the account_holder.
-
created
final Optional<OffsetDateTime> created()
When the account_holder updated event was created
-
email
final Optional<String> email()
If updated, the newly updated email associated with the account_holder otherwise the existing email is provided.
-
eventType
final Optional<ParsedWebhookEvent.LegacyPayload.EventType> eventType()
The type of event that occurred.
-
externalId
final Optional<String> externalId()
If applicable, represents the external_id associated with the account_holder.
-
firstName
final Optional<String> firstName()
If applicable, represents the account_holder's first name.
-
lastName
final Optional<String> lastName()
If applicable, represents the account_holder's last name.
-
legalBusinessName
final Optional<String> legalBusinessName()
If applicable, represents the account_holder's business name.
-
phoneNumber
final Optional<String> phoneNumber()
If updated, the newly updated phone_number associated with the account_holder otherwise the existing phone_number is provided.
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_businessAccountToken
final JsonField<String> _businessAccountToken()
Returns the raw JSON value of businessAccountToken.
Unlike businessAccountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<ParsedWebhookEvent.LegacyPayload.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_legalBusinessName
final JsonField<String> _legalBusinessName()
Returns the raw JSON value of legalBusinessName.
Unlike legalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ParsedWebhookEvent.LegacyPayload.Builder toBuilder()
-
validate
final ParsedWebhookEvent.LegacyPayload validate()
-
builder
final static ParsedWebhookEvent.LegacyPayload.Builder builder()
Returns a mutable builder for constructing an instance of LegacyPayload.
The following fields are required:
.token()
-
-
-
-