Class Payment.PaymentEvent
-
- All Implemented Interfaces:
public final class Payment.PaymentEventNote: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related fields below are a preview. To learn more, contact your customer success manager.
Payment Event
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPayment.PaymentEvent.BuilderA builder for PaymentEvent.
public final classPayment.PaymentEvent.ResultAPPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
public final classPayment.PaymentEvent.PaymentEventTypeNote: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.
Event types:
ACH events:
ACH_ORIGINATION_INITIATED- ACH origination received and pending approval/release from an ACH hold.ACH_ORIGINATION_REVIEWED- ACH origination has completed the review process.ACH_ORIGINATION_CANCELLED- ACH origination has been cancelled.ACH_ORIGINATION_PROCESSED- ACH origination has been processed and sent to the Federal Reserve.ACH_ORIGINATION_SETTLED- ACH origination has settled.ACH_ORIGINATION_RELEASED- ACH origination released from pending to available balance.ACH_ORIGINATION_REJECTED- ACH origination was rejected and not sent to the Federal Reserve.ACH_RECEIPT_PROCESSED- ACH receipt pending release from an ACH holder.ACH_RECEIPT_SETTLED- ACH receipt funds have settled.ACH_RECEIPT_RELEASED- ACH receipt released from pending to available balance.ACH_RECEIPT_RELEASED_EARLY- ACH receipt released early from pending to available balance.ACH_RETURN_INITIATED- ACH initiated return for an ACH receipt.ACH_RETURN_PROCESSED- ACH receipt returned by the Receiving Depository Financial Institution.ACH_RETURN_SETTLED- ACH return settled by the Receiving Depository Financial Institution.ACH_RETURN_REJECTED- ACH return was rejected by the Receiving Depository Financial Institution.
Wire transfer events:
WIRE_TRANSFER_INBOUND_RECEIVED- Inbound wire transfer received from the Federal Reserve and pending release to available balance.WIRE_TRANSFER_INBOUND_SETTLED- Inbound wire transfer funds released from pending to available balance.WIRE_TRANSFER_INBOUND_BLOCKED- Inbound wire transfer blocked and funds frozen for regulatory review.
Wire return events:
WIRE_RETURN_OUTBOUND_INITIATED- Outbound wire return initiated to return funds from an inbound wire transfer.WIRE_RETURN_OUTBOUND_SENT- Outbound wire return sent to the Federal Reserve and pending acceptance.WIRE_RETURN_OUTBOUND_SETTLED- Outbound wire return accepted by the Federal Reserve and funds returned to sender.WIRE_RETURN_OUTBOUND_REJECTED- Outbound wire return rejected by the Federal Reserve.
public final classPayment.PaymentEvent.DetailedResult
-
Method Summary
Modifier and Type Method Description final Stringtoken()Globally unique identifier. final Longamount()Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents). final OffsetDateTimecreated()Date and time when the financial event occurred. final Payment.PaymentEvent.Resultresult()APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network. final Payment.PaymentEvent.PaymentEventTypetype()Note: Inbound wire transfers are coming soon (availability varies by partner bank). final Optional<List<Payment.PaymentEvent.DetailedResult>>detailedResults()More detailed reasons for the event final Optional<String>externalId()Payment event external ID. final JsonField<String>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_created()Returns the raw JSON value of created. final JsonField<Payment.PaymentEvent.Result>_result()Returns the raw JSON value of result. final JsonField<Payment.PaymentEvent.PaymentEventType>_type()Returns the raw JSON value of type. final JsonField<List<Payment.PaymentEvent.DetailedResult>>_detailedResults()Returns the raw JSON value of detailedResults. final JsonField<String>_externalId()Returns the raw JSON value of externalId. final Map<String, JsonValue>_additionalProperties()final Payment.PaymentEvent.BuildertoBuilder()final Payment.PaymentEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Payment.PaymentEvent.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentEvent. -
-
Method Detail
-
amount
final Long amount()
Amount of the financial event that has been settled in the currency's smallest unit (e.g., cents).
-
created
final OffsetDateTime created()
Date and time when the financial event occurred. UTC time zone.
-
result
final Payment.PaymentEvent.Result result()
APPROVED financial events were successful while DECLINED financial events were declined by user, Lithic, or the network.
-
type
final Payment.PaymentEvent.PaymentEventType type()
Note: Inbound wire transfers are coming soon (availability varies by partner bank). Wire-related event types below are a preview. To learn more, contact your customer success manager.
Event types:
ACH events:
ACH_ORIGINATION_INITIATED- ACH origination received and pending approval/release from an ACH hold.ACH_ORIGINATION_REVIEWED- ACH origination has completed the review process.ACH_ORIGINATION_CANCELLED- ACH origination has been cancelled.ACH_ORIGINATION_PROCESSED- ACH origination has been processed and sent to the Federal Reserve.ACH_ORIGINATION_SETTLED- ACH origination has settled.ACH_ORIGINATION_RELEASED- ACH origination released from pending to available balance.ACH_ORIGINATION_REJECTED- ACH origination was rejected and not sent to the Federal Reserve.ACH_RECEIPT_PROCESSED- ACH receipt pending release from an ACH holder.ACH_RECEIPT_SETTLED- ACH receipt funds have settled.ACH_RECEIPT_RELEASED- ACH receipt released from pending to available balance.ACH_RECEIPT_RELEASED_EARLY- ACH receipt released early from pending to available balance.ACH_RETURN_INITIATED- ACH initiated return for an ACH receipt.ACH_RETURN_PROCESSED- ACH receipt returned by the Receiving Depository Financial Institution.ACH_RETURN_SETTLED- ACH return settled by the Receiving Depository Financial Institution.ACH_RETURN_REJECTED- ACH return was rejected by the Receiving Depository Financial Institution.
Wire transfer events:
WIRE_TRANSFER_INBOUND_RECEIVED- Inbound wire transfer received from the Federal Reserve and pending release to available balance.WIRE_TRANSFER_INBOUND_SETTLED- Inbound wire transfer funds released from pending to available balance.WIRE_TRANSFER_INBOUND_BLOCKED- Inbound wire transfer blocked and funds frozen for regulatory review.
Wire return events:
WIRE_RETURN_OUTBOUND_INITIATED- Outbound wire return initiated to return funds from an inbound wire transfer.WIRE_RETURN_OUTBOUND_SENT- Outbound wire return sent to the Federal Reserve and pending acceptance.WIRE_RETURN_OUTBOUND_SETTLED- Outbound wire return accepted by the Federal Reserve and funds returned to sender.WIRE_RETURN_OUTBOUND_REJECTED- Outbound wire return rejected by the Federal Reserve.
-
detailedResults
final Optional<List<Payment.PaymentEvent.DetailedResult>> detailedResults()
More detailed reasons for the event
-
externalId
final Optional<String> externalId()
Payment event external ID. For ACH transactions, this is the ACH trace number. For inbound wire transfers, this is the IMAD (Input Message Accountability Data).
-
_token
final JsonField<String> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Payment.PaymentEvent.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Payment.PaymentEvent.PaymentEventType> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_detailedResults
final JsonField<List<Payment.PaymentEvent.DetailedResult>> _detailedResults()
Returns the raw JSON value of detailedResults.
Unlike detailedResults, this method doesn't throw if the JSON field has an unexpected type.
-
_externalId
final JsonField<String> _externalId()
Returns the raw JSON value of externalId.
Unlike externalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Payment.PaymentEvent.Builder toBuilder()
-
validate
final Payment.PaymentEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Payment.PaymentEvent.Builder builder()
Returns a mutable builder for constructing an instance of PaymentEvent.
The following fields are required:
.token() .amount() .created() .result() .type()
-
-
-
-