Package com.lithic.api.models
Class PaymentCreateParams.PaymentMethodRequestAttributes
-
- All Implemented Interfaces:
public final class PaymentCreateParams.PaymentMethodRequestAttributes
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPaymentCreateParams.PaymentMethodRequestAttributes.BuilderA builder for PaymentMethodRequestAttributes.
public final classPaymentCreateParams.PaymentMethodRequestAttributes.SecCode
-
Method Summary
Modifier and Type Method Description final PaymentCreateParams.PaymentMethodRequestAttributes.SecCodesecCode()final Optional<Long>achHoldPeriod()Number of days to hold the ACH payment final Optional<String>addenda()final JsonField<PaymentCreateParams.PaymentMethodRequestAttributes.SecCode>_secCode()Returns the raw JSON value of secCode. final JsonField<Long>_achHoldPeriod()Returns the raw JSON value of achHoldPeriod. final JsonField<String>_addenda()Returns the raw JSON value of addenda. final Map<String, JsonValue>_additionalProperties()final PaymentCreateParams.PaymentMethodRequestAttributes.BuildertoBuilder()final PaymentCreateParams.PaymentMethodRequestAttributesvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PaymentCreateParams.PaymentMethodRequestAttributes.Builderbuilder()Returns a mutable builder for constructing an instance of PaymentMethodRequestAttributes. -
-
Method Detail
-
secCode
final PaymentCreateParams.PaymentMethodRequestAttributes.SecCode secCode()
-
achHoldPeriod
final Optional<Long> achHoldPeriod()
Number of days to hold the ACH payment
-
_secCode
final JsonField<PaymentCreateParams.PaymentMethodRequestAttributes.SecCode> _secCode()
Returns the raw JSON value of secCode.
Unlike secCode, this method doesn't throw if the JSON field has an unexpected type.
-
_achHoldPeriod
final JsonField<Long> _achHoldPeriod()
Returns the raw JSON value of achHoldPeriod.
Unlike achHoldPeriod, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<String> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PaymentCreateParams.PaymentMethodRequestAttributes.Builder toBuilder()
-
validate
final PaymentCreateParams.PaymentMethodRequestAttributes validate()
-
builder
final static PaymentCreateParams.PaymentMethodRequestAttributes.Builder builder()
Returns a mutable builder for constructing an instance of PaymentMethodRequestAttributes.
The following fields are required:
.secCode()
-
-
-
-