Class ReportStats
-
- All Implemented Interfaces:
public final class ReportStats
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.BuilderA builder for ReportStats.
public final classReportStats.ActionCountsA mapping of action types to the number of times that action was returned by this rule during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
public final classReportStats.Example
-
Method Summary
Modifier and Type Method Description final Optional<ReportStats.ActionCounts>actionCounts()A mapping of action types to the number of times that action was returned by this rule during the relevant period. final Optional<Long>approved()The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode. final Optional<Long>challenged()The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. final Optional<Long>declined()The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode. final Optional<List<ReportStats.Example>>examples()Example events and their outcomes. final JsonField<ReportStats.ActionCounts>_actionCounts()Returns the raw JSON value of actionCounts. final JsonField<Long>_approved()Returns the raw JSON value of approved. final JsonField<Long>_challenged()Returns the raw JSON value of challenged. final JsonField<Long>_declined()Returns the raw JSON value of declined. final JsonField<List<ReportStats.Example>>_examples()Returns the raw JSON value of examples. final Map<String, JsonValue>_additionalProperties()final ReportStats.BuildertoBuilder()final ReportStatsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Builderbuilder()Returns a mutable builder for constructing an instance of ReportStats. -
-
Method Detail
-
actionCounts
final Optional<ReportStats.ActionCounts> actionCounts()
A mapping of action types to the number of times that action was returned by this rule during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
approved
@Deprecated(message = "deprecated") final Optional<Long> approved()
The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
challenged
@Deprecated(message = "deprecated") final Optional<Long> challenged()
The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
-
declined
@Deprecated(message = "deprecated") final Optional<Long> declined()
The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
examples
final Optional<List<ReportStats.Example>> examples()
Example events and their outcomes.
-
_actionCounts
final JsonField<ReportStats.ActionCounts> _actionCounts()
Returns the raw JSON value of actionCounts.
Unlike actionCounts, this method doesn't throw if the JSON field has an unexpected type.
-
_approved
@Deprecated(message = "deprecated") final JsonField<Long> _approved()
Returns the raw JSON value of approved.
Unlike approved, this method doesn't throw if the JSON field has an unexpected type.
-
_challenged
@Deprecated(message = "deprecated") final JsonField<Long> _challenged()
Returns the raw JSON value of challenged.
Unlike challenged, this method doesn't throw if the JSON field has an unexpected type.
-
_declined
@Deprecated(message = "deprecated") final JsonField<Long> _declined()
Returns the raw JSON value of declined.
Unlike declined, this method doesn't throw if the JSON field has an unexpected type.
-
_examples
final JsonField<List<ReportStats.Example>> _examples()
Returns the raw JSON value of examples.
Unlike examples, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Builder toBuilder()
-
validate
final ReportStats validate()
-
builder
final static ReportStats.Builder builder()
Returns a mutable builder for constructing an instance of ReportStats.
-
-
-
-