Package com.lithic.api.models
Class ReportStats.ActionCounts
-
- All Implemented Interfaces:
public final class ReportStats.ActionCountsA mapping of action types to the number of times that action was returned by this version during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.ActionCounts.BuilderA builder for ActionCounts.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ReportStats.ActionCounts.BuildertoBuilder()final ReportStats.ActionCountsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.ActionCounts.Builderbuilder()Returns a mutable builder for constructing an instance of ActionCounts. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.ActionCounts.Builder toBuilder()
-
validate
final ReportStats.ActionCounts validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ReportStats.ActionCounts.Builder builder()
Returns a mutable builder for constructing an instance of ActionCounts.
-
-
-
-