Class ReportStats.Builder
-
- All Implemented Interfaces:
public final class ReportStats.BuilderA builder for ReportStats.
-
-
Method Summary
Modifier and Type Method Description final ReportStats.BuilderactionCounts(ReportStats.ActionCounts actionCounts)A mapping of action types to the number of times that action was returned by this rule during the relevant period. final ReportStats.BuilderactionCounts(JsonField<ReportStats.ActionCounts> actionCounts)Sets Builder.actionCounts to an arbitrary JSON value. final ReportStats.Builderapproved(Long approved)The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode. final ReportStats.Builderapproved(JsonField<Long> approved)Sets Builder.approved to an arbitrary JSON value. final ReportStats.Builderchallenged(Long challenged)The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. final ReportStats.Builderchallenged(JsonField<Long> challenged)Sets Builder.challenged to an arbitrary JSON value. final ReportStats.Builderdeclined(Long declined)The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode. final ReportStats.Builderdeclined(JsonField<Long> declined)Sets Builder.declined to an arbitrary JSON value. final ReportStats.Builderexamples(List<ReportStats.Example> examples)Example events and their outcomes. final ReportStats.Builderexamples(JsonField<List<ReportStats.Example>> examples)Sets Builder.examples to an arbitrary JSON value. final ReportStats.BuilderaddExample(ReportStats.Example example)Adds a single Example to examples. final ReportStats.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ReportStats.BuilderputAdditionalProperty(String key, JsonValue value)final ReportStats.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ReportStats.BuilderremoveAdditionalProperty(String key)final ReportStats.BuilderremoveAllAdditionalProperties(Set<String> keys)final ReportStatsbuild()Returns an immutable instance of ReportStats. -
-
Method Detail
-
actionCounts
final ReportStats.Builder actionCounts(ReportStats.ActionCounts actionCounts)
A mapping of action types to the number of times that action was returned by this rule during the relevant period. Actions are the possible outcomes of a rule evaluation, such as DECLINE, CHALLENGE, REQUIRE_TFA, etc. In case rule didn't trigger any action, it's counted under NO_ACTION key.
-
actionCounts
final ReportStats.Builder actionCounts(JsonField<ReportStats.ActionCounts> actionCounts)
Sets Builder.actionCounts to an arbitrary JSON value.
You should usually call Builder.actionCounts with a well-typed ActionCounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approved
@Deprecated(message = "deprecated") final ReportStats.Builder approved(Long approved)
The total number of historical transactions approved by this rule during the relevant period, or the number of transactions that would have been approved if the rule was evaluated in shadow mode.
-
approved
@Deprecated(message = "deprecated") final ReportStats.Builder approved(JsonField<Long> approved)
Sets Builder.approved to an arbitrary JSON value.
You should usually call Builder.approved with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challenged
@Deprecated(message = "deprecated") final ReportStats.Builder challenged(Long challenged)
The total number of historical transactions challenged by this rule during the relevant period, or the number of transactions that would have been challenged if the rule was evaluated in shadow mode. Currently applicable only for 3DS Auth Rules.
-
challenged
@Deprecated(message = "deprecated") final ReportStats.Builder challenged(JsonField<Long> challenged)
Sets Builder.challenged to an arbitrary JSON value.
You should usually call Builder.challenged with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declined
@Deprecated(message = "deprecated") final ReportStats.Builder declined(Long declined)
The total number of historical transactions declined by this rule during the relevant period, or the number of transactions that would have been declined if the rule was evaluated in shadow mode.
-
declined
@Deprecated(message = "deprecated") final ReportStats.Builder declined(JsonField<Long> declined)
Sets Builder.declined to an arbitrary JSON value.
You should usually call Builder.declined with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
examples
final ReportStats.Builder examples(List<ReportStats.Example> examples)
Example events and their outcomes.
-
examples
final ReportStats.Builder examples(JsonField<List<ReportStats.Example>> examples)
Sets Builder.examples to an arbitrary JSON value.
You should usually call Builder.examples with a well-typed
List<Example>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExample
final ReportStats.Builder addExample(ReportStats.Example example)
-
additionalProperties
final ReportStats.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ReportStats.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ReportStats.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ReportStats.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ReportStats.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ReportStats build()
Returns an immutable instance of ReportStats.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-