Class ReportStats.Example
-
- All Implemented Interfaces:
public final class ReportStats.Example
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.BuilderA builder for Example.
public final classReportStats.Example.Actionpublic final classReportStats.Example.DecisionThe decision made by the rule for this event.
-
Method Summary
Modifier and Type Method Description final Optional<List<ReportStats.Example.Action>>actions()The actions taken by the rule for this event. final Optional<Boolean>approved()Whether the rule would have approved the request. final Optional<ReportStats.Example.Decision>decision()The decision made by the rule for this event. final Optional<String>eventToken()The event token. final Optional<OffsetDateTime>timestamp()The timestamp of the event. final JsonField<List<ReportStats.Example.Action>>_actions()Returns the raw JSON value of actions. final JsonField<Boolean>_approved()Returns the raw JSON value of approved. final JsonField<ReportStats.Example.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_eventToken()Returns the raw JSON value of eventToken. final JsonField<OffsetDateTime>_timestamp()Returns the raw JSON value of timestamp. final Map<String, JsonValue>_additionalProperties()final ReportStats.Example.BuildertoBuilder()final ReportStats.Examplevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Example.Builderbuilder()Returns a mutable builder for constructing an instance of Example. -
-
Method Detail
-
actions
final Optional<List<ReportStats.Example.Action>> actions()
The actions taken by the rule for this event.
-
approved
@Deprecated(message = "deprecated") final Optional<Boolean> approved()
Whether the rule would have approved the request.
-
decision
@Deprecated(message = "deprecated") final Optional<ReportStats.Example.Decision> decision()
The decision made by the rule for this event.
-
eventToken
final Optional<String> eventToken()
The event token.
-
timestamp
final Optional<OffsetDateTime> timestamp()
The timestamp of the event.
-
_actions
final JsonField<List<ReportStats.Example.Action>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_approved
@Deprecated(message = "deprecated") final JsonField<Boolean> _approved()
Returns the raw JSON value of approved.
Unlike approved, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
@Deprecated(message = "deprecated") final JsonField<ReportStats.Example.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_eventToken
final JsonField<String> _eventToken()
Returns the raw JSON value of eventToken.
Unlike eventToken, this method doesn't throw if the JSON field has an unexpected type.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
Returns the raw JSON value of timestamp.
Unlike timestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Builder toBuilder()
-
validate
final ReportStats.Example validate()
-
builder
final static ReportStats.Example.Builder builder()
Returns a mutable builder for constructing an instance of Example.
-
-
-
-