Package com.lithic.api.models
Class ReportStats.Example.Action.RequireTfaAction
-
- All Implemented Interfaces:
public final class ReportStats.Example.Action.RequireTfaAction
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classReportStats.Example.Action.RequireTfaAction.BuilderA builder for RequireTfaAction.
public final classReportStats.Example.Action.RequireTfaAction.TypeRequire two-factor authentication for the tokenization request
public final classReportStats.Example.Action.RequireTfaAction.ReasonReason code for requiring two-factor authentication
-
Method Summary
Modifier and Type Method Description final ReportStats.Example.Action.RequireTfaAction.Typetype()Require two-factor authentication for the tokenization request final Optional<ReportStats.Example.Action.RequireTfaAction.Reason>reason()Reason code for requiring two-factor authentication final JsonField<ReportStats.Example.Action.RequireTfaAction.Type>_type()Returns the raw JSON value of type. final JsonField<ReportStats.Example.Action.RequireTfaAction.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final ReportStats.Example.Action.RequireTfaAction.BuildertoBuilder()final ReportStats.Example.Action.RequireTfaActionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ReportStats.Example.Action.RequireTfaAction.Builderbuilder()Returns a mutable builder for constructing an instance of RequireTfaAction. -
-
Method Detail
-
type
final ReportStats.Example.Action.RequireTfaAction.Type type()
Require two-factor authentication for the tokenization request
-
reason
final Optional<ReportStats.Example.Action.RequireTfaAction.Reason> reason()
Reason code for requiring two-factor authentication
-
_type
final JsonField<ReportStats.Example.Action.RequireTfaAction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<ReportStats.Example.Action.RequireTfaAction.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ReportStats.Example.Action.RequireTfaAction.Builder toBuilder()
-
validate
final ReportStats.Example.Action.RequireTfaAction validate()
-
builder
final static ReportStats.Example.Action.RequireTfaAction.Builder builder()
Returns a mutable builder for constructing an instance of RequireTfaAction.
The following fields are required:
.type()
-
-
-
-