Class RuleFeature
-
- All Implemented Interfaces:
public final class RuleFeatureA feature made available to the rule. The
namefield is the variable name used in the rule function signature. Thetypefield determines which data the feature provides to the rule at evaluation time.AUTHORIZATION: The authorization request being evaluated. Only available for AUTHORIZATION event stream rules.AUTHENTICATION: The 3DS authentication request being evaluated. Only available for THREE_DS_AUTHENTICATION event stream rules.TOKENIZATION: The tokenization request being evaluated. Only available for TOKENIZATION event stream rules.ACH_RECEIPT: The ACH receipt being evaluated. Only available for ACH_CREDIT_RECEIPT and ACH_DEBIT_RECEIPT event stream rules.CARD: The card associated with the event. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.ACCOUNT_HOLDER: The account holder associated with the card. Available for AUTHORIZATION and THREE_DS_AUTHENTICATION event stream rules.IP_METADATA: IP address metadata for the request. Available for THREE_DS_AUTHENTICATION event stream rules.SPEND_VELOCITY: Spend velocity data for the card or account. Requiresscope,period, and optionallyfiltersto configure the velocity calculation. Available for AUTHORIZATION event stream rules.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRuleFeature.VisitorAn interface that defines how to map each variant of RuleFeature to a value of type T.
public final classRuleFeature.AuthorizationFeaturepublic final classRuleFeature.AuthenticationFeaturepublic final classRuleFeature.TokenizationFeaturepublic final classRuleFeature.AchReceiptFeaturepublic final classRuleFeature.CardFeaturepublic final classRuleFeature.AccountHolderFeaturepublic final classRuleFeature.IpMetadataFeaturepublic final classRuleFeature.SpendVelocityFeature
-
Method Summary
-
-
Method Detail
-
authorization
final Optional<RuleFeature.AuthorizationFeature> authorization()
-
authentication
final Optional<RuleFeature.AuthenticationFeature> authentication()
-
tokenization
final Optional<RuleFeature.TokenizationFeature> tokenization()
-
achReceipt
final Optional<RuleFeature.AchReceiptFeature> achReceipt()
-
card
final Optional<RuleFeature.CardFeature> card()
-
accountHolder
final Optional<RuleFeature.AccountHolderFeature> accountHolder()
-
ipMetadata
final Optional<RuleFeature.IpMetadataFeature> ipMetadata()
-
spendVelocity
final Optional<RuleFeature.SpendVelocityFeature> spendVelocity()
-
isAuthorization
final Boolean isAuthorization()
-
isAuthentication
final Boolean isAuthentication()
-
isTokenization
final Boolean isTokenization()
-
isAchReceipt
final Boolean isAchReceipt()
-
isAccountHolder
final Boolean isAccountHolder()
-
isIpMetadata
final Boolean isIpMetadata()
-
isSpendVelocity
final Boolean isSpendVelocity()
-
asAuthorization
final RuleFeature.AuthorizationFeature asAuthorization()
-
asAuthentication
final RuleFeature.AuthenticationFeature asAuthentication()
-
asTokenization
final RuleFeature.TokenizationFeature asTokenization()
-
asAchReceipt
final RuleFeature.AchReceiptFeature asAchReceipt()
-
asCard
final RuleFeature.CardFeature asCard()
-
asAccountHolder
final RuleFeature.AccountHolderFeature asAccountHolder()
-
asIpMetadata
final RuleFeature.IpMetadataFeature asIpMetadata()
-
asSpendVelocity
final RuleFeature.SpendVelocityFeature asSpendVelocity()
-
accept
final <T extends Any> T accept(RuleFeature.Visitor<T> visitor)
-
validate
final RuleFeature validate()
-
ofAuthorization
final static RuleFeature ofAuthorization(RuleFeature.AuthorizationFeature authorization)
-
ofAuthentication
final static RuleFeature ofAuthentication(RuleFeature.AuthenticationFeature authentication)
-
ofTokenization
final static RuleFeature ofTokenization(RuleFeature.TokenizationFeature tokenization)
-
ofAchReceipt
final static RuleFeature ofAchReceipt(RuleFeature.AchReceiptFeature achReceipt)
-
ofCard
final static RuleFeature ofCard(RuleFeature.CardFeature card)
-
ofAccountHolder
final static RuleFeature ofAccountHolder(RuleFeature.AccountHolderFeature accountHolder)
-
ofIpMetadata
final static RuleFeature ofIpMetadata(RuleFeature.IpMetadataFeature ipMetadata)
-
ofSpendVelocity
final static RuleFeature ofSpendVelocity(RuleFeature.SpendVelocityFeature spendVelocity)
-
-
-
-