Class RuleFeature.SpendVelocityFeature
-
- All Implemented Interfaces:
public final class RuleFeature.SpendVelocityFeature
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRuleFeature.SpendVelocityFeature.BuilderA builder for SpendVelocityFeature.
public final classRuleFeature.SpendVelocityFeature.VelocityScopeThe scope the velocity is calculated for
public final classRuleFeature.SpendVelocityFeature.Type
-
Method Summary
-
-
Method Detail
-
period
final VelocityLimitPeriod period()
Velocity over the current day since 00:00 / 12 AM in Eastern Time
-
scope
final RuleFeature.SpendVelocityFeature.VelocityScope scope()
The scope the velocity is calculated for
-
type
final RuleFeature.SpendVelocityFeature.Type type()
-
filters
final Optional<VelocityLimitFilters> filters()
-
name
final Optional<String> name()
The variable name for this feature in the rule function signature
-
_period
final JsonField<VelocityLimitPeriod> _period()
Returns the raw JSON value of period.
Unlike period, this method doesn't throw if the JSON field has an unexpected type.
-
_scope
final JsonField<RuleFeature.SpendVelocityFeature.VelocityScope> _scope()
Returns the raw JSON value of scope.
Unlike scope, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RuleFeature.SpendVelocityFeature.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_filters
final JsonField<VelocityLimitFilters> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RuleFeature.SpendVelocityFeature.Builder toBuilder()
-
validate
final RuleFeature.SpendVelocityFeature validate()
-
builder
final static RuleFeature.SpendVelocityFeature.Builder builder()
Returns a mutable builder for constructing an instance of SpendVelocityFeature.
The following fields are required:
.period() .scope() .type()
-
-
-
-