Class TokenizationResultWebhookEvent
-
- All Implemented Interfaces:
public final class TokenizationResultWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTokenizationResultWebhookEvent.BuilderA builder for TokenizationResultWebhookEvent.
public final classTokenizationResultWebhookEvent.EventTypeThe type of event that occurred.
public final classTokenizationResultWebhookEvent.TokenizationResultDetailsThe result of the tokenization request.
-
Method Summary
-
-
Method Detail
-
accountToken
final String accountToken()
Account token
-
created
final OffsetDateTime created()
Created date
-
eventType
final TokenizationResultWebhookEvent.EventType eventType()
The type of event that occurred.
-
tokenizationResultDetails
final TokenizationResultWebhookEvent.TokenizationResultDetails tokenizationResultDetails()
The result of the tokenization request.
-
tokenizationToken
final String tokenizationToken()
Tokenization token
-
_accountToken
final JsonField<String> _accountToken()
Returns the raw JSON value of accountToken.
Unlike accountToken, this method doesn't throw if the JSON field has an unexpected type.
-
_cardToken
final JsonField<String> _cardToken()
Returns the raw JSON value of cardToken.
Unlike cardToken, this method doesn't throw if the JSON field has an unexpected type.
-
_created
final JsonField<OffsetDateTime> _created()
Returns the raw JSON value of created.
Unlike created, this method doesn't throw if the JSON field has an unexpected type.
-
_eventType
final JsonField<TokenizationResultWebhookEvent.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationResultDetails
final JsonField<TokenizationResultWebhookEvent.TokenizationResultDetails> _tokenizationResultDetails()
Returns the raw JSON value of tokenizationResultDetails.
Unlike tokenizationResultDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenizationToken
final JsonField<String> _tokenizationToken()
Returns the raw JSON value of tokenizationToken.
Unlike tokenizationToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TokenizationResultWebhookEvent.Builder toBuilder()
-
validate
final TokenizationResultWebhookEvent validate()
-
builder
final static TokenizationResultWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of TokenizationResultWebhookEvent.
The following fields are required:
.accountToken() .cardToken() .created() .eventType() .tokenizationResultDetails() .tokenizationToken()
-
-
-
-