Package com.lithic.api.models
Class V2RetrieveReportResponse.DailyStatistic
-
- All Implemented Interfaces:
public final class V2RetrieveReportResponse.DailyStatistic
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2RetrieveReportResponse.DailyStatistic.BuilderA builder for DailyStatistic.
-
Method Summary
Modifier and Type Method Description final LocalDatedate()The date (UTC) for which the statistics are reported. final List<ReportStats>versions()Statistics for each version of the rule that was evaluated during the reported day. final JsonField<LocalDate>_date()Returns the raw JSON value of date. final JsonField<List<ReportStats>>_versions()Returns the raw JSON value of versions. final Map<String, JsonValue>_additionalProperties()final V2RetrieveReportResponse.DailyStatistic.BuildertoBuilder()final V2RetrieveReportResponse.DailyStatisticvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static V2RetrieveReportResponse.DailyStatistic.Builderbuilder()Returns a mutable builder for constructing an instance of DailyStatistic. -
-
Method Detail
-
versions
final List<ReportStats> versions()
Statistics for each version of the rule that was evaluated during the reported day.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_versions
final JsonField<List<ReportStats>> _versions()
Returns the raw JSON value of versions.
Unlike versions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final V2RetrieveReportResponse.DailyStatistic.Builder toBuilder()
-
validate
final V2RetrieveReportResponse.DailyStatistic validate()
-
builder
final static V2RetrieveReportResponse.DailyStatistic.Builder builder()
Returns a mutable builder for constructing an instance of DailyStatistic.
The following fields are required:
.date() .versions()
-
-
-
-